(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1282736,      29535]
NotebookOptionsPosition[   1182096,      27056]
NotebookOutlinePosition[   1216900,      27793]
CellTagsIndexPosition[   1216697,      27783]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[" Euclidean Geometry", "Title",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center],

Cell["by Rolf Sulanke", "Subtitle",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center,
 FontFamily->"Times"],

Cell["\<\
Sept 18, 2003
version 5, January 30, 2010 \
\>", "Text",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 CellChangeTimes->{{3.472108888417272*^9, 3.472108945279709*^9}, {
   3.472970842671875*^9, 3.472970851578125*^9}, {3.473864880984375*^9, 
   3.47386488346875*^9}, {3.474011737140625*^9, 3.47401173921875*^9}, 
   3.474011825640625*^9},
 TextAlignment->Center],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell[TextData[{
 "In this notebook we develop some linear algebraic tools which can be \
applied to calculations in any dimension, and to creating graphics in the \
two- and three-dimensional case. The notebook contains new modules \
implementing spheres  as objects of Euclidean and Riemannian spherical \
geometry. As an application the construction and plotting of a sphere through \
four points in the Euclidean 3-space is given. Furthermore, it contains a \
recursive definition of the generalized geographical parameter \
representations of n-spheres in the (n+1)-dimensional Euclidean space. Some \
concepts needed in M\[ODoubleDot]bius geometry, the conformal geometry of the \
n-sphere, are introduced in Euclidean terms. These concepts are: \
stereographic projection, its inversion, and reflections at hyperspheres \
(also called inversions). A version of Erhard Schmidt's orthogonalization: \
esorthonorm, is introduced in section 2; it has some other features as  the \
function Orthogonalize now built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{
  3.472106645361439*^9, 3.472106690082299*^9, 3.472802214279442*^9, {
   3.472802248177626*^9, 3.472802293918714*^9}, {3.472802324295116*^9, 
   3.472802352469628*^9}, {3.472803575467373*^9, 3.472803575618905*^9}, {
   3.472803637007954*^9, 3.472803642385094*^9}, {3.4729717919375*^9, 
   3.472971795125*^9}, {3.4732298324375*^9, 3.47322986846875*^9}, {
   3.474009998734375*^9, 3.474010002796875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Keywords", "Subsubsection",
 FontFamily->"Times"],

Cell["\<\
vector objects, random vectors, rank, orthoframes, unit vectors, norming, \
cross product, nullvector,  standard base, hyperplanes, stereographic \
projection, inverse stereographic projection, spheres, spheres through four \
points, hyperspheres,  parameter representation for n-spheres, inversion at \
hyperspheres, torus, geodesics on the flat torus, spiral, spiral group, \
spiral cylinder, Erhard Schmidt's othogonalization, orthogonal complement.\
\>", "Text",
 CellChangeTimes->{{3.4729713559375*^9, 3.472971361625*^9}, {
   3.472974378640625*^9, 3.472974485453125*^9}, {3.473136628671875*^9, 
   3.4731366649375*^9}, 3.473136713109375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version", "Subsubsection"],

Cell[TextData[{
 "This notebook is a new version of the notebook eusphere.nb,  first \
published  in the item ",
 ButtonBox["[2]",
  BaseStyle->"Hyperlink",
  ButtonData:>"S3"],
 "  in MathSource. The same is true for the accompanying package euvec.m. In \
the new version  the pacckages vectorcalc.m and euvec.m together replace the \
old package euvec.m.  The package vectorcalc.m contains mainly concepts \
belonging to affine geometry,  while the metric concepts are gathered within \
the new euvec.m, which needs vectorcalc.m.  Since these packages contain the \
most important procedures used in this and other notebooks, published first \
in the  item Spheres, and the contents as well as some names have been \
changed, the two versions should not be mixed.   The notebook has been \
developed with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v. 4.2 and is revised now, as version 5,  with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v. 7.0. The actual versions of the notebook and the packages  may be \
downloaded from my ",
 ButtonBox["homepage",
  BaseStyle->"Hyperlink",
  ButtonData->"HP"],
 ". \n"
}], "Text",
 CellChangeTimes->{{3.472106773691811*^9, 3.472106800074409*^9}, {
   3.472108975825448*^9, 3.472108985683109*^9}, {3.47280323262765*^9, 
   3.472803233471019*^9}, {3.472803348746877*^9, 3.472803441740411*^9}, {
   3.472803749057795*^9, 3.472803935260036*^9}, {3.472804002012659*^9, 
   3.472804098126176*^9}, {3.472804134473351*^9, 3.472804145723058*^9}, {
   3.472804196662674*^9, 3.472804211467858*^9}, 3.472973405453125*^9, {
   3.472973441765625*^9, 3.47297356278125*^9}, {3.47297361259375*^9, 
   3.472973856765625*^9}, {3.472974208484375*^9, 3.472974281828125*^9}, {
   3.472975311859375*^9, 3.472975313328125*^9}, 3.472975805828125*^9, {
   3.4731367815*^9, 3.47313678415625*^9}, {3.474011786515625*^9, 
   3.4740117868125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Copyright", "Subsubsection",
 CellTags->"copyrigt"],

Cell["\<\
This notebook, the linked notebooks, and the accompanying packages are  \
public. Authors who intend to publish a changed or completed version of them \
should do it under their own names, and under the condition that they cite \
the original notebook with the Internet address or other source where they \
got it. I am not responsible for errors or damages originated by the use of \
the procedures contained in my notebooks or packages; anybody who applies \
them should test carefully whether they are appropriate for his purposes.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 FontFamily->"Times"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " yields a lot of tools and procedures with the help of  which one can work \
in Euclidean geometry immediately.  Especially useful are its capabilities in \
the field of graphics in the plane and the space. But, nothing is perfect, \
and applying ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to certain concrete geometrical problems I felt the necessity to create \
some variants of ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "functions  adapting them to my purposes, and to construct new functions \
which have not been built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " in the year 1999, as the first version of the package euvec.m originated.  \
Now, in 2010, some of the Modules or Functions  introduced in  this package \
or in the notebook have corresponding  similar concepts built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " v. 7. We discuss the relations and differences between the analog \
functions in some cases below. The reach language, and the conceptual \
framework of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " make it  easy to go its own way, and after overcoming the first starting \
troubles and being acustomed to the syntax and grammar of the program  \
language one enjoys the functionality and the speed of the new created \
procedures. \nWorking with mathematica one can do with the arts and tools of \
informatics, using methods of  computer languages like Pascal or C; a \
knowledge of such a language may be useful, but is not necessary.  For me the \
main advantage of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  is that one can create functions and procedures following very closely \
the mathematical ideas of the  field one is working in; the informatics part \
of the work is implemented, and is done by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " in the background.  I hope that studying this notebook and applying it in \
the comparatively simple and well known field of Euclidean geometry will be \
useful for students of mathematics beginning to learn ",
 StyleBox["Mathematica.",
  FontSlant->"Italic"],
 "  Of course, I shall apply the functions developed here in my further work, \
and I would like to exchange my experiences with  colleagues applying ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " in their own fields, especially in geometry.  From their side, and also \
from the students, critique and questions are welcome."
}], "Text",
 CellChangeTimes->{{3.472971797609375*^9, 3.472971800265625*^9}, {
   3.472975477578125*^9, 3.472975568171875*^9}, {3.472975613125*^9, 
   3.472975677625*^9}, {3.472975742171875*^9, 3.47297574790625*^9}, {
   3.47297579203125*^9, 3.4729758159375*^9}, {3.472975847578125*^9, 
   3.47297589096875*^9}, {3.47297593140625*^9, 3.472975956484375*^9}, {
   3.472976004609375*^9, 3.472976070046875*^9}, {3.472976261*^9, 
   3.47297626290625*^9}, {3.4729763141875*^9, 3.472976395328125*^9}, 
   3.47297648046875*^9, {3.47313706634375*^9, 3.4731370904375*^9}}],

Cell[TextData[{
 "If you want to use the material of this or the accompanying notebooks or \
packages for your publications, please, consider the point ",
 ButtonBox["copyright",
  BaseStyle->"Hyperlink",
  ButtonData:>"copyrigt"],
 " (click!),"
}], "Text",
 CellChangeTimes->{
  3.472976560265625*^9, 3.4729766634375*^9, 3.472976700296875*^9, {
   3.472976851953125*^9, 3.472976852921875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 FontFamily->"Times"],

Cell["\<\
The operation of this section are necessary only at the first use of this \
notebook on your computer.  If this is done once, and if the conditions of \
the subsection \"The needed packages\" are fulfilled, you may start calling \
the initialization as described in the next subsection. \
\>", "Text",
 CellChangeTimes->{3.474010147703125*^9},
 FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["Preparation", "Subsection"],

Cell[CellGroupData[{

Cell["The needed packages", "Subsubsection",
 FontFamily->"Times New Roman"],

Cell["\<\
Before initializing the present notebook ensure that the packages
euvec.m, vectorcalc.m and the file rank1.txt are in your working directory, \
or e.g. in the directory ~/mymath/mathpack.
for Linux: \
\>", "Text",
 CellChangeTimes->{{3.468648615185651*^9, 3.468648648964528*^9}, {
  3.472108109739525*^9, 3.472108123262374*^9}, {3.472108153293856*^9, 
  3.472108192559477*^9}, {3.47297205003125*^9, 3.472972056921875*^9}, {
  3.472992181578125*^9, 3.4729921969375*^9}, {3.47313737646875*^9, 
  3.473137379171875*^9}},
 FontFamily->"Times New Roman"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{"$Path", ",", "\"\<~/mymath/mathpack\>\""}], "]"}], ";"}]], "Input",
 Evaluatable->False,
 InitializationCell->True,
 CellChangeTimes->{{3.457865878640625*^9, 3.45786591278125*^9}, 
   3.472188589040512*^9, {3.472972061859375*^9, 3.472972075578125*^9}},
 FontFamily->"Times",
 CellLabel->"In[1]:="],

Cell["for Windows", "Text",
 CellChangeTimes->{{3.472972088234375*^9, 3.472972092953125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PrependTo", "[", 
   RowBox[{
   "$Path", ",", 
    "\"\<C:\\\\Dokumente und Einstellungen\\\\rolf\\\\Eigene \
Dateien\\\\mymath\\\\mathpack\>\""}], "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.457865878640625*^9, 3.45786591278125*^9}, 
   3.472188589040512*^9, {3.472972061859375*^9, 3.472972116125*^9}, 
   3.472972179796875*^9, {3.4729724090625*^9, 3.4729724400625*^9}},
 FontFamily->"Times",
 CellLabel->"In[1]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Path of the working directory", "Subsubsection",
 FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["At the moment, DO NOT CONFIRM THE EVALUATION OF THE \
INITIALIZATION CELLS !",
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 FontFamily->"Times New Roman"],

Cell["If the result of the following command ", "Text",
 FontFamily->"Times New Roman"],

Cell[BoxData[
 RowBox[{"Directory", "[", "]"}]], "Input",
 FontFamily->"Times New Roman",
 CellLabel->"In[38]:="],

Cell[TextData[{
 "does not coincide with your wanted  working directory,  insert the Path of \
your working directory in the next command line according to your ",
 StyleBox["OS",
  InitializationCell->True],
 ", select it, choose Cell/Cell Propertie/Initialization Cell, and activate \
\"Initialization: Cell\""
}], "Text",
 CellChangeTimes->{{3.47313757978125*^9, 3.4731376171875*^9}},
 FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["e.g. for Windows:",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 FontFamily->"Times New Roman",
 FontSize->18],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  "\"\<C:\\\\Dokumente und Einstellungen\\\\rolf\\\\Eigene \
Dateien\\\\mymath\\\\Euklid\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.472108270890278*^9, 3.472108273817528*^9}},
 FontFamily->"Times New Roman",
 CellLabel->"In[2]:="],

Cell[TextData[StyleBox["or for Linux:",
 FontColor->RGBColor[1, 0, 0]]], "Text",
 FontFamily->"Times New Roman",
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<~/mymath/Euklid\>\"", "]"}]], "Input",
 Evaluatable->False,
 InitializationCell->True,
 CellChangeTimes->{{3.468649152831126*^9, 3.468649154243009*^9}, {
  3.472108249091671*^9, 3.472108252136463*^9}},
 FontFamily->"Times New Roman",
 CellLabel->"In[2]:="],

Cell[BoxData["\<\"/home/rolf/mymath/Euklid\"\>"], "Output",
 CellChangeTimes->{3.472875392834726*^9},
 CellLabel->"Out[2]="]
}, Closed]],

Cell["\<\
Save the notebook. Next time you can directly start the notebook with the \
evaluation of the initialization, as follows:\
\>", "Text",
 FontFamily->"Times New Roman"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
 CellChangeTimes->{{3.472108828769681*^9, 3.472108834063503*^9}},
 FontFamily->"Times New Roman"],

Cell[TextData[StyleBox["Activite Evaluation/Evaluate Initialization Cells \
from the menu.",
 FontSize->18,
 FontColor->RGBColor[1, 0, 0]]], "Text",
 CellChangeTimes->{{3.472108846807954*^9, 3.472108847003274*^9}, {
  3.473137732734375*^9, 3.473137736359375*^9}},
 FontFamily->"Times New Roman"],

Cell["\<\
The next cells make  available all commands contained in the needed packages \
euvec.m, vectorcalc.m, \
\>", "Text",
 CellChangeTimes->{{3.47210843837662*^9, 3.472108454878623*^9}},
 FontFamily->"Times New Roman"],

Cell[BoxData[
 RowBox[{"Get", "[", "\"\<euvec.m\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.472108469899589*^9, 3.472108471699404*^9}},
 FontFamily->"Times New Roman",
 CellLabel->"In[3]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[" The usages ", "Subsection",
 CellChangeTimes->{3.472109381000046*^9, 3.472977444796875*^9}],

Cell[TextData[{
 "Here is an overview of the new introduced symbols, and their usages. In \
difference to the names used in  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " the new introduced names begin always with small letters. To read the \
usages first initialize the notebook.  The command"
}], "Text",
 CellChangeTimes->{{3.472109401689912*^9, 3.472109404732082*^9}}],

Cell[BoxData[
 RowBox[{"?", "name`*"}]], "Input",
 Evaluatable->False,
 CellLabel->"In[31]:="],

Cell["\<\
yields a table of symbols in the Context \"name`\".in alphabetical order.  \
Example: All active symbols defined in the Global Context of the current \
notebook\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "Global`*"}]], "Input",
 CellLabel->"In[30]:="],

Cell[TextData[{
 " Clicking on any symbol of the table  returns the \"usage\"-message for the \
symbol, or, if no usage is defined, the definition of the symbol.\n",
 StyleBox["WARNING!",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" ",
  FontWeight->"Bold"],
 "If the symbol denotes a graphics object, the answer may become very large! "
}], "Text",
 CellChangeTimes->{3.472109731145535*^9}],

Cell["\<\
Mostly the Context \"name\" coincides with the name of the package:  \
\"name\".m.  The next tables contain the symbols defined in  the packages \
loaded in the current notebook during the initialization:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "vectorcalc`*"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{"?", "euvec`*"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[5]:="],

Cell["\<\
Click on the item to read its usage! The table of the globally defined \
symbols can be obtained also:\
\>", "Text",
 CellChangeTimes->{{3.473061259203125*^9, 3.473061322328125*^9}}],

Cell[BoxData[
 RowBox[{"?", "Global`*"}]], "Input",
 CellChangeTimes->{{3.472796360126836*^9, 3.472796369180203*^9}},
 CellLabel->"In[40]:="],

Cell[CellGroupData[{

Cell["Full definitions and attributes", "Subsubsection",
 CellChangeTimes->{{3.4731408190625*^9, 3.47314083309375*^9}},
 FontFamily->"Times"],

Cell["\<\
For getting the usage together with the complete definition, enter the name \
prepended with two ?, e.g. \
\>", "Text",
 CellChangeTimes->{{3.4731392954375*^9, 3.47313931384375*^9}, 
   3.473139591484375*^9}],

Cell[BoxData[
 RowBox[{"??", "sphbasis"}]], "Input",
 CellChangeTimes->{{3.473139486640625*^9, 3.473139493703125*^9}},
 CellLabel->"In[53]:="],

Cell["\<\
Most built-in functions have the Attribute ReadProtected, its definitions \
remain hidden:\
\>", "Text",
 CellChangeTimes->{{3.473139614828125*^9, 3.473139712859375*^9}}],

Cell[BoxData[
 RowBox[{"??", "Sphere"}]], "Input",
 CellChangeTimes->{{3.47313811890625*^9, 3.47313812290625*^9}},
 CellLabel->"In[33]:="],

Cell["\<\
The Attribute ReadProtected can be removed, but the definition remains hidden:\
\>", "Text",
 CellChangeTimes->{{3.4731397930625*^9, 3.473139838515625*^9}}],

Cell[BoxData[
 RowBox[{"Unprotect", "[", "Sphere", "]"}]], "Input",
 CellChangeTimes->{{3.473138320109375*^9, 3.47313834121875*^9}},
 CellLabel->"In[45]:="],

Cell[BoxData[
 RowBox[{"ClearAttributes", "[", 
  RowBox[{"Sphere", ",", "ReadProtected"}], "]"}]], "Input",
 CellChangeTimes->{{3.47313835290625*^9, 3.4731383958125*^9}, {
  3.47313873678125*^9, 3.473138746640625*^9}, {3.47313882690625*^9, 
  3.473138828734375*^9}, {3.473139145859375*^9, 3.473139151578125*^9}},
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{"??", "Sphere"}]], "Input",
 CellChangeTimes->{{3.473138405109375*^9, 3.4731384088125*^9}},
 CellLabel->"In[49]:="],

Cell["Now all Attributes of Sphere are removed:", "Text",
 CellChangeTimes->{{3.4731399954375*^9, 3.47314001596875*^9}}],

Cell[BoxData[
 RowBox[{"Attributes", "[", "Sphere", "]"}]], "Input",
 CellLabel->"In[55]:="],

Cell[BoxData[
 RowBox[{"FullDefinition", "[", "Sphere", "]"}]], "Input",
 CellChangeTimes->{{3.4731390995625*^9, 3.47313911328125*^9}, {
  3.473139177703125*^9, 3.4731392115*^9}, {3.47314010678125*^9, 
  3.473140108375*^9}},
 CellLabel->"In[56]:="],

Cell["\<\
In spite of the removed attribute ReadProtected the definition of Sphere \
remains hidden. We restore the attributes of the built-in function Sphere;\
\>", "Text",
 CellChangeTimes->{{3.473140156109375*^9, 3.47314026015625*^9}}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{"Sphere", ",", " ", 
   RowBox[{"{", 
    RowBox[{"Protected", ",", "ReadProtected"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47313885153125*^9, 3.473138871484375*^9}, {
  3.473138923859375*^9, 3.473138930234375*^9}},
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{"Attributes", "[", "Sphere", "]"}]], "Input",
 CellChangeTimes->{{3.47313894775*^9, 3.473138958921875*^9}},
 CellLabel->"In[44]:="],

Cell["\<\
The definition of symbols contained in the imported packages are often hard \
to read since the names of all are prepended by the ContextNames, e.g. \
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.4731403864375*^9, 3.473140514296875*^9}}],

Cell[BoxData[
 RowBox[{"??", "sterproj"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[34]:="],

Cell["\<\
So it is recommended to look into the packageand to evaluate the functions \
with general variables:.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.473140576953125*^9, 3.4731406320625*^9}, {
  3.4731407385625*^9, 3.47314074675*^9}}],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473140635328125*^9, 3.473140663578125*^9}},
 CellLabel->"In[57]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Comparison of some new defined with similar built-in functions\
\>", "Subsection",
 CellChangeTimes->{{3.472980801828125*^9, 3.472980807078125*^9}, {
   3.472980869984375*^9, 3.47298090096875*^9}, {3.472981159890625*^9, 
   3.47298116153125*^9}, {3.473002438171875*^9, 3.473002440578125*^9}, 
   3.473061156234375*^9}],

Cell[CellGroupData[{

Cell["Dimension, dim, vec, matrix, Array, rank, MatrixRank", "Subsubsection",
 CellChangeTimes->{{3.472993528421875*^9, 3.472993588328125*^9}, 
   3.4731409281875*^9}],

Cell[TextData[{
 StyleBox["General Hint",
  FontSize->16,
  FontColor->RGBColor[1, 0, 0]],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " built-in constructs have names starting with capital letters; our new \
names start with small letters."
}], "Text",
 CellChangeTimes->{{3.472981066453125*^9, 3.472981134125*^9}, {
  3.47298118478125*^9, 3.472981225921875*^9}}],

Cell[BoxData[
 RowBox[{"?", "dim"}]], "Input",
 CellChangeTimes->{{3.47298210209375*^9, 3.47298210371875*^9}},
 CellLabel->"In[123]:="],

Cell["\<\
The global constant dim should not be confused with the formal\
\>", "Text",
 CellChangeTimes->{{3.472982152421875*^9, 3.472982186828125*^9}, {
  3.472982227578125*^9, 3.472982238640625*^9}}],

Cell[BoxData[
 RowBox[{"?", "Dimensions"}]], "Input",
 CellChangeTimes->{{3.472982247203125*^9, 3.472982268453125*^9}},
 CellLabel->"In[125]:="],

Cell[TextData[{
 "Unfortunately, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not explain the \"dimensions of expr\""
}], "Text",
 CellChangeTimes->{{3.472982312890625*^9, 3.472982373046875*^9}, {
  3.473146112796875*^9, 3.473146120953125*^9}}],

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47298239140625*^9, 3.47298240378125*^9}},
 CellLabel->"In[126]:="],

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"matrix", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47298239140625*^9, 3.47298242315625*^9}},
 CellLabel->"In[127]:="],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "4", "]"}]], "Input",
 CellChangeTimes->{{3.47298239140625*^9, 3.472982455515625*^9}, {
   3.472982493140625*^9, 3.47298251190625*^9}, 3.472982815109375*^9},
 CellLabel->"In[128]:="],

Cell[BoxData[
 RowBox[{"Dimensions", "[", "dim", "]"}]], "Input",
 CellChangeTimes->{{3.472982462328125*^9, 3.472982464375*^9}, {
  3.47298253496875*^9, 3.472982543890625*^9}},
 CellLabel->"In[129]:="],

Cell[BoxData["dim"], "Input",
 CellChangeTimes->{{3.473146085609375*^9, 3.473146086*^9}},
 CellLabel->"In[124]:="],

Cell["\<\
The constant dim is important as the default value of the dimension in many \
functions  defined and used in our notebook und the packages, e.g. vec and \
matrix, which are special cases of the built-in function \
\>", "Text",
 CellChangeTimes->{{3.472982857140625*^9, 3.47298301434375*^9}}],

Cell[BoxData[
 RowBox[{"?", "Array"}]], "Input",
 CellChangeTimes->{{3.47298302009375*^9, 3.472983022375*^9}},
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.4729830563125*^9, 3.472983062*^9}},
 CellLabel->"In[53]:="],

Cell[BoxData[
 RowBox[{"matrix", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.472982701484375*^9, 3.472982706921875*^9}},
 CellLabel->"In[49]:="],

Cell["Without predefined dim vec and matrix can not be evatuated:", "Text",
 CellChangeTimes->{{3.47298308578125*^9, 3.472983124453125*^9}}],

Cell[BoxData[
 RowBox[{"Clear", "[", "dim", "]"}]], "Input",
 CellChangeTimes->{{3.472983130484375*^9, 3.472983140046875*^9}},
 CellLabel->"In[130]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.472983143875*^9, 3.47298314759375*^9}},
 CellLabel->"In[131]:="],

Cell[BoxData[
 RowBox[{"matrix", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.472983165671875*^9, 3.472983171765625*^9}},
 CellLabel->"In[132]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.47298319784375*^9, 3.47298320196875*^9}},
 CellLabel->"In[133]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.47298320771875*^9, 3.472983221421875*^9}},
 CellLabel->"In[134]:="],

Cell["\<\
If the constant dim appears as the default argument of a function it should \
not have a value if the definition is activated; otherwise this value would \
be taken as the default of the variable in the given function. We organized \
the order in which the definitions are evaluated such that dim may be \
changed, if necessary or appropriate:\
\>", "Text",
 CellChangeTimes->{{3.473146260671875*^9, 3.473146570015625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", " ", "3"}], ";", " ", 
  RowBox[{"vec", "[", "x", "]"}]}]], "Input",
 CellLabel->"In[135]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrix", "[", "a", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.473146597953125*^9, 3.473146615828125*^9}},
 CellLabel->"In[136]:="],

Cell[TextData[{
 "The function rank has ben replaced by the built-in function MatrixRank \
being faster than the earlier defined rank, see the ",
 ButtonBox["protocol",
  BaseStyle->"Hyperlink",
  ButtonData->{"rank1.txt", None}],
 " "
}], "Text",
 CellChangeTimes->{{3.472984317890625*^9, 3.4729843948125*^9}, {
  3.4729861926875*^9, 3.47298622978125*^9}, {3.4729862771875*^9, 
  3.4729862771875*^9}, {3.472988219984375*^9, 3.472988219984375*^9}, {
  3.472988369328125*^9, 3.472988392859375*^9}, {3.47298843240625*^9, 
  3.47298843240625*^9}, {3.472992592359375*^9, 3.472992629171875*^9}}],

Cell[BoxData[
 RowBox[{"??", "rank"}]], "Input",
 CellChangeTimes->{{3.472984008890625*^9, 3.47298401159375*^9}, 
   3.472992894421875*^9},
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"?", "MatrixRank"}]], "Input",
 CellChangeTimes->{{3.472983835421875*^9, 3.472983839109375*^9}, {
  3.472983976734375*^9, 3.47298398559375*^9}},
 CellLabel->"In[38]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"matrix", "[", "x", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.472984444234375*^9, 3.47298445784375*^9}},
 CellLabel->"In[31]:="],

Cell[BoxData[
 RowBox[{"rank", "[", 
  RowBox[{"matrix", "[", "x", "]"}], "]"}]], "Input",
 CellLabel->"In[31]:="],

Cell["The null vector and the null matrix have nothing to do with", "Text",
 CellChangeTimes->{{3.472997502734375*^9, 3.472997516375*^9}, {
  3.472997556046875*^9, 3.472997594875*^9}}],

Cell[BoxData[
 RowBox[{"?", "Null"}]], "Input",
 CellChangeTimes->{{3.4729976038125*^9, 3.4729976085*^9}},
 CellLabel->"In[68]:="],

Cell[BoxData[
 RowBox[{"null", "[", "]"}]], "Input",
 CellChangeTimes->{{3.472997628765625*^9, 3.4729976335625*^9}},
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"nullmatrix", "[", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.472997639890625*^9, 3.47299765278125*^9}},
 CellLabel->"In[70]:="],

Cell[BoxData[
 RowBox[{"?", "nullmatrix"}]], "Input",
 CellChangeTimes->{{3.47299766496875*^9, 3.472997669765625*^9}},
 CellLabel->"In[71]:="],

Cell[BoxData[
 RowBox[{"?", "ConstantArray"}]], "Input",
 CellChangeTimes->{{3.4729977*^9, 3.472997713875*^9}},
 CellLabel->"In[72]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"nullmatrix", "[", "]"}], " ", "\[Equal]", " ", 
  RowBox[{"ConstantArray", "[", 
   RowBox[{"0", ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.47299772840625*^9, 3.47299775315625*^9}, {
  3.472997812546875*^9, 3.472997820765625*^9}},
 CellLabel->"In[74]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Normalize, dotnorme, Norm, norm.", "Subsubsection",
 CellChangeTimes->{{3.472993612953125*^9, 3.472993626328125*^9}, {
  3.4729996130625*^9, 3.472999632625*^9}}],

Cell[BoxData[
 RowBox[{"?", "dotnorme"}]], "Input",
 CellChangeTimes->{{3.4729937041875*^9, 3.472993708734375*^9}, 
   3.472994351609375*^9, 3.472995277625*^9},
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{"?", "Normalize"}]], "Input",
 CellChangeTimes->{{3.47299529465625*^9, 3.4729952988125*^9}},
 CellLabel->"In[44]:="],

Cell[BoxData[
 RowBox[{"dotnorme", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472993730203125*^9, 3.4729937463125*^9}},
 CellLabel->"In[64]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ".", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299649790625*^9, 3.472996508515625*^9}},
 CellLabel->"In[65]:="],

Cell[BoxData[
 RowBox[{"dotnorme", "[", 
  RowBox[{"null", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299378075*^9, 3.472993788421875*^9}},
 CellLabel->"In[33]:="],

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472993675234375*^9, 3.472993687*^9}},
 CellLabel->"In[66]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ".", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.472996529640625*^9, 3.472996538609375*^9}},
 CellLabel->"In[67]:="],

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"null", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472993799296875*^9, 3.4729938115625*^9}},
 CellLabel->"In[45]:="],

Cell["\<\
The norming of vec[x] show that the function are distinct; for real vectors \
they coincide, of course:\
\>", "Text",
 CellChangeTimes->{{3.472996034640625*^9, 3.472996123609375*^9}}],

Cell[BoxData[
 RowBox[{"dotnorme", "[", 
  RowBox[{"randomv", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472994403203125*^9, 3.472994423375*^9}},
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"%", ".", "%"}]], "Input",
 CellChangeTimes->{{3.472994432875*^9, 3.47299443465625*^9}},
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"randomv", "[", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4729959585*^9, 3.472995976109375*^9}},
 CellLabel->"In[54]:="],

Cell[BoxData[
 RowBox[{"%", ".", "%"}]], "Input",
 CellChangeTimes->{{3.472995987125*^9, 3.472995989359375*^9}},
 CellLabel->"In[55]:="],

Cell["\<\
For complex vectors dotnorme normalizes with respect  to the \
complex-Euclidean bilinear form\
\>", "Text",
 CellChangeTimes->{{3.472996153328125*^9, 3.4729962048125*^9}}],

Cell[BoxData[
 RowBox[{"dotnorme", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "I"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299451375*^9, 3.472994539890625*^9}},
 CellLabel->"In[56]:="],

Cell[BoxData[
 RowBox[{"%", ".", "%"}]], "Input",
 CellChangeTimes->{{3.47299622540625*^9, 3.47299622803125*^9}},
 CellLabel->"In[57]:="],

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "I"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299451375*^9, 3.4729945684375*^9}},
 CellLabel->"In[58]:="],

Cell[BoxData[
 RowBox[{"%", ".", "%"}]], "Input",
 CellChangeTimes->{{3.47299506153125*^9, 3.472995063765625*^9}},
 CellLabel->"In[59]:="],

Cell[BoxData[
 RowBox[{"dotnorme", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", 
    RowBox[{"2", "*", "I"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299451375*^9, 3.472994539890625*^9}, {
  3.472995173953125*^9, 3.472995175625*^9}},
 CellLabel->"In[60]:="],

Cell[BoxData[
 RowBox[{"%", ".", "%"}]], "Input",
 CellChangeTimes->{{3.472995185359375*^9, 3.472995187328125*^9}},
 CellLabel->"In[61]:="],

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", 
    RowBox[{"2", "*", "I"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299451375*^9, 3.4729945684375*^9}, {
  3.47299519784375*^9, 3.4729951991875*^9}},
 CellLabel->"In[62]:="],

Cell[BoxData[
 RowBox[{"%", ".", "%"}]], "Input",
 CellChangeTimes->{{3.47299506153125*^9, 3.472995063765625*^9}, 
   3.47299514471875*^9},
 CellLabel->"In[63]:="],

Cell[BoxData[
 RowBox[{"?", "Norm"}]], "Input",
 CellChangeTimes->{{3.472995418359375*^9, 3.472995420640625*^9}},
 CellLabel->"In[46]:="],

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", 
    RowBox[{"2", "*", "I"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299451375*^9, 3.4729945684375*^9}, {
  3.47299519784375*^9, 3.4729951991875*^9}, {3.4729953806875*^9, 
  3.47299538409375*^9}, {3.4729954363125*^9, 3.472995438265625*^9}, {
  3.47299580046875*^9, 3.472995800984375*^9}},
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"%", ".", "%"}]], "Input",
 CellChangeTimes->{{3.47299544696875*^9, 3.4729954488125*^9}},
 CellLabel->"In[48]:="],

Cell["\<\
Normalize  yields for complex vectors the vector normed with respect to the \
standard positive definite Hermitean form:\
\>", "Text",
 CellChangeTimes->{{3.47299634315625*^9, 3.4729963735*^9}, {
   3.47299640540625*^9, 3.472996447734375*^9}, 3.472996696828125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"herm", "[", 
   RowBox[{"x_List", ",", "y_List"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Conjugate", "[", "x", "]"}], ".", "y"}]}]], "Input",
 CellChangeTimes->{{3.472995514015625*^9, 3.4729955163125*^9}, {
  3.472995634625*^9, 3.472995731015625*^9}},
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{"herm", "[", 
  RowBox[{
   RowBox[{"vec", "[", "x", "]"}], ",", 
   RowBox[{"vec", "[", "y", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47299573734375*^9, 3.4729957566875*^9}},
 CellLabel->"In[50]:="],

Cell[BoxData[
 RowBox[{"Normalize", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", 
    RowBox[{"2", "*", "I"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299451375*^9, 3.4729945684375*^9}, {
  3.47299519784375*^9, 3.4729951991875*^9}},
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{"herm", "[", 
  RowBox[{"%", ",", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.472995860859375*^9, 3.47299587096875*^9}},
 CellLabel->"In[53]:="],

Cell["Now we compare the functions norm and Norm:", "Text",
 CellChangeTimes->{{3.4729987938125*^9, 3.472998824671875*^9}}],

Cell[BoxData[
 RowBox[{"?", "Norm"}]], "Input",
 CellChangeTimes->{{3.472998841234375*^9, 3.47299884446875*^9}},
 CellLabel->"In[98]:="],

Cell[BoxData[
 RowBox[{"?", "norm"}]], "Input",
 CellChangeTimes->{{3.472997965*^9, 3.472997966828125*^9}},
 CellLabel->"In[75]:="],

Cell["\<\
Obviously, the functions are distinct. We define the Hermitean norm:\
\>", "Text",
 CellChangeTimes->{{3.472999210921875*^9, 3.472999264984375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"hnorm", "[", "v_", "]"}], " ", ":=", " ", 
  RowBox[{"norm", "[", 
   RowBox[{"v", ",", " ", 
    RowBox[{"innerprod", " ", "\[Rule]", " ", "herm"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.472997996875*^9, 3.47299804703125*^9}},
 CellLabel->"In[76]:="],

Cell[BoxData[
 RowBox[{"hnorm", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", 
    RowBox[{"2", "*", "I"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299806490625*^9, 3.4729980859375*^9}, {
  3.47299933221875*^9, 3.472999344953125*^9}},
 CellLabel->"In[101]:="],

Cell[BoxData[
 RowBox[{"Norm", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", 
    RowBox[{"2", "*", "I"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299806490625*^9, 3.4729980859375*^9}, {
  3.472999292875*^9, 3.472999300625*^9}},
 CellLabel->"In[99]:="],

Cell[BoxData[
 RowBox[{"hnorm", "[", 
  RowBox[{"Normalize", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"2", "*", "I"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299806490625*^9, 3.47299816825*^9}},
 CellLabel->"In[78]:="],

Cell[BoxData[
 RowBox[{"Norm", "[", 
  RowBox[{"Normalize", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"2", "*", "I"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299806490625*^9, 3.47299816825*^9}, {
  3.4729993711875*^9, 3.47299938078125*^9}},
 CellLabel->"In[102]:="],

Cell[BoxData[
 RowBox[{"hnorm", "[", 
  RowBox[{"dotnorme", "[", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"2", "*", "I"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299806490625*^9, 3.4729981885*^9}},
 CellLabel->"In[79]:="],

Cell[BoxData[
 RowBox[{"norm", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47299827621875*^9, 3.472998287640625*^9}},
 CellLabel->"In[82]:="],

Cell["For complex vectors Norm yields the Hermitean norm.", "Text",
 CellChangeTimes->{{3.472999432515625*^9, 3.472999464734375*^9}}],

Cell[BoxData[
 RowBox[{"Norm", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472998252265625*^9, 3.47299826475*^9}},
 CellLabel->"In[94]:="],

Cell[BoxData[
 RowBox[{"hnorm", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472998325734375*^9, 3.472998338421875*^9}},
 CellLabel->"In[95]:="],

Cell["\<\
Unfortunately, Mathematica is sometimes toiling simplifying expressions which \
contain Abs or Sqrt:\
\>", "Text",
 CellChangeTimes->{{3.47299948596875*^9, 3.472999573046875*^9}}],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "\[Equal]", " ", "%%"}], "]"}]], "Input",
 CellChangeTimes->{{3.472998355640625*^9, 3.472998363515625*^9}, {
  3.472998440609375*^9, 3.472998445046875*^9}},
 CellLabel->"In[96]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.4729985563125*^9, 3.47299859071875*^9}},
 CellLabel->"In[97]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Conjugate", "[", 
    RowBox[{"x", "[", "1", "]"}], "]"}], " ", 
   RowBox[{"x", "[", "1", "]"}]}], "\[Equal]", "  ", 
  RowBox[{
   RowBox[{"Abs", "[", 
    RowBox[{"x", "[", "1", "]"}], "]"}], "^", "2"}]}]], "Input",
 CellChangeTimes->{{3.472998488515625*^9, 3.472998545046875*^9}},
 CellLabel->"In[88]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.4729985563125*^9, 3.472998568046875*^9}},
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.4729985563125*^9, 3.47299859071875*^9}},
 CellLabel->"In[90]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
 Wedge, Cross and cross,  Orthogonalize and  esorthonorm, smoothing and Chop\
\>", "Subsubsection",
 CellChangeTimes->{{3.473001123234375*^9, 3.473001190578125*^9}, {
  3.473001373328125*^9, 3.47300142009375*^9}, {3.47305086928125*^9, 
  3.473050875765625*^9}, {3.473051747078125*^9, 3.473051747359375*^9}, {
  3.473051843078125*^9, 3.4730518565*^9}, {3.47305190265625*^9, 
  3.473051946875*^9}}],

Cell["The symbol", "Text",
 CellChangeTimes->{{3.47300121078125*^9, 3.473001223734375*^9}}],

Cell[BoxData[
 RowBox[{"?", "Wedge"}]], "Input",
 CellChangeTimes->{{3.47300123415625*^9, 3.4730012648125*^9}},
 CellLabel->"In[104]:="],

Cell["has no built-in meaning. wedge is well defined", "Text",
 CellChangeTimes->{{3.473001293984375*^9, 3.4730013403125*^9}}],

Cell[BoxData[
 RowBox[{"?", "wedge"}]], "Input",
 CellChangeTimes->{{3.47300134471875*^9, 3.473001346859375*^9}},
 CellLabel->"In[105]:="],

Cell[BoxData[
 RowBox[{"wedge", "[", 
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], ",", 
   RowBox[{"vec", "[", "b", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47300143753125*^9, 3.4730014908125*^9}},
 CellLabel->"In[108]:="],

Cell[BoxData[
 RowBox[{"?", "Cross"}]], "Input",
 CellChangeTimes->{{3.47305196853125*^9, 3.473051974390625*^9}},
 CellLabel->"In[46]:="],

Cell["\<\
cross acts on matrices (list of lists), giving the same result as Cross \
applied to the row vectors of the matrix:\
\>", "Text",
 CellChangeTimes->{{3.47305233921875*^9, 3.473052391578125*^9}, {
  3.473052421984375*^9, 3.473052478703125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"?", "cross"}]}]], "Input",
 CellChangeTimes->{{3.473052107859375*^9, 3.473052110796875*^9}, {
  3.473052174296875*^9, 3.473052174609375*^9}},
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.473052217453125*^9, 3.473052222703125*^9}},
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cross", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vec", "[", "x", "]"}], ",", 
     RowBox[{"vec", "[", "y", "]"}]}], "}"}], "]"}], "\[Equal]", " ", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"vec", "[", "x", "]"}], ",", 
    RowBox[{"vec", "[", "y", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473052227390625*^9, 3.473052280421875*^9}},
 CellLabel->"In[50]:="],

Cell[TextData[{
 "Orthogonalize and esorthonorm are treated in ",
 ButtonBox["section 2",
  BaseStyle->"Hyperlink",
  ButtonData->"ortho"],
 "."
}], "Text",
 CellChangeTimes->{{3.473001611984375*^9, 3.473001665109375*^9}, {
  3.473001699328125*^9, 3.47300169934375*^9}}],

Cell[TextData[{
 "Chop and smoothing are very similar; they are compared in the notebook ",
 ButtonBox["Chop.nb",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www-irm.mathematik.hu-berlin.de/~sulanke/Notebooks/Chop.nb"], 
    None},
  ButtonNote->
   "http://www-irm.mathematik.hu-berlin.de/~sulanke/Notebooks/Chop.nb"],
 " which may be downloaded from my ",
 ButtonBox["homepage",
  BaseStyle->"Hyperlink",
  ButtonData->"HP"],
 "."
}], "Text",
 CellChangeTimes->{{3.4730017910625*^9, 3.473001861875*^9}, {
  3.4730019595625*^9, 3.47300195959375*^9}, {3.473002029296875*^9, 
  3.47300203740625*^9}, {3.47300226065625*^9, 3.473002260671875*^9}, {
  3.47300232259375*^9, 3.47300232259375*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Sphere and sphere, SphericalPlot3D and sphereplot3D. subsphere and subspheremf\
\>", "Subsubsection",
 CellChangeTimes->{{3.4730554965625*^9, 3.47305550390625*^9}, {
  3.47306108496875*^9, 3.473061139171875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.473141066578125*^9, 3.473141072765625*^9}},
 CellLabel->"In[60]:="],

Cell[BoxData[
 RowBox[{"?", "Sphere"}]], "Input",
 CellChangeTimes->{{3.473055511046875*^9, 3.473055514625*^9}},
 CellLabel->"In[61]:="],

Cell[BoxData[
 RowBox[{"Sphere", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.47305551940625*^9, 3.473055542734375*^9}, {
  3.473141106703125*^9, 3.47314113675*^9}},
 CellLabel->"In[64]:="],

Cell["So we generate the picture", "Text",
 CellChangeTimes->{{3.473055797078125*^9, 3.473055798578125*^9}, {
  3.47305587903125*^9, 3.473055899109375*^9}}],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{"Sphere", "[", 
   RowBox[{
    RowBox[{"stb", "[", "1", "]"}], ",", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47305551940625*^9, 3.47305560034375*^9}},
 CellLabel->"In[65]:="],

Cell["\<\
Our function sphere yields a parameter representation of the sphere, \
appropriate for calculus\
\>", "Text",
 CellChangeTimes->{{3.47305591575*^9, 3.473055990203125*^9}, {
  3.47314115775*^9, 3.4731411630625*^9}}],

Cell[BoxData[
 RowBox[{"?", "sphere"}]], "Input",
 CellChangeTimes->{{3.47305562546875*^9, 3.473055631640625*^9}},
 CellLabel->"In[66]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere", "[", 
   RowBox[{
    RowBox[{"vec", "[", "x", "]"}], ",", "r"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.47305564653125*^9, 3.473055686140625*^9}},
 CellLabel->"In[67]:="],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{"%", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.473055721515625*^9, 3.473055728140625*^9}},
 CellLabel->"In[68]:="],

Cell["and graphics, e.g. by ParameterPlot3D, or", "Text",
 CellChangeTimes->{{3.473056006359375*^9, 3.473056035390625*^9}}],

Cell[BoxData[
 RowBox[{"?", "sphereplot3D"}]], "Input",
 CellChangeTimes->{{3.47305605721875*^9, 3.473056066484375*^9}},
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{"sphereplot3D", "[", 
  RowBox[{
   RowBox[{"stb", "[", "1", "]"}], ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.473056095546875*^9, 3.4730561110625*^9}},
 CellLabel->"In[70]:="],

Cell["\<\
The function spheeplot3D should not be confused with the built-in function \
SphericalPlotz3D:\
\>", "Text",
 CellChangeTimes->{{3.473141280703125*^9, 3.4731413464375*^9}, 
   3.4731415258125*^9}],

Cell[BoxData[
 RowBox[{"??", "SphericalPlot3D"}]], "Input",
 CellChangeTimes->{{3.4730567093125*^9, 3.4730567104375*^9}, 
   3.473141491625*^9},
 CellLabel->"In[71]:="],

Cell[BoxData[
 RowBox[{"SphericalPlot3D", "[", 
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{"2", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", "\[Theta]"}], "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", "Pi"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", 
     RowBox[{"2", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[70]:="],

Cell["\<\
SphericalPlot3D yields the 3D-Plot of the function r given on the unit \
sphere; it may be used to plot the sphere with radius r and the origin as \
center:\
\>", "Text",
 CellChangeTimes->{{3.4730567405*^9, 3.473056853296875*^9}, {
   3.473141595203125*^9, 3.47314162059375*^9}, 3.47339649234375*^9}],

Cell[BoxData[
 RowBox[{"SphericalPlot3D", "[", 
  RowBox[{"2", ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", "Pi"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", "0", ",", 
     RowBox[{"2", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47305644290625*^9, 3.473056455859375*^9}, 
   3.473141579859375*^9},
 CellLabel->"In[72]:="],

Cell["\<\
The function subsphere is mainly used in M\[ODoubleDot]bius geometry; it \
yields a parameter representation of a 2-sphere contained in the unit \
3-sphere of the 4-dimensional Euclidean space. The 3D-Plot of its \
stereographical projection is a sphere in the Euclidean 3-space:\
\>", "Text",
 CellChangeTimes->{{3.473058314515625*^9, 3.473058486984375*^9}, {
  3.47314164784375*^9, 3.473141652453125*^9}}],

Cell[BoxData[
 RowBox[{"?", "subsphere"}]], "Input",
 CellChangeTimes->{{3.47305763471875*^9, 3.47305765428125*^9}},
 CellLabel->"In[88]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sterproj", "[", 
    RowBox[{
     RowBox[{"subsphere", "[", 
      RowBox[{
       RowBox[{"stb", "[", 
        RowBox[{"1", ",", "4"}], "]"}], ",", ".5"}], "]"}], "[", 
     RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"w", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473057753015625*^9, 3.4730577718125*^9}, {
   3.473057828765625*^9, 3.47305802090625*^9}, 3.4730580541875*^9, {
   3.473058117359375*^9, 3.473058118640625*^9}, {3.47305817065625*^9, 
   3.473058174421875*^9}},
 CellLabel->"In[91]:="],

Cell["\<\
subspheremf is subsphere with the vector n parametrized by the spherical \
coordinates of the unit 3-sphere. It represents the 2-sphere as an element of \
the 4-dimensional manifold of all 2-subspheres of the 3-sphere. The module is \
constructed for generating families of subspheres and visualize them in the \
Euclidean 3-space:\
\>", "Text",
 CellChangeTimes->{{3.47305860384375*^9, 3.47305875425*^9}, {
  3.4730603864375*^9, 3.473060450109375*^9}, {3.473060518375*^9, 
  3.473060553859375*^9}}],

Cell[BoxData[
 RowBox[{"?", "subspheremf"}]], "Input",
 CellChangeTimes->{{3.47305852103125*^9, 3.473058521671875*^9}},
 CellLabel->"In[92]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ParametricPlot3D", "[", 
      RowBox[{
       RowBox[{"sterproj", "[", 
        RowBox[{
         RowBox[{"subspheremf", "[", 
          RowBox[{"0", ",", "0", ",", "0", ",", 
           RowBox[{"1", "-", 
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{"10", "*", "j"}], ")"}]}]}]}], "]"}], "[", 
         RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", 
         RowBox[{
          RowBox[{"-", "Pi"}], "/", "2"}], ",", 
         RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"w", ",", "0", ",", 
         RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
        RowBox[{"Opacity", "[", ".2", "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473057753015625*^9, 3.4730577718125*^9}, {
   3.473057828765625*^9, 3.47305802090625*^9}, 3.4730580541875*^9, {
   3.473058117359375*^9, 3.473058118640625*^9}, {3.47305817065625*^9, 
   3.473058174421875*^9}, {3.473058850734375*^9, 3.47305886309375*^9}, {
   3.473058898546875*^9, 3.473058910359375*^9}, {3.4730589559375*^9, 
   3.473059014953125*^9}, 3.473059109125*^9, {3.473059143765625*^9, 
   3.473059181234375*^9}, {3.47305930396875*^9, 3.473059304171875*^9}, {
   3.473059442046875*^9, 3.473059453734375*^9}, 3.473059522421875*^9, {
   3.47305963590625*^9, 3.47305964375*^9}, {3.473059765625*^9, 
   3.47305977403125*^9}, 3.47305990628125*^9, {3.473060000015625*^9, 
   3.473060053421875*^9}, 3.473060212328125*^9, {3.473060300640625*^9, 
   3.47306032728125*^9}, 3.47306057546875*^9, {3.473081612421875*^9, 
   3.47308162725*^9}, {3.473083962046875*^9, 3.473083968109375*^9}, 
   3.473141772390625*^9},
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ParametricPlot3D", "[", 
      RowBox[{
       RowBox[{"sterproj", "[", 
        RowBox[{
         RowBox[{"subspheremf", "[", 
          RowBox[{"0", ",", 
           RowBox[{"j", "*", "2", "*", 
            RowBox[{"Pi", "/", "5"}]}], ",", "0", ",", ".9"}], "]"}], "[", 
         RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", 
         RowBox[{
          RowBox[{"-", "Pi"}], "/", "2"}], ",", 
         RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"w", ",", "0", ",", 
         RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473057753015625*^9, 3.4730577718125*^9}, {
   3.473057828765625*^9, 3.47305802090625*^9}, 3.4730580541875*^9, {
   3.473058117359375*^9, 3.473058118640625*^9}, {3.47305817065625*^9, 
   3.473058174421875*^9}, {3.473058850734375*^9, 3.47305886309375*^9}, {
   3.473058898546875*^9, 3.473058910359375*^9}, {3.4730589559375*^9, 
   3.473059014953125*^9}, 3.473059109125*^9, {3.473059143765625*^9, 
   3.473059181234375*^9}, {3.47305930396875*^9, 3.473059304171875*^9}, {
   3.473059442046875*^9, 3.473059453734375*^9}, 3.473059522421875*^9, {
   3.47305963590625*^9, 3.47305964375*^9}, {3.473059765625*^9, 
   3.47305977403125*^9}, 3.47305990628125*^9, {3.473060000015625*^9, 
   3.473060053421875*^9}, 3.473060212328125*^9, {3.473060300640625*^9, 
   3.47306032728125*^9}, 3.47306057546875*^9, {3.473081612421875*^9, 
   3.47308162725*^9}, {3.473083962046875*^9, 3.473083968109375*^9}, {
   3.47308451209375*^9, 3.473084518328125*^9}, {3.473142019640625*^9, 
   3.473142116703125*^9}, {3.47314379040625*^9, 3.473143813546875*^9}, {
   3.473143949625*^9, 3.47314397334375*^9}, {3.47314538175*^9, 
   3.473145381765625*^9}, {3.47314545740625*^9, 3.47314546509375*^9}, 
   3.47314551003125*^9, {3.473145562640625*^9, 3.473145572140625*^9}},
 CellLabel->"In[122]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Control of the Module subspheremf", "Subsubsection",
 CellChangeTimes->{{3.4731449970625*^9, 3.47314501359375*^9}}],

Cell["\<\
To control the correctness and efectiveness of the Module subspheremf we use \
random points and compare the results with those obtained using the Module \
spheremf1, which  is only a temporary example of the application of sphbasis; \
in principle, it makes the same as subspheremf, but slower and less effective.\
\>", "Text",
 CellChangeTimes->{{3.473084062171875*^9, 3.473084107015625*^9}, {
  3.473084278359375*^9, 3.473084365765625*^9}, {3.473145035984375*^9, 
  3.47314514596875*^9}}],

Cell[BoxData[
 RowBox[{"?", "spheremf1"}]], "Input",
 CellChangeTimes->{{3.473144964359375*^9, 3.473144971578125*^9}},
 CellLabel->"In[119]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ParametricPlot3D", "[", 
      RowBox[{
       RowBox[{"sterproj", "[", 
        RowBox[{
         RowBox[{"spheremf1", "[", 
          RowBox[{"0", ",", "0", ",", 
           RowBox[{"j", "*", "2", "*", 
            RowBox[{"Pi", "/", "5"}]}], ",", ".9"}], "]"}], "[", 
         RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", 
         RowBox[{
          RowBox[{"-", "Pi"}], "/", "2"}], ",", 
         RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"w", ",", "0", ",", 
         RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
       RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
        RowBox[{"Opacity", "[", ".2", "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473057753015625*^9, 3.4730577718125*^9}, {
   3.473057828765625*^9, 3.47305802090625*^9}, 3.4730580541875*^9, {
   3.473058117359375*^9, 3.473058118640625*^9}, {3.47305817065625*^9, 
   3.473058174421875*^9}, {3.473058850734375*^9, 3.47305886309375*^9}, {
   3.473058898546875*^9, 3.473058910359375*^9}, {3.4730589559375*^9, 
   3.473059014953125*^9}, 3.473059109125*^9, {3.473059143765625*^9, 
   3.473059181234375*^9}, {3.47305930396875*^9, 3.473059304171875*^9}, {
   3.473059442046875*^9, 3.473059453734375*^9}, 3.473059522421875*^9, {
   3.47305963590625*^9, 3.47305964375*^9}, {3.473059765625*^9, 
   3.47305977403125*^9}, 3.47305990628125*^9, {3.473060000015625*^9, 
   3.473060053421875*^9}, 3.473060212328125*^9, {3.473060300640625*^9, 
   3.47306032728125*^9}, 3.47306057546875*^9, {3.473081612421875*^9, 
   3.47308162725*^9}, {3.473083962046875*^9, 3.473083968109375*^9}, {
   3.47308451209375*^9, 3.473084518328125*^9}, {3.473142019640625*^9, 
   3.473142116703125*^9}},
 CellLabel->"In[75]:="],

Cell["Here are four random parameters;", "Text",
 CellChangeTimes->{{3.473084910390625*^9, 3.4730849371875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"s1", " ", "=", " ", 
   RowBox[{"2", "*", "Pi", "*", 
    RowBox[{"Random", "[", "]"}]}]}], ";", 
  RowBox[{"t1", " ", "=", " ", 
   RowBox[{
    RowBox[{"Random", "[", "]"}], "*", 
    RowBox[{"Pi", "/", "2"}]}]}], ";", " ", 
  RowBox[{"u1", "=", 
   RowBox[{
    RowBox[{"Random", "[", "]"}], "*", 
    RowBox[{"Pi", "/", "2"}]}]}], ";", " ", 
  RowBox[{"p1", " ", "=", " ", 
   RowBox[{"Random", "[", "]"}]}], ";", 
  RowBox[{"{", 
   RowBox[{"s1", ",", "t1", ",", "u1", ",", "p1"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.47307887934375*^9, 3.473078918921875*^9}, {
  3.4730790216875*^9, 3.473079141171875*^9}},
 CellLabel->"In[110]:="],

Cell["\<\
We choose four random points of the sphere obtained using spheremf1[s1, t1, \
u1, p1]:\
\>", "Text",
 CellChangeTimes->{{3.473084956359375*^9, 3.473084993890625*^9}, {
  3.473085032921875*^9, 3.473085041234375*^9}}],

Cell[BoxData[
 RowBox[{"pts1", " ", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"spheremf1", "[", 
       RowBox[{"s1", ",", "t1", ",", "u1", ",", "p1"}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Random", "[", "]"}], "*", "2", "*", "Pi"}], ",", 
       RowBox[{
        RowBox[{"Random", "[", "]"}], "*", 
        RowBox[{"Pi", "/", "2"}]}]}], "]"}], "]"}], ",", 
    RowBox[{"{", "4", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473078772359375*^9, 3.473078798109375*^9}, {
   3.47307884903125*^9, 3.473078867984375*^9}, {3.473079166671875*^9, 
   3.473079264765625*^9}, 3.4730793099375*^9, {3.473079358421875*^9, 
   3.473079362609375*^9}},
 CellLabel->"In[111]:="],

Cell["\<\
We choose other four random points of the sphere obtained using \
subspheremf[s1, t1, u1, p1]:\
\>", "Text",
 CellChangeTimes->{{3.473084956359375*^9, 3.473084993890625*^9}, {
  3.473085032921875*^9, 3.473085041234375*^9}, {3.473085079234375*^9, 
  3.47308508996875*^9}, {3.473145905078125*^9, 3.473145907390625*^9}}],

Cell[BoxData[
 RowBox[{"pts2", " ", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"subspheremf", "[", 
       RowBox[{"s1", ",", "t1", ",", "u1", ",", "p1"}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Random", "[", "]"}], "*", "2", "*", "Pi"}], ",", 
       RowBox[{
        RowBox[{"Random", "[", "]"}], "*", 
        RowBox[{"Pi", "/", "2"}]}]}], "]"}], "]"}], ",", 
    RowBox[{"{", "4", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473078772359375*^9, 3.473078798109375*^9}, {
   3.47307884903125*^9, 3.473078867984375*^9}, {3.473079166671875*^9, 
   3.473079264765625*^9}, 3.4730793099375*^9, {3.473079358421875*^9, 
   3.473079417890625*^9}},
 CellLabel->"In[112]:="],

Cell["\<\
pts1, pts2 define the same sphere, depending on s1, t1, u1, p1 :\
\>", "Text",
 CellChangeTimes->{{3.473085115875*^9, 3.473085199546875*^9}}],

Cell[BoxData[
 RowBox[{"radius", "[", "pts1", "]"}]], "Input",
 CellChangeTimes->{{3.473079444765625*^9, 3.47307945734375*^9}},
 CellLabel->"In[113]:="],

Cell[BoxData[
 RowBox[{"center", "[", "pts1", "]"}]], "Input",
 CellChangeTimes->{{3.473079475609375*^9, 3.473079488421875*^9}, 
   3.473396492390625*^9},
 CellLabel->"In[114]:="],

Cell[BoxData[
 RowBox[{"radius", "[", "pts2", "]"}]], "Input",
 CellChangeTimes->{{3.47307950021875*^9, 3.473079510125*^9}},
 CellLabel->"In[115]:="],

Cell[BoxData[
 RowBox[{"center", "[", "pts2", "]"}]], "Input",
 CellChangeTimes->{{3.473079517359375*^9, 3.473079528859375*^9}, 
   3.47339649240625*^9},
 CellLabel->"In[116]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"subspheremf", "[", 
       RowBox[{"s1", ",", "t1", ",", "u1", ",", "p1"}], "]"}], "[", 
      RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", 
    RowBox[{"PlotPoints", " ", "\[Rule]", " ", "60"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.473057753015625*^9, 3.4730577718125*^9}, {
   3.473057828765625*^9, 3.47305802090625*^9}, 3.4730580541875*^9, {
   3.473058117359375*^9, 3.473058118640625*^9}, {3.47305817065625*^9, 
   3.473058174421875*^9}, {3.473058850734375*^9, 3.47305886309375*^9}, {
   3.473058898546875*^9, 3.473058910359375*^9}, {3.4730589559375*^9, 
   3.473059014953125*^9}, 3.473059109125*^9, {3.473059143765625*^9, 
   3.473059181234375*^9}, {3.47305930396875*^9, 3.473059304171875*^9}, {
   3.473059442046875*^9, 3.473059453734375*^9}, 3.473059522421875*^9, {
   3.47305963590625*^9, 3.47305964375*^9}, {3.473059765625*^9, 
   3.47305977403125*^9}, 3.47305990628125*^9, {3.473060000015625*^9, 
   3.473060053421875*^9}, 3.473060212328125*^9, {3.473060300640625*^9, 
   3.47306032728125*^9}, 3.47306057546875*^9, {3.473081612421875*^9, 
   3.47308162725*^9}, 3.47308225946875*^9, 3.473082296296875*^9, 
   3.47308235490625*^9, 3.473084626296875*^9, {3.473084703703125*^9, 
   3.47308472371875*^9}, 3.473084760125*^9, {3.473144193484375*^9, 
   3.473144229421875*^9}, {3.4731444696875*^9, 3.473144482375*^9}},
 CellLabel->"In[117]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"spheremf1", "[", 
       RowBox[{"s1", ",", "t1", ",", "u1", ",", "p1"}], "]"}], "[", 
      RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", 
    RowBox[{"PlotPoints", " ", "\[Rule]", " ", "60"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.473057753015625*^9, 3.4730577718125*^9}, {
   3.473057828765625*^9, 3.47305802090625*^9}, 3.4730580541875*^9, {
   3.473058117359375*^9, 3.473058118640625*^9}, {3.47305817065625*^9, 
   3.473058174421875*^9}, {3.473058850734375*^9, 3.47305886309375*^9}, {
   3.473058898546875*^9, 3.473058910359375*^9}, {3.4730589559375*^9, 
   3.473059014953125*^9}, 3.473059109125*^9, {3.473059143765625*^9, 
   3.473059181234375*^9}, {3.47305930396875*^9, 3.473059304171875*^9}, {
   3.473059442046875*^9, 3.473059453734375*^9}, 3.473059522421875*^9, {
   3.47305963590625*^9, 3.47305964375*^9}, {3.473059765625*^9, 
   3.47305977403125*^9}, 3.47305990628125*^9, {3.473060000015625*^9, 
   3.473060053421875*^9}, 3.473060212328125*^9, {3.473060300640625*^9, 
   3.47306032728125*^9}, 3.47306057546875*^9, {3.473081612421875*^9, 
   3.47308162725*^9}, 3.47308225946875*^9, 3.473082296296875*^9, 
   3.47308235490625*^9, 3.473084626296875*^9, {3.473084703703125*^9, 
   3.47308472371875*^9}, {3.473084760125*^9, 3.473084795015625*^9}, 
   3.473144256890625*^9, 3.47314452509375*^9},
 CellLabel->"In[118]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1 The vector space. Basic operations", "Section",
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection",
 FontFamily->"Times"],

Cell[TextData[{
 "In this section we declare vector objects, fix the dimension dim of the \
vector space, control the linear operations and discuss the ",
 "Euclidean",
 " scalar product which is the Dot product of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " applied to vector objects.  The cross product is applied to find the \
equation of the hyperplane through n points in general position."
}], "Text",
 CellChangeTimes->{3.472971845765625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.1 Vector objects. The dimension ", "Subsection",
 FontFamily->"Times",
 FontSize->14],

Cell["\<\
One has to fix the dimension dim of the underlying vector space.This global \
constant enters in almost all of the defined functions and modules. Since we \
aim considering the 3-sphere as a hypersurface of the Euclidean space we put\
\>", "Text",
 CellChangeTimes->{3.472971845796875*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";"}]], "Input",
 InitializationCell->True,
 FontFamily->"Times",
 CellLabel->"In[6]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dim", "::", "usage"}], " ", "=", " ", 
   "\"\<dim is the globally defined dimension of the finite dimensional \
vector space under consideration.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[7]:="],

Cell["For convenience, we introduced the vector object:", "Text"],

Cell[BoxData[
 RowBox[{"?", "vec"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[33]:="],

Cell[BoxData[
 RowBox[{"Head", "[", "vec", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"vec", "[", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"Head", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[36]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "x", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"vec", "[", 
  RowBox[{"x", ",", "3"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[38]:="],

Cell["\<\
The dimension dim appears in many constructs as an omitted, globally defined \
parameter.  If wanted, its value may be changed globally:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"dim", " ", "=", " ", "3"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[39]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "a", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[40]:="],

Cell["and resetted again", "Text"],

Cell[BoxData[
 RowBox[{"dim", "=", "4"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "a", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[42]:="],

Cell["The null vector is", "Text"],

Cell[BoxData[
 RowBox[{"null", "[", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[43]:="],

Cell["\<\
Of course, one may consider objects depending on the dimension explicitly \
entering d, independent on the value of dim:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"null", "[", "7", "]"}], "\[NotEqual]", 
  RowBox[{"null", "[", "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[44]:="],

Cell[BoxData[
 RowBox[{"null", "[", "7", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[45]:="],

Cell[TextData[{
 "The vector operations are implemented by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "; they work well with the vec objects:"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", "a", "]"}], "+", 
  RowBox[{"vec", "[", "b", "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[46]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], "+", 
   RowBox[{"vec", "[", "b", "]"}]}], "==", 
  RowBox[{
   RowBox[{"vec", "[", "b", "]"}], "+", 
   RowBox[{"vec", "[", "a", "]"}]}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[47]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"vec", "[", "a", "]"}], "+", 
     RowBox[{"vec", "[", "b", "]"}]}], ")"}], "+", 
   RowBox[{"vec", "[", "c", "]"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], "+", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"vec", "[", "b", "]"}], "+", 
     RowBox[{"vec", "[", "c", "]"}]}], ")"}]}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], "+", 
   RowBox[{"null", "[", "]"}]}], "==", 
  RowBox[{"vec", "[", "a", "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], "-", 
   RowBox[{"vec", "[", "a", "]"}]}], "\[Equal]", " ", 
  RowBox[{"null", "[", "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[50]:="],

Cell["\<\
vec is protected; therefore the following definition does not work:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", "c", "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], "+", 
   RowBox[{"vec", "[", "b", "]"}]}]}]], "Input",
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"c", "[", "1", "]"}]], "Input",
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{"c", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[53]:="],

Cell[BoxData[
 RowBox[{"Clear", "[", "c", "]"}]], "Input",
 CellLabel->"In[54]:="],

Cell["One may set", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "[", "i_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"a", "[", "i", "]"}], "+", 
   RowBox[{"b", "[", "i", "]"}]}]}]], "Input",
 CellLabel->"In[55]:="],

Cell["Now vec[c] is what we wanted", "Text"],

Cell[BoxData[
 RowBox[{"vec", "[", "c", "]"}]], "Input",
 CellLabel->"In[56]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", "c", "]"}], "\[Equal]", "  ", 
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], "+", 
   RowBox[{"vec", "[", "b", "]"}]}]}]], "Input",
 CellLabel->"In[57]:="],

Cell["The next rule is recognized by using Simplify only:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", "a", "]"}], " ", "c"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"vec", "[", "b", "]"}], " ", "c"}]}], " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"vec", "[", "a", "]"}], "+", 
     RowBox[{"vec", "[", "b", "]"}]}], ")"}], " ", "c"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[58]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[59]:="],

Cell["The argument of vec may be any symbol, well or not defined:", "Text"],

Cell[BoxData[
 RowBox[{"vec", "[", "Cos", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[60]:="],

Cell["Cos is a well defined function, vec[Cos] may be evaluated", "Text"],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[61]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "CO", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[62]:="],

Cell[BoxData[
 RowBox[{"?", "CO"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[63]:="],

Cell["Of course, CO[i] is not defined:", "Text"],

Cell[BoxData[
 RowBox[{"CO", "[", "1", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[64]:="],

Cell[BoxData[
 RowBox[{"N", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[65]:="],

Cell["Defining", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CO", "[", "i_", "]"}], ":=", " ", 
  RowBox[{"N", "[", 
   RowBox[{"i", "^", "i"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[66]:="],

Cell["we obtain", "Text"],

Cell[BoxData[
 RowBox[{"vec", "[", "CO", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[67]:="],

Cell["\<\
The Euclidean scalar product with respect to the orthonormal standard  basis \
(stb[i])\
\>", "Text",
 CellChangeTimes->{3.47297184584375*^9}],

Cell[BoxData[
 RowBox[{"?", "stb"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[68]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"stb", "[", "i", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"i", ",", "dim"}], "}"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[69]:="],

Cell["is the Dot product of Mathematica", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", "a", "]"}], ".", 
  RowBox[{"vec", "[", "b", "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[71]:="],

Cell["It obeys the well known rules", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], ".", 
   RowBox[{"vec", "[", "b", "]"}]}], "\[Equal]", " ", 
  RowBox[{
   RowBox[{"vec", "[", "b", "]"}], ".", 
   RowBox[{"vec", "[", "a", "]"}]}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[72]:="],

Cell["Sometimes only under Simplify", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], ".", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"vec", "[", "b", "]"}], "+", " ", 
     RowBox[{"vec", "[", "c", "]"}]}], ")"}]}], "\[Equal]", 
  RowBox[{
   RowBox[{
    RowBox[{"vec", "[", "a", "]"}], ".", 
    RowBox[{"vec", "[", "b", "]"}]}], "+", 
   RowBox[{
    RowBox[{"vec", "[", "a", "]"}], ".", 
    RowBox[{"vec", "[", "c", "]"}]}]}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[74]:="],

Cell["\<\
In Euclidean geometry norming a nonzero vector means  to apply\
\>", "Text",
 CellChangeTimes->{3.47297184590625*^9}],

Cell[BoxData[
 RowBox[{"?", "dotnorme"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[75]:="],

Cell[BoxData[
 RowBox[{"dotnorme", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[76]:="],

Cell["The scalar square is", "Text",
 CellChangeTimes->{{3.47211140852425*^9, 3.472111415507725*^9}}],

Cell[BoxData[
 RowBox[{"%", ".", "%"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[77]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[78]:="],

Cell[BoxData[
 RowBox[{"?", "norm"}]], "Input",
 CellChangeTimes->{{3.472189891421224*^9, 3.472189893523322*^9}},
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"norm", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472189429292178*^9, 3.472189439027971*^9}, 
   3.472189954561352*^9},
 CellLabel->"In[36]:="],

Cell["\<\
norm must be distinguished from the Mathemmatica function Norm\
\>", "Text",
 CellChangeTimes->{{3.472189549192459*^9, 3.472189557173689*^9}, {
   3.472189610534249*^9, 3.472189636281068*^9}, {3.472189681639322*^9, 
   3.472189693959474*^9}, {3.472189920538994*^9, 3.472189925132151*^9}, 
   3.47218998005052*^9}],

Cell[BoxData[
 RowBox[{"Norm", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472189429292178*^9, 3.472189439027971*^9}},
 CellLabel->"In[31]:="],

Cell[BoxData[
 RowBox[{"norm", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "I"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472189725637453*^9, 3.472189728274627*^9}, {
  3.472189779214862*^9, 3.472189809849736*^9}, {3.472189987585349*^9, 
  3.472189992837855*^9}},
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"Norm", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "I"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472189818091167*^9, 3.472189839777933*^9}},
 CellLabel->"In[38]:="],

Cell["Remark. I denotes the imaginary unit:", "Text",
 CellChangeTimes->{{3.472190062831853*^9, 3.472190089537577*^9}}],

Cell[BoxData[
 RowBox[{"I", "*", "I"}]], "Input",
 CellChangeTimes->{{3.472190096603153*^9, 3.472190098672636*^9}},
 CellLabel->"In[39]:="],

Cell["\<\
The 3-sphere is the submanifold of the unit vectors in the four-dimensional \
Euclidean space (\"4-space\"). We do not distinguish free vectors and radius \
vectors of points; thus vec[x]  in the next equation means the point with \
coordinates x[i].\
\>", "Text",
 CellChangeTimes->{3.47297184596875*^9}],

Cell["\<\
The equation of the unit-3-sphere with center at the origin is\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", "x", "]"}], ".", 
   RowBox[{"vec", "[", "x", "]"}]}], " ", "==", " ", "1"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[79]:="],

Cell["\<\
Sometimes it is useful, e.g. for testing purposes, to generate random vectors:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "randomv"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[80]:="],

Cell[BoxData[
 RowBox[{"randomv", "[", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[81]:="],

Cell["This gives a random matrix", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"randomv", "[", "6", "]"}], ",", " ", 
    RowBox[{"{", "7", "}"}]}], "]"}], "//", "TableForm"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[82]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[83]:="],

Cell["Here are two special applications:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{"randomv", ",", "6"}], "]"}], "//", "MatrixForm"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[84]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"wekk", "[", "a_", "]"}], "[", 
   RowBox[{"d_:", "dim"}], "]"}], " ", ":=", " ", 
  RowBox[{"vec", "[", 
   RowBox[{"a", ",", "d"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[85]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", 
   RowBox[{
    RowBox[{"wekk", "[", "a", "]"}], ",", "6"}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[86]:="],

Cell["More complicated expressions may be generated:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"m", "[", "i_", "]"}], ":=", 
  RowBox[{
   RowBox[{"a", "[", "i", "]"}], "*", 
   RowBox[{"x", "^", "i"}]}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[87]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "m", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[88]:="],

Cell[BoxData[
 RowBox[{"Remove", "[", 
  RowBox[{"CO", ",", "wekk", ",", "m"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{"vec", "[", "m", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[90]:="],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "c", ",", "m"}], "]"}]], "Input",
 CellLabel->"In[91]:="],

Cell[TextData[{
 "A list (i.e. a finite sequence) of vectors appears as a matrix. Often one \
wants to now the rank of the matrix, what  is the same as the dimension of \
the span of their column vectors (or their  ",
 StyleBox["line vectors):", "MathCaption"]
}], "Text"],

Cell[BoxData[
 RowBox[{"?", "rank"}]], "Input",
 CellLabel->"In[92]:="],

Cell["\<\
Given a list of vectors, one often needs a sublist consisting of a basis of \
the span:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "basis"}]], "Input",
 CellLabel->"In[93]:="],

Cell["\<\
The last two constructs don't depend on the global dimension dim. The user \
may test the effectivity of these modules applying it to arbitrary vector \
sequences.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"randommatrix", "[", 
  RowBox[{"7", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.472190276394985*^9, 3.47219029063337*^9}, {
  3.472190348973451*^9, 3.472190382120499*^9}},
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{"basis", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.472190400812783*^9, 3.472190411369786*^9}},
 CellLabel->"In[42]:="],

Cell[BoxData[
 RowBox[{"Det", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.4721904186189*^9, 3.472190426544171*^9}},
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{"rank", "[", "%%%", "]"}]], "Input",
 CellChangeTimes->{{3.472190434280366*^9, 3.472190441393386*^9}},
 CellLabel->"In[44]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2  The Cross product ", "Subsection",
 FontFamily->"Times",
 FontSize->14],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " comes with a cross product in arbitrary dimension:"
}], "Text"],

Cell[BoxData[
 RowBox[{"??", "Cross"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[94]:="],

Cell["\<\
The Cross product is antisymmetric, but that is recognized only after \
applying FullSimplify:\
\>", "Text",
 CellChangeTimes->{{3.472112107545451*^9, 3.472112176731568*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cross", "[", 
   RowBox[{"a", ",", "b"}], "]"}], "+", 
  RowBox[{"Cross", "[", 
   RowBox[{"b", ",", "a"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[101]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.472112043768108*^9, 3.472112070971301*^9}},
 CellLabel->"In[102]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.47211181050441*^9, 3.472111819447746*^9}, {
  3.472112023683258*^9, 3.472112025508613*^9}},
 CellLabel->"In[103]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"a", ",", "3"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"b", ",", "3"}], "]"}]}], "]"}], "+", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"b", ",", "3"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"a", ",", "3"}], "]"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[97]:="],

Cell[BoxData[
 RowBox[{"Cross", "[", 
  RowBox[{
   RowBox[{"stb", "[", "1", "]"}], ",", 
   RowBox[{"stb", "[", "2", "]"}], ",", 
   RowBox[{"stb", "[", "3", "]"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[98]:="],

Cell[BoxData[
 RowBox[{"Cross", "[", 
  RowBox[{
   RowBox[{"stb", "[", 
    RowBox[{"1", ",", "3"}], "]"}], ",", 
   RowBox[{"stb", "[", 
    RowBox[{"2", ",", "3"}], "]"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[104]:="],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"x", ",", "3"}], "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"1", ",", "3"}], "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"2", ",", "3"}], "]"}]}], "}"}], "]"}]], "Input",
 CellLabel->"In[105]:="],

Cell[BoxData[
 RowBox[{"Det", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", "1", "]"}], ",", 
    RowBox[{"stb", "[", "2", "]"}], ",", 
    RowBox[{"stb", "[", "3", "]"}], ",", 
    RowBox[{"vec", "[", "x", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472112341480862*^9, 3.472112349676576*^9}, {
  3.472112420211925*^9, 3.472112431618614*^9}},
 FontFamily->"Times",
 CellLabel->"In[109]:="],

Cell[BoxData[
 RowBox[{"%", " ", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"vec", "[", "x", "]"}], ".", 
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"stb", "[", "1", "]"}], ",", 
     RowBox[{"stb", "[", "2", "]"}], ",", 
     RowBox[{"stb", "[", "3", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472112313523075*^9, 3.472112371441196*^9}},
 CellLabel->"In[110]:="],

Cell[TextData[{
 "The ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " definition fulfils the rule"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], ".", "x"}], " ", "\[Equal]", 
  " ", 
  RowBox[{"Det", "[", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "x"}], "}"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.472112246545919*^9, 3.472112265942562*^9}, {
  3.472112453616836*^9, 3.472112461019155*^9}},
 FontFamily->"Times"],

Cell["\<\
  We have another definition of the cross product with only one argument, \
being a list of vectors:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "cross"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[111]:="],

Cell[BoxData[
 RowBox[{"cross", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", "1", "]"}], ",", 
    RowBox[{"stb", "[", "2", "]"}], ",", 
    RowBox[{"stb", "[", "3", "]"}]}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[112]:="],

Cell[BoxData[
 RowBox[{"cross", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"1", ",", "3"}], "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"2", ",", "3"}], "]"}]}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[113]:="],

Cell[BoxData[
 RowBox[{"cross", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472112521032725*^9, 3.472112536792143*^9}},
 CellLabel->"In[114]:="],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", 
  RowBox[{"Cross", "[", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.472112553932096*^9, 3.472112565912111*^9}},
 CellLabel->"In[115]:="],

Cell["Our definition fulfils the rule", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cross", "[", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}], ".", "x"}], " ", 
  "\[Equal]", " ", 
  RowBox[{"Det", "[", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "x"}], "}"}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.472112579290797*^9, 3.472112583980183*^9}},
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "mat", "]"}], ";", " ", 
  RowBox[{"mat", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"a", "[", "i", "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[116]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cross", "[", "mat", "]"}], ".", 
   RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
  RowBox[{"Det", "[", 
   RowBox[{"AppendTo", "[", 
    RowBox[{"mat", ",", 
     RowBox[{"vec", "[", "x", "]"}]}], "]"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[117]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[118]:="],

Cell["This is valid in any dimension:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "5"}], ";", 
  RowBox[{"Clear", "[", "mat", "]"}], ";", " ", 
  RowBox[{"mat", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"a", "[", "i", "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.472112647185583*^9},
 FontFamily->"Times",
 CellLabel->"In[119]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cross", "[", "mat", "]"}], ".", 
    RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", 
   RowBox[{"Det", "[", 
    RowBox[{"AppendTo", "[", 
     RowBox[{"mat", ",", 
      RowBox[{"vec", "[", "x", "]"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472112658286231*^9, 3.472112670250754*^9}},
 FontFamily->"Times",
 CellLabel->"In[120]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";"}]], "Input",
 CellChangeTimes->{3.472112723092139*^9},
 FontFamily->"Times",
 CellLabel->"In[123]:="],

Cell["Of course, cross and Cross are antisymmetric:", "Text",
 CellChangeTimes->{{3.472113167124591*^9, 3.472113197772299*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cross", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"a", "[", "1", "]"}], "]"}], ",", 
     RowBox[{"vec", "[", 
      RowBox[{"a", "[", "2", "]"}], "]"}], ",", 
     RowBox[{"vec", "[", 
      RowBox[{"a", "[", "3", "]"}], "]"}]}], "}"}], "]"}], "+", 
  RowBox[{"cross", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"a", "[", "2", "]"}], "]"}], ",", 
     RowBox[{"vec", "[", 
      RowBox[{"a", "[", "1", "]"}], "]"}], ",", 
     RowBox[{"vec", "[", 
      RowBox[{"a", "[", "3", "]"}], "]"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.472112799276242*^9, 3.472112945275686*^9}, 
   3.472112982263649*^9, {3.472113082189223*^9, 3.47211309669701*^9}},
 CellLabel->"In[125]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"a", "[", "1", "]"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"a", "[", "2", "]"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"a", "[", "3", "]"}], "]"}]}], "]"}], "+", 
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"a", "[", "2", "]"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"a", "[", "1", "]"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"a", "[", "3", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.472112799276242*^9, 3.472112945275686*^9}, 
   3.472112982263649*^9, {3.472113082189223*^9, 3.47211309669701*^9}, {
   3.472113205965076*^9, 3.472113240165899*^9}},
 CellLabel->"In[127]:="],

Cell[BoxData[
 RowBox[{"cross", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"a", "[", "1", "]"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"a", "[", "1", "]"}], "]"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"a", "[", "3", "]"}], "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472112799276242*^9, 3.472112945275686*^9}, 
   3.472112982263649*^9, {3.472113082189223*^9, 3.472113126413318*^9}},
 CellLabel->"In[126]:="],

Cell[BoxData[
 RowBox[{"Cross", "[", 
  RowBox[{
   RowBox[{"vec", "[", 
    RowBox[{"a", "[", "1", "]"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"a", "[", "1", "]"}], "]"}], ",", 
   RowBox[{"vec", "[", 
    RowBox[{"a", "[", "3", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472112799276242*^9, 3.472112945275686*^9}, 
   3.472112982263649*^9, {3.472113082189223*^9, 3.472113126413318*^9}, {
   3.472113252336346*^9, 3.472113270670101*^9}},
 CellLabel->"In[128]:="],

Cell["\<\
The next well known rule cross.cross== Det is satisfied by both definitions:\
\>", "Text",
 CellChangeTimes->{{3.47211315208685*^9, 3.472113153139766*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"mat", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"a", "[", "i", "]"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}]}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[129]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"cross", "[", "mat", "]"}], ".", 
    RowBox[{"cross", "[", "mat", "]"}]}], "\[Equal]", 
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"mat", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ".", 
       RowBox[{"mat", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472113298671519*^9, 3.472113326817899*^9}},
 FontFamily->"Times",
 CellLabel->"In[130]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Cross", "[", 
     RowBox[{
      RowBox[{"mat", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"mat", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"mat", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "]"}], ".", 
    RowBox[{"Cross", "[", 
     RowBox[{
      RowBox[{"mat", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"mat", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"mat", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], "\[Equal]", 
   RowBox[{"Det", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"mat", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ".", 
       RowBox[{"mat", "[", 
        RowBox[{"[", "j", "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "3"}], "}"}]}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472113346446485*^9, 3.472113359174114*^9}},
 FontFamily->"Times",
 CellLabel->"In[131]:="],

Cell[BoxData[
 RowBox[{"Remove", "[", "mat", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[132]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.472113440462396*^9, 3.472113447574027*^9}, {
  3.472113557290637*^9, 3.472113565185664*^9}},
 CellLabel->"In[136]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cross", "[", 
   RowBox[{
    RowBox[{"vec", "[", "a", "]"}], ",", " ", 
    RowBox[{
     RowBox[{"vec", "[", "b", "]"}], " ", "+", " ", 
     RowBox[{"vec", "[", "c", "]"}]}]}], "]"}], " ", "\[Equal]", 
  RowBox[{
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"vec", "[", "a", "]"}], ",", " ", 
     RowBox[{"vec", "[", "b", "]"}]}], " ", "]"}], " ", "+", 
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"vec", "[", "a", "]"}], ",", " ", 
     RowBox[{"vec", "[", "c", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472113453460174*^9, 3.472113530285806*^9}},
 CellLabel->"In[137]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"cross", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"vec", "[", "a", "]"}], ",", " ", 
     RowBox[{
      RowBox[{"vec", "[", "b", "]"}], " ", "+", " ", 
      RowBox[{"vec", "[", "c", "]"}]}]}], "}"}], "]"}], " ", "\[Equal]", 
  RowBox[{
   RowBox[{"cross", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"vec", "[", "a", "]"}], ",", " ", 
      RowBox[{"vec", "[", "b", "]"}]}], "}"}], " ", "]"}], " ", "+", 
   RowBox[{"cross", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"vec", "[", "a", "]"}], ",", " ", 
      RowBox[{"vec", "[", "c", "]"}]}], "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472113453460174*^9, 3.472113530285806*^9}, {
  3.472113587172579*^9, 3.472113669025429*^9}},
 CellLabel->"In[138]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3 Hyperplanes through n points: Hesse*s normal form", "Subsection",
 CellChangeTimes->{3.473148446671875*^9},
 FontFamily->"Times",
 FontSize->14],

Cell[CellGroupData[{

Cell["The definition", "Subsubsection",
 CellChangeTimes->{{3.473918394890625*^9, 3.473918399625*^9}}],

Cell["\<\
As an application of the cross-product we find the Hesse normal form of the \
equation of a hyperplane  through  n points  in general position in the \
Euclidean n-space. If vn  denotes the normal unit vector of the hyperplane,  \
and p its oriented distance to the origin,  the Hesse normal form of the \
equation for the points x of the hyperplane is\
\>", "Text",
 CellChangeTimes->{
  3.472971846046875*^9, {3.47314755984375*^9, 3.473147567625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vn", ".", "x"}], "\[Equal]", " ", "p"}]], "Input",
 Evaluatable->False],

Cell["\<\
The definition of the Module hyperplane is contained in euvec.m\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "hyperplane"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[137]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hyperplane", "[", "pt_List", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "q", ",", "p", ",", 
       RowBox[{"d", "=", 
        RowBox[{"Length", "[", "pt", "]"}]}], ",", "fin"}], "}"}], ",", 
     RowBox[{
      RowBox[{"q", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"pt", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "-", 
          RowBox[{"pt", "[", 
           RowBox[{"[", "d", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"d", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"cross", "[", "q", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "n", "]"}], "\[NotEqual]", "d"}], ",", 
        RowBox[{"Goto", "[", "fin", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"n", "===", 
         RowBox[{"null", "[", "d", "]"}]}], ",", 
        RowBox[{"Goto", "[", "fin", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"n", "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"n", ".", "n"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"p", "=", 
       RowBox[{"n", ".", 
        RowBox[{"pt", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{"{", 
        RowBox[{"n", ",", "p"}], "}"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Label", "[", "fin", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<The points \>\"", ",", "pt", ",", 
        "\"\< are not in general position!\>\""}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Return", "[", "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}]], "Input",
 Evaluatable->False,
 FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Examples", "Subsubsection"]], "Subsubsection",
 CellChangeTimes->{{3.472194539818465*^9, 3.472194543333213*^9}},
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.472190720112307*^9, 3.472190720695688*^9}, {
  3.473147658*^9, 3.473147660765625*^9}},
 CellLabel->"In[139]:="],

Cell[BoxData[
 RowBox[{"hyperplane", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", "1", "]"}], ",", " ", 
    RowBox[{"stb", "[", "2", "]"}], ",", " ", 
    RowBox[{"0.9", "*", 
     RowBox[{"stb", "[", "3", "]"}]}], ",", " ", 
    RowBox[{"stb", "[", "4", "]"}]}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[150]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"n1", " ", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
  RowBox[{"p1", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[151]:="],

Cell["\<\
Here is Hesse's normal form of the equation of the hyperplane thrugh the four \
points:\
\>", "Text",
 CellChangeTimes->{{3.473147878203125*^9, 3.473147939171875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"n1", ".", 
   RowBox[{"vec", "[", "x", "]"}]}], " ", "\[Equal]", " ", "p1"}]], "Input",
 CellChangeTimes->{{3.473147777546875*^9, 3.47314779728125*^9}},
 CellLabel->"In[154]:="],

Cell[BoxData[
 RowBox[{"n1", ".", "n1"}]], "Input",
 CellChangeTimes->{{3.473148334109375*^9, 3.473148338796875*^9}},
 CellLabel->"In[162]:="],

Cell["Indeed, they are solutions:", "Text",
 CellChangeTimes->{{3.473147989125*^9, 3.473148004859375*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"n1", ".", 
     RowBox[{"stb", "[", "i", "]"}]}], " ", "-", "p1"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473148032421875*^9, 3.4731480639375*^9}},
 CellLabel->"In[155]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"n1", ".", 
    RowBox[{"stb", "[", "3", "]"}]}], "*", "0.9"}], " ", "-", "p1"}]], "Input",
 CellLabel->"In[152]:="],

Cell["A test with seven random points in the 7-dimensional space:", "Text"],

Cell[BoxData[
 RowBox[{"rtt", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"randomv", "[", "7", "]"}], ",", 
    RowBox[{"{", "7", "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[156]:="],

Cell[BoxData[
 RowBox[{"hyperplane", "[", "rtt", "]"}]], "Input",
 CellLabel->"In[157]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"n1", " ", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", " ", 
  RowBox[{"p1", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.472190781608253*^9},
 CellLabel->"In[158]:="],

Cell[BoxData[
 RowBox[{"n1", ".", "n1"}]], "Input",
 CellLabel->"In[159]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"n1", ".", 
     RowBox[{"rtt", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], "-", "p1"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "7"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[160]:="],

Cell["\<\
Up to unavoidable numerical disturbances the equation of the hyperplane is \
satisfied by the random points\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Chop", "[", "%", "]"}]], "Input",
 CellLabel->"In[161]:="],

Cell[BoxData[
 RowBox[{"Remove", "[", "rtt", "]"}]], "Input",
 CellLabel->"In[163]:="],

Cell["The next two examples return only messages...", "Text"],

Cell[BoxData[
 RowBox[{"hyperplane", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", "1", "]"}], ",", " ", 
    RowBox[{"stb", "[", "2", "]"}], ",", " ", 
    RowBox[{"stb", "[", "2", "]"}], ",", " ", 
    RowBox[{"-", 
     RowBox[{"stb", "[", "3", "]"}]}]}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[164]:="],

Cell[BoxData[
 RowBox[{"hyperplane", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"1", ",", "5"}], "]"}], ",", " ", 
    RowBox[{"stb", "[", 
     RowBox[{"2", ",", "5"}], "]"}], ",", " ", 
    RowBox[{"stb", "[", "3", "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"3", ",", "5"}], "]"}], ",", " ", 
    RowBox[{"-", 
     RowBox[{"stb", "[", 
      RowBox[{"3", ",", "5"}], "]"}]}]}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[165]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The planes as 3DGraphics", "Subsubsection",
 CellChangeTimes->{{3.472194609730292*^9, 3.472194631904075*^9}, {
   3.472218783937811*^9, 3.472218797946862*^9}, 3.473148426265625*^9}],

Cell["\<\
We set the dimension and choose three points in general position:\
\>", "Text",
 CellChangeTimes->{{3.472194705471709*^9, 3.472194731752782*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.472190935221096*^9, 3.472190943890797*^9}, {
  3.472191084009968*^9, 3.472191093006853*^9}},
 CellLabel->"In[167]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"pts", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"null", "[", "]"}], ",", " ", 
    RowBox[{"stb", "[", "1", "]"}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"stb", "[", "2", "]"}], "*", 
      RowBox[{"Cos", "[", "t", "]"}]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"stb", "[", "3", "]"}], "*", 
      RowBox[{"Sin", "[", "t", "]"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.472191181463379*^9, 3.472191288132542*^9}},
 CellLabel->"In[181]:="],

Cell[BoxData[
 RowBox[{"pts", "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.472191301344271*^9, 3.472191307706453*^9}},
 CellLabel->"In[169]:="],

Cell["\<\
Hesse's normal form of the equation of the plane through these points is \
defined by\
\>", "Text",
 CellChangeTimes->{{3.472194764731648*^9, 3.472194792792318*^9}, {
  3.473148755953125*^9, 3.473148768046875*^9}}],

Cell[BoxData[
 RowBox[{"hyperplane", "[", 
  RowBox[{"pts", "[", "t", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472191380544413*^9, 3.472191395134409*^9}},
 CellLabel->"In[170]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", 
   RowBox[{"t", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472191433315226*^9, 3.472191448837803*^9}},
 CellLabel->"In[171]:="],

Cell["\<\
A parameter representation of the hyperplane through n = dim points can be \
obtained  by the formula\
\>", "Text",
 CellChangeTimes->{{3.472272828291398*^9, 3.472272902681386*^9}, {
  3.47227304018539*^9, 3.472273096197994*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"par", "[", 
    RowBox[{
     SubscriptBox["p", "0"], ",", "...", ",", 
     SubscriptBox["p", 
      RowBox[{"n", "-", "1"}]]}], "]"}], "[", 
   RowBox[{
    SubscriptBox["u", "1"], ",", "...", ",", 
    SubscriptBox["u", 
     RowBox[{"n", "-", "1"}]]}], "]"}], ":=", 
  RowBox[{
   SubscriptBox["p", "0"], "+", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["p", "i"], "-", 
        SubscriptBox["p", "0"]}], ")"}], "*", 
      SubscriptBox["u", "i"]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.472272931876976*^9, 3.472273017807611*^9}, {
  3.472273107697234*^9, 3.472273191254616*^9}, {3.472273251963893*^9, 
  3.472273623710532*^9}, {3.472273796441186*^9, 3.472273799086169*^9}}],

Cell["\<\
The following command plots a parallelogram in the plane defined by three \
points  pt0,pt1,pt2 in the 3-space, by default the parallelogram :with \
vertices pt0,pt1,pt2  \
\>", "Text",
 CellChangeTimes->{{3.472194839771885*^9, 3.47219488917009*^9}, {
  3.473149126453125*^9, 3.473149339421875*^9}, {3.473149386921875*^9, 
  3.473149389828125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"planeplot3D", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"pt0_", ",", "pt1_", ",", "pt2_"}], "}"}], ",", 
    RowBox[{"u0_:", "0"}], ",", 
    RowBox[{"u1_:", "1"}], ",", 
    RowBox[{"v0_:", "0"}], ",", 
    RowBox[{"v1_:", "1"}], ",", "opts___"}], "]"}], ":=", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"pt0", " ", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"pt1", "-", "pt0"}], ")"}], "*", "u"}], " ", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"pt2", "-", "pt0"}], ")"}], "*", "v"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "u0", ",", "u1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "v0", ",", "v1"}], "}"}], ",", "opts"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.472191680588439*^9, 3.472191890358542*^9}, {
   3.472191922143184*^9, 3.472192048002289*^9}, 3.472192276026543*^9, {
   3.473148842125*^9, 3.473148970640625*^9}},
 CellLabel->"In[177]:="],

Cell["Here is such a parallelogram", "Text",
 CellChangeTimes->{{3.472194839771885*^9, 3.47219488917009*^9}, {
  3.4731494308125*^9, 3.473149434375*^9}, {3.47315243265625*^9, 
  3.473152465703125*^9}}],

Cell[BoxData[
 RowBox[{"planeplot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"stb", "[", "1", "]"}], ",", 
     RowBox[{"stb", "[", "2", "]"}], ",", 
     RowBox[{"stb", "[", "3", "]"}]}], "}"}], ",", 
   RowBox[{"-", "1"}], ",", "1", ",", " ", "2", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.473149442734375*^9, 3.473149493640625*^9}, {
  3.4731495464375*^9, 3.473149601359375*^9}},
 CellLabel->"In[179]:="],

Cell["\<\
Here is the parallelogram defined by pts[t], t a random angle:
Evaluate the cell several times!\
\>", "Text",
 CellChangeTimes->{{3.472194946081092*^9, 3.472194949278879*^9}, {
  3.472194981834532*^9, 3.472195060047172*^9}}],

Cell[BoxData[
 RowBox[{"planeplot3D", "[", 
  RowBox[{"pts", "[", 
   RowBox[{"2", "*", "Pi", "*", 
    RowBox[{"RandomReal", "[", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472192060094957*^9, 3.472192075338198*^9}, {
   3.472192133613807*^9, 3.472192148758414*^9}, {3.47219321578856*^9, 
   3.472193223769693*^9}, {3.47219329592981*^9, 3.472193300848998*^9}, {
   3.472194360417662*^9, 3.472194376487396*^9}, 3.47315229428125*^9},
 CellLabel->"In[183]:="],

Cell["\<\
The following procedure generates three random points in the unit cube , \
prints the coordinates of the points and plots the points and the \
paralleogram they define:\
\>", "Text",
 CellChangeTimes->{{3.472195266967222*^9, 3.472195408965533*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ma", " ", "=", 
   RowBox[{"randommatrix", "[", 
    RowBox[{"3", ",", "3"}], "]"}]}], ";", " ", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\<ma = \>\"", ",", "ma"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ppa", " ", "=", 
    RowBox[{"planeplot3D", "[", "ma", "]"}]}], ";", 
   RowBox[{"pta", " ", "=", " ", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", ".03", "]"}], ",", 
       RowBox[{"Point", "[", "ma", "]"}]}], "}"}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"pta", ",", "ppa"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.472193370996344*^9, 3.472193408232858*^9}, {
  3.472193494460502*^9, 3.472193509134729*^9}, {3.472193564153386*^9, 
  3.472193714000495*^9}, {3.472193762915727*^9, 3.4721937937984*^9}, {
  3.472194020589353*^9, 3.472194063304218*^9}, {3.472194187809135*^9, 
  3.47219420544665*^9}, {3.47219425635788*^9, 3.472194305849359*^9}, {
  3.473152325484375*^9, 3.47315232840625*^9}, {3.47315263740625*^9, 
  3.473152667671875*^9}},
 CellLabel->"In[227]:="],

Cell[BoxData[
 RowBox[{"Remove", "[", 
  RowBox[{"pts", ",", "ma", ",", "pta", ",", "ppa"}], "]"}]], "Input",
 CellChangeTimes->{{3.472195529824009*^9, 3.472195583831178*^9}},
 CellLabel->"In[230]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Determinat  equation of the hyperplane through n points", \
"Subsubsection",
 CellChangeTimes->{{3.472218818492527*^9, 3.472218826292218*^9}, {
  3.473153632625*^9, 3.473153666578125*^9}}],

Cell["We consider the case n=3; the method works in any dimension.", "Text",
 CellChangeTimes->{
  3.472220393365315*^9, {3.473153658328125*^9, 3.4731536733125*^9}}],

Cell["Here are four random points", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";", " ", 
  RowBox[{"mat", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"randomv", "[", "]"}], ",", 
     RowBox[{"{", "dim", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.47219562626523*^9, 3.472195633041376*^9}, 
   3.472220402639013*^9},
 CellLabel->"In[68]:="],

Cell["Almost surely they are in general position:", "Text",
 CellChangeTimes->{{3.47220561846497*^9, 3.472205619323635*^9}}],

Cell[BoxData[
 RowBox[{"Det", "[", "%", "]"}]], "Input",
 CellLabel->"In[55]:="],

Cell["\<\
The following formula can be proved as an excersise in affine geometry: If \
v[i] are the Cartesian coordinates of n points in general position of the \
n-dimensional  point space, i = 1,...,n, then\
\>", "Text",
 CellChangeTimes->{{3.472218879792353*^9, 3.472219032960757*^9}, {
  3.472219423569533*^9, 3.472219431169588*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v", "[", "1", "]"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v", "[", "2", "]"}], ",", "1"}], "}"}], ",", "...", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v", "[", "n", "]"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"vec", "[", "x", "]"}], ",", "1"}], "}"}]}]}]}], "]"}], 
  "\[Equal]", "0"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.472219044276318*^9, 3.472219230938934*^9}}],

Cell[TextData[{
 "is the equation of the uniquely defined hyperplane containing these points: \
it consists of all the points with Cartesian coordinates vec[x] satisfying \
the equation. \nThis formula leads to  the following Module in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Let v be the square n-matrix whose rows are the coordinates of the point, \
and y the list of unknowns. Set"
}], "Text",
 CellChangeTimes->{{3.472219404437673*^9, 3.47221972538561*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hplane", "::", " ", "usage"}], " ", "=", " ", 
   "\"\<If v is a square matrix of order n and x is a list of at least n \
unknowns, then hplane[v,x] is a linear function such that the rows of v \
satisfy hplane[v,v[[i]]]==0.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.47227175734852*^9, 3.472271906813936*^9}, {
   3.47227195350067*^9, 3.472272070353502*^9}, 3.472272115759952*^9},
 CellLabel->"In[8]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"hplane", "[", 
   RowBox[{"v_", ",", "x_List"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "n", ",", " ", "arg", ",", "w", ",", "i", ",", "xx", ",", "y", ",", 
      "dd"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"Not", "[", 
        RowBox[{"MatrixQ", "[", "v", "]"}], "]"}], ",", 
       RowBox[{"Goto", "[", "arg", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"n", "=", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"v", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "v", "]"}], "!=", " ", "n"}], "||", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], "<", "n"}]}], ",", " ", 
       RowBox[{"Goto", "[", "arg", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"w", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"v", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"xx", "=", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"Array", "[", 
         RowBox[{"y", ",", "n"}], "]"}], ",", "1"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dd", "=", 
      RowBox[{"Det", "[", 
       RowBox[{"Append", "[", 
        RowBox[{"w", ",", "xx"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"dd", "/.", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "[", "i", "]"}], "\[Rule]", 
          RowBox[{"x", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Label", "[", "arg", "]"}], ";", " ", 
     RowBox[{"Print", "[", "\"\<Incorrect argument! \>\"", "]"}], ";", " ", 
     RowBox[{"Return", "[", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.472196511871867*^9, 3.472196685908187*^9}, {
   3.472196732769418*^9, 3.472196813442839*^9}, {3.472196847819164*^9, 
   3.472197139124366*^9}, {3.472197325258912*^9, 3.47219739643655*^9}, {
   3.472197578475587*^9, 3.472197815751007*^9}, {3.472197933604185*^9, 
   3.472197963682691*^9}, {3.472198005732781*^9, 3.47219800683584*^9}, {
   3.472198040979588*^9, 3.472198114727471*^9}, {3.472198272148126*^9, 
   3.472198278081924*^9}, 3.472198502669612*^9, 3.472198698012843*^9, {
   3.472198918987918*^9, 3.472198931888719*^9}, 3.47219909705897*^9, 
   3.472199261686188*^9, {3.472203464711038*^9, 3.472203545303854*^9}, 
   3.472203585858162*^9, {3.472203621646273*^9, 3.472203693322062*^9}, {
   3.472203814892789*^9, 3.472203826028406*^9}, {3.472204016002725*^9, 
   3.472204017145364*^9}, {3.472204135700679*^9, 3.47220422798395*^9}, 
   3.472204296881171*^9, {3.472204337394665*^9, 3.47220436356755*^9}, {
   3.472204972301788*^9, 3.472204991105768*^9}, 3.47220506064288*^9, {
   3.472205708411828*^9, 3.472205719884615*^9}, {3.472205785061605*^9, 
   3.472205796718369*^9}, {3.472219807838148*^9, 3.472219863163133*^9}, {
   3.472220017031333*^9, 3.472220029512487*^9}, {3.472220066954763*^9, 
   3.47222007950163*^9}, 3.472220136752588*^9, {3.472220170340359*^9, 
   3.472220180967609*^9}},
 CellLabel->"In[9]:="],

Cell[BoxData[
 RowBox[{"hplane", "[", 
  RowBox[{"mat", ",", 
   RowBox[{"vec", "[", "x", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472204597494828*^9, 3.472204630533987*^9}, 
   3.472205030734804*^9, {3.472205648847881*^9, 3.472205664155337*^9}, 
   3.472205816737635*^9, 3.472219959594338*^9},
 CellLabel->"In[56]:="],

Cell[BoxData[
 RowBox[{"hplane", "[", 
  RowBox[{"mat", ",", 
   RowBox[{"vec", "[", 
    RowBox[{"y", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472204597494828*^9, 3.472204630533987*^9}, 
   3.472205030734804*^9, {3.472205648847881*^9, 3.472205664155337*^9}, 
   3.472205816737635*^9, {3.472205847233814*^9, 3.472205856291702*^9}, 
   3.472220445621147*^9},
 CellLabel->"In[58]:="],

Cell[BoxData[
 RowBox[{"hplane", "[", 
  RowBox[{"mat", ",", 
   RowBox[{"vec", "[", 
    RowBox[{"y", ",", "7"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472204597494828*^9, 3.472204630533987*^9}, 
   3.472205030734804*^9, {3.472205648847881*^9, 3.472205664155337*^9}, 
   3.472205816737635*^9, {3.472205847233814*^9, 3.472205870164507*^9}},
 CellLabel->"In[59]:="],

Cell[BoxData[
 RowBox[{"hplane", "[", 
  RowBox[{"mat", ",", 
   RowBox[{"mat", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472204597494828*^9, 3.472204630533987*^9}, 
   3.472205030734804*^9, {3.472205087364447*^9, 3.47220510186535*^9}},
 CellLabel->"In[60]:="],

Cell[BoxData[
 RowBox[{"hplane", "[", 
  RowBox[{"mat", ",", 
   RowBox[{"mat", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472204597494828*^9, 3.472204630533987*^9}, 
   3.472205030734804*^9, {3.472205087364447*^9, 3.472205162117599*^9}},
 CellLabel->"In[61]:="],

Cell[BoxData[
 RowBox[{"hplane", "[", 
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], ",", 
   RowBox[{"vec", "[", "y", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472205172701553*^9, 3.472205227271303*^9}, 
   3.472205597942162*^9},
 CellLabel->"In[62]:="],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"mat", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"randomv", "[", "]"}], ",", 
      RowBox[{"{", "dim", "}"}]}], "]"}]}], ";", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hplane", "[", 
       RowBox[{"mat", ",", 
        RowBox[{"vec", "[", "x", "]"}]}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"vec", "[", "x", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472204597494828*^9, 3.472204630533987*^9}, 
   3.472205030734804*^9, {3.472205648847881*^9, 3.472205664155337*^9}, 
   3.472205816737635*^9, 3.472219959594338*^9, {3.47222033750598*^9, 
   3.472220359985274*^9}, {3.472220924996144*^9, 3.47222092914293*^9}},
 CellLabel->"In[32]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"vec", "[", "x", "]"}], "/.", "%"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "2", "]"}], "\[Rule]", "u"}], ",", 
     RowBox[{
      RowBox[{"x", "[", "3", "]"}], "\[Rule]", " ", "v"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.472220525271619*^9, 3.472220540414381*^9}, {
  3.47222058360435*^9, 3.472220610355568*^9}, {3.472220653595006*^9, 
  3.472220733352383*^9}},
 CellLabel->"In[94]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"ff", "[", 
    RowBox[{"u", ",", "v"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472220759152766*^9, 3.472220823588815*^9}, {
   3.47222112131459*^9, 3.472221137583388*^9}, 3.473153849046875*^9},
 CellLabel->"In[95]:="],

Cell["\<\
Evaluate the last three input cells several times!  The Module hplane works \
in any dimension, e.g. in the plane, where it defines the line through two \
pints:\
\>", "Text",
 CellChangeTimes->{{3.472221277237351*^9, 3.472221301770241*^9}, {
  3.472222611417848*^9, 3.472222676385394*^9}, {3.472223300771154*^9, 
  3.472223334075244*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"dim", " ", "=", " ", "2"}], ";", 
   RowBox[{"mat", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"randomv", "[", "]"}], ",", 
      RowBox[{"{", "dim", "}"}]}], "]"}]}], ";", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hplane", "[", 
       RowBox[{"mat", ",", 
        RowBox[{"vec", "[", "x", "]"}]}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"vec", "[", "x", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472204597494828*^9, 3.472204630533987*^9}, 
   3.472205030734804*^9, {3.472205648847881*^9, 3.472205664155337*^9}, 
   3.472205816737635*^9, 3.472219959594338*^9, {3.47222033750598*^9, 
   3.472220359985274*^9}, {3.472220924996144*^9, 3.47222092914293*^9}, {
   3.47222271535395*^9, 3.472222719581269*^9}},
 CellLabel->"In[72]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "1", "]"}], ",", 
      RowBox[{"x", "[", "2", "]"}]}], "}"}], "/.", "%"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "2", "]"}], ",", " ", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472222735838441*^9, 3.472222798065047*^9}, {
  3.472222867353033*^9, 3.47222289106291*^9}},
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"gga", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.472223208922248*^9, 3.472223228090897*^9}},
 CellLabel->"In[74]:="],

Cell[BoxData["mat"], "Input",
 CellChangeTimes->{{3.472223076348968*^9, 3.472223077372302*^9}},
 CellLabel->"In[75]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppa", " ", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", ".03", "]"}], ",", 
      RowBox[{"Point", "[", "mat", "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.47222295901915*^9, 3.472223058222384*^9}, 
   3.472223090824004*^9, {3.472223268619308*^9, 3.472223269665162*^9}, 
   3.472272453345689*^9, 3.472272498461809*^9},
 CellLabel->"In[76]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"gga", ",", "ppa"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472223105944655*^9, 3.472223117249906*^9}, {
  3.472223246058461*^9, 3.472223246584239*^9}},
 CellLabel->"In[77]:="],

Cell["\<\
In higher dimension we may solve the equation of the hyperplane. Of course, \
we don't have Graphics\
\>", "Text",
 CellChangeTimes->{{3.472223437661308*^9, 3.472223494145371*^9}, {
  3.473154028609375*^9, 3.47315403053125*^9}}],

Cell[BoxData[
 RowBox[{"?", "hplane"}]], "Input",
 CellChangeTimes->{{3.472272657312362*^9, 3.472272660041081*^9}},
 CellLabel->"In[80]:="],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"dim", " ", "=", " ", "5"}], ";", 
   RowBox[{"mat", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"randomv", "[", "]"}], ",", 
      RowBox[{"{", "dim", "}"}]}], "]"}]}], ";", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"hplane", "[", 
       RowBox[{"mat", ",", 
        RowBox[{"vec", "[", "x", "]"}]}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"vec", "[", "x", "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472204597494828*^9, 3.472204630533987*^9}, 
   3.472205030734804*^9, {3.472205648847881*^9, 3.472205664155337*^9}, 
   3.472205816737635*^9, 3.472219959594338*^9, {3.47222033750598*^9, 
   3.472220359985274*^9}, {3.472220924996144*^9, 3.47222092914293*^9}, {
   3.47222271535395*^9, 3.472222719581269*^9}, 3.472223381859611*^9},
 CellLabel->"In[78]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"hplane", "[", 
     RowBox[{"mat", ",", 
      RowBox[{"mat", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472272580159887*^9, 3.472272631689747*^9}},
 CellLabel->"In[79]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.472223503747454*^9, 3.472223506912937*^9}},
 CellLabel->"In[33]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{"t", "=", 
   RowBox[{
    RowBox[{"RandomReal", "[", "]"}], "*", "2", "*", "Pi"}]}], ";", " ", 
  RowBox[{"mat", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"null", "[", "]"}], ",", 
     RowBox[{"stb", "[", "1", "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"stb", "[", "2", "]"}], "*", 
       RowBox[{"Cos", "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"stb", "[", "3", "]"}], "*", 
       RowBox[{"Sin", "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"par", "[", "m_", "]"}], "[", 
    RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"m", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "  ", "+", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"m", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "-", " ", 
       RowBox[{"m", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "*", "u"}], "+", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"m", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "-", " ", 
       RowBox[{"m", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "*", "v"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"par", "[", "mat", "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]}], "Input",
 CellChangeTimes->{{3.472204597494828*^9, 3.472204630533987*^9}, 
   3.472205030734804*^9, {3.472205648847881*^9, 3.472205664155337*^9}, 
   3.472205816737635*^9, 3.472219959594338*^9, {3.47222033750598*^9, 
   3.472220359985274*^9}, {3.472220924996144*^9, 3.47222092914293*^9}, {
   3.47222271535395*^9, 3.472222719581269*^9}, 3.472223381859611*^9, {
   3.472273810197105*^9, 3.472273830264365*^9}, {3.472273864763093*^9, 
   3.472274173898777*^9}, {3.472274886972232*^9, 3.472274937627737*^9}, {
   3.472275049407364*^9, 3.472275141557819*^9}},
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", "1"}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"Opacity", "[", ".3", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472274192730447*^9, 3.472274273088239*^9}},
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"gga", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.472274305539039*^9, 3.47227431241532*^9}},
 CellLabel->"In[38]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ppa", " ", "=", " ", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
      RowBox[{"Point", "[", "mat", "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.472274320713414*^9, 3.472274395045196*^9}, 
   3.47227445244048*^9},
 CellLabel->"In[39]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"gga", ",", "ppa"}], "}"}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472274398832812*^9, 3.472274414552561*^9}, {
   3.472275555670968*^9, 3.472275576163493*^9}, 3.472275624806076*^9},
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{"Remove", "[", 
  RowBox[{"gga", ",", "ppa", ",", "mat"}], "]"}]], "Input",
 CellChangeTimes->{{3.472223510562029*^9, 3.472223544425758*^9}},
 CellLabel->"In[41]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2 Erhard Schmidt's orthogonalization", "Section",
 CellChangeTimes->{{3.473154079125*^9, 3.473154082515625*^9}, 
   3.47323493271875*^9},
 FontFamily->"Times",
 CellTags->"ortho"],

Cell[CellGroupData[{

Cell["Summary ", "Subsubsection",
 FontFamily->"Times"],

Cell["\<\
The orthogonalization procedure esorthonorm  is contained in the package \
euvec.m. It follows Erhard Schmidt's orthogonalization, the only difference \
to which is that the given vector sequence m_List needs not to be linearly \
independent.  If a vector linearly depends on the foregoing vectors, \
esorthonorm generates the zero vector and eliminates it.  Like Erhard \
Schmidt's orthogonalization it is independant of the dimension; it may be \
applied to infinite dimensional spaces with a positive semidefinite scalar \
product, too. The numerical behavior of esorthonorm can be influenced by the \
option neglect, which sets the parameter of Chop.  We describe the Module \
esorthonorm in the first subsection. After some simple tests we apply it to \
find the Legendre polynomials. We compare the action of the function \
esorthonotm with the built-in function Orthogonalize. The last subsection is \
devoted to find an orthonormal basis of the orthogonal complement of a \
subspace of a finite dimensional Euclidean vector space.\
\>", "Text",
 CellChangeTimes->{
  3.472971846109375*^9, {3.473917302625*^9, 3.47391735815625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.1 The procedure esorthonorm", "Subsection",
 FontFamily->"Times",
 FontSize->14],

Cell[BoxData[
 RowBox[{"?", "esorthonorm"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[55]:="],

Cell[BoxData[
 RowBox[{"Options", "[", "esorthonorm", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[56]:="],

Cell["\<\
The first option fixes the scalar product under consideration:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "innerprod"}]], "Input",
 CellLabel->"In[57]:="],

Cell["\<\
The default scalar product Dot may be replaced by some other, see e.g. the \
next subsection 2.2.
Remark.  pssp is an indefinite scalar product in a pseudo-Euclidean vector \
space; orthonorm is an orthogonalization in this case, see the package \
pseuvec.m (not relevant for the actual notebook).\
\>", "Text",
 CellChangeTimes->{3.472971846171875*^9}],

Cell[BoxData[
 RowBox[{"?", "normed"}]], "Input",
 CellLabel->"In[58]:="],

Cell[BoxData[
 RowBox[{"?", "print"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[59]:="],

Cell["\<\
If print is set print = True, the output of the vectors is done by\
\>", "Text",
 CellChangeTimes->{3.473225993*^9}],

Cell[BoxData[
 RowBox[{"?", "Print"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[60]:="],

Cell[BoxData[
 RowBox[{"?", "neglect"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[61]:="],

Cell["neglect rules the behavior of", "Text"],

Cell[BoxData[
 RowBox[{"?", "Chop"}]], "Input",
 CellLabel->"In[72]:="],

Cell["\<\
WARNING: Because of the partly numerical character of the procedure, an \
inappropriate setting of the option neglect may cause false results. One \
always should control the result of esorthonorm checking the orthogonality \
and completeness of the produced sequence!\
\>", "Text"],

Cell["\<\
The following definition of esorthonorm is contained in the package euvec.m:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"esorthonorm", "[", 
    RowBox[{"m_List", ",", "opts___"}], "]"}], " ", ":=", " ", "\n", "  ", 
   RowBox[{"Module", "[", "\n", "\t\t", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ma", "=", " ", "m"}], ",", 
       RowBox[{"mb", "=", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"k", " ", "=", " ", 
        RowBox[{"Length", "[", "m", "]"}]}], ",", 
       RowBox[{"rd", "=", 
        RowBox[{"Length", "[", "m", "]"}]}], ",", " ", 
       RowBox[{"j", " ", "=", " ", "0"}], ",", " ", "i", ",", "ne", ",", 
       "prod", ",", " ", "pr", ",", " ", "bn", ",", " ", "sm", ",", "aus", 
       ",", " ", "h", ",", " ", "f"}], "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"prod", ",", "nor", ",", "pr", ",", " ", "bn"}], "}"}], " ", 
       "=", " ", "\n", "\t\t\t", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "innerprod", ",", "normed", ",", " ", "print", ",", " ", 
           "neglect"}], "}"}], "/.", 
         RowBox[{"{", "opts", "}"}]}], "/.", 
        RowBox[{"Options", "[", "esorthonorm", "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", 
          RowBox[{"m", "[", 
           RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "\[Equal]", " ", 
         "List"}], ",", 
        RowBox[{"rd", " ", "=", " ", 
         RowBox[{"Length", "[", 
          RowBox[{"m", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"h_", ",", 
         RowBox[{"bn_:", "-", "10"}]}], "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"bn", "\[Equal]", "0"}], ",", "h", ",", 
         RowBox[{"Chop", "[", 
          RowBox[{"h", ",", 
           RowBox[{"10", "^", "bn"}]}], "]"}]}], "]"}]}], ";", "\n", "\t", 
      RowBox[{
       RowBox[{"sm", "[", "aus_", "]"}], " ", ":=", " ", 
       RowBox[{"MapAll", "[", 
        RowBox[{"f", ",", "aus"}], "]"}]}], ";", "\n", "\t\t", 
      RowBox[{"Label", "[", "ne", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "mb", "]"}], "\[GreaterEqual]", " ", 
         RowBox[{"Min", "[", 
          RowBox[{"rd", ",", "k"}], "]"}]}], ",", " ", 
        RowBox[{"Return", "[", "mb", "]"}]}], "]"}], ";", "\n", "\t\t", 
      RowBox[{"j", " ", "=", " ", 
       RowBox[{"j", "+", "1"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"j", ">", "k"}], ",", 
        RowBox[{"Return", "[", "mb", "]"}]}], "]"}], ";", "\n", "\t\t\t", 
      RowBox[{
       RowBox[{"ma", "[", 
        RowBox[{"[", "j", "]"}], "]"}], "=", 
       RowBox[{"sm", "[", 
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"ma", "[", 
           RowBox[{"[", "j", "]"}], "]"}], " ", "-", "\n", "\t", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"mb", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "*", 
             RowBox[{
              RowBox[{"prod", "[", 
               RowBox[{
                RowBox[{"ma", "[", 
                 RowBox[{"[", "j", "]"}], "]"}], ",", " ", 
                RowBox[{"mb", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "/", 
              RowBox[{"prod", "[", 
               RowBox[{
                RowBox[{"mb", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
                RowBox[{"mb", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}]}], ",", " ", "\n", 
            "\t", 
            RowBox[{"{", 
             RowBox[{"i", ",", "1", ",", " ", 
              RowBox[{"Length", "[", "mb", "]"}]}], "}"}]}], "]"}]}], "]"}], 
        "]"}]}], ";", " \t\t", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"pr", " ", "==", "True"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"ma", "[", 
          RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "]"}], ";", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"prod", "[", 
          RowBox[{
           RowBox[{"ma", "[", 
            RowBox[{"[", "j", "]"}], "]"}], ",", " ", 
           RowBox[{"ma", "[", 
            RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "==", " ", "0"}], ",", 
        RowBox[{"Goto", "[", "ne", "]"}], ",", "\n", "        ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"nor", " ", "==", " ", "True"}], ",", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"mb", ",", 
            RowBox[{"sm", "[", 
             RowBox[{"Simplify", "[", 
              RowBox[{
               RowBox[{"ma", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "/", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"prod", "[", 
                 RowBox[{
                  RowBox[{"ma", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], ",", 
                  RowBox[{"ma", "[", 
                   RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}]}], "]"}], 
             "]"}]}], "]"}], ",", "\n", "\t\t\t\t", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"mb", ",", 
            RowBox[{"Simplify", "[", 
             RowBox[{"ma", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "]"}]}], "]"}], ",", 
        "\n", "\t\t\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"nor", " ", "==", "True"}], ",", "\n", "\t", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"mb", ",", 
            RowBox[{"sm", "[", 
             RowBox[{"Simplify", "[", 
              RowBox[{
               RowBox[{"ma", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "/", 
               RowBox[{"Sqrt", "[", 
                RowBox[{"prod", "[", 
                 RowBox[{
                  RowBox[{"ma", "[", 
                   RowBox[{"[", "j", "]"}], "]"}], ",", 
                  RowBox[{"ma", "[", 
                   RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "]"}]}], "]"}], 
             "]"}]}], "]"}], ",", " \t\t\t", "\n", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"mb", ",", 
            RowBox[{"Simplify", "[", 
             RowBox[{"ma", "[", 
              RowBox[{"[", "j", "]"}], "]"}], "]"}]}], "]"}]}], "]"}]}], 
       "]"}], ";", "\t\t", "\n", "\t\t", 
      RowBox[{"Goto", "[", "ne", "]"}]}]}], "]"}]}], "\n"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.4732252569375*^9, 3.47322526275*^9}},
 FontFamily->"Times",
 CellLabel->"In[18]:="],

Cell[CellGroupData[{

Cell[" Simple tests", "Subsubsection",
 FontFamily->"Times"],

Cell["First we give some simple examples.", "Text"],

Cell[BoxData[
 RowBox[{"esorthonorm", "[", 
  RowBox[{"{", 
   RowBox[{"null", "[", "]"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[33]:="],

Cell[BoxData[
 RowBox[{"esorthonorm", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"stb", "[", "i", "]"}], "*", "i"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "dim"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"print", " ", "->", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{3.473225432046875*^9},
 FontFamily->"Times",
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"esorthonorm", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"stb", "[", "i", "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"i", "-", "1"}], ")"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "dim"}], "}"}]}], "]"}], ",", 
   RowBox[{"normed", " ", "->", " ", "False"}], ",", 
   RowBox[{"print", " ", "->", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{3.4732254446875*^9},
 FontFamily->"Times",
 CellLabel->"In[35]:="],

Cell["Linearly dependent vectors are omitted:", "Text"],

Cell[BoxData[
 RowBox[{"at", " ", "=", 
  RowBox[{"AppendTo", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"randomv", "[", "]"}], "*", 
       RowBox[{"(", 
        RowBox[{"j", "-", "2"}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "7"}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"null", "[", "]"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[63]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellLabel->"In[64]:="],

Cell["neglect -> 0 amd neglect -> default give the same results:", "Text"],

Cell[BoxData[
 RowBox[{"ot1", "=", 
  RowBox[{"esorthonorm", "[", 
   RowBox[{"at", ",", 
    RowBox[{"print", " ", "->", " ", "True"}], ",", 
    RowBox[{"neglect", " ", "->", " ", "0"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[65]:="],

Cell["", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ot1", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ".", 
     RowBox[{"ot1", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "ot1", "]"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "ot1", "]"}]}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.473226981234375*^9, 3.47322699946875*^9}, {
  3.4732270855*^9, 3.47322711490625*^9}},
 FontFamily->"Times",
 CellLabel->"In[78]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[79]:="],

Cell[BoxData[
 RowBox[{"ot2", "=", 
  RowBox[{"esorthonorm", "[", 
   RowBox[{"at", ",", 
    RowBox[{"print", " ", "->", " ", "True"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[80]:="],

Cell[BoxData[
 RowBox[{"ot2", "-", "ot1"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[81]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.4732265791875*^9, 3.473226587984375*^9}},
 CellLabel->"In[82]:="],

Cell["\<\
Also with normed -> False (and neglect -> 0) one gets the same results.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"at", " ", "=", 
  RowBox[{"AppendTo", "[", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"randomv", "[", "]"}], "*", 
       RowBox[{"(", 
        RowBox[{"j", "-", "2"}], ")"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "7"}], "}"}]}], "]"}], ",", " ", 
    RowBox[{"null", "[", "]"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[83]:="],

Cell[BoxData[
 RowBox[{"ot3", "=", 
  RowBox[{"esorthonorm", "[", 
   RowBox[{"at", ",", 
    RowBox[{"normed", " ", "->", " ", "False"}], ",", " ", 
    RowBox[{"print", " ", "->", " ", "True"}], ",", 
    RowBox[{"neglect", " ", "->", " ", "0"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[84]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ot3", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ".", 
     RowBox[{"ot3", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "ot3", "]"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "ot3", "]"}]}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.47322723246875*^9, 3.47322724334375*^9}},
 FontFamily->"Times",
 CellLabel->"In[85]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[86]:="],

Cell["Now again with the default value of neglect:", "Text"],

Cell[BoxData[
 RowBox[{"ot4", "=", 
  RowBox[{"esorthonorm", "[", 
   RowBox[{"at", ",", 
    RowBox[{"normed", " ", "->", " ", "False"}], ",", " ", 
    RowBox[{"print", " ", "->", " ", "True"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[90]:="],

Cell[BoxData[
 RowBox[{"ot3", "-", "ot4"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[91]:="],

Cell[BoxData[
 RowBox[{"ot5", "=", 
  RowBox[{"esorthonorm", "[", "at", "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[92]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ot5", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ".", 
     RowBox[{"ot5", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", 
      RowBox[{"Length", "[", "ot5", "]"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"Length", "[", "ot5", "]"}]}], "}"}]}], "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.47322737359375*^9, 3.473227389203125*^9}},
 FontFamily->"Times",
 CellLabel->"In[93]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Chop", "[", "%", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.47322741875*^9, 3.473227425765625*^9}},
 FontFamily->"Times",
 CellLabel->"In[94]:="],

Cell[BoxData[
 RowBox[{"Remove", "[", 
  RowBox[{"at", ",", "ot1", ",", "ot2", ",", "ot3", ",", "ot4", ",", "ot5"}], 
  "]"}]], "Input",
 CellLabel->"In[95]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
 2.2 The Legendre polynomials  generated by esorthonorm and by Orthogonalize\
\>", "Subsection",
 CellChangeTimes->{{3.472285599465363*^9, 3.472285605461839*^9}, {
  3.473227459546875*^9, 3.473227462203125*^9}},
 FontFamily->"Times",
 FontSize->14],

Cell["\<\
The procedure esorthonorm  may be applied also to function spaces, for which \
a positive semidefinite scalar product must be defined in terms of \
Mathematica.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"prodint", "[", 
   RowBox[{"f_", ",", "g_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"f", "*", "g"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", " ", 
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[33]:="],

Cell[BoxData[
 RowBox[{"prodint", "[", 
  RowBox[{"1", ",", 
   RowBox[{"x", "^", "2"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"seq", "[", "h_", "]"}], " ", ":=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"x", "^", "i"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "h"}], "}"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"seq", "[", "3", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[36]:="],

Cell[BoxData[
 RowBox[{"esorthonorm", "[", 
  RowBox[{
   RowBox[{"seq", "[", "7", "]"}], ",", " ", 
   RowBox[{"innerprod", " ", "->", " ", "prodint"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[37]:="],

Cell[TextData[{
 StyleBox["In Mathematica",
  FontSlant->"Italic"],
 " 7.0 under Windows XP esorthonorm needed 17 s for the next \
orthonormalization, "
}], "Text",
 CellChangeTimes->{{3.472282334744776*^9, 3.47228241063382*^9}, {
  3.47322780803125*^9, 3.473227879734375*^9}, {3.473229925125*^9, 
  3.473229936140625*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"esorthonorm", "[", 
   RowBox[{
    RowBox[{"seq", "[", "15", "]"}], ",", " ", 
    RowBox[{"innerprod", " ", "->", " ", "prodint"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.473227742046875*^9},
 FontFamily->"Times",
 CellLabel->"In[38]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[39]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"eslegpol15", " ", "=", " ", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4732279085*^9, 3.47322791040625*^9}},
 FontFamily->"Times",
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"prodint", "[", 
     RowBox[{
      RowBox[{"eslegpol15", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{"eslegpol15", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "16"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "16"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.473227928375*^9, 3.47322794946875*^9}},
 FontFamily->"Times",
 CellLabel->"In[105]:="],

Cell[TextData[{
 "We tried the same with GramSchmidt, a procedure defined in the standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "  v. 4.2 package"
}], "Text",
 CellChangeTimes->{{3.472802410333857*^9, 3.472802419892443*^9}, {
  3.473228039796875*^9, 3.473228040734375*^9}}],

Cell[BoxData[
 RowBox[{"<<", "\"\<LinearAlgebra/Orthogonalization.m\>\""}]], "Input",
 FontFamily->"Times",
 FontSize->15,
 CellLabel->"In[106]:="],

Cell[BoxData[
 RowBox[{"?", "GramSchmidt"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[107]:="],

Cell["\<\
The function Orthogonalize has now been added to the Mathematica kernel. \
\>", "Text",
 CellChangeTimes->{{3.472802731337487*^9, 3.472802752001766*^9}, 
   3.47322807828125*^9}],

Cell[BoxData[
 RowBox[{"?", "Orthogonalize"}]], "Input",
 CellChangeTimes->{{3.472284678630474*^9, 3.472284687789013*^9}},
 CellLabel->"In[108]:="],

Cell[BoxData[
 RowBox[{"Options", "[", "Orthogonalize", "]"}]], "Input",
 CellChangeTimes->{{3.472284628525841*^9, 3.472284646356142*^9}},
 FontFamily->"Times",
 CellLabel->"In[109]:="],

Cell["\<\
Orthogonalize applied to the polynomials generates very large, unsimplified \
Output. Composed with Simplify it generates the same sequence as esorthonorm \
very fast, it needs 4 s  only  for the same orthonormalization:\
\>", "Text",
 CellChangeTimes->{{3.472284942259459*^9, 3.472284966010533*^9}, {
   3.473228355734375*^9, 3.473228371984375*^9}, 3.47323018140625*^9, {
   3.473230216953125*^9, 3.47323033053125*^9}, {3.473230360890625*^9, 
   3.473230450296875*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Orthogonalize", "[", 
    RowBox[{
     RowBox[{"seq", "[", "15", "]"}], ",", " ", "prodint"}], "]"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.472284748260453*^9, 3.472284770863342*^9}, 
   3.47322811465625*^9, {3.47322920334375*^9, 3.4732292160625*^9}},
 FontFamily->"Times",
 CellLabel->"In[42]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ortho15", " ", "=", " ", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.472285076840196*^9, 3.47228508993863*^9}, 
   3.472285152417131*^9, 3.47322816615625*^9},
 CellLabel->"In[44]:="],

Cell[BoxData[
 RowBox[{"ortho15", "-", "eslegpol15"}]], "Input",
 CellChangeTimes->{{3.473228270875*^9, 3.473228281171875*^9}, {
  3.473230481578125*^9, 3.473230529265625*^9}},
 CellLabel->"In[50]:="],

Cell[CellGroupData[{

Cell["Comparison with the implemented LegendreP", "Subsubsection",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{"?", "LegendreP"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[51]:="],

Cell[TextData[{
 "The functions LegendreP implemented in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " are normed by the condition"
}], "Text"],

Cell[BoxData[
 RowBox[{"LegendreP", "[", 
  RowBox[{"_", ",", "1"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[52]:="],

Cell["\<\
Thus they are orthogonal but not normed with respect to prodint:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"legpol", "[", "k_", "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"LegendreP", "[", 
     RowBox[{"j", ",", "x"}], "]"}], ",", " ", 
    RowBox[{"{", " ", 
     RowBox[{"j", ",", "0", ",", "k"}], "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.47323078515625*^9, 3.473230823765625*^9}},
 FontFamily->"Times",
 CellLabel->"In[53]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"prodint", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"legpol", "[", "15", "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ",", 
      RowBox[{
       RowBox[{"legpol", "[", "15", "]"}], "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "16"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "16"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.47323083859375*^9, 3.473230878453125*^9}},
 FontFamily->"Times",
 CellLabel->"In[54]:="],

Cell[BoxData[
 RowBox[{"LegendreP", "[", 
  RowBox[{"15", ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.4732309611875*^9, 3.473230962046875*^9}},
 FontFamily->"Times",
 CellLabel->"In[55]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"eslegpol15", "[", 
   RowBox[{"[", "16", "]"}], "]"}], "/.", 
  RowBox[{"x", "\[Rule]", "1"}]}]], "Input",
 CellChangeTimes->{{3.473230978859375*^9, 3.473231009671875*^9}},
 FontFamily->"Times",
 CellLabel->"In[56]:="],

Cell["\<\
Up to the norming they coincide with the orthonormal polynomials obtained by \
esorthonorm or Orthogonalize:\
\>", "Text",
 CellChangeTimes->{{3.47323103496875*^9, 3.4732310441875*^9}}],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"LegendreP", "[", 
      RowBox[{"i", ",", "x"}], "]"}], "-", 
     RowBox[{
      RowBox[{"eslegpol15", "[", 
       RowBox[{"[", 
        RowBox[{"i", "+", "1"}], "]"}], "]"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"eslegpol15", "[", 
         RowBox[{"[", 
          RowBox[{"i", "+", "1"}], "]"}], "]"}], "/.", 
        RowBox[{"x", "\[Rule]", "1"}]}], ")"}]}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "15"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4732310725625*^9, 3.473231129140625*^9}},
 FontFamily->"Times",
 CellLabel->"In[57]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3  The Euclidean orthogonal complement", "Subsection",
 Evaluatable->False,
 FontFamily->"Times",
 FontSize->14],

Cell["\<\
For a given list of  vectors of a finite dimensional vector space the \
following Module yields an orthonormal basis of the orthogonal complement of \
the span of the vectors\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"?", "orthocomplement"}]], "Input",
 CellLabel->"In[33]:="],

Cell["The definition is given in euvec.m as ", "Text",
 CellChangeTimes->{{3.47323486596875*^9, 3.47323488925*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"orthocomplement", "[", 
   RowBox[{"v_List", ",", "opts___"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ve", "=", " ", "v"}], ",", "d", ",", " ", "veo", ",", "rk", 
      ",", "bas", ",", " ", "vm", ",", "vef", ",", "veff", ",", "i"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"Not", "[", 
        RowBox[{"MatrixQ", "[", "ve", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<Incorrect argument!\>\"", "]"}], ";", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"d", "=", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"ve", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"veo", "=", 
      RowBox[{"esorthonorm", "[", 
       RowBox[{"ve", ",", "opts"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rk", " ", "=", " ", 
      RowBox[{"Length", "[", "veo", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"bas", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"stb", "[", 
         RowBox[{"i", ",", "d"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "d"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vm", "  ", "=", " ", 
      RowBox[{"Join", "[", 
       RowBox[{"veo", ",", "bas"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"vef", " ", "=", " ", 
      RowBox[{"esorthonorm", "[", 
       RowBox[{"vm", ",", " ", "opts"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"veff", " ", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"vef", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"rk", "+", "1"}], ",", "d"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", "veff", "]"}]}]}], "]"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.473232891734375*^9, 3.473232975875*^9}, {
   3.47323301778125*^9, 3.4732330756875*^9}, {3.473233141203125*^9, 
   3.473233195359375*^9}, {3.473233262140625*^9, 3.47323327753125*^9}, {
   3.473233333515625*^9, 3.473233371640625*^9}, 3.473234272453125*^9},
 CellLabel->"In[73]:="],

Cell[CellGroupData[{

Cell["Tests", "Subsubsection"],

Cell[BoxData["dim"], "Input",
 CellChangeTimes->{{3.4722889320687*^9, 3.47228893256308*^9}},
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", "3", "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"4", ",", "5"}], "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.473233451484375*^9, 3.47323427246875*^9},
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"{", "}"}], "]"}]], "Input",
 CellChangeTimes->{3.47323346275*^9, 3.47323427246875*^9},
 CellLabel->"In[36]:="],

Cell["The standard basis is generated by ", "Text",
 CellChangeTimes->{{3.473231282546875*^9, 3.47323134071875*^9}}],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"{", 
   RowBox[{"null", "[", "]"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.473231245890625*^9, 3.473231257953125*^9}, 
   3.473233489375*^9, 3.47323427246875*^9},
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", "3", "]"}], ",", 
    RowBox[{"Cos", "[", "2", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.47323349734375*^9, 3.473234272484375*^9},
 CellLabel->"In[38]:="],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47323209309375*^9, 3.473232125546875*^9}, 
   3.473233508953125*^9, 3.473234272484375*^9},
 CellLabel->"In[39]:="],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", "3", "]"}], ",", 
    RowBox[{"stb", "[", "2", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.473233519765625*^9, 3.473234272484375*^9},
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{"v1", "=", 
  RowBox[{"randomv", "[", "]"}]}]], "Input",
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{"v2", "=", 
  RowBox[{"randomv", "[", "]"}]}]], "Input",
 CellLabel->"In[42]:="],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"{", 
   RowBox[{"v1", ",", "v2"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.473233544609375*^9, 3.4732342725*^9},
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", "i", "]"}], "]"}], ".", 
    RowBox[{"%", "[", 
     RowBox[{"[", "j", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", 
     RowBox[{"Length", "[", "%", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", 
     RowBox[{"Length", "[", "%", "]"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[44]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", "%", "]"}]], "Input",
 CellLabel->"In[45]:="],

Cell[BoxData[
 RowBox[{"v1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Cos", "[", "t", "]"}], ",", " ", 
    RowBox[{"Sin", "[", "t", "]"}], ",", "0", ",", "0"}], "}"}]}]], "Input",
 CellLabel->"In[46]:="],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"{", 
   RowBox[{"v1", ",", 
    RowBox[{"stb", "[", "3", "]"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.473233580265625*^9, 3.4732342725*^9},
 CellLabel->"In[47]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"t", "\[Element]", "Reals"}]}], "]"}]], "Input",
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", "%", "]"}]], "Input",
 CellChangeTimes->{3.47323363646875*^9, 3.473233677046875*^9, 3.4732342725*^9},
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{"rtt", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"randomv", "[", "7", "]"}], ",", 
    RowBox[{"{", "6", "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[50]:="],

Cell[BoxData[
 RowBox[{"esorthonorm", "[", "rtt", "]"}]], "Input",
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"rtt", ",", " ", 
   RowBox[{"print", " ", "\[Rule]", " ", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{3.4732337645625*^9, 3.473234272515625*^9},
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "[", 
   RowBox[{"[", "1", "]"}], "]"}], ".", 
  RowBox[{"%", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellLabel->"In[53]:="],

Cell["\<\
Of course, here we have the usual unexactness caused by the numerical \
calculations:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"%%", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ".", 
    RowBox[{"rtt", "[", 
     RowBox[{"[", "i", "]"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "6"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[54]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", "%", "]"}]], "Input",
 CellLabel->"In[55]:="],

Cell[BoxData[
 RowBox[{"Remove", "[", 
  RowBox[{"v1", ",", "v2", ",", "rtt"}], "]"}]], "Input",
 CellLabel->"In[56]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Finding an orthonormal basis of an arbitrary positive definite scalar product\
\>", "Subsubsection"],

Cell["\<\
The orthocomplement of the null space null[] is the whole vector space; thus \
orthocomplement yields an orthonormal basis.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{"{", 
   RowBox[{"null", "[", "]"}], "}"}], "]"}]], "Input",
 CellLabel->"In[57]:="],

Cell["\<\
Let us construct a random scalar product. We start with the random matrix\
\>", "Text"],

Cell[BoxData[
 RowBox[{"rtt", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"randomv", "[", "]"}], ",", 
    RowBox[{"{", "4", "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[58]:="],

Cell["wich is with probability 1 non degenerated:", "Text"],

Cell[BoxData[
 RowBox[{"Det", "[", "%", "]"}]], "Input",
 CellLabel->"In[59]:="],

Cell["The matrix", "Text"],

Cell[BoxData[
 RowBox[{"gg", "=", 
  RowBox[{"rtt", ".", 
   RowBox[{"Transpose", "[", "rtt", "]"}]}]}]], "Input",
 CellLabel->"In[60]:="],

Cell["is symmetric", "Text"],

Cell[BoxData[
 RowBox[{"gg", "//", "MatrixForm"}]], "Input",
 CellLabel->"In[61]:="],

Cell["and has positive eigenvalues only:", "Text"],

Cell[BoxData[
 RowBox[{"Eigenvalues", "[", "gg", "]"}]], "Input",
 CellLabel->"In[62]:="],

Cell["\<\
Thus, the new random scalar product must be positive definite:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"newdot", "[", 
   RowBox[{"x_List", ",", "y_List"}], "]"}], ":=", " ", 
  RowBox[{"x", ".", "gg", ".", "y"}]}]], "Input",
 CellLabel->"In[63]:="],

Cell[BoxData[
 RowBox[{"newdot", "[", 
  RowBox[{
   RowBox[{"vec", "[", "x", "]"}], ",", 
   RowBox[{"vec", "[", "y", "]"}]}], "]"}]], "Input",
 CellLabel->"In[64]:="],

Cell["\<\
Applying orthocomplement with respect to newdot, we find an \
newdot-orthonormal basis:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"orthocomplement", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"null", "[", "]"}], "}"}], ",", 
   RowBox[{"innerprod", " ", "\[Rule]", "newdot"}]}], "]"}]], "Input",
 CellChangeTimes->{3.473233924453125*^9, 3.473234272515625*^9},
 CellLabel->"In[65]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ggbas", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472289405994386*^9},
 CellLabel->"In[66]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"newdot", "[", 
    RowBox[{
     RowBox[{"%", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"%", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[67]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Chop", "[", "%", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[68]:="],

Cell["\<\
Of course, this basis is not orthonormal with respect to Dot:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Dot", "[", 
    RowBox[{
     RowBox[{"ggbas", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"ggbas", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{"%", "//", "MatrixForm"}]], "Input",
 CellLabel->"In[70]:="],

Cell["The eigenvectors of gg form a Dot-orthonormal basis:", "Text"],

Cell[BoxData[
 RowBox[{"Eigenvectors", "[", "gg", "]"}]], "Input",
 CellLabel->"In[71]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dotgg", " ", "=", "%"}], ";"}]], "Input",
 CellLabel->"In[72]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Dot", "[", 
    RowBox[{
     RowBox[{"dotgg", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"dotgg", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", "%", "]"}]], "Input",
 CellLabel->"In[74]:="],

Cell["\<\
which is orthonormal, but not normalised with respect to newdot:\
\>", "Text",
 CellChangeTimes->{{3.472289471785173*^9, 3.472289476394383*^9}}],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"newdot", "[", 
    RowBox[{
     RowBox[{"dotgg", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ",", 
     RowBox[{"dotgg", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[75]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Chop", "[", "%", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[76]:="],

Cell["The diagonal elements coincide with the eigenvalues of gg:", "Text"],

Cell[BoxData[
 RowBox[{"Eigenvalues", "[", "gg", "]"}]], "Input",
 CellLabel->"In[77]:="],

Cell[BoxData[
 RowBox[{"Remove", "[", 
  RowBox[{"gg", ",", "newdot", ",", "ggbas", ",", "dotgg"}], "]"}]], "Input",
 CellLabel->"In[78]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3 Euclidean representations of spheres", "Section",
 CellChangeTimes->{{3.472289590965956*^9, 3.472289593549753*^9}, 
   3.47236630057928*^9, 3.47323493915625*^9, 3.47340044078125*^9},
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell["\<\
In 3.1 we recursively define a parameter representation of the n-dimensional \
unit sphere. Subsection 3.2 contains parameter representations for arbitrary \
hyperspheres, and, for n=3, plot commands for spheres or simple parts of \
them. Finally, in subsection 3, we construct modules for calculating center, \
radius and therewith the sphere through four points of the 3-space in general \
position.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "3.1 A parameter representation of the unit n-sphere ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "n"], TraditionalForm]]]
}], "Subsection",
 FontFamily->"Times",
 FontSize->14],

Cell["\<\
We define parameter representations for the unit vectors in subspaces of the \
d-dimensional Euclidean space:\
\>", "Text",
 CellChangeTimes->{3.47297184625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit1", "[", 
   RowBox[{"s_", ",", " ", 
    RowBox[{"d_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"1", ",", "d"}], "]"}], "*", 
    RowBox[{"Cos", "[", "s", "]"}]}], "+", " ", 
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"2", ",", "d"}], "]"}], "*", 
    RowBox[{"Sin", "[", "s", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 FontFamily->"Times",
 CellLabel->"In[10]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit2", "[", 
   RowBox[{"s_", ",", " ", "t_", ",", " ", 
    RowBox[{"d_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"unit1", "[", 
     RowBox[{"s", ",", " ", "d"}], "]"}], "*", 
    RowBox[{"Cos", "[", "t", "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"3", ",", "d"}], "]"}], "*", " ", 
    RowBox[{"Sin", "[", "t", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 FontFamily->"Times",
 CellLabel->"In[11]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit3", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_", ",", " ", 
    RowBox[{"d_:", "dim"}]}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"unit2", "[", 
     RowBox[{"s", ",", "t", ",", " ", "d"}], "]"}], "*", 
    RowBox[{"Cos", "[", "u", "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"4", ",", "d"}], "]"}], "*", " ", 
    RowBox[{"Sin", "[", "u", "]"}]}]}]}]], "Input",
 InitializationCell->True,
 FontFamily->"Times",
 CellLabel->"In[12]:="],

Cell[CellGroupData[{

Cell[TextData[{
 " A parameter representation of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "n"], TraditionalForm]]],
 ", recursive Definition"
}], "Subsubsection",
 FontFamily->"Times"],

Cell["\<\
The following recursive definition, contained in euvec.m,  yields the usual \
parameter representation of the unit n-sphere as a hypersurface in the \
(n+1)-dimensional Euclidean space. For n =1,2,3 it almost coincides with the \
definitions above. The parameters appear as the first n elements of the \
List-argument.\
\>", "Text",
 CellChangeTimes->{3.472971846328125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"unit", "[", "n_", "]"}], "[", "s_List", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"un", ",", "i"}], "}"}], ",", "\n", "\t\t", 
     RowBox[{
      RowBox[{
       RowBox[{"un", "[", "1", "]"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"s", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"s", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "}"}]}], ";", "\n", 
      "\t\t\t", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "2"}], ",", " ", 
        RowBox[{"i", "<=", " ", "n"}], ",", " ", 
        RowBox[{"i", "++"}], ",", "\n", "\t\t", 
        RowBox[{
         RowBox[{"un", "[", "i", "]"}], "=", 
         RowBox[{
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{
             RowBox[{"un", "[", 
              RowBox[{"i", "-", "1"}], "]"}], ",", "0"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"s", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"stb", "[", 
            RowBox[{
             RowBox[{"1", "+", "i"}], ",", 
             RowBox[{"i", "+", "1"}]}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"s", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "]"}]}]}]}]}], "]"}], ";", "\n", 
      "\t\t\t\t", 
      RowBox[{"Return", "[", 
       RowBox[{"un", "[", "n", "]"}], "]"}]}]}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", "s", "]"}], ">=", "n"}]}]}]], "Input",
 Evaluatable->False,
 FontFamily->"Times",
 CellLabel->"In[20]:="],

Cell[BoxData[
 RowBox[{"?", "unit"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[32]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit", "[", "2", "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[33]:="],

Cell["\<\
unit1,uni2,unit3 yield vectors of the fixed dimension d, completed with \
zeros, if necessary:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"unit2", "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"TrueQ", "[", 
  RowBox[{
   RowBox[{"unit2", "[", 
    RowBox[{"s", ",", "t", ",", "3"}], "]"}], " ", "==", 
   RowBox[{
    RowBox[{"unit", "[", "2", "]"}], "[", 
    RowBox[{"{", 
     RowBox[{"s", ",", "t"}], "}"}], "]"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit", "[", "3", "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[36]:="],

Cell[BoxData[
 RowBox[{"unit3", "[", 
  RowBox[{"s", ",", "t", ",", "u"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"unit", "[", 
  RowBox[{"vec", "[", "a", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472308981814056*^9, 3.472308991888198*^9}},
 CellLabel->"In[38]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit", "[", "4", "]"}], "[", 
  RowBox[{"vec", "[", "a", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[39]:="],

Cell[BoxData[
 RowBox[{"unit", "[", 
  RowBox[{"vec", "[", 
   RowBox[{"a", ",", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47230906806739*^9, 3.472309083427689*^9}},
 CellLabel->"In[40]:="],

Cell["\<\
If Length[s_List] > n only the first n components are considered:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"vec", "[", "a", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit", "[", "2", "]"}], "[", 
  RowBox[{"vec", "[", "a", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[42]:="],

Cell["If Length[s_List] < n the evaluation failes:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit", "[", "5", "]"}], "[", 
  RowBox[{"vec", "[", "a", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[43]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "3.2 The standard parameter representations of spheres in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " and of hyperspheres in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 " "
}], "Subsection",
 CellChangeTimes->{{3.472309195964369*^9, 3.472309199133124*^9}, 
   3.472361806829517*^9, 3.472971846390625*^9, {3.473343093359375*^9, 
   3.473343108*^9}, {3.473400500984375*^9, 3.473400502703125*^9}, {
   3.4734005814375*^9, 3.473400646328125*^9}, {3.47340067984375*^9, 
   3.47340072796875*^9}},
 FontFamily->"Times",
 FontSize->14],

Cell["\<\
The general sphere with radius r and center  m has the parameter \
representation with geographical coordinates u, v, defined in euvec.m:\
\>", "Text",
 CellChangeTimes->{3.473396492421875*^9}],

Cell[BoxData[
 RowBox[{"?", "sphere"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[153]:="],

Cell["\<\
sphere[m_List, r_][u_, v_] := {m[[1]] + r*Cos[u]*Cos[v], 
    m[[2]] + r*Cos[v]*Sin[u], m[[3]] + r*Sin[v]} /; Length[m] == 3\
\>", "Input",
 Evaluatable->False,
 FontFamily->"Times",
 CellLabel->"In[27]:="],

Cell["\<\
 Of course, the 2-spheres in the 3-space can directly be plotted; the sphere \
with center m and radius r (optionally a part of it)  is\
\>", "Text",
 CellChangeTimes->{3.4733964924375*^9}],

Cell[BoxData[
 RowBox[{"?", "sphereplot3D"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[32]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphereplot3D", "[", 
   RowBox[{"m_List", ",", " ", "r_", ",", " ", 
    RowBox[{"u0_:", "0"}], ",", " ", 
    RowBox[{"u1_:", "2", " ", "Pi"}], ",", 
    RowBox[{"v0_:", "-", 
     RowBox[{"Pi", "/", "2"}]}], ",", 
    RowBox[{"v1_:", 
     RowBox[{"Pi", "/", "2"}]}], ",", " ", "opt___"}], "]"}], " ", ":=", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sphere", "[", 
      RowBox[{"m", ",", "r"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "u0", ",", "u1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "v0", ",", "v1"}], "}"}], ",", "opt"}], 
   "]"}]}]], "Input",
 Evaluatable->False,
 FontFamily->"Times",
 CellLabel->"In[28]:="],

Cell["\<\
Using unit[n][s], one easily generalizes the definition of the parameter \
representation to the case of arbitrary n-spheres:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hypersphere", "[", 
    RowBox[{"m_List", ",", " ", "r_"}], "]"}], "[", "s_List", "]"}], " ", ":=",
   " ", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"di", " ", "=", " ", 
       RowBox[{
        RowBox[{"Length", "[", "m", "]"}], "-", "1"}]}], "}"}], ",", "\n", 
     "\t\t", 
     RowBox[{"m", " ", "+", " ", 
      RowBox[{"r", "*", 
       RowBox[{
        RowBox[{"unit", "[", "di", "]"}], "[", "s", "]"}]}]}]}], "]"}], "/;", 
   RowBox[{
    RowBox[{"Length", "[", "s", "]"}], "\[Equal]", 
    RowBox[{
     RowBox[{"Length", "[", "m", "]"}], "-", "1"}]}]}]}]], "Input",
 InitializationCell->True,
 FontFamily->"Times",
 CellLabel->"In[13]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"hypersphere", "::", "usage"}], " ", "=", 
   "\"\<hypersphere[mList,r][sList] is a parameter representation of a \
hypersphere with center mList, radius r and parameters sList in the \
n-dimensional Euclidean space, n= Length[m] = Length[s] +1.\>\""}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.472971846453125*^9},
 CellLabel->"In[14]:="],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere", "[", 
   RowBox[{
    RowBox[{"null", "[", "3", "]"}], ",", "1"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{"sphereplot3D", "[", 
  RowBox[{
   RowBox[{"null", "[", "3", "]"}], ",", "1", ",", "0", ",", 
   RowBox[{"2", "*", "Pi"}], ",", " ", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "2"}], ",", "0", ",", " ", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", "Red"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472361263244833*^9, 3.472361299983226*^9}, {
  3.472361340878655*^9, 3.472361397556032*^9}, {3.473343562796875*^9, 
  3.473343566125*^9}},
 FontFamily->"Times",
 CellLabel->"In[83]:="],

Cell[BoxData[
 RowBox[{"sphereplot3D", "[", 
  RowBox[{
   RowBox[{"null", "[", "3", "]"}], ",", "1", ",", "0", ",", 
   RowBox[{"Pi", "/", "2"}], ",", " ", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "2"}], ",", "0", ",", " ", 
   RowBox[{"PlotStyle", " ", "->", 
    RowBox[{"Opacity", "[", ".5", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472361263244833*^9, 3.472361299983226*^9}, {
   3.472361340878655*^9, 3.472361397556032*^9}, {3.472361429360517*^9, 
   3.472361480054761*^9}, {3.472361521667747*^9, 3.472361527673137*^9}, {
   3.472361559582869*^9, 3.472361564946021*^9}, 3.47334352490625*^9},
 FontFamily->"Times",
 CellLabel->"In[82]:="],

Cell[BoxData[
 RowBox[{"sphereplot3D", "[", 
  RowBox[{
   RowBox[{"null", "[", "3", "]"}], ",", "1", ",", "0", ",", 
   RowBox[{"Pi", "/", "2"}], ",", " ", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "4"}], ",", 
   RowBox[{"Pi", "/", "4"}], ",", " ", 
   RowBox[{"PlotStyle", " ", "->", 
    RowBox[{"Opacity", "[", ".2", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472361263244833*^9, 3.472361299983226*^9}, {
  3.472361340878655*^9, 3.472361397556032*^9}, {3.472361429360517*^9, 
  3.472361480054761*^9}, {3.472361521667747*^9, 3.472361527673137*^9}, {
  3.472361559582869*^9, 3.472361587357334*^9}, {3.472361625765902*^9, 
  3.472361642708814*^9}},
 FontFamily->"Times",
 CellLabel->"In[72]:="],

Cell[BoxData[
 RowBox[{"sphereplot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "5"}], "}"}], ",", " ", "2"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{"sphereplot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "5"}], "}"}], ",", " ", "2", ",", "0", ",", 
   " ", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[74]:="],

Cell[BoxData[
 RowBox[{"sphereplot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "5"}], "}"}], ",", " ", "2", ",", "0", ",", 
   RowBox[{"Pi", "/", "2"}], ",", "0", ",", 
   RowBox[{"Pi", "/", "2"}], ",", " ", 
   RowBox[{"Boxed", " ", "->", " ", "False"}], ",", 
   RowBox[{"Axes", " ", "->", " ", "False"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "30"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[75]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypersphere", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m1", ",", "m2"}], "}"}], ",", "r"}], "]"}], "[", 
  RowBox[{"{", "s", "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[76]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypersphere", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m1", ",", "m2", ",", "m3"}], "}"}], ",", "r"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"u", ",", "v"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[77]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"hypersphere", "[", 
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"1", ",", "4"}], "]"}], ",", " ", "r"}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"u", ",", "v", ",", "w"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[78]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3 Cirles in the Euclidean plane", "Subsection",
 CellChangeTimes->{{3.473343191265625*^9, 3.473343213*^9}}],

Cell["\<\
Here is the parameter representation of a circle with center m and radius r \
in the Euclidean plane:\
\>", "Text",
 CellChangeTimes->{{3.473342341515625*^9, 3.473342404703125*^9}, 
   3.47339649246875*^9, 3.47340055915625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"circle2D", "[", 
    RowBox[{"m_List", ",", "r_"}], "]"}], "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"m", "+", 
   RowBox[{"r", "*", 
    RowBox[{
     RowBox[{"unit", "[", "1", "]"}], "[", 
     RowBox[{"{", "t", "}"}], "]"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.473340275640625*^9, 3.47334037721875*^9}, {
  3.473340446390625*^9, 3.473340484265625*^9}},
 CellLabel->"In[15]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"circle2D", "[", 
   RowBox[{
    RowBox[{"vec", "[", 
     RowBox[{"m", ",", "2"}], "]"}], ",", "r"}], "]"}], "[", "t", 
  "]"}]], "Input",
 CellChangeTimes->{{3.47334038665625*^9, 3.473340410625*^9}},
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"circle2D", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"m", ",", "2"}], "]"}], ",", "r"}], "]"}], "[", "t", "]"}], " ",
   "\[Equal]", " ", 
  RowBox[{
   RowBox[{"hypersphere", "[", 
    RowBox[{
     RowBox[{"vec", "[", 
      RowBox[{"m", ",", "2"}], "]"}], ",", "r"}], "]"}], "[", 
   RowBox[{"{", "t", "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.47334334128125*^9, 3.473343409*^9}},
 CellLabel->"In[79]:="],

Cell["The next cell contains the corresponding plot function", "Text",
 CellChangeTimes->{{3.473342421703125*^9, 3.473342446140625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotcircle2D", "[", 
   RowBox[{"m_List", ",", "r_", ",", 
    RowBox[{"t0_:", "0"}], ",", 
    RowBox[{"t1_:", "2", "*", "Pi"}], ",", "opts___"}], "]"}], ":=", " ", 
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"circle2D", "[", 
      RowBox[{"m", ",", "r"}], "]"}], "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "t0", ",", "t1"}], "}"}], ",", "opts"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4733405328125*^9, 3.473340699390625*^9}, {
  3.4733407558125*^9, 3.473340765484375*^9}},
 CellLabel->"In[16]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"plotcircle2D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"1", "/", "i"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "10"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47334077265625*^9, 3.47334079465625*^9}, {
  3.4733409638125*^9, 3.473340994828125*^9}, {3.473341066*^9, 
  3.473341069296875*^9}, {3.47334200153125*^9, 3.47334208528125*^9}, {
  3.473342215046875*^9, 3.473342255*^9}},
 CellLabel->"In[80]:="],

Cell[BoxData[
 RowBox[{"plotcircle2D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1"}], "}"}], ",", "1", ",", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "4"}], ",", 
   RowBox[{"Pi", "/", "4"}], ",", " ", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", " ", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473342468921875*^9, 3.473342564546875*^9}},
 CellLabel->"In[81]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "3.4 Center and radius of the hypersphere  in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 " through n+1 points"
}], "Subsection",
 CellChangeTimes->{{3.473396534484375*^9, 3.473396568328125*^9}, 
   3.473400491953125*^9, {3.473400819625*^9, 3.473400852890625*^9}, {
   3.473400884828125*^9, 3.473400903671875*^9}},
 FontFamily->"Times",
 FontSize->14],

Cell["\<\
We want to plot the sphere through four given points in the 3-space. First we \
calculate its center and radius of a hypersphere trough n+1 points  and then, \
in the case n= 3,  we apply sphereplot3D.\
\>", "Text",
 CellChangeTimes->{
  3.473396492484375*^9, {3.473396602546875*^9, 3.47339668434375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"center", "::", "usage"}], " ", "=", " ", 
   "\"\<center[pts] is the center of the hypersphere through n+1 points pts \
in the Euclidean n-space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.472971846484375*^9, {3.473396492484375*^9, 3.473396492484375*^9}, {
   3.473396704078125*^9, 3.473396723734375*^9}, {3.4733969065625*^9, 
   3.473396908328125*^9}},
 CellLabel->"In[17]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"center", "[", "pt_List", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", " ", "=", 
       RowBox[{"Length", "[", "pt", "]"}]}], ",", " ", "i", ",", "at", ",", 
      "ab", ",", "mat", ",", "d"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"p", "\[LessEqual]", " ", "1"}], "||", 
        RowBox[{"Not", "[", 
         RowBox[{"MatrixQ", "[", "pt", "]"}], "]"}], "||", 
        RowBox[{
         RowBox[{"Length", "[", 
          RowBox[{"pt", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "]"}], "\[NotEqual]", " ", 
         RowBox[{"p", "-", "1"}]}]}], ",", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<Incorrect argument!\>\"", "]"}], ";", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", " ", 
       RowBox[{"i", "<", "p"}], ",", " ", 
       RowBox[{"i", "++"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"at", "[", "i", "]"}], "=", 
         RowBox[{
          RowBox[{"pt", "[", 
           RowBox[{"[", 
            RowBox[{"i", "+", "1"}], "]"}], "]"}], "-", 
          RowBox[{"pt", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}], ";", "\n", "\t", 
        RowBox[{
         RowBox[{"ab", "[", "i", "]"}], "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"pt", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}], ".", 
              RowBox[{"pt", "[", 
               RowBox[{"[", 
                RowBox[{"i", "+", "1"}], "]"}], "]"}]}], ")"}], "-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"pt", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ".", 
              RowBox[{"pt", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}], ")"}], "/", 
          "2"}]}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"mat", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"at", "[", "j", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", 
          RowBox[{"p", "-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t", 
     RowBox[{"d", " ", "=", " ", 
      RowBox[{"Det", "[", "mat", "]"}]}], ";", "\n", "\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"d", "==", " ", "0."}], ",", " ", 
       RowBox[{
        RowBox[{
        "Print", "[", "\"\<Points are not in general position!\>\"", "]"}], 
        ";", " ", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"mb", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"ab", "[", "k", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", 
          RowBox[{"p", "-", "1"}]}], "}"}]}], "]"}]}], ";", "\n", "\t\t\t ", 
     RowBox[{"LinearSolve", "[", 
      RowBox[{"mat", ",", "mb"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.473345282171875*^9, 3.473345304140625*^9}, {
   3.473345436859375*^9, 3.473345795140625*^9}, {3.47334582634375*^9, 
   3.47334582825*^9}, {3.473345868*^9, 3.473345927390625*^9}, {
   3.4733460046875*^9, 3.473346016046875*^9}, {3.4733461179375*^9, 
   3.473346119015625*^9}, {3.473346167328125*^9, 3.473346206921875*^9}, {
   3.473346322828125*^9, 3.473346359375*^9}, {3.47334641190625*^9, 
   3.473346522046875*^9}, {3.473346571375*^9, 3.473346624546875*^9}, {
   3.473346666890625*^9, 3.473346670546875*^9}, 3.47334692484375*^9, {
   3.473396756578125*^9, 3.473396809734375*^9}},
 CellLabel->"In[18]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"radius", "[", "pt_List", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", " ", "=", 
      RowBox[{"center", "[", "pt", "]"}]}], "}"}], " ", ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"c", "\[Equal]", " ", "Null"}], ",", " ", 
       RowBox[{"Return", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"pt", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "c"}], ")"}], ".", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"pt", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "c"}], ")"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.473346685703125*^9, 3.4733466861875*^9}},
 FontFamily->"Times",
 CellLabel->"In[19]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"radius", "::", "usage"}], " ", "=", " ", 
   "\"\<radius[pts] is the radius of the hypersphere through n+1 points pts \
in the Euclidean n-space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.472971846515625*^9, {3.4733968763125*^9, 3.4733968978125*^9}},
 CellLabel->"In[20]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere4ptsplot3D", "[", 
   RowBox[{"p_List", ",", 
    RowBox[{"s0_:", "0"}], ",", " ", 
    RowBox[{"s1_:", "2", " ", "Pi"}], ",", 
    RowBox[{"t0_:", "-", 
     RowBox[{"Pi", "/", "2"}]}], ",", " ", 
    RowBox[{"t1_:", 
     RowBox[{"Pi", "/", "2"}]}], ",", " ", "opt___"}], "]"}], " ", ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "r"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"m", " ", "=", " ", 
      RowBox[{"center", "[", "p", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"m", " ", "\[Equal]", "Null"}], ",", " ", 
       RowBox[{"Return", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"r", " ", "=", " ", 
      RowBox[{"radius", "[", "p", "]"}]}], ";", "\n", "\t", 
     RowBox[{"sphereplot3D", "[", 
      RowBox[{
      "m", ",", "r", ",", "s0", ",", " ", "s1", ",", "t0", ",", " ", "t1", 
       ",", " ", "opt"}], "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.4733467600625*^9},
 FontFamily->"Times",
 CellLabel->"In[21]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sphere4ptsplot3D", "::", "usage"}], " ", "=", " ", 
   "\"\<sphere4ptsplot3D[pList,s0:0, s1:2 Pi,t0:-Pi/2, t1:Pi/2, opt] plots \
the sphere through four points in the Euclidean 3-space, or a section of it, \
using sphereplot3D.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.472971846546875*^9},
 CellLabel->"In[22]:="],

Cell[BoxData[
 RowBox[{"?", "sphereplot3D"}]], "Input",
 CellLabel->"In[32]:="],

Cell[CellGroupData[{

Cell["Examples, tests", "Subsubsection",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{"center", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", "2", "}"}], ",", 
    RowBox[{"{", "4", "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.473397086328125*^9, 3.473397114390625*^9}},
 CellLabel->"In[63]:="],

Cell[BoxData[
 RowBox[{"radius", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", "2", "}"}], ",", 
    RowBox[{"{", "4", "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.473397123828125*^9, 3.473397153046875*^9}},
 CellLabel->"In[64]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sqr", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.5", ",", " ", "1", ",", " ", "2."}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", " ", "1.5", ",", " ", "0.7"}], "}"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"2.", ",", " ", "1.", ",", " ", "0."}], "}"}], ",", " ", 
     RowBox[{"stb", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.472362316418058*^9},
 FontFamily->"Times",
 CellLabel->"In[33]:="],

Cell[BoxData[
 RowBox[{"cpt", " ", "=", 
  RowBox[{"center", "[", "sqr", "]"}]}]], "Input",
 CellChangeTimes->{{3.472362361724885*^9, 3.472362364144665*^9}, 
   3.47334676346875*^9, {3.473346834828125*^9, 3.473346844953125*^9}},
 FontFamily->"Times",
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cpt", "-", 
      RowBox[{"sqr", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{"cpt", "-", 
      RowBox[{"sqr", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"j", ",", "1", ",", "4"}], "}"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"radius", "[", "sqr", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[36]:="],

Cell[BoxData[
 RowBox[{"%", "^", "2"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"sphere4ptsplot3D", "[", 
  RowBox[{"sqr", ",", "0", ",", 
   RowBox[{"2", "*", "Pi"}], ",", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
   RowBox[{"Pi", "/", "2"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Opacity", "[", ".4", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472365524557648*^9, 3.472365590360447*^9}},
 FontFamily->"Times",
 CellLabel->"In[38]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"testgrtt", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472362449797284*^9},
 FontFamily->"Times",
 CellLabel->"In[39]:="],

Cell[BoxData["sqr"], "Input",
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{"grptts", "=", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
     RowBox[{"Point", "[", "sqr", "]"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.472365352381947*^9, 3.472365465824819*^9}},
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"testgrtt", ",", "grptts"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[42]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"testgrtt1", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472365628154979*^9},
 FontFamily->"Times",
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{"p2", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"null", "[", "3", "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"1", ",", "3"}], "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"2", ",", "3"}], "]"}], ",", " ", 
    RowBox[{"stb", "[", 
     RowBox[{"3", ",", "3"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{3.472365678673498*^9},
 FontFamily->"Times",
 CellLabel->"In[44]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"grp2", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
      RowBox[{"Point", "[", "p2", "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.472365352381947*^9, 3.472365465824819*^9}, {
  3.472365975122119*^9, 3.472366003040935*^9}},
 CellLabel->"In[45]:="],

Cell[BoxData[
 RowBox[{"cp2", " ", "=", 
  RowBox[{"center", "[", "p2", "]"}]}]], "Input",
 CellChangeTimes->{{3.472365706508296*^9, 3.472365709677209*^9}, 
   3.4733467646875*^9},
 FontFamily->"Times",
 CellLabel->"In[46]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"cp2", "-", 
      RowBox[{"p2", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{"cp2", "-", 
      RowBox[{"p2", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ")"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[47]:="],

Cell[BoxData[
 RowBox[{"radius", "[", "p2", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{"sphere4ptsplot3D", "[", 
  RowBox[{"p2", ",", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "4"}], ",", " ", 
   RowBox[{"5", "*", 
    RowBox[{"Pi", "/", "4"}]}], ",", " ", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
   RowBox[{"Pi", "/", "2"}], ",", " ", 
   RowBox[{"PlotPoints", "\[Rule]", " ", "40"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Opacity", "[", ".4", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472365772852033*^9, 3.472365788909597*^9}, {
  3.472366115906239*^9, 3.472366119928537*^9}, {3.472366155505719*^9, 
  3.472366165506112*^9}},
 FontFamily->"Times",
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"grp2", ",", "%"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472366030557749*^9, 3.472366044547312*^9}},
 CellLabel->"In[50]:="],

Cell["Error messages", "Text"],

Cell[BoxData[
 RowBox[{"sphere4ptsplot3D", "[", 
  RowBox[{"Take", "[", 
   RowBox[{"p2", ",", "2"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"p3", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"null", "[", "3", "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"1", ",", "3"}], "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"2", ",", "3"}], "]"}], ",", " ", 
    RowBox[{"2", "*", 
     RowBox[{"stb", "[", 
      RowBox[{"2", ",", "3"}], "]"}]}]}], "}"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{"center", "[", "p3", "]"}]], "Input",
 CellChangeTimes->{3.4733467656875*^9},
 FontFamily->"Times",
 CellLabel->"In[53]:="],

Cell[BoxData[
 RowBox[{"radius", "[", "p3", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[54]:="],

Cell[BoxData[
 RowBox[{"sphere4ptsplot3D", "[", "p3", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[55]:="],

Cell[BoxData[
 RowBox[{"Symbolic", " ", "calculations"}]], "Text",
 CellChangeTimes->{{3.473397209765625*^9, 3.473397274875*^9}}],

Cell[BoxData[
 RowBox[{"pts3", " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}], ",", 
    RowBox[{"vec", "[", 
     RowBox[{"x", ",", "2"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.47334711546875*^9, 3.473347191015625*^9}},
 CellLabel->"In[56]:="],

Cell[BoxData[
 RowBox[{"center", "[", "pts3", "]"}]], "Input",
 CellChangeTimes->{{3.4733472013125*^9, 3.473347209375*^9}},
 CellLabel->"In[57]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"pts3", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "-", "%"}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"pts3", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "-", "%"}], ")"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473347238375*^9, 3.473347311859375*^9}},
 CellLabel->"In[58]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.473347326578125*^9, 3.47334733575*^9}},
 CellLabel->"In[59]:="],

Cell[BoxData[
 RowBox[{"radius", "[", "pts3", "]"}]], "Input",
 CellChangeTimes->{{3.473347362765625*^9, 3.4733473775*^9}},
 CellLabel->"In[60]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "^", "2"}], "-", 
   RowBox[{"%%", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47334741453125*^9, 3.4733474591875*^9}},
 CellLabel->"In[61]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%%", "^", "2"}], "-", 
   RowBox[{"%%%", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47334741453125*^9, 3.47334751453125*^9}},
 CellLabel->"In[62]:="],

Cell["Randim points", "Text",
 CellChangeTimes->{{3.47339739884375*^9, 3.473397404859375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.473397417640625*^9, 3.47339743528125*^9}, 
   3.4733974926875*^9},
 CellLabel->"In[66]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"mat8", " ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"randomv", "[", "7", "]"}], ",", " ", 
     RowBox[{"{", "8", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4733974410625*^9, 3.473397521953125*^9}},
 CellLabel->"In[67]:="],

Cell[BoxData[
 RowBox[{"mat8", "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.4733975308125*^9, 3.47339753971875*^9}},
 CellLabel->"In[68]:="],

Cell[BoxData[
 RowBox[{"center", "[", "mat8", "]"}]], "Input",
 CellChangeTimes->{{3.47339755625*^9, 3.473397566890625*^9}},
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Norm", "[", 
    RowBox[{
     RowBox[{"mat8", "[", 
      RowBox[{"[", "i", "]"}], "]"}], "-", "%"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "8"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47339758003125*^9, 3.47339764659375*^9}},
 CellLabel->"In[70]:="],

Cell[BoxData[
 RowBox[{"radius", "[", "mat8", "]"}]], "Input",
 CellChangeTimes->{{3.47339767215625*^9, 3.473397680734375*^9}},
 CellLabel->"In[71]:="],

Cell["Plot circle through 3 points", "Text",
 CellChangeTimes->{{3.473397912890625*^9, 3.47339795565625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotcircle3pts", "[", 
   RowBox[{"m_List", ",", " ", 
    RowBox[{"t0_:", "0"}], ",", 
    RowBox[{"t1_:", "2", "*", "Pi"}], ",", "opts___"}], "]"}], ":=", 
  RowBox[{"plotcircle2D", "[", 
   RowBox[{
    RowBox[{"center", "[", "m", "]"}], ",", " ", 
    RowBox[{"radius", "[", "m", "]"}], ",", "t0", ",", "t1", ",", "opts"}], 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.47339796409375*^9, 3.473398153296875*^9}},
 CellLabel->"In[23]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"plotcircle3pts", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", ".03", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
   "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.473398176203125*^9, 3.473398260078125*^9}, {
  3.473398755*^9, 3.47339883196875*^9}, {3.473398865546875*^9, 
  3.473398958234375*^9}, {3.473399654140625*^9, 3.473399674796875*^9}, {
  3.473399773296875*^9, 3.473399784625*^9}},
 CellLabel->"In[108]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "pf2D", "]"}], ";", 
  RowBox[{
   RowBox[{"pf2D", "[", "m3_", "]"}], " ", ":=", 
   RowBox[{"Show", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"plotcircle3pts", "[", "m3", "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", ".03", "]"}], ",", 
         RowBox[{"Point", "[", "m3", "]"}]}], "}"}], "]"}]}], "}"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.473399800265625*^9, 3.47339986646875*^9}, {
  3.473399924734375*^9, 3.47339994634375*^9}},
 CellLabel->"In[99]:="],

Cell[BoxData[
 RowBox[{"pf2D", "[", 
  RowBox[{"randommatrix", "[", 
   RowBox[{"3", ",", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4733996824375*^9, 3.473399701640625*^9}, 
   3.473399903734375*^9},
 CellLabel->"In[114]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"pf2D", "[", 
    RowBox[{"randommatrix", "[", 
     RowBox[{"3", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"{", "5", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47339997321875*^9, 3.47340001828125*^9}, 
   3.473400090578125*^9},
 CellLabel->"In[106]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473398448875*^9, 3.47339847259375*^9}},
 CellLabel->"In[107]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "3.5  Parameter representations of spheres in the 3-sphere ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]]
}], "Subsection",
 CellChangeTimes->{{3.472372703306739*^9, 3.472372704774333*^9}, 
   3.47278698578779*^9, 3.4735808650625*^9, {3.473605086078125*^9, 
   3.473605099015625*^9}, 3.473764165453125*^9},
 FontFamily->"Times",
 FontSize->14],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell[TextData[{
 "The 3-dimensional spherical geometries, e.g. the Riemannian or the M\
\[ODoubleDot]bius geometry of the 3-sphere  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 ", cannot be visualized directly, because this sphere is a subset of the \
4-dimensional Euclidean space. The stereographical projection, considered in \
Section 4 gives the possibility to get a conformal picture of these spherical \
geometries in the 3-dimensional Euclidean space. The spheres and circles \
contained in  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 " play an important role as geometric objects; as we shall show, the spheres \
are projected onto spheres or planes by the stereographical projection. To \
study the spherical geometries we need parameter representations of the \
spheres contained in  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 " and a description of the manifold of all these subspheres by appropriate \
parameters.The parameter representation unit3 of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 " itself is a vector function with values  in the 4-space; geometric objects \
in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{" ", "3"}]], TraditionalForm]]],
 "can be plotted only after stereographic projection onto the 3-space, as \
done in  section 4 below. Each sphere (= hypersphere of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{" ", "3"}]], TraditionalForm]]],
 ") is the intersection of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{" ", "3"}]], TraditionalForm]]],
 " with a hyperplane"
}], "Text",
 CellChangeTimes->{{3.4736053785*^9, 3.473605380546875*^9}, {
   3.4736055289375*^9, 3.473605674328125*^9}, {3.4736058060625*^9, 
   3.4736058448125*^9}, {3.473605990078125*^9, 3.47360616378125*^9}, {
   3.47360620565625*^9, 3.47360621578125*^9}, 3.47360627215625*^9, {
   3.47360630309375*^9, 3.47360645928125*^9}, {3.47360650328125*^9, 
   3.473606689390625*^9}, 3.473607269984375*^9, {3.47360732209375*^9, 
   3.47360737546875*^9}, {3.473607619671875*^9, 3.473607620328125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"vec", "[", "n", "]"}], ".", 
   RowBox[{"vec", "[", "x", "]"}]}], " ", "==", " ", "p"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[196]:="],

Cell[TextData[{
 "with  normal unit vector  vec[n]=unit3 \[Epsilon] ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["S", 
     RowBox[{" ", "3"}]]}], TraditionalForm]]],
 ", and distance p, -1 < p < 1, from the center. "
}], "Text",
 CellChangeTimes->{{3.472371586449405*^9, 3.472371588192381*^9}, {
   3.472971846890625*^9, 3.472971846921875*^9}, 3.47339649253125*^9, 
   3.473607459765625*^9, {3.47360751784375*^9, 3.47360752465625*^9}}],

Cell[BoxData[
 RowBox[{"unit3", "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.473607478890625*^9, 3.473607496484375*^9}},
 CellLabel->"In[40]:="],

Cell[TextData[{
 "The ambiguity in the signs of vec[n] and p can be used to distinguish the \
orientations of the spheres. The manifold of subspheres in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{" ", "3"}]], TraditionalForm]]],
 " is 4-dimensional: three parameters of unit3, and p ((n+1-dimensional in \
case of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{" ", "n"}]], TraditionalForm]]],
 "), or center and radius of the subsphere. From the parameter representation \
of a sphere in  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{" ", "3"}]], TraditionalForm]]],
 " we get a corresponding parameter representation of the image in the \
Euclidean space,  and may plot the corresponding sphere. By this manner not \
only special spheres, but also any geometric configuration in the 3-sphere \
may be visualized in the Euclidean 3-space. There are many ways to carry out \
this visualization with the help of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", some of which we shall describe in the following section. "
}], "Text",
 CellChangeTimes->{{3.472371586449405*^9, 3.472371588192381*^9}, {
   3.472971846890625*^9, 3.472971846921875*^9}, 3.47339649253125*^9, 
   3.473607459765625*^9, {3.47360755928125*^9, 3.47360759221875*^9}, 
   3.47360767365625*^9, {3.473607704953125*^9, 3.473607711984375*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["3.5.1  orthocomplement,  sphbasis, basisf and ",
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontVariations->{"CompatibilityType"->0},
  FontColor->RGBColor[0, 0, 1]],
 "spheremf1[s, t, u, p][v, w]"
}], "Subsubsection",
 CellChangeTimes->{{3.47360783021875*^9, 3.473607833296875*^9}, {
  3.473689096453125*^9, 3.4736891164375*^9}, {3.47368919184375*^9, 
  3.47368921696875*^9}, {3.47368925296875*^9, 3.47368926515625*^9}, {
  3.473691060328125*^9, 3.473691069265625*^9}},
 FontFamily->"Times"],

Cell[TextData[{
 "To get a parameter representation of the 2-sphere in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{" ", "3"}]], TraditionalForm]]],
 " corresponding to vec[n] and p we need an orthogonal basis with first \
vector  vec[n]. Applying orthocomplement we  get it.  Since orthocomplement  \
may handle not only numeric, but also symbolic vectors, we may develop an \
explicit formula for the wanted basis. "
}], "Text",
 CellChangeTimes->{{3.473685960546875*^9, 3.47368603309375*^9}, 
   3.47368917553125*^9}],

Cell[BoxData[
 RowBox[{"unit", "[", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{3.473582437125*^9},
 CellLabel->"In[80]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"orthocomplement", "[", 
    RowBox[{"{", "%", "}"}], "]"}], ",", 
   RowBox[{
    RowBox[{"s", ">", "0"}], "&&", 
    RowBox[{"t", ">", "0"}], "&&", 
    RowBox[{"u", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47358256475*^9, 3.47358256871875*^9}, {
  3.473686197921875*^9, 3.473686296015625*^9}},
 CellLabel->"In[81]:="],

Cell["We start with the definition", "Text",
 CellChangeTimes->{{3.473686137953125*^9, 3.473686147078125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sphbasis", "[", 
    RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], "=", " ", "%"}], 
  ";"}]], "Input",
 CellChangeTimes->{3.473664353546875*^9, {3.473686335*^9, 3.4736863468125*^9}},
 CellLabel->"In[83]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit", "[", "3", "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.473082809359375*^9, 3.47308282434375*^9}},
 CellLabel->"In[45]:="],

Cell[TextData[{
 "Unfortunately, this explicit definition leads to errors, because ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " symbolically evaluates the general expression only, neglecting \
singularities:"
}], "Text",
 CellChangeTimes->{{3.47368645946875*^9, 3.47368661228125*^9}, {
  3.47368664265625*^9, 3.47368667521875*^9}}],

Cell[BoxData[
 RowBox[{"sphbasis", "[", 
  RowBox[{"0", ",", "0", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.473083039140625*^9, 3.473083052875*^9}},
 CellLabel->"In[84]:="],

Cell[BoxData[
 RowBox[{"sphbasis", "[", 
  RowBox[{"s", ",", "t", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.473083039140625*^9, 3.473083052875*^9}, {
  3.473686689890625*^9, 3.47368670103125*^9}},
 CellLabel->"In[85]:="],

Cell["\<\
Thus we try the following definition with unevaluated orthocomplement :\
\>", "Text",
 CellChangeTimes->{{3.47368676140625*^9, 3.473686798015625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphbasis", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], " ", ":=", " ", 
  RowBox[{"orthocomplement", "[", 
   RowBox[{"{", 
    RowBox[{"unit", "[", 
     RowBox[{"{", 
      RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.473686817453125*^9, 3.47368690321875*^9}},
 CellLabel->"In[86]:="],

Cell["Here we get a llarge expression:", "Text",
 CellChangeTimes->{{3.47368704559375*^9, 3.473687072390625*^9}}],

Cell[BoxData[
 RowBox[{"sphbasis", "[", 
  RowBox[{"s", ",", "t", ",", "u"}], "]"}]], "Input",
 CellLabel->"In[87]:="],

Cell["and the correct simple results", "Text",
 CellChangeTimes->{{3.4736870846875*^9, 3.473687094890625*^9}}],

Cell[BoxData[
 RowBox[{"sphbasis", "[", 
  RowBox[{"0", ",", "0", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.47366544903125*^9, 3.473665469734375*^9}},
 CellLabel->"In[88]:="],

Cell[BoxData[
 RowBox[{"sphbasis", "[", 
  RowBox[{"s", ",", "0", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.47366544903125*^9, 3.473665469734375*^9}, {
  3.473686982359375*^9, 3.47368699065625*^9}},
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{"sphbasis", "[", 
  RowBox[{"s", ",", "t", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.473665420109375*^9, 3.473665425625*^9}, {
  3.473665498765625*^9, 3.473665510921875*^9}},
 CellLabel->"In[90]:="],

Cell["\<\
Applying these and the general result for sphbasis[s,t,u] we come to the \
following definition of the wanted basis, giving the same results as \
sphbasis, but is based on built-in Mahematica functions only:\
\>", "Text",
 CellChangeTimes->{{3.473687273640625*^9, 3.47368746609375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"basisf", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ar00", ",", "ar0"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ar00", " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sin", "[", "s", "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Cos", "[", "s", "]"}]}], ",", "0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Sin", "[", "t", "]"}], "\[Equal]", " ", "0"}], "&&", 
        RowBox[{
         RowBox[{"Sin", "[", "u", "]"}], "\[Equal]", "0"}]}], ",", 
       RowBox[{"Return", "[", "ar00", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ar0", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
             RowBox[{
              RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
            RowBox[{
             RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], "]"}], ",", " ", 
          "\n", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", "s", "]"}], "*", 
               RowBox[{
                RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
               RowBox[{"Sin", "[", "s", "]"}]}], ")"}], "/", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
               RowBox[{
                RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], "]"}]}], 
            ")"}]}], ",", " ", "\n", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", "s", "]"}], "*", 
               RowBox[{"Cos", "[", "t", "]"}], "*", 
               RowBox[{"Sin", "[", "t", "]"}]}], ")"}], "/", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
               RowBox[{
                RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], "]"}]}], 
            ")"}]}], ",", " ", "0"}], "}"}], ",", " ", "\n", "  ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Sin", "[", "t", "]"}], "^", "2"}], "/", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
              RowBox[{
               RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], ")"}]}], "]"}], 
          ",", " ", "\n", "   ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", 
             RowBox[{"Cot", "[", "t", "]"}]}], ")"}], "*", 
           RowBox[{"Sin", "[", "s", "]"}], "*", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Sin", "[", "t", "]"}], "^", "2"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
               RowBox[{
                RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], ")"}]}], 
            "]"}]}], ",", " ", "0"}], "}"}], ",", " ", "\n", "  ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", "0", ",", " ", "0", ",", " ", "1"}], "}"}]}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", "u", "]"}], "\[Equal]", "0"}], ",", " ", 
       RowBox[{"Return", "[", "ar0", "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
            RowBox[{
             RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
            RowBox[{
             RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
            RowBox[{
             RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], "]"}], ",", " ", 
         "\n", "   ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", "s", "]"}], "*", 
              RowBox[{
               RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
              RowBox[{"Sin", "[", "s", "]"}]}], ")"}], "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
              "\n", "       ", 
              RowBox[{
               RowBox[{
                RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
              RowBox[{
               RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], "]"}]}], ")"}]}],
          ",", " ", "\n", "   ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", "s", "]"}], "*", 
              RowBox[{"Cos", "[", "t", "]"}], "*", 
              RowBox[{
               RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
              RowBox[{"Sin", "[", "t", "]"}]}], ")"}], "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
              "\n", "       ", 
              RowBox[{
               RowBox[{
                RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
              RowBox[{
               RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], "]"}]}], ")"}]}],
          ",", " ", "\n", "   ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", "s", "]"}], "*", 
              RowBox[{"Cos", "[", "t", "]"}], "*", 
              RowBox[{"Cos", "[", "u", "]"}], "*", 
              RowBox[{"Sin", "[", "u", "]"}]}], ")"}], "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
              "\n", "       ", 
              RowBox[{
               RowBox[{
                RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
              RowBox[{
               RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], "]"}]}], 
           ")"}]}]}], "}"}], ",", " ", "\n", "  ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
             RowBox[{
              RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
             "\n", "      ", 
             RowBox[{
              RowBox[{
               RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
              RowBox[{
               RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
             RowBox[{
              RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], ")"}]}], "]"}], 
         ",", " ", "\n", "   ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", "t", "]"}], "*", 
              RowBox[{
               RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
              RowBox[{"Sin", "[", "s", "]"}], "*", 
              RowBox[{"Sin", "[", "t", "]"}]}], ")"}], "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
                RowBox[{
                 RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], ")"}], "*", 
              "\n", "       ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
                RowBox[{
                 RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], ")"}]}], 
             "]"}]}], ")"}]}], ",", " ", "\n", "   ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Cos", "[", "t", "]"}], "*", 
              RowBox[{"Cos", "[", "u", "]"}], "*", 
              RowBox[{"Sin", "[", "s", "]"}], "*", 
              RowBox[{"Sin", "[", "u", "]"}]}], ")"}], "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
                RowBox[{
                 RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], ")"}], "*", 
              "\n", "       ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", "t", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "+", " ", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
                 RowBox[{
                  RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
                RowBox[{
                 RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], ")"}]}], 
             "]"}]}], ")"}]}]}], "}"}], ",", " ", "\n", "  ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0", ",", " ", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"Sin", "[", "u", "]"}], "]"}], "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
             RowBox[{
              RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
            RowBox[{
             RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], "]"}]}], ",", " ", 
         "\n", "   ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"Sin", "[", "u", "]"}], "]"}], "*", 
              RowBox[{"Cot", "[", "u", "]"}], "*", 
              RowBox[{"Sin", "[", "t", "]"}]}], ")"}], "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Cos", "[", "u", "]"}], "^", "2"}], "*", 
               RowBox[{
                RowBox[{"Sin", "[", "t", "]"}], "^", "2"}]}], " ", "+", " ", 
              RowBox[{
               RowBox[{"Sin", "[", "u", "]"}], "^", "2"}]}], "]"}]}], 
           ")"}]}]}], "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.473683733140625*^9, 3.4736837963125*^9}, {
   3.4736838408125*^9, 3.473683888328125*^9}, {3.47368394365625*^9, 
   3.4736839950625*^9}, 3.473684030140625*^9, {3.473684067484375*^9, 
   3.47368419728125*^9}, {3.473684338953125*^9, 3.473684349984375*^9}, {
   3.473684992953125*^9, 3.4736850356875*^9}},
 CellLabel->"In[24]:="],

Cell[BoxData[
 RowBox[{"basisf", "[", 
  RowBox[{"s", ",", "0", ",", 
   RowBox[{"5", "*", "Pi"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473666663953125*^9, 3.4736666796875*^9}, {
   3.473666724359375*^9, 3.47366673665625*^9}, {3.473667257796875*^9, 
   3.47366726328125*^9}, 3.4736829516875*^9, {3.473683267828125*^9, 
   3.4736832880625*^9}},
 CellLabel->"In[92]:="],

Cell[BoxData[
 RowBox[{"basisf", "[", 
  RowBox[{"0", ",", "0", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.473666663953125*^9, 3.4736666796875*^9}, {
   3.473666724359375*^9, 3.47366673665625*^9}, {3.473667257796875*^9, 
   3.47366726328125*^9}, 3.4736829516875*^9, {3.473683267828125*^9, 
   3.4736832880625*^9}, {3.473685055234375*^9, 3.473685074484375*^9}},
 CellLabel->"In[93]:="],

Cell[BoxData[
 RowBox[{"basisf", "[", 
  RowBox[{"s", ",", "t", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.473666663953125*^9, 3.4736666796875*^9}, {
   3.473666724359375*^9, 3.47366673665625*^9}, {3.473667257796875*^9, 
   3.47366726328125*^9}, 3.4736829516875*^9, {3.473683267828125*^9, 
   3.4736832880625*^9}, {3.473685055234375*^9, 3.47368510659375*^9}},
 CellLabel->"In[94]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"basisf", "[", 
   RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473666663953125*^9, 3.4736666796875*^9}, {
   3.473666724359375*^9, 3.47366673665625*^9}, {3.473667257796875*^9, 
   3.47366726328125*^9}, 3.4736829516875*^9, {3.473683267828125*^9, 
   3.4736832880625*^9}, {3.47368355409375*^9, 3.473683564609375*^9}, {
   3.473684406125*^9, 3.47368441921875*^9}, {3.473687520984375*^9, 
   3.473687535734375*^9}},
 CellLabel->"In[105]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"%", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ".", 
      RowBox[{
       RowBox[{"%", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"s", ">", "0"}], "&&", 
    RowBox[{"t", ">", "0"}], "&&", 
    RowBox[{"u", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4736844325625*^9, 3.473684498640625*^9}, {
  3.4736879885*^9, 3.473688057375*^9}},
 CellLabel->"In[106]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"sphbasis", "[", 
   RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473687542640625*^9, 3.47368755725*^9}},
 CellLabel->"In[107]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"%", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "[", 
       RowBox[{"[", "i", "]"}], "]"}], ".", 
      RowBox[{
       RowBox[{"%", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "3"}], "}"}]}], "]"}], ",", 
   RowBox[{
    RowBox[{"s", ">", "0"}], "&&", 
    RowBox[{"t", ">", "0"}], "&&", 
    RowBox[{"u", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4736844325625*^9, 3.473684498640625*^9}, {
  3.4736879885*^9, 3.473688057375*^9}},
 CellLabel->"In[108]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"basisf", "[", 
   RowBox[{"s", ",", "t", ",", "u"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.473666663953125*^9, 3.4736666796875*^9}, {
   3.473666724359375*^9, 3.47366673665625*^9}, {3.473667257796875*^9, 
   3.47366726328125*^9}, 3.4736829516875*^9, {3.473683267828125*^9, 
   3.4736832880625*^9}, {3.47368355409375*^9, 3.473683564609375*^9}, {
   3.473684406125*^9, 3.47368441921875*^9}, {3.473684702734375*^9, 
   3.4736847144375*^9}},
 CellLabel->"In[110]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"%", "[", 
       RowBox[{"[", "i", "]"}], "]"}], ".", 
      RowBox[{"unit", "[", 
       RowBox[{"{", 
        RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"s", ">", "0"}], "&&", 
    RowBox[{"t", ">", "0"}], "&&", 
    RowBox[{"u", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4736844325625*^9, 3.473684498640625*^9}, {
   3.473684753921875*^9, 3.473684840640625*^9}, 3.473684879671875*^9},
 CellLabel->"In[111]:="],

Cell["\<\
OK! Now it is easy to write down the corresponding parameter representation \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"spheremf1", "[", 
    RowBox[{"s_", ",", "t_", ",", "u_", ",", "p_"}], "]"}], "[", 
   RowBox[{"v_", ",", "w_"}], "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"bas", ",", " ", "vn", ",", "mn", ",", " ", "rp"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Abs", "[", "p", "]"}], " ", "\[GreaterEqual]", " ", "1"}], 
       ",", " ", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Parameter p = \>\"", ",", "p", ",", "\"\< too large!\>\""}], 
         "]"}], ";", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"rp", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{"p", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"mn", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"unit", "[", "3", "]"}], "[", 
        RowBox[{"{", 
         RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}], "*", "p"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"bas", " ", "=", 
      RowBox[{"basisf", "[", 
       RowBox[{"s", ",", "t", ",", "u"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{"mn", " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"bas", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", "v", "]"}], "*", 
           RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"bas", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", "v", "]"}], "*", 
           RowBox[{"Sin", "[", "w", "]"}]}], " ", "\[IndentingNewLine]", "+", 
          " ", 
          RowBox[{
           RowBox[{"bas", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}], "*", "rp"}]}], 
      "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.47368835046875*^9},
 CellLabel->"In[25]:="],

Cell["\<\
The general formula looks complicated enough; we shall later give a better \
solution:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spheremf1", "[", 
   RowBox[{"s", ",", "t", ",", "u", ",", "p"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.473080982703125*^9, 3.47308099696875*^9}, {
  3.473086003953125*^9, 3.47308601853125*^9}, {3.473689034546875*^9, 
  3.47368903828125*^9}},
 CellLabel->"In[114]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.473086057484375*^9, 3.473086065*^9}},
 CellLabel->"In[115]:="],

Cell["\<\
Now we generate random spheres; you may repeat the procedure as often you \
want, with probability 1 you will always obtain a sphere, sometimes  a bit \
distorted by numerical reasons:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.47308615665625*^9, 3.47308616340625*^9}},
 CellLabel->"In[116]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vv", "=", 
  RowBox[{"randomv", "[", "]"}]}]], "Input",
 CellChangeTimes->{3.473688776234375*^9},
 CellLabel->"In[128]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.4163462810262558`", ",", "0.22356873672857408`", ",", 
   "0.7125478368630319`", ",", "0.23061041412915126`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.4730866043125*^9, 3.473086657640625*^9, 3.473581079578125*^9, 
   3.47368862878125*^9, {3.47368877625*^9, 3.47368881340625*^9}, 
   3.473688914859375*^9},
 CellLabel->"Out[128]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.2549791692519818`", ",", "0.7230835573621424`", ",", 
   "0.8484624553415849`", ",", "0.7336520790835602`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.4730866043125*^9, 3.473086657640625*^9, 3.473581079578125*^9, 
   3.47368862878125*^9, {3.47368877625*^9, 3.47368881340625*^9}},
 CellLabel->"Out[123]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.7032480229710216`", ",", "0.42714361337602963`", ",", 
   "0.23301898284710748`", ",", "0.8585417704443252`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.4730866043125*^9, 3.473086657640625*^9, 3.473581079578125*^9, 
   3.47368862878125*^9, {3.47368877625*^9, 3.473688788640625*^9}},
 CellLabel->"Out[120]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.15698470554295596`", ",", "0.7548386486293048`", ",", 
   "0.6862307531418053`", ",", "0.09974621968566968`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.4730866043125*^9, 3.473086657640625*^9, 
  3.473581079578125*^9, 3.47368862878125*^9, 3.47368877625*^9},
 CellLabel->"Out[117]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"spheremf1", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"vv", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "*", "2", "*", "Pi"}], ",", 
    RowBox[{
     RowBox[{"vv", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "*", "Pi"}], ",", 
    RowBox[{
     RowBox[{"vv", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "*", "Pi"}], ",", 
    RowBox[{"vv", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{3.47368877625*^9},
 CellLabel->"In[129]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.09428633097801933`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.8880010966481701`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.05468960321761834`"}], "+", 
    RowBox[{"0.973046163804771`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.10624674160463493`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.9656452769522842`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.09224988013571662`"}], "+", 
    RowBox[{"0.973046163804771`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.17921594967214063`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.891037171579528`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"0.11796006857555238`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.18108080464358287`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.973046163804771`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3517898161369028`"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.45393034582802955`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"0.2315483131473806`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.473086604375*^9, 3.4730866576875*^9, 3.473581079625*^9, 
   3.47368862884375*^9, {3.47368877625*^9, 3.47368881346875*^9}, 
   3.473688914921875*^9},
 CellLabel->"Out[129]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.013153031667250124`"}], "+", 
    RowBox[{"0.6794160803121702`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}]}], ",", 
   RowBox[{"0.4202883837270278`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.679525295229228`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.01027218314021925`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.8195808078854673`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.4983803634996368`"}], "+", 
    RowBox[{"0.679525295229228`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.012180813378564212`"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.559264827848548`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"0.47498056196084476`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.33622471456405945`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.679525295229228`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.008217600052713178`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.8289890544099684`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"0.320438395179424`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.473086604375*^9, 3.4730866576875*^9, 3.473581079625*^9, 
   3.47368862884375*^9, {3.47368877625*^9, 3.47368881346875*^9}},
 CellLabel->"Out[124]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "0.041952269297002756`"}], "+", 
    RowBox[{"0.5121311118118285`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.1386839148275002`"}], "+", 
    RowBox[{"0.512743628339079`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.007902741994437993`"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.9868354612274564`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.6219334987454013`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.512743628339079`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.03544015889944016`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.6781229674442522`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"0.11886135050906302`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.5738462107611505`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.512743628339079`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.0326999605813839`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "-", 
       RowBox[{"0.7349484614750897`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"0.10967110749488808`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.473086604375*^9, 3.4730866576875*^9, 3.473581079625*^9, 
   3.47368862884375*^9, {3.47368877625*^9, 3.47368878871875*^9}},
 CellLabel->"Out[121]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.021814402445969685`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.970925996100506`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}]}], ",", 
   RowBox[{"0.032976088513871835`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.9950129102973579`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07409555531666609`"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.9408578884899277`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", "0.03835432498271102`"}], "+", 
    RowBox[{"0.9950129102973579`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.08618017286053727`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.908065252795382`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "+", 
       RowBox[{"0.1418997845132847`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.08315625970997632`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.9950129102973579`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.18684778938155994`"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.41882871996277804`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"0.3076538392761547`", " ", 
        RowBox[{"Cos", "[", "v", "]"}], " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473086604375*^9, 3.4730866576875*^9, 3.473581079625*^9, 
  3.47368862884375*^9, 3.47368877625*^9},
 CellLabel->"Out[118]="]
}, Closed]],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"spheremf1", "[", 
       RowBox[{
        RowBox[{"vv", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"vv", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{"vv", "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{"vv", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], "]"}], "[", 
      RowBox[{"v", ",", "w"}], "]"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"w", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "160"}]}], "]"}]], "Input",
 CellChangeTimes->{3.47368877625*^9, 3.47368884134375*^9},
 CellLabel->"In[130]:="],

Cell["\<\
Moreover one sees that the coordinate lines of the spheres and their images \
under sterproj are orthogonal circle families.\
\>", "Text",
 CellChangeTimes->{{3.472372578317799*^9, 3.472372628881423*^9}, 
   3.47368877628125*^9, {3.4736889381875*^9, 3.4736889571875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["3.5.2 Sphere given by subsphere[vec[n], p]:", "Subsubsection",
 CellChangeTimes->{{3.472372656711428*^9, 3.4723726581017*^9}, 
   3.472392530215931*^9, {3.473689410890625*^9, 3.473689412640625*^9}, 
   3.473691017359375*^9, {3.473691091578125*^9, 3.4736910995*^9}},
 FontFamily->"Times"],

Cell[TextData[{
 "Sometimes the parameters s,t,u of the normal vector of the hyperplane are \
not known. Let vec[n] be an arbitrary vector of dimension 4, and  p any real \
number. The following Module yields a parameter representation of the \
intersection of the hyperplane vec[n].x=p with the unit sphere ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{"3", " "}]], TraditionalForm]]],
 ", or an error message, if the intersection is not a sphere.  The parameter \
representation of this sphere as a surface in the 4-space is given by \
subsphere[n,p][v,w], contained in euvec.m."
}], "Text"],

Cell[BoxData[
 RowBox[{"?", "subsphere"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[216]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"stb", "[", "1", "]"}], "*", 
      RowBox[{"Cos", "[", "t", "]"}]}], " ", "+", 
     RowBox[{
      RowBox[{"stb", "[", "2", "]"}], "*", 
      RowBox[{"Sin", "[", "t", "]"}]}]}], ",", " ", "6"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[131]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"stb", "[", "1", "]"}], "*", 
      RowBox[{"Cos", "[", "t", "]"}]}], " ", "+", 
     RowBox[{
      RowBox[{"stb", "[", "2", "]"}], "*", 
      RowBox[{"Sin", "[", "t", "]"}]}]}], ",", " ", 
    RowBox[{"1", "/", "6"}]}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[132]:="],

Cell[BoxData[
 RowBox[{"%", "/.", 
  RowBox[{"t", "\[Rule]", " ", 
   RowBox[{"Pi", "/", "3"}]}]}]], "Input",
 CellLabel->"In[133]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sterproj", "[", "%", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"w", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "60"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{3.473689808484375*^9},
 CellLabel->"In[135]:="],

Cell["\<\
Here you may generate random spheres again; if 2*Random[] is too large, you \
will get an error message\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"randomv", "[", "]"}], ",", 
    RowBox[{
     RowBox[{"-", "1.5"}], "*", 
     RowBox[{"Random", "[", "]"}]}]}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.473690382078125*^9, 3.473690383328125*^9}, {
   3.4736906025*^9, 3.473690620515625*^9}, 3.473690695828125*^9},
 FontFamily->"Times",
 CellLabel->"In[168]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sterproj", "[", "%", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"w", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "40"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellLabel->"In[169]:="],

Cell["Also now you get an error message :", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"5", ",", "7"}], "]"}], ",", "0"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[170]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"null", "[", "]"}], ",", "0"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[171]:="],

Cell["\<\
The next command gives the unit sphere with center in the origin in the \
hyperplane spanned by stb[1], stb[2], stb[3]; similar the following command, \
in the hyperplane x[1] == 0:.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"stb", "[", "1", "]"}], ",", "0"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[172]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"stb", "[", "1", "]"}], ",", "p"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[173]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"%", "-", 
     RowBox[{
      RowBox[{"stb", "[", "1", "]"}], "*", "p"}]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"%", "-", 
     RowBox[{
      RowBox[{"stb", "[", "1", "]"}], "*", "p"}]}], ")"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[174]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"stb", "[", "1", "]"}], ",", "0.5"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[175]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}], "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
    RowBox[{"1", "/", "2"}]}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[176]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"1", "/", 
     RowBox[{"Sqrt", "[", "2", "]"}]}]}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[177]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"1", "/", "2"}]}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[178]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"stb", "[", "4", "]"}], ",", " ", ".9"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[179]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"subsphere", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"stb", "[", "2", "]"}], "*", 
       RowBox[{"Cos", "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"stb", "[", "3", "]"}], "*", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", 
     RowBox[{"Random", "[", "]"}]}], "]"}], "[", 
   RowBox[{"v", ",", "w"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[180]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"subsphere", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"stb", "[", "2", "]"}], "*", 
       RowBox[{"Cos", "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"stb", "[", "3", "]"}], "*", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], ",", "0.8"}], "]"}], "[", 
   RowBox[{"v", ",", "w"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[181]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["3.5.Tangential framing: tg4frame[s,t,u]", "Subsubsection",
 CellChangeTimes->{
  3.473691027515625*^9, {3.473691110609375*^9, 3.473691116359375*^9}, 
   3.473746252390625*^9},
 FontFamily->"Times"],

Cell[TextData[{
 "The adapted basisf in section 3.5.1 is comparatively complicated. Now we \
describe another way to find formulas defining the frame explicitely as a \
function of the geographical coordinates s,t,u.  This definition is contained \
in euvec.m. The frame is a natural tangential frame at unit3[s,t,u]. We  \
derive  the parameter representation of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{"3", " "}]], TraditionalForm]]],
 ", and norm the tangential vectors. We use"
}], "Text",
 CellChangeTimes->{
  3.47368836084375*^9, {3.4737376014375*^9, 3.47373760446875*^9}, {
   3.47373771875*^9, 3.47373774378125*^9}, {3.473737773890625*^9, 
   3.47373784075*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dotnorme", "[", "b", "]"}], " "}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{"unit3", "[", 
  RowBox[{"s", ",", " ", "t", ",", "u"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[42]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"tg1", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], " ", ":=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"unit3", "[", 
     RowBox[{"s", ",", " ", "t", ",", "u"}], "]"}], ",", "s"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.472786647630456*^9, 3.472786657452668*^9}},
 FontFamily->"Times",
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{"tg1", "[", 
  RowBox[{"s", ",", "t", ",", "u"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[46]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ".", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.473738052046875*^9, 3.47373807703125*^9}},
 FontFamily->"Times",
 CellLabel->"In[47]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ntg1", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], ":=", " ", 
  RowBox[{"dotnorme", "[", 
   RowBox[{"tg1", "[", 
    RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"ntg1", "[", 
   RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473738121453125*^9, 3.473738133046875*^9}},
 FontFamily->"Times",
 CellLabel->"In[50]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{
    RowBox[{"s", "\[Element]", "Reals"}], "&&", 
    RowBox[{"t", "\[Element]", "Reals"}], "&&", 
    RowBox[{"u", "\[Element]", "Reals"}]}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[51]:="],

Cell["\<\
Since t, u fulfil the inequality -Pi/2< t, u < Pi/2 we may set\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "ntg1", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ntg1", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Sin", "[", "s", "]"}], ",", " ", 
    RowBox[{"-", 
     RowBox[{"Cos", "[", "s", "]"}]}], ",", "0", ",", "0"}], 
   "}"}]}]}], "Input",
 FontFamily->"Times",
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"tg2", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], " ", ":=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"unit3", "[", 
     RowBox[{"s", ",", " ", "t", ",", "u"}], "]"}], ",", "t"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.47373832996875*^9, 3.47373834203125*^9}},
 FontFamily->"Times",
 CellLabel->"In[55]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ntg2", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], ":=", " ", 
  RowBox[{"dotnorme", "[", 
   RowBox[{"tg2", "[", 
    RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[56]:="],

Cell[BoxData[
 RowBox[{"ntg2", "[", 
  RowBox[{"s", ",", "t", ",", "u"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[57]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{
    RowBox[{"s", "\[Element]", "Reals"}], "&&", 
    RowBox[{"t", "\[Element]", "Reals"}], "&&", 
    RowBox[{"u", "\[Element]", "Reals"}]}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[58]:="],

Cell["Since u fulfils the inequality -Pi/2< u < Pi/2 we may set", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "ntg2", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ntg2", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", "s", "]"}]}], "*", 
     RowBox[{"Sin", "[", "t", "]"}]}], ",", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", "s", "]"}]}], "*", 
     RowBox[{"Sin", "[", "t", "]"}]}], ",", " ", 
    RowBox[{"Cos", "[", "t", "]"}], ",", "0"}], "}"}]}]}], "Input",
 FontFamily->"Times",
 CellLabel->"In[59]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"tg3", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], " ", ":=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"unit3", "[", 
     RowBox[{"s", ",", " ", "t", ",", "u"}], "]"}], ",", "u"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.472786707688306*^9, 3.472786749953261*^9}},
 FontFamily->"Times",
 CellLabel->"In[61]:="],

Cell[BoxData[
 RowBox[{"tg3", "[", 
  RowBox[{"s", ",", "t", ",", "u"}], "]"}]], "Input",
 CellChangeTimes->{{3.472786764683273*^9, 3.472786774399068*^9}},
 CellLabel->"In[62]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ntg3", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], ":=", " ", 
  RowBox[{"dotnorme", "[", 
   RowBox[{"tg3", "[", 
    RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[63]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"ntg3", "[", 
    RowBox[{"s", ",", "t", ",", "u"}], "]"}], ",", " ", 
   RowBox[{
    RowBox[{"s", "\[Element]", "Reals"}], "&&", 
    RowBox[{"t", "\[Element]", "Reals"}], "&&", 
    RowBox[{"u", "\[Element]", "Reals"}]}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[64]:="],

Cell["We set", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "ntg3", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ntg3", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", "s", "]"}]}], " ", 
     RowBox[{"Cos", "[", "t", "]"}], " ", 
     RowBox[{"Sin", "[", "u", "]"}]}], ",", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", "t", "]"}]}], " ", 
     RowBox[{"Sin", "[", "s", "]"}], " ", 
     RowBox[{"Sin", "[", "u", "]"}]}], ",", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", "t", "]"}]}], " ", 
     RowBox[{"Sin", "[", "u", "]"}]}], ",", 
    RowBox[{"Cos", "[", "u", "]"}]}], "}"}]}]}], "Input",
 FontFamily->"Times",
 CellLabel->"In[65]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"tgframe", "[", 
   RowBox[{"s_", ",", "t_", ",", "u_"}], "]"}], " ", ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ntg1", "[", 
     RowBox[{"s", ",", "t", ",", "u"}], "]"}], ",", 
    RowBox[{"ntg2", "[", 
     RowBox[{"s", ",", "t", ",", "u"}], "]"}], ",", 
    RowBox[{"ntg3", "[", 
     RowBox[{"s", ",", "t", ",", "u"}], "]"}], ",", 
    RowBox[{"unit3", "[", 
     RowBox[{"s", ",", "t", ",", "u"}], "]"}]}], "}"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[67]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"tgframe", "[", 
   RowBox[{"s", ",", "t", ",", "u"}], "]"}], "//", "MatrixForm"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[68]:="],

Cell["\<\
This coincides with the  definition  of tg4frame contained in the package \
euvec.m:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "tg4frame"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"tg4frame", "[", 
   RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[70]:="],

Cell[BoxData[
 RowBox[{"%", "-", "%%%"}]], "Input",
 CellChangeTimes->{{3.472392763245375*^9, 3.472392768294267*^9}},
 CellLabel->"In[71]:="],

Cell["tg4frame yields a positively oriented frame:", "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Det", "[", 
   RowBox[{"tg4frame", "[", 
    RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[72]:="],

Cell["We check the orhonormality condition:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tg4frame", "[", 
   RowBox[{"s", ",", "t", ",", "u"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{3.473738802734375*^9},
 CellLabel->"In[77]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"%", "[", 
      RowBox[{"[", "i", "]"}], "]"}], ".", 
     RowBox[{"%", "[", 
      RowBox[{"[", "j", "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "4"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473738739546875*^9, 3.473738751*^9}},
 CellLabel->"In[78]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.5.4 Another parameter representation of the spheres, using tg4frame\
\>", "Subsubsection",
 CellChangeTimes->{{3.47369112778125*^9, 3.4736911310625*^9}},
 FontFamily->"Times"],

Cell["\<\
The tangential framing gives the possibility of the following parameter \
representation of arbitrary spheres, defined in euvec.m:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "subspheremf"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[79]:="],

Cell[TextData[{
 "We named this procedure subspheremf since the argumants s,t,u,p may serve \
as coordinates on the 4-dimensional manifold of all subspheres of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 ".  The procedure is much faster, and more effectiv,  than spheremf1, and \
the composition of subsphere with unit[3]:"
}], "Text",
 CellChangeTimes->{{3.472392950236242*^9, 3.472392951007327*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"subspheremf", "[", 
    RowBox[{"s", ",", "t", ",", "u", ",", " ", "p"}], "]"}], "[", 
   RowBox[{"v", ",", "w"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[40]:="],

Cell["\<\
The next results look very clumsy; their calculation and simplification needs \
plenty of time, try it!\
\>", "Text",
 CellChangeTimes->{{3.473739850625*^9, 3.473739940078125*^9}, {
  3.47374002115625*^9, 3.47374003821875*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"subsphere", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"unit", "[", "3", "]"}], "[", 
      RowBox[{"{", 
       RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}], ",", "p"}], "]"}], 
   "[", 
   RowBox[{"v", ",", "w"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"s", ">", "0"}], "&&", 
    RowBox[{"t", ">", "0"}], "&&", 
    RowBox[{"u", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472393029984592*^9, 3.472393101714596*^9}, {
   3.472393152081708*^9, 3.472393179713386*^9}, 3.473739361421875*^9, 
   3.473739630828125*^9},
 CellLabel->"In[42]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"spheremf1", "[", 
    RowBox[{"s", ",", "t", ",", "u", ",", "p"}], "]"}], "[", 
   RowBox[{"v", ",", "w"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"s", ">", "0"}], "&&", 
    RowBox[{"t", ">", "0"}], "&&", 
    RowBox[{"u", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47358137615625*^9, 3.47358140990625*^9}, 
   3.473739145859375*^9},
 CellLabel->"In[86]:="],

Cell["\<\
In the next subsection we compare the three methods, applying the \
stereographical projection sterproj on the parameter representations and then \
plotting the image spheres for the same randomly chosen parameters s,,u,p. \
The result of the test is the following: The parameter representations \
obtained by the methods differ, the image spheres obtained coincide. The \
simplest parameter representation and the fastest plot is obtained using the \
function subspheremf, Evaluate the next subsection several times!\
\>", "Text",
 CellChangeTimes->{{3.47374312978125*^9, 3.473743439453125*^9}, {
  3.473743907453125*^9, 3.4737439459375*^9}, {3.4737445850625*^9, 
  3.47374465825*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical effectiveness of the three methods", "Subsubsection",
 CellChangeTimes->{{3.473741156625*^9, 3.47374117765625*^9}, 
   3.4737458294375*^9}],

Cell[CellGroupData[{

Cell[BoxData["dim"], "Input",
 CellChangeTimes->{{3.473740070421875*^9, 3.473740070953125*^9}, 
   3.4737458294375*^9},
 CellLabel->"In[172]:="],

Cell[BoxData["4"], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.47374007196875*^9, 3.473742987828125*^9, 3.473743023546875*^9, 
   3.473744770203125*^9, 3.473745185875*^9, {3.4737458294375*^9, 
   3.473745844984375*^9}},
 CellLabel->"Out[172]="]
}, Closed]],

Cell["A random vector gives the random parameters:", "Text",
 CellChangeTimes->{{3.47374482390625*^9, 3.473744850015625*^9}, 
   3.4737458294375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"vv", "=", 
  RowBox[{"randomv", "[", "]"}]}]], "Input",
 CellChangeTimes->{{3.473740163359375*^9, 3.47374019440625*^9}, 
   3.4737458294375*^9},
 CellLabel->"In[173]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1545449877032811`", ",", "0.5471712628274885`", ",", 
   "0.7679829476632339`", ",", "0.17308227953832067`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.47374020003125*^9, 3.473742987875*^9, 3.473743023578125*^9, 
   3.47374477025*^9, 3.47374518590625*^9, {3.4737458294375*^9, 
   3.473745845046875*^9}},
 CellLabel->"Out[173]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9982165599899495`", ",", "0.9997568913569377`", ",", 
   "0.07100310859642987`", ",", "0.18272654138984568`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.47374020003125*^9, 3.473742987875*^9, 
  3.473743023578125*^9, 3.47374477025*^9, 3.47374518590625*^9, 
  3.4737458294375*^9},
 CellLabel->"Out[150]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"s", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";", 
  RowBox[{"t", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";", 
  RowBox[{"u", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", "3", "]"}], "]"}]}], ";", 
  RowBox[{"p", "=", 
   RowBox[{"%", "[", 
    RowBox[{"[", "4", "]"}], "]"}]}], ";", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t", ",", "u", ",", "p"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.4737402113125*^9, 3.473740342140625*^9}, 
   3.4737458294375*^9},
 CellLabel->"In[174]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1545449877032811`", ",", "0.5471712628274885`", ",", 
   "0.7679829476632339`", ",", "0.17308227953832067`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.473740344765625*^9, 3.47374298790625*^9, 3.473743023609375*^9, 
   3.473744770265625*^9, 3.4737451859375*^9, {3.4737458294375*^9, 
   3.47374584509375*^9}},
 CellLabel->"Out[174]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9982165599899495`", ",", "0.9997568913569377`", ",", 
   "0.07100310859642987`", ",", "0.18272654138984568`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473740344765625*^9, 3.47374298790625*^9, 
  3.473743023609375*^9, 3.473744770265625*^9, 3.4737451859375*^9, 
  3.4737458294375*^9},
 CellLabel->"Out[151]="]
}, Closed]],

Cell["\<\
Now we get the parameter representations by the three methods:\
\>", "Text",
 CellChangeTimes->{{3.47374489546875*^9, 3.4737449285*^9}, {
   3.47374496859375*^9, 3.473745*^9}, 3.4737458294375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"subspheremf", "[", 
    RowBox[{"s", ",", "t", ",", "u", ",", "p"}], "]"}], "[", 
   RowBox[{"v", ",", "w"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47374512815625*^9, 3.473745157609375*^9}, 
   3.473745829453125*^9},
 CellLabel->"In[175]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.10505609785243683`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.984907368491991`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"0.15393052592971998`", " ", 
             RowBox[{"Cos", "[", "v", "]"}]}], "-", 
            RowBox[{"0.5140727827367686`", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"0.5861907156465656`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.01636640050200901`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.984907368491991`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.9880816733382923`"}], " ", 
             RowBox[{"Cos", "[", "v", "]"}]}], "-", 
            RowBox[{"0.0800859847399811`", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"0.09132103913003309`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.06477426496105021`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.984907368491991`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"0.8539996540382804`", " ", 
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"Sin", "[", "v", "]"}]}], "-", 
         RowBox[{"0.3614266426146108`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.12023779492141436`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.708457018137086`", " ", 
       RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.47374516603125*^9, 3.47374518596875*^9}, {
  3.473745829453125*^9, 3.473745845125*^9}},
 CellLabel->"Out[175]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.0130785099704553`*^-14", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.05337623274670118`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9831637763219844`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"0.8405060503534322`", " ", 
             RowBox[{"Cos", "[", "v", "]"}]}], "-", 
            RowBox[{"0.4558396158107529`", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"0.020775636136492588`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.08280337358762895`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9831637763219844`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.5418021588359294`"}], " ", 
             RowBox[{"Cos", "[", "v", "]"}]}], "-", 
            RowBox[{"0.7071510307432062`", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"0.03222956495814065`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.15334771625092788`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9831637763219844`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"0.540506858768995`", " ", 
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"Sin", "[", "v", "]"}]}], "-", 
         RowBox[{"0.05968754614643139`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.01296325380440575`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.980686536025479`", " ", 
       RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.47374516603125*^9, 3.47374518596875*^9}, 
   3.473745829453125*^9},
 CellLabel->"Out[152]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"subsphere", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"unit", "[", "3", "]"}], "[", 
      RowBox[{"{", 
       RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}], ",", "p"}], "]"}], 
   "[", 
   RowBox[{"v", ",", "w"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.473745829453125*^9},
 FontFamily->"Times",
 CellLabel->"In[176]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.10505609785243683`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.7827287500020408`", " ", 
       RowBox[{"Cos", "[", "v", "]"}], " ", 
       RowBox[{"Cos", "[", "w", "]"}]}]}], ",", 
     RowBox[{"0.01636640050200901`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.984907368491991`", " ", 
       RowBox[{"Cos", "[", "w", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.07221930889534602`"}], " ", 
          RowBox[{"Cos", "[", "v", "]"}]}], "+", 
         RowBox[{"0.9928962995948971`", " ", 
          RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.06477426496105021`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.984907368491991`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.28582660244180413`"}], " ", 
             RowBox[{"Cos", "[", "v", "]"}]}], "-", 
            RowBox[{"0.05643061254586769`", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"0.8803768320403742`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.12023779492141436`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.984907368491991`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.5305681265259867`"}], " ", 
             RowBox[{"Cos", "[", "v", "]"}]}], "-", 
            RowBox[{"0.10474981727171763`", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"0.4742748502783536`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.473740381765625*^9, 3.473740825859375*^9, 3.473742988*^9, 
   3.473743023671875*^9, 3.473744770453125*^9, {3.47374517715625*^9, 
   3.473745186015625*^9}, {3.473745829453125*^9, 3.47374584515625*^9}},
 CellLabel->"Out[176]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.05337623274670118`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9402828491331914`", " ", 
       RowBox[{"Cos", "[", "v", "]"}], " ", 
       RowBox[{"Cos", "[", "w", "]"}]}]}], ",", 
     RowBox[{"0.08280337358762895`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9831637763219844`", " ", 
       RowBox[{"Cos", "[", "w", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.1384076312001672`"}], " ", 
          RowBox[{"Cos", "[", "v", "]"}]}], "+", 
         RowBox[{"0.8806215033051387`", " ", 
          RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.15334771625092788`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9831637763219844`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.25632402686811917`"}], " ", 
             RowBox[{"Cos", "[", "v", "]"}]}], "-", 
            RowBox[{"0.4721364155594395`", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"0.08423458846640673`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.01296325380440575`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9831637763219844`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "w", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "0.021668359318906007`"}], " ", 
             RowBox[{"Cos", "[", "v", "]"}]}], "-", 
            RowBox[{"0.039912066086359894`", " ", 
             RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"0.9964459514223012`", " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.473740381765625*^9, 3.473740825859375*^9, 3.473742988*^9, 
   3.473743023671875*^9, 3.473744770453125*^9, {3.47374517715625*^9, 
   3.473745186015625*^9}, 3.473745829453125*^9},
 CellLabel->"Out[153]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%", "[", 
   RowBox[{"[", "2", "]"}], "]"}], "-", 
  RowBox[{"%%", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473740483921875*^9, 3.4737405145625*^9}, 
   3.473745829453125*^9},
 CellLabel->"In[177]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.7827287500020408`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}], "-", 
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0.15393052592971998`", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.5140727827367686`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.5861907156465656`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07221930889534602`"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}]}], "+", 
       RowBox[{"0.9928962995948971`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.9880816733382923`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.0800859847399811`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.09132103913003309`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.`", "\[InvisibleSpace]", "-", 
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.8539996540382804`", " ", 
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"0.3614266426146108`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.28582660244180413`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.05643061254586769`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"0.8803768320403742`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.5305681265259867`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.10474981727171763`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.4742748502783536`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.708457018137086`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.4737405160625*^9, 3.47374084746875*^9, 3.47374298803125*^9, 
   3.473743023703125*^9, 3.473744770484375*^9, 3.473745186046875*^9, {
   3.473745829453125*^9, 3.4737458451875*^9}},
 CellLabel->"Out[177]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.9402828491331914`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}], "-", 
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0.8405060503534322`", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.4558396158107529`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.020775636136492588`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.1384076312001672`"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}]}], "+", 
       RowBox[{"0.8806215033051387`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.5418021588359294`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.7071510307432062`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.03222956495814065`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.`", "\[InvisibleSpace]", "-", 
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.540506858768995`", " ", 
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"0.05968754614643139`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.25632402686811917`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.4721364155594395`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"0.08423458846640673`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{"0.`", "\[InvisibleSpace]", "+", 
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.021668359318906007`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.039912066086359894`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.9964459514223012`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.980686536025479`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.4737405160625*^9, 3.47374084746875*^9, 
  3.47374298803125*^9, 3.473743023703125*^9, 3.473744770484375*^9, 
  3.473745186046875*^9, 3.473745829453125*^9},
 CellLabel->"Out[154]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.47374053396875*^9, 3.4737405403125*^9}, 
   3.473745829453125*^9},
 CellLabel->"In[178]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"0.7827287500020408`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}], "-", 
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0.15393052592971998`", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.5140727827367686`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.5861907156465656`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.07221930889534602`"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}]}], "+", 
       RowBox[{"0.9928962995948971`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.9880816733382923`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.0800859847399811`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.09132103913003309`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.984907368491991`"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.8539996540382804`", " ", 
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"0.3614266426146108`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.28582660244180413`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.05643061254586769`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"0.8803768320403742`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.984907368491991`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.5305681265259867`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.10474981727171763`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.4742748502783536`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.708457018137086`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.47374054134375*^9, 3.473740856125*^9, 3.4737429880625*^9, 
   3.473743023734375*^9, 3.473744770515625*^9, 3.473745186078125*^9, {
   3.473745829453125*^9, 3.47374584521875*^9}},
 CellLabel->"Out[178]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"0.9402828491331914`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}], "-", 
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0.8405060503534322`", " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.4558396158107529`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.020775636136492588`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.1384076312001672`"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}]}], "+", 
       RowBox[{"0.8806215033051387`", " ", 
        RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.5418021588359294`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.7071510307432062`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.03222956495814065`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.9831637763219844`"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.540506858768995`", " ", 
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"Sin", "[", "v", "]"}]}], "-", 
       RowBox[{"0.05968754614643139`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.25632402686811917`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.4721364155594395`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"0.08423458846640673`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.9831637763219844`", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "w", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "0.021668359318906007`"}], " ", 
           RowBox[{"Cos", "[", "v", "]"}]}], "-", 
          RowBox[{"0.039912066086359894`", " ", 
           RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"0.9964459514223012`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.980686536025479`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.47374054134375*^9, 3.473740856125*^9, 3.4737429880625*^9,
   3.473743023734375*^9, 3.473744770515625*^9, 3.473745186078125*^9, 
  3.473745829453125*^9},
 CellLabel->"Out[155]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"spheremf1", "[", 
    RowBox[{"s", ",", "t", ",", "u", ",", "p"}], "]"}], "[", 
   RowBox[{"v", ",", "w"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{3.473745829453125*^9},
 FontFamily->"Times",
 CellLabel->"In[179]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.10505609785243683`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.7827287500020407`", " ", 
       RowBox[{"Cos", "[", "v", "]"}], " ", 
       RowBox[{"Cos", "[", "w", "]"}]}]}], ",", 
     RowBox[{"0.01636640050200901`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.984907368491991`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.07221930889534603`"}], " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Cos", "[", "w", "]"}]}], "+", 
         RowBox[{"0.9928962995948972`", " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.06477426496105021`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.984907368491991`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.2858266024418042`"}], " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Cos", "[", "w", "]"}]}], "+", 
         RowBox[{"0.8803768320403742`", " ", 
          RowBox[{"Sin", "[", "v", "]"}]}], "-", 
         RowBox[{"0.05643061254586771`", " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.12023779492141436`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.984907368491991`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.530568126525987`"}], " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Cos", "[", "w", "]"}]}], "-", 
         RowBox[{"0.47427485027835375`", " ", 
          RowBox[{"Sin", "[", "v", "]"}]}], "-", 
         RowBox[{"0.10474981727171769`", " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.47374059903125*^9, 3.473740877734375*^9, 3.47374298809375*^9, 
   3.47374302378125*^9, 3.473744770546875*^9, 3.473745186109375*^9, {
   3.473745829453125*^9, 3.47374584525*^9}},
 CellLabel->"Out[179]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.05337623274670118`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9402828491331915`", " ", 
       RowBox[{"Cos", "[", "v", "]"}], " ", 
       RowBox[{"Cos", "[", "w", "]"}]}]}], ",", 
     RowBox[{"0.08280337358762895`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9831637763219844`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.13840763120016722`"}], " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Cos", "[", "w", "]"}]}], "+", 
         RowBox[{"0.8806215033051386`", " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.15334771625092788`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9831637763219844`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.2563240268681192`"}], " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Cos", "[", "w", "]"}]}], "+", 
         RowBox[{"0.08423458846640436`", " ", 
          RowBox[{"Sin", "[", "v", "]"}]}], "-", 
         RowBox[{"0.4721364155594396`", " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"0.01296325380440575`", "\[InvisibleSpace]", "+", 
      RowBox[{"0.9831637763219844`", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.021668359318906018`"}], " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Cos", "[", "w", "]"}]}], "-", 
         RowBox[{"0.9964459514223016`", " ", 
          RowBox[{"Sin", "[", "v", "]"}]}], "-", 
         RowBox[{"0.03991206608635991`", " ", 
          RowBox[{"Cos", "[", "v", "]"}], " ", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}]}], "}"}]}], 
  "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.47374059903125*^9, 3.473740877734375*^9, 
  3.47374298809375*^9, 3.47374302378125*^9, 3.473744770546875*^9, 
  3.473745186109375*^9, 3.473745829453125*^9},
 CellLabel->"Out[156]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%", "[", 
     RowBox[{"[", "2", "]"}], "]"}], " ", "-", 
    RowBox[{
     RowBox[{"subsphere", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"unit", "[", "3", "]"}], "[", 
        RowBox[{"{", 
         RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}], ",", "p"}], "]"}], 
     "[", 
     RowBox[{"v", ",", "w"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47374064778125*^9, 3.47374065659375*^9}, {
   3.4737409234375*^9, 3.473740952515625*^9}, 3.473745829453125*^9},
 CellLabel->"In[180]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.9779108816194456`"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{"0.9779108816194457`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"0.8670896289262006`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.05557892610494168`", " ", 
        RowBox[{"Cos", "[", "w", "]"}]}]}], ")"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "-", 
    RowBox[{"0.8670896289262006`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}], "-", 
    RowBox[{"0.0555789261049417`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "0.46711679472958645`"}], "+", 
       RowBox[{"0.10316886687910432`", " ", 
        RowBox[{"Cos", "[", "w", "]"}]}]}], ")"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{"0.4671167947295863`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}], "-", 
    RowBox[{"0.10316886687910437`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.4737409548125*^9, 3.473742988265625*^9, 3.4737430239375*^9, 
   3.473744770703125*^9, 3.47374518628125*^9, {3.473745829453125*^9, 
   3.473745845421875*^9}},
 CellLabel->"Out[180]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.8657951626998229`"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{"0.8657951626998228`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"0.08281639609355838`", "\[InvisibleSpace]", "+", 
       RowBox[{"0.46418742126054424`", " ", 
        RowBox[{"Cos", "[", "w", "]"}]}]}], ")"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "-", 
    RowBox[{"0.08281639609356072`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}], "-", 
    RowBox[{"0.4641874212605443`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "0.9796695645011027`"}], "+", 
       RowBox[{"0.0392400976142782`", " ", 
        RowBox[{"Cos", "[", "w", "]"}]}]}], ")"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{"0.9796695645011022`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}], "-", 
    RowBox[{"0.03924009761427821`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.4737409548125*^9, 3.473742988265625*^9, 
  3.4737430239375*^9, 3.473744770703125*^9, 3.47374518628125*^9, 
  3.473745829453125*^9},
 CellLabel->"Out[157]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"%%", "[", 
     RowBox[{"[", "2", "]"}], "]"}], " ", "-", 
    RowBox[{
     RowBox[{"subspheremf", "[", 
      RowBox[{"s", ",", "t", ",", "u", ",", " ", "p"}], "]"}], "[", 
     RowBox[{"v", ",", "w"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47374064778125*^9, 3.47374065659375*^9}, {
   3.4737409234375*^9, 3.473741002515625*^9}, 3.473741058578125*^9, 
   3.473745829453125*^9},
 CellLabel->"In[181]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"0.631121440778012`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}], "+", 
    RowBox[{"0.5063140716586257`", " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{"0.5773435551818958`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.07887727648334454`", " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.9020395912643551`", " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.9779108816194457`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"0.08994276433751502`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"0.8670896289262006`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.8411105519519134`", " ", 
        RowBox[{"Cos", "[", "w", "]"}]}]}], ")"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.28151272685596385`"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "-", 
       RowBox[{"0.0555789261049417`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"0.3559717634804516`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.46711679472958645`"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5225604573024355`"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "-", 
       RowBox[{"0.10316886687910437`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.708457018137086`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.473741062046875*^9, 3.473742988390625*^9, 3.4737430240625*^9, 
   3.47374477084375*^9, 3.473745186421875*^9, {3.473745829453125*^9, 
   3.4737458455625*^9}},
 CellLabel->"Out[181]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"0.11392774664623517`", " ", 
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"Cos", "[", "w", "]"}]}], "+", 
    RowBox[{"0.44816499807766236`", " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{"0.020425852879445535`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"0.6952452778154743`", " ", 
     RowBox[{"Cos", "[", "w", "]"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.39660288713799907`", " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "+", 
       RowBox[{"0.8657951626998228`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"0.03168694079346026`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"0.08281639609355838`", "\[InvisibleSpace]", "-", 
       RowBox[{"0.5314067643952586`", " ", 
        RowBox[{"Cos", "[", "w", "]"}]}]}], ")"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.25200849821771787`"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "-", 
       RowBox[{"0.4641874212605443`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"0.05868263326871819`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "0.9796695645011027`"}], " ", 
     RowBox[{"Sin", "[", "v", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", "v", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.0213035459746773`"}], " ", 
        RowBox[{"Cos", "[", "w", "]"}]}], "-", 
       RowBox[{"0.03924009761427821`", " ", 
        RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"0.980686536025479`", " ", 
     RowBox[{"Sin", "[", "w", "]"}]}]}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473741062046875*^9, 3.473742988390625*^9, 
  3.4737430240625*^9, 3.47374477084375*^9, 3.473745186421875*^9, 
  3.473745829453125*^9},
 CellLabel->"Out[158]="]
}, Closed]],

Cell["\<\
The parameter representations differ, but the image spheres coincide, of \
course:\
\>", "Text",
 CellChangeTimes->{{3.473745320625*^9, 3.473745355953125*^9}, 
   3.473745829453125*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"subspheremf", "[", 
       RowBox[{"s", ",", "t", ",", "u", ",", " ", "p"}], "]"}], "[", 
      RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.473741225765625*^9, 3.47374130134375*^9}, {
   3.473742734453125*^9, 3.473742763203125*^9}, 3.473745829453125*^9},
 CellLabel->"In[196]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.5940000000000172`", ",", 
   Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx0nHc4V/8f922+KSO7YUuFVLKi3kJStIykFBJlVSgrGSWSJNkhSkXDzCav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     "], {{
       {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1m3fgV9Mfxu86n3sl2lJZISGljFBWSmUUknYpe1QiJFsDEbILpaxk7z1T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           "]], Polygon3DBox[CompressedData["
1:eJxFmwO07sjWtZM3eZPdPm3jtE7b5m1bp227b9u3bdu2bdu2bdv8nufM/OMf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           "]], Polygon3DBox[CompressedData["
1:eJwt1gmcz3Uex/H/3BMiZxmDlSOZUEK1Zdstu10arbXb1jp2sZIYJOTIfR+D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           "]], 
          Polygon3DBox[{{1619, 1948, 992, 847, 846, 1076}, {1612, 1946, 985, 
           832, 831, 1055}, {1603, 1895, 888, 724, 723, 
           1034}}]}]}, {}, {}, {}, {}}, {{}, {}, {}, {
        Line3DBox[{716, 1026, 1027, 1979, 717, 895, 1990, 738, 910, 2000, 753,
          925, 2008, 768, 2063, 940, 783, 2072, 955, 798, 2084, 970, 813, 
         1047, 1221, 1048, 2026, 828, 1068, 1235, 1069, 2037, 843, 1091, 1249,
          1092, 2044, 1251, 1096, 1133, 1097, 1267, 2132, 1136, 1166, 1137, 
         1274, 1351, 2141, 1169, 1376, 1170, 1350, 1281, 1311, 2137, 1190, 
         1288, 1191, 1312, 1204}], 
        Line3DBox[{718, 1028, 1029, 1980, 719, 896, 1991, 739, 911, 2001, 754,
          926, 2009, 769, 941, 2015, 784, 2073, 956, 799, 2085, 971, 814, 
         1049, 1222, 1050, 2027, 829, 1070, 1236, 1071, 2038, 844, 1094, 1250,
          2127, 1095, 1253, 1100, 1135, 1101, 1268, 1139, 2108, 1168, 1140, 
         1275, 1353, 2142, 1172, 1377, 1173, 1352, 1282, 2134, 1313, 1192, 
         1289, 1193, 1314, 1205}], 
        Line3DBox[{720, 1030, 1031, 1981, 721, 897, 1992, 740, 912, 2002, 755,
          927, 2010, 770, 942, 2016, 785, 957, 2020, 800, 2086, 972, 815, 
         1051, 1223, 1052, 2028, 830, 1072, 1237, 1073, 845, 1098, 1252, 2128,
          1099, 1255, 1105, 1138, 1106, 1269, 1142, 2109, 1171, 1143, 1276, 
         2133, 634, 703, 633, 681, 1884, 549, 1290, 551, 1206}], 
        Line3DBox[{722, 1032, 2098, 1034, 723, 898, 1993, 741, 913, 2003, 756,
          928, 2011, 771, 943, 2017, 786, 958, 2021, 801, 973, 2023, 816, 
         1053, 1224, 2124, 1055, 831, 1074, 1238, 2125, 1076, 846, 1102, 1254,
          2129, 1104, 1257, 1108, 1141, 1110, 1270, 1145, 2110, 1174, 1147, 
         1277, 1356, 2143, 1357, 1194, 1355, 1354, 1374, 1315, 2138, 1316, 
         1291, 1320, 1319, 1207}], 
        Line3DBox[{411, 237, 1985, 728, 903, 1996, 746, 918, 2004, 761, 933, 
         776, 2068, 948, 791, 2078, 963, 806, 2091, 978, 821, 252, 2032, 836, 
         266, 2041, 851, 289, 1713, 462, 292, 478, 1729, 320, 492, 1743, 349, 
         506, 1757, 378, 396}], 
        Line3DBox[{729, 1038, 1039, 1986, 730, 904, 1997, 747, 919, 2005, 762,
          934, 2012, 777, 949, 792, 2079, 964, 807, 2092, 979, 822, 1059, 
         1229, 1060, 2033, 837, 1080, 1243, 1081, 2042, 852, 1116, 1261, 1117,
          1263, 1120, 1154, 1121, 1271, 1156, 2111, 1181, 1157, 1278, 1367, 
         2144, 1183, 1378, 1184, 1366, 1283, 1325, 1199, 1296, 1200, 1326, 
         1208}], 
        Line3DBox[{731, 1040, 1041, 1987, 732, 905, 1998, 748, 920, 2006, 763,
          935, 2013, 778, 950, 2018, 793, 2080, 965, 808, 2093, 980, 823, 
         1061, 1230, 1062, 2034, 838, 1082, 1244, 1083, 2043, 853, 1118, 1262,
          2130, 1119, 1265, 1124, 1155, 1125, 1272, 1159, 2112, 1182, 1160, 
         1279, 1369, 2145, 1186, 1379, 1187, 1368, 1284, 2135, 1327, 1202, 
         1297, 1203, 1328, 1209}], 
        Line3DBox[{733, 1042, 1043, 1988, 734, 906, 1999, 749, 921, 2007, 764,
          936, 2014, 779, 951, 2019, 794, 966, 2022, 809, 2094, 981, 824, 
         1063, 1231, 1064, 2035, 839, 1084, 1245, 2126, 1085, 1345, 1122, 
         1264, 2131, 1123, 1266, 1126, 1158, 1127, 1273, 1161, 2113, 1185, 
         1162, 1280, 1372, 2146, 1373, 1201, 1371, 1370, 1375, 2147, 1329, 
         1330, 1298, 1332, 1331, 1210}], 
        Line3DBox[{878, 1020, 1299, 1285, 1309, 1308, 875, 1017, 1333, 1188, 
         1347, 2121, 1346, 868, 1010, 1163, 2114, 1129, 861, 1003, 1128, 1088,
          854, 996, 2103, 1246, 1086, 840, 989, 2100, 1232, 1065, 825, 982, 
         1218, 1044, 810, 967, 2081, 795, 952, 2069, 780, 937, 2060, 765, 922,
          2053, 750, 907, 2048, 735, 892, 2045, 713, 885, 1023, 1211}], 
        Line3DBox[{879, 524, 1286, 538, 1805, 581, 580, 620, 619, 2140, 869, 
         1011, 1164, 2115, 1131, 862, 1004, 1130, 1090, 855, 997, 2104, 1247, 
         1087, 841, 990, 1233, 1066, 826, 2024, 983, 1219, 1045, 811, 968, 
         2082, 796, 953, 2070, 781, 938, 2061, 766, 923, 2054, 751, 908, 2049,
          736, 893, 714, 1977, 886, 1024, 1212}], 
        Line3DBox[{880, 1301, 1300, 1287, 1189, 1310, 1336, 1335, 1334, 1349, 
         1167, 2095, 1348, 870, 1012, 1165, 2116, 1134, 863, 1005, 1132, 1093,
          856, 998, 1248, 1089, 842, 2036, 991, 1234, 1067, 827, 2025, 984, 
         1220, 1046, 812, 969, 2083, 797, 954, 2071, 782, 939, 2062, 767, 924,
          2055, 752, 909, 737, 1989, 894, 715, 1978, 887, 1025, 1213}], 
        Line3DBox[{881, 1021, 1302, 1292, 1318, 2136, 1317, 876, 1018, 1337, 
         1195, 1359, 2122, 1358, 871, 1013, 1175, 2117, 1146, 864, 1006, 1144,
          1109, 857, 999, 2105, 1256, 1103, 847, 992, 2101, 1239, 1075, 832, 
         985, 2099, 1225, 1054, 817, 974, 2087, 802, 959, 2074, 787, 944, 
         2064, 772, 929, 2056, 757, 914, 2050, 742, 899, 2046, 724, 888, 2097,
          1033, 1214}], 
        Line3DBox[{882, 1022, 1303, 1293, 1322, 1321, 877, 1019, 1338, 1196, 
         1361, 2123, 1360, 872, 1014, 1176, 2118, 1149, 865, 1007, 1148, 1112,
          858, 1000, 2106, 1258, 1107, 848, 993, 2102, 1240, 1077, 833, 2029, 
         986, 1226, 1056, 818, 975, 2088, 803, 960, 2075, 788, 945, 2065, 773,
          930, 2057, 758, 915, 2051, 743, 900, 2047, 725, 1982, 889, 1035, 
         1215}], Line3DBox[{883, 1305, 1304, 1294, 1197, 1323, 2139, 1341, 
         1340, 1339, 1363, 1178, 1362, 873, 1015, 1177, 2119, 1151, 866, 1008,
          1150, 1114, 859, 1001, 2107, 1259, 1111, 849, 2039, 994, 1241, 1078,
          834, 2030, 987, 1227, 1057, 819, 976, 2089, 804, 961, 2076, 789, 
         946, 2066, 774, 931, 2058, 759, 916, 2052, 744, 1994, 901, 726, 1983,
          890, 1036, 1216}], 
        Line3DBox[{884, 1307, 1306, 1295, 1198, 1324, 1344, 1343, 1342, 1365, 
         1180, 2096, 1364, 874, 1016, 1179, 2120, 1153, 867, 1009, 1152, 1115,
          860, 1002, 1260, 1113, 850, 2040, 995, 1242, 1079, 835, 2031, 988, 
         1228, 1058, 820, 977, 2090, 805, 962, 2077, 790, 947, 2067, 775, 932,
          2059, 760, 917, 745, 1995, 902, 727, 1984, 891, 1037, 1217}]}, {
        Line3DBox[{1381, 1600, 885, 1380, 1601, 1977, 1531, 1382, 1602, 1978, 
         1532, 1383, 1955, 1979, 1533, 1384, 1956, 1980, 1534, 1385, 1957, 
         1981, 1535, 1386, 2098, 1603, 1895, 2097, 1387, 1604, 1982, 1536, 
         1388, 1605, 1983, 1537, 1389, 1606, 1984, 1538, 1390, 1607, 1985, 
         1539, 1391, 1958, 1986, 1540, 1392, 1959, 1987, 1541, 1393, 1960, 
         1988, 1542, 1608}], 
        Line3DBox[{1395, 1896, 2045, 1394, 893, 1396, 1989, 1543, 1397, 1990, 
         1544, 1398, 1991, 1545, 1399, 1992, 1546, 1400, 1993, 1897, 2046, 
         1401, 1898, 2047, 1402, 1994, 1547, 1403, 1995, 1548, 1404, 1996, 
         1549, 1405, 1997, 1550, 1406, 1998, 1551, 1407, 1999, 1552, 1408}], 
        Line3DBox[{1410, 1899, 2048, 1409, 1900, 2049, 1411, 909, 1412, 2000, 
         1553, 1413, 2001, 1554, 1414, 2002, 1555, 1415, 2003, 1901, 2050, 
         1416, 1902, 2051, 1417, 1903, 2052, 1418, 917, 1419, 2004, 1556, 
         1420, 2005, 1557, 1421, 2006, 1558, 1422, 2007, 1559, 1423}], 
        Line3DBox[{1425, 1904, 2053, 1424, 1905, 2054, 1426, 1906, 2055, 1427,
          2008, 1560, 1428, 2009, 1561, 1429, 2010, 1562, 1430, 2011, 1907, 
         2056, 1431, 1908, 2057, 1432, 1909, 2058, 1433, 1910, 2059, 1434, 
         933, 1435, 2012, 1563, 1436, 2013, 1564, 1437, 2014, 1565, 1438}], 
        Line3DBox[{1440, 1911, 2060, 1439, 1912, 2061, 1441, 1913, 2062, 1442,
          1914, 2063, 1443, 2015, 1566, 1444, 2016, 1567, 1445, 2017, 1915, 
         2064, 1446, 1916, 2065, 1447, 1917, 2066, 1448, 1918, 2067, 1449, 
         1919, 2068, 1450, 949, 1451, 2018, 1568, 1452, 2019, 1569, 1453}], 
        Line3DBox[{1455, 1920, 2069, 1454, 1921, 2070, 1456, 1922, 2071, 1457,
          1923, 2072, 1458, 1924, 2073, 1459, 2020, 1570, 1460, 2021, 1925, 
         2074, 1461, 1926, 2075, 1462, 1927, 2076, 1463, 1928, 2077, 1464, 
         1929, 2078, 1465, 1930, 2079, 1466, 1931, 2080, 1467, 2022, 1571, 
         1468}], Line3DBox[{106, 810, 107, 811, 108, 812, 109, 813, 110, 814, 
         111, 815, 112, 816, 817, 113, 818, 114, 819, 115, 820, 116, 821, 117,
          822, 118, 823, 119, 824, 120}], 
        Line3DBox[{1470, 1932, 2081, 1469, 1933, 2082, 1471, 1934, 2083, 1472,
          1935, 2084, 1473, 1936, 2085, 1474, 1937, 2086, 1475, 2023, 1938, 
         2087, 1476, 1939, 2088, 1477, 1940, 2089, 1478, 1941, 2090, 1479, 
         1942, 2091, 1480, 1943, 2092, 1481, 1944, 2093, 1482, 1945, 2094, 
         1483}], Line3DBox[{1484, 1609, 982, 1666, 1610, 2024, 1572, 1667, 
         1611, 2025, 1573, 1668, 1961, 2026, 1574, 1669, 1962, 2027, 1575, 
         1670, 1963, 2028, 1576, 1671, 2124, 1612, 1946, 2099, 1672, 1613, 
         2029, 1577, 1673, 1614, 2030, 1578, 1674, 1615, 2031, 1579, 1675, 
         1616, 2032, 1580, 1676, 1964, 2033, 1581, 1677, 1965, 2034, 1582, 
         1678, 1966, 2035, 1583, 1485}], 
        Line3DBox[{1486, 697, 1821, 1947, 2100, 1679, 1617, 990, 1680, 1618, 
         2036, 1584, 1681, 1967, 2037, 1585, 1682, 1968, 2038, 1586, 1683, 
         1073, 1587, 1684, 2125, 1619, 1948, 2101, 1685, 1620, 1949, 2102, 
         1686, 1621, 2039, 1588, 1687, 1622, 2040, 1589, 1688, 1623, 2041, 
         1590, 1689, 1969, 2042, 1591, 1690, 1970, 2043, 1592, 1691, 2126, 
         1624, 1820, 696, 1819}], 
        Line3DBox[{1487, 1625, 1693, 1950, 2103, 1692, 1626, 1695, 1951, 2104,
          1694, 1627, 1697, 998, 1696, 1971, 2044, 1699, 1593, 1698, 2127, 
         1628, 1701, 1594, 1700, 2128, 1629, 1703, 1595, 1702, 2129, 1630, 
         1705, 1952, 2105, 1704, 1631, 1707, 1953, 2106, 1706, 1632, 1709, 
         1954, 2107, 1708, 1633, 1711, 1002, 1710, 1634, 1713, 1596, 1712, 
         1117, 1715, 1597, 1714, 2130, 1635, 1717, 1598, 1716, 2131, 1636, 
         1718, 1599, 1488}], 
        Line3DBox[{300, 272, 1128, 298, 274, 1130, 301, 276, 1132, 303, 1133, 
         278, 305, 1135, 280, 307, 1138, 282, 309, 1141, 284, 1144, 311, 286, 
         1148, 313, 288, 1150, 315, 290, 1152, 317, 292, 319, 1154, 294, 321, 
         1155, 296, 323, 1158, 297, 325}], 
        Line3DBox[{1502, 1663, 1732, 1662, 2113, 1501, 1661, 1731, 1660, 2112,
          1500, 1659, 1730, 1658, 2111, 1499, 1657, 1729, 1656, 1498, 2120, 
         1655, 1728, 1654, 1497, 2119, 1653, 1727, 1652, 1496, 2118, 1651, 
         1726, 1650, 1495, 2117, 1649, 1725, 1648, 2110, 1494, 1647, 1724, 
         1646, 2109, 1493, 1645, 1723, 1644, 2108, 1492, 1643, 1722, 2132, 
         1972, 1491, 2116, 1642, 1721, 1641, 1490, 2115, 1640, 1720, 1639, 
         1489, 2114, 1638, 1719, 1637, 1664}], Line3DBox[CompressedData["
1:eJwVzcVRRFEUBuHDAokCGNxncHedwR+wQ18AEAPB4U4CuBMEH4uu/uv0rbqZ
9CDZL4qIFL/FEWulEeu4L4lIeBVpWcSPtmyv4E7bc1uyF/GtzfMCbrVdrWDn
8aXN8hxutBmexqf7JE8h5/21NmGP40Mb44Sv3EftEbz//+PtkD2MS22QB/Cm
FbQ+ux8XWi/3YMf9Ve+yu3GudfKGewe/aDlux5m27Z612/CstXArTrUtrdlu
wpPWwI3Iup/o9XYdHrUa3nSv5WMtw5V40PLu5XYFjrRqrsKh/QcN+C2P
         "]], Line3DBox[CompressedData["
1:eJwV0cVOQ2EUReG/SCnuGkLCkARehgQoFC8whCkvhrwH7u5UoFjx7w5W1t7n
nNt7k/bOLg0uxkIIy/gsD6GzIoR5dOE0HkI1zyGdCGGdi24quQNVOHGzxiP2
aU7gw02c21GBYzcDZrNyOd7lUm5DGY7sS3gGMbzZB25Fv3xo/4dp/ZdfzX64
RU957yof6N+Ykr/4xU0fmvVPfR9FTEbfxwW7pGff5Kbom3gv+m1M6C88Zv/s
7lluNCvwLp4wruejbJ/lBj3HO1iRhz2b4oyed/PA9fojb2PU/j56h9kd59zc
cp3eI2/JN9Gdfs1Zs0uu1a94ExdI6uecse9GjX6mb2A4+l8whAX8AwBjSWw=

         "]]}}},
     VertexNormals->CompressedData["
1:eJx0fGk0le8XdooGFUopRVGZisiQkLYmlIRSpkgKSSWhTIlm8VORKSGRVEKm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      "]],
    Axes->True,
    PlotRange->{All, All, All},
    PlotRangePadding->{Automatic, Automatic, Automatic},
    ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.4737413056875*^9, 3.473742765859375*^9, 3.473742989953125*^9, 
   3.473743025671875*^9, 3.47374477225*^9, 3.473745187875*^9, {
   3.47374582946875*^9, 3.473745847265625*^9}, 3.473746121171875*^9},
 CellLabel->"Out[196]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"subsphere", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"unit", "[", "3", "]"}], "[", 
         RowBox[{"{", 
          RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}], ",", "p"}], "]"}], 
      "[", 
      RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473741225765625*^9, 3.47374134071875*^9}, 
   3.473741386875*^9, {3.473742790609375*^9, 3.473742814359375*^9}, 
   3.47374582946875*^9},
 CellLabel->"In[183]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"14.093000000000012`", ",", 
   Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJwsmnc81v/3/y+b0lAkSooko6gQhUNlVEQiLS2aSiQjIzNRRpTiXVnZIzuZ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     "], {{
       {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxNnHccV9P/xz93X4pkJTJK2TIzEk0JZZSSndFAKZFRVhkh2TOjrK9N9t6y
lZG9iRKy9/q9nr3eHn5/nM95f84999xz7z3n/X69122938i+h6SNRmNw2Whk
qv/MG42li0bj+aTR+FoHvlJ5XGV81Wi0rBuN6eo0QfTyom8XfbbodUW/LPpz
nfeYxhmkcb7UOfNVHlLZQ20P6djaav9b/+9Q39aid1P7A2pfU/S+oh8X3VF0
oeP3ZO5/h8bvo/FX0rwW0Zz+Uls7lYHqf7/6ryF6d9EPil5LdKk+hcqqos9R
nSduP1Dj/a1yuegrNWYnjZlozMtFbyb6Nx3bR+VHlXPVZ5Dqn1TOY26qf1Y5
X/R+qn9RuUD03qp/UDlH9BUaZ3ON87v+D1H5Q2WK2oeq/lPlUtHT1GcL9Wno
uleJ3lJ0KnqYjv+lcpkOrabn00Vz3lhlpNpy+qr9ENGZ6CtFjxJdiL5a9E6q
91LJ1H9H1XuopKIrlT90vK3KSbrWCrrWfTqv0vi/q+03lTfU51fVi6vMFv2j
6qYqt+hZ3qYyR31P1rmtdO79OvcU0SuKfkD0uzr+oJ77zur/jugHRO8kemUd
m6GyneiVVD+lsq3o6eozV+N9rrKKyka63moqkzRmW435jPqdIbqd6GdFny56
VdFPs8Z07u1cQ+f113XuLfx+B4i+r/A95qpXVHlFY/7J+lNZViVTW0uVl9W+
hZ7NDirfsGZUD1D7YmrfTfQuopuILnW9e1XWUZ/LNIdNNYdf9f8LHZulMl/t
c1W/pPK56NdV/6x6MZWtNE6pcb4XPU/tM1Xmid5c7b1Vvhb9l+rP1P6CSifR
hfp/q/Z1RP/NMdGvqe3+0s/tUF27VPs1oq/RfDprPrX+Xyx6E9Ff6fgAla95
Zuqzq+oFKpNEj9MYfxVew9fqnO+4Z133Ip3bQed+qX79VObzbtXnfzr+vcqu
6rOz2uapnKT2rzXGDI01lD2lczfUubN1rKfKhypHMk8d/7Fw/4Fq+4b3Kbov
z07lZNFbq/5A5QjRX6nvUzpniOheavtYZazoy3X9b1V21By6q20b1WPU/qT6
rl/7/zOawwaiz4t+/VVOUJ8t2ZdqGyH6fa2VDVRuZh/p3OPV/93M+yXLzHMm
q30ptTdV27Zq+0RlnNq3U/2pyjGiz9e1Nlafj/T/Lo3VV+U43oXOWbPwtU/S
sUX1/361363//VSO51mpbZ7K1vp/suq5Kh1Fn6sxN9KYr+u8a0V3Eb2Ijh2h
/01U38i7UHvX2uPeJLqn6CVFH5l5vjepz3GilxJ9u+gTRC8j+k7RE0W3Ev2g
6FNEryD6Afa1xumlcVro/82itxG9rOij1Gcx2tTneNFLi75D9G3qs536tNT/
6aK3F7286FtFbyt6OdHXi+4uupnoG0T3EL0E9yB6a9HNRV/B2lfZiTWv8d9S
Ga7xz1XbVyo91d5RbW+oHKT2s9W2vZ5td7WfybsR3VV0Dx1/P/N6uFrjb6Xx
Kx2/jLHVZwf1+Uelt8r2Kjer/Sd4ougbVf+osrvoS+ED6t9H9P3sf67D/are
VuUQ0VvoOm+qHAzvUtt2rCPRE3TuVjq3g/4fIfoklXVEn6X5rKP5zNI5xyJL
a6/7q3R8Qe418afOe6HyvjhGfdLae+wl0c+pnMU7VZ3X3pP7Z96jF6t9EZ33
mo5dIXpR0bNFTxV9l+gd1X8VXWNw8AHkTqH2mepztugDMvOJS3i/aitq84j2
mfnuXqwftZe19+26mfnunshTjTOrtIwbEfIOGXRMZtk1XfTYzDLtVmSN+i5S
W16Ozsw7r1P7yWpftLbsPDHzer+P55mZn90renzm93mP6Enq37w275sguqot
m08UXdeWzZXm9nJpeX2a6ma15eW4zLL9NrWfrvYlasvLY0OGsl+GqP2byvKp
q9qqwnz8F72n10IWbqU+7/BuRJ+lfm3V7wnRHdV2q+gZrBPRL2qcp0V3Ev2S
6GdE36N6Z123Dfcmuq/oVUU/mpr3w+c7q/+7Ks+L7qH6E5VZ8EnVn6q8DE9T
/bbKs6J7qp6j8gp8RvM9h3sT3ZU2XeNF0duI/kzlVdGPpMZxc0S317X/yS2z
wE0XlMZOqegVCsu2RPX8kFsb5iwiy6+tRdeFscIPiWUsMusn1a8mlnffJpax
C0QflhlPXc+cwW2F8cbluub5KquLXh8eAyYQfbTmPrQyJjxK9WCVVXiGOr6/
6JUblvMPVZb1l2qM81RWaxgLPFgZDxyeGX/dAN/T8Sa1cdhE0U1r47BZ6n+X
/ndlzXAdtT+u9pfVfo/au6n9M9GPit5H9Nvqc4r6bKa2iaJXEv2o+p/KvEQ/
hpxT3yVr8+471b6D6JVzy7vZIR+RlfD7o3g+OtZB462u57VN8D1k30Ea54fK
/PFu1TtpnNbqe6Dav6/Mj5ZUeURlC/VvrvrhzJj5WY3XOjF9pM75VKW9/p+o
uquObSr6fdUPa6xd1ecD0Y+IHgj2gAep7Cb6TF1nbV13pv5PFr2W6BfZ9+r/
bGWZ+Kro+3RuL9F7gl9VltD4y6rUKhupfRnVS7OORO+t42+rLKn/F6usrLI5
e1Bt64LP9H+o6PVZi6Kbat22UL2oSjdd+zWVw5FfieU/9Pnqc1Ni2ToJ3ARf
Fj1e9Rm58fNmmec+DHkK/lMZzHxSy5PNVGbonubouns3LJvQY0YE/58Vcmqi
xpuj0kn9T9V9L1Ybrx8BvqqMFR5X/bbG2VH9x6j9z8p4Ark2M+TIMLV/V/lZ
9w/MA2ZbLzPmZQ67a26bJ353x+qaH6lswN7Uec/r/AnsWdEviD5R9CU6/mVu
eTdabb9VlpGHi/6jMj67WMfn55Zhh6n998o47Hy1faHSi/eSWh72UNklM945
DXmk4xN1bEMwjehBhbH7sxrnCZXx6jMgtTxcS2Wy+gwprMMMSi3DwTwDU69B
ZOVyuv56rGfRDdV7qtzOGtB516rspb4fsRfhp+qyof7vreN7qbxVmufCb98s
zYvhwx+W5oPwwNmV+Sm8dIjoMSr3a4xDghei726sn1LlU9Ejgx8jxt6ozGfh
sTMr83T4+euV+TI8mfNG6JxPkK1qP1zlXrV9rOPdVWaCYVQvV1tmzKrMx+Hh
H6juovICMlfntFK5jPeiejmV89k/egaXqTTT/7dVtlWZAi7huirnoj+o3kZl
RfaExv+ltG58ldqap95Hx6puqXKp6F11/JLSuvMrrIXcvPTlynIOGXcq+pXK
1eo/TfXiqffmJprL5SpL6v8o9qbKeWq/LLN845mcpTGWrY1BzxS9TG0c+RW8
Uecem1jfP0rtt+m8n8HRIWd3VPvXpenj1faT6uUbPucH1S1VfhR9TMiandR3
QWl5vQ91aV33QN3LESoPa36zdO1uKis0bB/4qfS4f8ATE8ujvmq7SGUlnoP6
bpNbjozSGEeqPIG+quOtRB+qc77T/3XzhVCnMUxtNyN71HZ6Zsz7CDIlMxZ+
GHmXWeazls7OjLVZq2dkxvKPiZ4cGP5xME9mvPyo6EVF78veF31OZszOmr80
s0xgbV8Q2B78cH5mbM57PC8zZme9nZsZp7OGL8ksl9hTUzJjRtbqxZntK+yd
DXVPE9CLU/Nv+Diysg7+jnwcmXptsgZm67yBuXn+m2rrHOuzY2p9Ghl9QOrx
Juv/NciNyrac9rrOFJVFdWxorLczE9tsmifW0a5T/13Uvxn8LfUaZI9sgD6i
Uuv/Vqn1eHDFwbH+z9L/3TX2iML7BPsIY4B5sIfMUHt71h46fuW9N7A2jnpA
97MzdiHsJmo/Qu1vil5C5xwoekDlfXg9z1D0xxr3FP1/r7CcQQ4jj9Hf99Dx
V0RfwbNUn7MTy0He+Rql33u/2hjyNrXtJvpV0Q+iq4h+TfRDud/zBoEV96iN
FYfBq2tjzum5se1ypfHtsNrvb7/ctrIj9f9WZKn+988tl/dL/Z4mshdVtw5e
ARbiHtvyzDLL683U/y0dX1nlIv1vFe1ggEHxDMEznXTu1MJ8512VfipXsXdV
jws+9mysE2T8NamfC3yshcYcmXu9HZH62V+g9heDB7YTvWrieWF32lvXOUxl
Z96R6iOxP4heAnmbG2M8Bq7UvY/IvU5OTWwfwwb0t0oL9mzi9cHaGJJ6PbIO
90+9vli33+lYA9kF/tFYfXLzUvjP1aXX/96qryr9bAepnl95LWPbvAFbA2tb
c9snt03yH429s+g28BzN/VDugX0A/sv8zA9S28GsO/hM7A32BbKRdcJeHhfz
Y24/IIs1pg43ntLxNXXvp+TGOe1FnwofQf6KPl30cRr7eGxEOu9WnnHgj780
wNbqd63oh9AVauOnTTLXQ1iH6vtWYqy1n/p2BDvCX9W+qsrl3LvGvqqwXDlA
9dEqu4leEz0zMRbtobZTC6+/e3WtNrWPvRPzmSr6D7VvVVk2vZZ6DOaJTe/n
1Pd+tPr8oz6fa+wt1f5LatnxkuiVNP5Y3h+2bfQZtbcS/SL6CfIG3Ty3zRB7
3U+p18a+wQfW1LlnpsYmN3C/6n+1yq7YmFTaBAa6Je4drHOO6n1UbuS9wR8S
29/+BNtozGtEn556DOhZqdcyz/BJHR+rSZ6Q27b2K/qk2keJ/kX0e7rHJrr+
lbntUUeVtjVgZ0jZe/AGle3Vbyq6L+s98fsCK26l9oty2zpu55qB1bbRmJPQ
TeDjKuvF/PdQ/zmZbRTTeX+pMXRvtb2d2f42DP5X+J7PhgfHs8KOx9zB7YCv
txPbgkZozi0rz2dFdKPc/OQJeInu/ZjcuHo10WMDB4NDByGvg7eARTvo3Bcy
Y3vs0vAZ+mEDHpP4naIbdE5sw5mdeu12iTk8Xdpet6fG+CyzzYTnjz+Da90R
zwF8fGdquyK2JjAr9kfu/ZDSmHi86DY6d3xtXRpb8ahkoSrdeFr3sExhvAnu
2lV97gYHsJ54N+rzOHxH5W3RF2ou94Z8v0r0GqLfaRhPDtC5d+r/NWpfS/V7
ar9W9Nqi3w8cuze6Lfs9saz4oGGMivzg/9Xqv6aOvxuYeU+1P5wb6+6FnguG
UL+DVD5Sn2dUH6jyoejxsebBrp11T9MKY1n20Gaxj55RvZ7KUqLngbMqv4/n
1LYJz0Lt3/M8cz+fZ8ERKks3bNv/RuUL0XNVr6hzD9O5G6n/cNUHJ8a035Z+
z0cHT2fPfqG2lcFwalugclRiu8SXqo9Q+Yp1qHu/OTM++S4xb8CmkajtlsxY
Yn5p+c7YX5bGAPDaR+FrKm+CLbE35LYfgr9PTiwXwKMnJcbY4FqwLr4VMCgY
F1wKfj0hse8A302aWQb1LzwP5tAxt7xhzH6F582c8UccnixUnxbaUMCnPDdw
7yrqNz6xD2J0YlmAb2KmShPRnVX/mhpj83x5rryLXxo+r1XDtp4JiX1D+6b2
G4GbxzKY1sZczeMglW8z2yTRlfrjE9TYO6ltYGL9dDfsf2qbzNjoVaXtrfgm
ktr9ruRe1ecN9ZnG/bEGRU8V3U70bNEzcvtN0OGWwneQW497XeO8ofIUfENt
T+Zeq8N17vcq00QfrPq7zPZS+mO7Q5c8XNd/X//vy623gbXAw/gSH64so7fP
jXGR72DgSYnpYbr4FoEzsVecgRxU+8469/Xc9OFq7xEYZjFdf/PC/bGHLB7y
/VD4aGBaZN60kIngh99KY5jLdXyRwCFv6tzhgbF31XhvMXf1uRLcE5h82ThO
+/o838S2rMHIpcA2V6teKq57HWshsN8qgdH6NoxFLkQmiO4VuK9nw7iPdubf
N+Rz/4ZlN1iX/uAwMO8A0avrXrcujAeWF92t8DNZA55f+Pwr1L9JzO0G8GDw
lj10/P3c89khMMUu7CHR20ef4cj90nLwYNV/l5Z3+InwM4FVdsQmoeuNbtj+
g0w7VHQftXfOTINzwPDM+V2de7LWR+/CsvuexLx9sP5/rvmMEr2l2q5PLEPB
VNgNec7gEnALNpy5attCx/aF94YtBTz8o+plC+9fcBq2Od472Oq6xHNuBnat
vDeRifhZ8bFiSwGX7S96H7V9knt8MEBemRfh88JmNIH3KDqrvAe7IqsL+8XA
A9NDJmJXuzX5z9f2ZWF5+p7GHhtrAhl+5/+T43eIPoy1ob4batz9GrYFgWWg
8eX1yfzc3kuNMbHZYRfi+rwL8Az2LHjFumr/M3GfqfEMWVcr8N4Kr782Kpck
fg6DVD+SmFdcktpO9BBtuu7vueUd/OW+4EXwLnwG+AuGqm1GYrk5RPVTieXg
YNVPJpaz92uM33LLYmwUy1TBtxP7COCle6p+MDFmuAvMmVsu7KO2hxPzrnvg
t7nl+x3g1eB1vyb2uzcN3lhXjk9ANiOzkeO91N5U7Us2bKPCd4CdalvskJVl
63aiF6/M/9Ghu6e228xp2P4Pn5ySWnY+p//bl15brKveopeoLK8f07z+yC3f
d1D70pVlBP6zBxJjP+Qpdn7wcx90muo/+wy+gEUblqf4CBaJcbD/fJrYN968
sA0Hv3ezwjIXG2+7wrjw/MCHrKvfE/vXkY/YfJatLJvw8YFj2YP44d9P7NfY
Lmw1/MeH8UFi/wX+7HsT7wV0BHxa+LOQn8hRfPo7q72F2lcUfZaeQdPCmHCN
whj3BO4FrFUYx4Oz30ncB5sttswDGsaibQv/xxa9aOH9NSuuxX5Hhn0W7wf5
PC/miU1xTmK7IjKOOBz+o99ga0DHQS+5LjPOgQ9jTwczz4xxyngm4E7gwvaB
nXgWzOHDuN9R0efzWANgM469SFtiG9cLMU/W2zqBXTmG3/Nw0W1T856ehfkP
Og+6Dzbe5hqvXeV5gr++SYzB0L+Ix/gqsf5FzAbHFuKyxNgMO9+PsZZeDZo1
w7pgMbM2lkRHqPxM8C+zfpLgSfRBv1iI+2Ktsh5Zl6y3TqEPfh9r9vu41tjo
w7odqLFv0XNZPtb7gpg/OO7n2Pvsj7Vjj+Af65EbN+FL7JIb38Ez1g2+0TWw
2W/BPxgHbPgHWLow1moftvE/Y42z1tGP4MfrV+bJ8EeO4/tg/60Ze5B4A9be
X4l9An/Hub1jHPYL65F21uTGok8pjBuW00t+UKUH+zG1fa+p+l2a2t7NY2VP
rBb7gngS9kKReo8QC5GF3kmN7oltnXNZz5cFhmwmeiPNt09lO0tTXfMulU0a
xpf0wTa7jsY7sTDuYb8hg8ervYn63qnSoWFZxDtHHq2H7acwhjgg8BLzvyfO
HRA8gPnCB4YG3lhcbS013kNgFLX3TG0/xJ91bWosBY4C021QGNcNiz7MGV67
eIwzOGjmtqvu7yZ8AIltW9i4sPvhLxvO3gY3pcaOjAl+hMbndXb031Ttu2EX
hK/xvlPbP7kWdrOlo8+mGm9iYTwHHuxYeM4367xNKtvr8RFgd+2Q2hYHziP+
CmzVvTC+Gh+4Cz/OanoeT2b/YS10vX6svTiX/neUtvn8axOkBh920XinFx6r
k8qWrJ/EWOtMlfb63zu1jZD9xZqfX5h/HohNQvRKYLTUNWOukxofsPZvLW23
xWa7Y2q9k+fTTvN9IvM8e1S2X/1r16DGDzWJ+0vt++OaPStf9/LgXdwvdrC2
gT1OY33zrhPbSzvFvWyncycXHgs7yJox5pZqO60wnsamSr2G2rtWtvnQD70A
2ybrDZtRm3jmxAiNLXyv00vboOn3fGo9gv7ohsStMQ9smdg00RPBPeAf9Bqw
LfYKMC12GJ53N7XdFRjptYZtGfTB3wcmABugU98dOOFj9Xkqtb7Aeu6nuVxR
+t7Z0xsHT0DfuVhlk9QY+yz4VOr13CHWNjoO7wregg5LrN1mrCGNeRnYvWFb
0/oxH7AhNhbw4Q5BEyOEntQ91j/6TefYm/jL8CWDeZ5J/Uyw8T6dWkdjn85I
betm/ti7odGj+2sOU0v3h2d0C77xXOrrMedTEs+XeVJvHvTo6MN81i4cR4jP
A73sUmRAaht359jX+E26xPhj4p3CZ5poDgepNG84bhb/FTgEnH9GaqyPPe60
WIe7pPbVYQvtUtk2Co0d8fRYS6z3ybHm0WWw5zIOa4E1gV0OO905sW73TG3f
pH2voLnWgBgTTI/eM66wHIEPjY573zvGYd2dFeN3C342NZ4B635SXIt1d268
a9bjJbEmn9Ec96qMtf7Fgsg4dAdo5D52tnES6O9k5vlNQ3YgS9Ah0R+RHU1C
RmC/R39Gd14/rss8icU7tvDz6V7ZJntNrG1kHljsg9R+8R4hl5BhxM6yP6bE
HmFds77Ro5Gj+EfRwdHxsE/u27AfdrvUvA49Cl8G/JP33zPWAD5WYiDw27aL
PsiOman1XvgS+m6f1LwOPwtxJPhc0JGvKHwN1vtBqe0M2Dexc2Kfbx7XYnyw
KZgV/RQf9PYx5ktBwz+xsdMH3kh8x26F54nfGVsAPPmooJFrzHEnlZVY29hX
CtOsU9YrPBBd9crC/09ObTtYJbENl2eFPJoV7fBe9MQLUvMD9MvnQsdkT7A3
wJkT4vlwLeyQh+e21ROXt3/hPqzfAbEvNtIYz2fWnV+NcaBfiT6MD4a8MNYb
MYo3FP7fP/Yd97JI5jh2/LOP6fijlekBXDe3reiAsNXgNx0semDhvVBnjp1f
H5yAbaOwP7TKHF+/HrqMxju0Mv9dKnPs9lbgFmyelWOsR+vcPQuvl2Uyx2V3
adhnOq00NuitvqMrr4ulM8dxd4Ynh16PLw0f2czC5/aJNcC6wsaDjoE9Zzi2
59y+zdaZ4552UPsB+O4rxyGtkjk2qk/D8f7vV47hJ7dgQeW4pf2wLVSO7+8Z
PJA1CV+Hl8LDd4p3yntkLeAPYZ2w1sBSrDdsS9jLsNWMwoad2zfYJnM8F3E4
R6PLYoOGh1Tm9fD5/TWHryrHeeNPw6+Gra9r8DT2MvJ398rrClx1WLQzX+Q3
sniFoLFlgUnAauwj/A/HxHrGfsJ//JXEcoyNfY1vdGL0wVcBPSh4wpgYk/tl
j4GtDtI41+mZHh3vbOy/Y6p9ZOFnclxcizFXiTnAb4gHu76wj/pfXIKtj/d8
fOx3MMj42CNtov2y6HNC0L1y+4/xb7aKdu73et37laXtgfCgY2P8lkHD98BW
J8ae/UBjjCn8TlvHfNaIdw1fmBr8hL0NLlsx5sYc3ov74L2TO3JhaX8o73d/
yYUDC/O6g4Ovgh3w2YAlkDVgIGKJ4OFgneFxvzfHc2CetwS/RU7h+wFHgd/m
FeYPYMsvCvMN4n7uSR2HyXWJv9kk5OPVsWbAkmBK7IJg9Zaha2xe2W+6drwv
sDW8EFx/Tfqf3gDNXm4X4/QPWfBS7NNd9AzGVvYjM5/PYk79SsdWtm44d4Lc
C+xI1HODvi91ngfY49bCeR+cP0/li9T2JfIv7iz8f0/kb+X8CHAKeIUcH/JW
bkstc+ZHOxiGGBryiMgh+ipo4m320jjHoBs3rGtiv0ZuopMuF3oo+gQ6ALKG
OJsHYs7c76foV5nHGVl5fMZ+IsZnLz8X/OSbuF9iwL5NfS8Pxv/74t55Vp9o
nBsz29uGh83tIvW9oPC9gOOIXQBzEhN7vtof0/8P1PeM2v/PUzmnsJ0Ke9Uh
YbNiX4Pj4XXEo7wQ99UraN41ukO70F+IO8X3DA8EY/wv9TOB51yfev2gZ60W
OloH9d2nsixgb94Q++X+uHfuk/14XexN3vWCuHewBjEWYBKwMxiaeJo/GSdz
LC5Y/snUeB7sDJ4G6yJf/le6PzLr2tLtPBPisVgj5Is9XHicCwvn2LB+iAlC
VwcPI+eR9+CxN4Jmz2KzfzXs9tjerymMVReJc8F1yEh07w7x3g+NZ4VOsn/0
QS+fFn3Q+9Glwa5vBUYaFfeFjoeOQHwR+gk4v1O0TwwciD8MOwYYmbmAk/Eh
vBJ+hNdTY2Jo8P7IWNvo49iV4IfNop17J24KnICOgJweFjyEeWKnODPmPzTm
DBYGE6MLY58gLhB9CJzBON0axuPMYbM4d3CMc2Np2wQyCDsMel0S7cQ2EdeE
j2lEjMOzHRLnNo+5gS3PizmAkcBuyDPkDtfk/tGJeYe8S/Rv9s6bcY/gSvAl
/BD8BQ7DdrhbtIM5eSez472AuT9N/4vZIzaP/8T9XVza10r845TSPljsEodV
li+DcscD4Uc7rnI8ObzxO/U5t3ROFrmNjxSOMyf+AgwKj0UGgb//xSG0w6vJ
m/skta1vbwy6lWMBsMkTE/hx6j2FvF8uZDX0lJBH5Cahz8LPiXFpH/KfZ4je
QB7YTYXt/eSLfZTaVsxzJu5h34axKpgV+wE+gkm1+w2P58x6YH//L/Mevyi1
PoMug62bOEnuYVRtn+z1+LBr81L2KLF1G1bWn4gPQlfinZMTt7j6X6Qxp0LX
zqu8KXeOJf4LYttWLx2HxrjkN5LbiK7aubI9hXgf7E7I/y3x/9S2Ix+tvv/g
g2+Yb5E3CO+Cho/Dk5F194e84z3fWfpdk6v1G2M0HJdLfsQnDcdZ/1441voS
tb9aOg+IHLqkdJwzeaCLlc61IdZu/dI5U7zPm+Kd3lj4eX6YOt+zWemcmimV
c3Pwk1xaOTcHvxBxTMTJg1PJF3ihMIY/BKwaGJX8xzcKY+ZxXDdzHDj5j2+q
vXfDMXzLBrYnzgK7HDweWzK2ZezJxJvgKyTmhPhNbJXwV3I2ny6saxxcOR4a
mXBJYTsq75c1jN6Nrrs8srS0/r5t2Gfgo8TmkJMIlv5Z7c9Xjj0nfhP7Lfo3
+hC60AaBydtm9tP9WDrf5IfA5Gtl9nWSf/FSYX2EZ0RMGLhuTrxfckTIN6pL
5xwR30Q8AX5Mcia+K5wvtljhPE/s9B/pvAcq56+A0d6pjNM+Zo9Xzkch74S4
lLlq/1Bt91XOj9k4d/wJMRHjC9sY2DefVc4x4ThOFeJV8NewFoj9Zj38pPq5
yrH2P1bOlbgw9zN5tDAGI+6C2Geew9zKMQbduV5l/bGv6LsCb4Bnts0dSwOP
alE4VwcfDnk8xCHju1mhchw+/IT9D7/Ab4NMfquyXF6nsp+C3CZyfIgPxAdE
PsJH+n+g6BGVY5rBRcT6kSeyRZxLbDYxKyMCF5HDRIwTMT3E87AOiccmduQC
tb9Y2v5/de74GPzRn1fO39k0d45aXjpPjff4beH8F44RF0Q8T9vKcTzE8KxR
Of6G2JtOon8vzSeJLSQfDx4I/yPOn2dwYeV8OmKzVqscx0MMD+sfOxt5UeSA
L1M6JmStynHqxJuTG5uKPhW8UVu+9Aq/CnkL2E7mVdZtzy0c64rNGWzFOPhi
yItCd8deivw8unb8J7KI+RMPAF4mL2zT0jHA6NnNQk6hUz9XOIeaPNCVS+c0
kbO5jui7G87BXLd03txOlX0E6Kn4CfGN4Rfbt7aMI4boOPLPKsc5klvUoXSc
ObYB7J/gjot07oq5cxPI91yvdE4rOaorlc7nIie0fencPTAnPg4wyDG13zvv
/NjaPBaZsENlPxq2MXLiNikd904uc6vSuYHkcq4o+n8N5+XNLpyLRA5pu9J5
fOTArlY63xBeRA4Sfs9TNefF9f+hhu0MzyO7Gs5LXbW0HCEvtW3p/ER06NGh
R+NnIBYFH8N+tfcLMel3l84Fw55wu9pa1M6nnVhb1izUxdW+dO282RG1eSZ+
Y3gC9lxk7uTaMhTb8Gm1ZR+xEthwXle9u/pMIGaqtN+D/Ny1S+c/oq8fFbru
qbX9OFsU9rsSS4NOeVJt/oYvgu8kbFj6OZCDtlHpHATyQzcunZsANsAmBQYj
j5u87qHRDuYD74FVsFnsHDR2IjAM8SHEceJrA6tgawDv/RsTPLjh+Gv0emJ/
yC0iX3dM9Cf2ZVDDOWXknpF3hn2Fe8fGQk70gsK5WuS+4IsEI5Nz96L+b9kw
H8DnSw4i+Sj47NCziZvGBkK8EvY34si7xp4iTn2bhnOpNsgcn8N3Bt4qbL/C
rkXsKWsJXoHPmlzGkwv70fCdkf+1aeaYHHLNiJ0l5gdbC/GmPKtjCtvGsX8T
A4vOgn2dGGHsjdjmyW1CR8C+Thw09kkw7/el8xmJX9xY1z+4dn4gfkJixrAH
ECNN/hX2AeKpsYVij4Qv4RfG50ssPHZXMCw2ridFd2pE/HjhGHLylD8unNtL
rt8novdo+DsenxbOBcZG90ThHMPTcufVkxPHNyuWLR1TxzzZ2+xrbJjEw6Mr
kW+BrRgdl+9dLF06PpB4bPIPiFMnj5/cf9YUeWnEIZObtnhh/kU+xYk699fS
cfnstW619/mxok+oHQNBXAnxJMSWnFcZu4BbiJkn3g49hfw2vhNAjhvymO8D
kOMNJvw15A7fAWhTOl+efHS+E4A8Jd+DGJVPEsfXgCuIsVmYp1k4F5L4CGTu
nKCJUyReokXgDewG+Nvxu6Nrvlc65vCAJPI6C39z4BZs5pnjUhYLTILthRx2
4pKJLyJOER4Nf165cIwBMUR8Y4AcSXwl+CTJnccvSe4gMdTETf9dOfd8Wm4b
PHl82OHBnMRWEyeIbj0k9GvspkeF7ZR8SuLQ8SPg2yT/HTviGYVz88HzxMOT
a4oeR+4p8djoNdw7sQjT4x0Nrx0vzvcAiGEnTgOfIfn7+GfYR1NyxyyAwcjt
xwdIjm3rwOR8x4IYf3z6q6vPN7m/u0CePfHwxOaAAQ6pHc+Nz5l8f3xf3D/x
8H0Dq4ysHddO3Du5i9ivVi2cs4ye1y93Xhg6JjkaxKJhjyWXYePMPjXwPPkl
xKYhOw6qnceCvZw8FGzm5CIR+4hdl/zQPwp/owO/DTZ87Kb/6t7obnyLY8fM
cWvkmfLtgDOC58Cf0SXBUVlpvQafA3k9+B2IfwSLEgNJXCRYndjIXXLn/aEj
s78OqJ1nQtwEubfYG8gHIUYQnwt4lPwUvqeD3BgYsgO9YGhtvwX5Yvg28GsQ
YwhGB5/jMyHOEL8JeTrEgGLLJeaXnH3i8vB1E1+Jvxu8Bz75OnGcYfeQHfMD
s4JXyV39ufC3SshtIseJHDnyXn8q/I2R1oXjcIgdI36E/GJsRbxTYmzI/8M3
iy8G28y4kGXY4MHYxGQSJ873Ish5IOaNuRLTfFLDuip5KPhjybH9Rf0nNvzN
h38Kfxfojdw5PuT7LPyuQmn9d+G3F0p/C4jvPBCsdWHD34L4u/D3hZDx+HWw
45HTRIws9nByKtcs/f2BIbVtHcQm/5A7/hx9lm8gtCz97Q50Vb7lRPwfuaib
l/4mwPGVbR/oFHwbYfnS3wzhuf2eOuab7y0sUvq7Q+TRNy/9TRLiq8knIE4A
3b9jbV2d3M+1kDcN68vYWNEj+GYPNlrstuSmtQg9Dh5OfP5HiXOk8B3gh0HX
x/6Kvs++JtaIXBZyX8h3Zl3w/YdFS3/7iDhP8hXISeD7Ek1Vrm34GxRNSn8z
54TK8hXZinzhO0HEgpHjR+4D8Z7Eg5OfOSP6D6qdA8A3KFZQuSue2z61cwaI
8yT3gpwN9NOqNN8mZ49cjCGBG3vXxtPE5vD9APA5MZbkVZBTQV4f+RrEomKX
OLR2PD3f4CG+nrhFdAzsydjYkYfTQiYSR0qsPXkI5N3wzRTsbMTdkO+PzwR7
1+m1bbg/lP72AvKXXHZywshnJzaVHBRyTrBjjK4dK48d47DaMfQ8H+LwiS0h
jxafC3kMyF/yCNCbyN3mWy3Y/chjJIafGFi+vbBk6e/V8C2ppwr7N5Ffv6XO
fyB3n1w0cnTIr1+q9LdowB7kqxFnjZ5MPi85CsjQMbVzY8h7JHeAWOD/A0uJ
F/I=
           "]], Polygon3DBox[CompressedData["
1:eJwtmwW03UQbRXNvcpOHQynuUCju7sWLOxQv7lZcS6G4u7u7uzs/7u7u7vbv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           "]], Polygon3DBox[CompressedData["
1:eJwt1nmUV3McxvE71cwUaVPSSCnh2OIkWymEDkqOcJC1shUailJCpX3RqlJR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           "]], 
          Polygon3DBox[{{1746, 1945, 1008, 874, 873, 1195}, {1757, 1756, 1207,
            918, 919, 1208}, {1740, 1941, 996, 859, 858, 
           1187}}]}]}, {}, {}, {}, {}}, {{}, {}, {}, {
        Line3DBox[{753, 1069, 1279, 1070, 2015, 1223, 1071, 1458, 1072, 2020, 
         767, 1105, 1106, 2025, 778, 1121, 2152, 1122, 790, 2081, 1133, 1134, 
         803, 2086, 1146, 1147, 816, 2094, 1160, 1161, 829, 1173, 1174, 2036, 
         842, 995, 2045, 855, 1006, 2053, 870, 1019, 2059, 885, 2113, 1034, 
         900, 2122, 1049, 915, 2133, 1201, 1202, 1270}], 
        Line3DBox[{754, 1073, 1280, 1074, 2016, 1224, 1075, 1076, 2021, 1232, 
         1095, 1107, 2149, 1096, 1235, 1109, 1123, 1110, 791, 1135, 2154, 
         1243, 1136, 804, 2087, 1148, 1248, 1149, 817, 2095, 1162, 1253, 1163,
          830, 1175, 1258, 1176, 2037, 843, 1183, 1184, 2046, 856, 1007, 2054,
          871, 1020, 2060, 886, 1035, 2066, 901, 2123, 1050, 916, 2134, 1203, 
         1204, 1271}], 
        Line3DBox[{755, 1077, 1281, 490, 2177, 1225, 1078, 1079, 2022, 1233, 
         1098, 1108, 2150, 1099, 1236, 1112, 1124, 620, 1239, 621, 2153, 1137,
          634, 1244, 635, 1150, 647, 1249, 2170, 1152, 1164, 1153, 1290, 510, 
         1259, 1177, 2038, 1291, 1185, 1262, 1186, 857, 1191, 2160, 1192, 872,
          1021, 2061, 887, 1036, 2067, 902, 1051, 917, 2135, 1205, 1206, 
         1272}], Line3DBox[CompressedData["
1:eJwVzc8rA2Acx/GvoRxw0la4uHC209qOFjk4WGpC+VGzHGyllDJTJEraTZpS
sov8Acvf4KZWLi4Org5cXOS1w7v35/N5nqdnYqtaqPRExBJ+EhHJ/ogUEhhD
fSBilF/6IjKYx6Yty69YQBEFd8r2G15ExzbNJ0ijpC/zLYp407N8hgvvcrxn
W+M7rOJdn+meI49jfYPvsY4PfZZPvb/kOVzZtrnV/ROf+iHX0JR33W3woD6J
KXzpNfsDr/RGPPI3jmxPvGP7w7B+wEO2EflcHpdT8rXclvflZ/7FP3wtKXw=

         "]], 
        Line3DBox[{382, 244, 1773, 383, 245, 1781, 394, 260, 2026, 783, 287, 
         796, 2082, 301, 809, 2088, 315, 822, 2096, 327, 835, 337, 2040, 848, 
         344, 2049, 863, 1012, 2055, 878, 1027, 893, 2118, 1042, 908, 2128, 
         1057, 923, 2139, 360, 454}], 
        Line3DBox[{761, 1311, 1088, 1287, 1089, 1312, 1231, 1090, 1091, 2023, 
         772, 1119, 1238, 2169, 1120, 784, 1131, 1242, 1132, 797, 1144, 1247, 
         1145, 810, 2089, 1158, 1252, 1159, 823, 2097, 1171, 1257, 1172, 836, 
         989, 2041, 849, 1000, 2050, 864, 1013, 2056, 879, 1028, 2063, 894, 
         1043, 909, 2129, 1058, 924, 2140, 1213, 1214, 1274}], 
        Line3DBox[{762, 1313, 1092, 1288, 1093, 1428, 2188, 1427, 1425, 1426, 
         2024, 773, 950, 2027, 785, 957, 2029, 798, 964, 2031, 811, 2090, 972,
          824, 2098, 980, 837, 990, 2042, 850, 1001, 2051, 865, 1014, 2057, 
         880, 1029, 2064, 895, 1044, 2069, 910, 2130, 1059, 925, 2141, 1215, 
         1216, 1275}], 
        Line3DBox[{763, 1314, 1315, 1289, 1094, 2017, 1431, 1429, 1460, 2190, 
         1430, 774, 951, 2028, 786, 958, 2030, 799, 965, 2032, 812, 973, 2033,
          825, 2099, 981, 838, 991, 2043, 851, 1002, 2052, 866, 1015, 2058, 
         881, 1030, 2065, 896, 1045, 2070, 911, 1060, 2072, 926, 2142, 1217, 
         1218, 1219}], 
        Line3DBox[{927, 1061, 1198, 912, 1046, 2119, 897, 1031, 2110, 882, 
         1016, 2103, 867, 1003, 2101, 852, 992, 2100, 839, 982, 826, 974, 
         2091, 813, 966, 2083, 800, 959, 2078, 787, 952, 2075, 775, 944, 2073,
          764, 937, 2186, 1453, 1455, 1454, 750, 934, 1450, 1276, 1300, 1299, 
         1220}], Line3DBox[{928, 1062, 1199, 2131, 913, 1047, 2120, 898, 1032,
          2111, 883, 1017, 2104, 868, 1004, 2102, 853, 993, 840, 2034, 983, 
         827, 975, 2092, 814, 967, 2084, 801, 960, 2079, 788, 953, 2076, 776, 
         945, 2074, 765, 2018, 938, 1456, 743, 751, 2187, 736, 1277, 485, 
         1221}], Line3DBox[{929, 1063, 1200, 2132, 914, 1048, 2121, 899, 1033,
          2112, 884, 1018, 2105, 869, 1005, 854, 2044, 994, 841, 2035, 984, 
         828, 976, 2093, 815, 968, 2085, 802, 961, 2080, 789, 954, 2077, 777, 
         946, 766, 2019, 939, 1457, 1424, 1459, 752, 1452, 1451, 1278, 1068, 
         1301, 1222}], Line3DBox[CompressedData["
1:eJwVzbErxHEcxvEPRykxMxhuUITlMJCjTKd+DEjJcDFQRy6dxXZRorBKp9RF
6rJZlO22sxnt9wcYmHn9hnfP83me5/v7ZXfKq4cdEbGBeiZipCviuCfijd66
h2jivuD7+UX+hP/DLF+i3zjif/QNbLnbKMse3aPdvotE9oUDeU2+IrvBMhbk
n3ji99Jcv0SvcGlfoDl9C3V+G6c282mPPIZ1TTzwc6jop+m+9+d0CgP6d9zz
k9i1maBnGEev7hV3/LV3Y3TTZp2uIXQvKOoS+Qx+OyOeZVVZn00Gg+m/8KH/
B5SsKIc=
         "]], Line3DBox[CompressedData["
1:eJwV0D8oxHEYx/Hn3CmDmBXKoiwohTLcyUb+pO66LoNuodRdycQkclFi1OVK
XclwNtNls10mo93OwOz1Hd497+f5PM/3V7+Jan27lomIItrZiKlcRBflgYg7
/Thf55d8mK/wYx58iR/wHxzyX7MOdvRfqJl961vpDf2J/lM97Y+4N9tSb7CJ
gvkHHvk+buVr6jVWce52Tt5DW1/FmZ1l9SrdY1L2hgeex5H8wt0ib2ABI/JX
tPg89uzMpvcxg0HZC5p8On3HfcVOiReRkT1j13wj/QP89UU8mQ3JcxjDKN5l
//71KGQ=
         "]], Line3DBox[CompressedData["
1:eJwVzS1PgnEUhvEDyLQwyQaciY1sccMAk+Z00wSIQQ2gvAR8mTDFOSlGm12C
Qb+An8FPQNdi0WLUH+HafZ1zn//zrBz0drqJiNjFUyqiMBfxhupCxKN5mW/x
e57lG3zIE7zI2/wHff5i1+B/8xEf8ts8QSHtG+aRm6n8snvAs/0NSnbXcoQr
fOrGGPBNjL1bdXPEL3GIO/05TnkFef2+7KOBM92tdy3ZNZex5KYmO6iiqdtD
m68hoz+WJ2jN/uN9Xb+NpO7C/CrXzb9J/zdn3S0ijaJ9Tr7Lf7XvJu8=
         "]], 
        Line3DBox[{933, 1067, 1212, 2138, 922, 1056, 2127, 907, 1041, 2117, 
         892, 1026, 2109, 877, 1011, 862, 2048, 999, 1266, 1190, 847, 2039, 
         988, 1261, 1182, 1317, 834, 979, 1256, 1169, 1316, 821, 971, 1251, 
         1143, 1448, 1400, 808, 1398, 1399, 1397, 1246, 2183, 1130, 1447, 
         1394, 795, 1392, 1393, 1391, 1241, 1118, 782, 949, 2148, 1117, 1104, 
         771, 2168, 943, 1087, 760, 1298, 1297, 1286, 1086, 1230}]}, {
        Line3DBox[CompressedData["
1:eJwVzrkyQ2EYgOHPmGBGbCE0lsQWW+7DnkilNsYghMJSyURNo3IHRqE1YxRu
Q2dpxH4NHsUz7/9955x/TnZtr1RpiIhVbhMRF00R680RB1w1RrTqNmU2OOSs
JWLWe0nnHXbZ5Mb3c/Ztznc882bu13lt13teqJsHdEE7NMupe4f13W5QF7VT
q/YjOsqH3ZCeULPv0jHG+fQso9f+O6U5Jviyf9Qj7y85dztPMsW3OeW/l7XH
PM0MP+YCaec8Ge/8mov0miucu+9Jt/7vZsWzPn3glX2OKdlf8gcD5Cdf
         "]], 
        Line3DBox[{1462, 1891, 1918, 2186, 1912, 1893, 2018, 1619, 1913, 1895,
          2019, 1620, 1914, 1977, 2020, 1621, 1463, 1979, 2021, 1775, 1622, 
         1464, 1980, 2022, 1776, 1623, 1689, 2145, 1682, 1777, 1919, 2143, 
         1691, 1683, 1778, 1920, 2144, 1693, 1684, 1779, 2167, 1624, 1465, 
         1685, 1780, 2168, 1625, 1466, 1686, 1781, 1626, 1467, 1981, 2023, 
         1627, 1468, 2013, 2024, 1628, 1915, 2190, 1903, 1629, 1916}], 
        Line3DBox[{1470, 1921, 2073, 1469, 1922, 2074, 1471, 946, 1472, 1983, 
         2025, 1630, 1698, 2149, 1688, 1782, 1631, 1699, 2150, 1690, 1783, 
         1863, 1864, 1700, 2151, 1865, 1692, 1874, 1841, 1867, 1842, 2189, 
         1701, 1866, 1905, 1694, 1875, 1843, 1869, 2146, 2008, 1702, 1868, 
         1906, 1695, 1877, 2012, 2147, 1876, 1703, 1696, 1784, 1923, 2148, 
         1704, 1697, 2026, 1632, 1785, 2169, 1705, 1633, 1473, 2027, 1634, 
         1474, 2028, 1635, 1475}], 
        Line3DBox[{1477, 1924, 2075, 1476, 1925, 2076, 1478, 1926, 2077, 1479,
          2152, 276, 277, 1123, 264, 278, 1124, 266, 279, 1125, 268, 578, 
         1126, 281, 579, 270, 581, 1127, 283, 582, 272, 1128, 285, 274, 1241, 
         406, 287, 408, 1242, 289, 1480, 2029, 1636, 1481, 2030, 1637, 1482}],
         Line3DBox[{1484, 1927, 2078, 1483, 1928, 2079, 1485, 1929, 2080, 
         1486, 1984, 2081, 1716, 1487, 2154, 1717, 1718, 1488, 1878, 2153, 
         1706, 1879, 1707, 1845, 1887, 2184, 1846, 1708, 1880, 1709, 1870, 
         1844, 2155, 1888, 1847, 1871, 1710, 1881, 1711, 1872, 2182, 2009, 
         1889, 1848, 1873, 1712, 1882, 1713, 2178, 1849, 1890, 1850, 1714, 
         1907, 1715, 2183, 1883, 1489, 1719, 2082, 1720, 1490, 1144, 1721, 
         1491, 2031, 1638, 1492, 2032, 1639, 1493}], 
        Line3DBox[{1495, 1930, 2083, 1494, 1931, 2084, 1496, 1932, 2085, 1497,
          1985, 2086, 1722, 1498, 1986, 2087, 1723, 1499, 635, 636, 544, 683, 
         1416, 545, 638, 538, 1417, 684, 546, 641, 541, 1418, 685, 547, 643, 
         1396, 548, 686, 549, 730, 1448, 646, 1500, 1724, 2088, 1725, 1501, 
         1988, 2089, 1726, 1502, 1933, 2090, 1503, 2033, 1640, 1504}], 
        Line3DBox[{106, 826, 107, 827, 108, 828, 109, 829, 110, 830, 111, 
         1290, 472, 112, 1254, 425, 831, 113, 426, 832, 114, 428, 833, 115, 
         473, 834, 116, 835, 117, 836, 118, 837, 119, 838, 120}], 
        Line3DBox[{1506, 1934, 2091, 1505, 1935, 2092, 1507, 1936, 2093, 1508,
          1989, 2094, 1727, 1509, 1990, 2095, 1728, 1510, 1987, 2170, 1786, 
         1852, 1851, 1511, 2179, 1853, 1854, 1787, 1856, 1855, 2185, 1512, 
         1857, 1858, 1788, 1859, 2180, 2010, 1513, 1860, 1861, 1789, 2011, 
         2181, 1862, 1514, 1838, 1839, 1816, 1316, 1840, 1515, 1731, 2096, 
         1732, 1516, 1991, 2097, 1733, 1517, 1937, 2098, 1518, 1938, 2099, 
         1519}], Line3DBox[{1521, 982, 1520, 2034, 1641, 1522, 2035, 1642, 
         1523, 1992, 2036, 1643, 1790, 1993, 2037, 1644, 1791, 1994, 2038, 
         1817, 1645, 1734, 2157, 1729, 1818, 1939, 2156, 1735, 1885, 1886, 
         1792, 1884, 2171, 1646, 1736, 1730, 1819, 2175, 1647, 1793, 1738, 
         2039, 1648, 1794, 1739, 2040, 1649, 1524, 2041, 1650, 1525, 2042, 
         1651, 1526, 2043, 1652, 1527}], 
        Line3DBox[{1529, 1940, 2100, 1528, 993, 1530, 2044, 1653, 1531, 2045, 
         1654, 1532, 1995, 2046, 1655, 1795, 1186, 1656, 1796, 2172, 1740, 
         1941, 2159, 1741, 1737, 1942, 2158, 1797, 1742, 2047, 1657, 1798, 
         1743, 2048, 1658, 1799, 1744, 2049, 1659, 1533, 2050, 1660, 1534, 
         2051, 1661, 1535, 2052, 1662, 1536}], 
        Line3DBox[{1538, 1943, 2101, 1537, 1944, 2102, 1539, 1005, 1540, 2053,
          1663, 1541, 2054, 1664, 1542, 2160, 1745, 1665, 1800, 2173, 1746, 
         1945, 2161, 1801, 1747, 1946, 2162, 1802, 1748, 1947, 2163, 1543, 
         1011, 1544, 2055, 1666, 1545, 2056, 1667, 1546, 2057, 1668, 1547, 
         2058, 1669, 1548}], 
        Line3DBox[{1550, 1948, 2103, 1549, 1949, 2104, 1551, 1950, 2105, 1552,
          2059, 1670, 1553, 2060, 1671, 1554, 2061, 1672, 1555, 2062, 1951, 
         2106, 1556, 1952, 2107, 1557, 1953, 2108, 1558, 1954, 2109, 1559, 
         1027, 1560, 2063, 1673, 1561, 2064, 1674, 1562, 2065, 1675, 1563}], 
        Line3DBox[{1565, 1955, 2110, 1564, 1956, 2111, 1566, 1957, 2112, 1567,
          1958, 2113, 1568, 2066, 1676, 1569, 2067, 1677, 1570, 2068, 1959, 
         2114, 1571, 1960, 2115, 1572, 1961, 2116, 1573, 1962, 2117, 1574, 
         1963, 2118, 1575, 1043, 1576, 2069, 1678, 1577, 2070, 1679, 1578}], 
        Line3DBox[{1580, 1964, 2119, 1579, 1965, 2120, 1581, 1966, 2121, 1582,
          1967, 2122, 1583, 1968, 2123, 1584, 1051, 1585, 2071, 1969, 2124, 
         1586, 1970, 2125, 1587, 1971, 2126, 1588, 1972, 2127, 1589, 1973, 
         2128, 1590, 1974, 2129, 1591, 1975, 2130, 1592, 2072, 1680, 1593}], 
        Line3DBox[{1607, 1765, 2142, 2006, 1606, 1764, 2141, 2005, 1605, 1763,
          2140, 2004, 1604, 1762, 2139, 1761, 1603, 2003, 2138, 1760, 1602, 
         2002, 2137, 1759, 1601, 2001, 2136, 1758, 1600, 2164, 1757, 1756, 
         2165, 1599, 1755, 2135, 2000, 1598, 1754, 2134, 1999, 1597, 1753, 
         2133, 1998, 1596, 1997, 2132, 1752, 1595, 1996, 2131, 1751, 1594, 
         1198, 1749, 1750}]}}},
     VertexNormals->CompressedData["
1:eJwcmHc01u8bx0sRSZKQGSVJ+hrREC5FiaQkDTIi2qEySouQBkXZIqNssrfL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      "]],
    Axes->True,
    PlotRange->{All, All, All},
    PlotRangePadding->{Automatic, Automatic, Automatic},
    ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473741404359375*^9, 3.47374283053125*^9, 
  3.473743001390625*^9, 3.47374304003125*^9, 3.473744783359375*^9, 
  3.47374519896875*^9, 3.47374582946875*^9, 3.473745862140625*^9},
 CellLabel->"Out[183]="]
}, Closed]],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"subsphere", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"unit", "[", "3", "]"}], "[", 
         RowBox[{"{", 
          RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}], ",", "p"}], "]"}], 
      "[", 
      RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473741225765625*^9, 3.47374134071875*^9}, 
   3.473741386875*^9, {3.473741491578125*^9, 3.4737415031875*^9}, {
   3.473742866546875*^9, 3.4737428943125*^9}, 3.47374582946875*^9, 
   3.47374600615625*^9, 3.473746055484375*^9},
 CellLabel->"In[195]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"spheremf1", "[", 
       RowBox[{"s", ",", "t", ",", "u", ",", "p"}], "]"}], "[", 
      RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "0", ",", 
      RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473741225765625*^9, 3.47374134071875*^9}, 
   3.473741386875*^9, {3.473741491578125*^9, 3.4737415031875*^9}, {
   3.473742866546875*^9, 3.4737428943125*^9}, 3.47374582946875*^9},
 CellLabel->"In[184]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.812999999999981`", ",", 
   Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJwcmHc81f8Xx21CyTeUIiIlhFSKxkl2UWYaUlKKpLRIsvcoKSKVERpUyMw4
195773uNa49rb797f3/55/nw+NznOe/3Oa/3nlsP9e4w0NHR6XLQ0TFS/259
/OV7pU4elAdHH3pVM4OT6op3zjYXAF13bcUe6Szw15UIGpwfxUeFhxIEC3qA
L15lxKskDbr/nShn5CWilEDKfAL3AAivhZu2OKZAwPdTE2ejCnCTWMlNFicy
cBrPDz6t+gtEnk5/0c3FcP6Fqf2e/QPA6TpU5uGbAqRruiHvPnbDh28xh7kv
kOCMW+vXD6Q0EGG1f11gPQRmsQHFWzSbwC/DUsfFOAtG6Pp3achMwV/XScl8
cTdgsfjo5fY8D3p/Fr2Ljp0GilbmwhhHN94ozeQsVSyBRO3DO+guUCBokK4n
apCCNV/hOomrGr6ylrkMZRMhbO/wNpLxKlbnpnRtJ9SCFiUulI6DiLdvrDEy
R6zjzYeHX2zqrgLJjcPJ7Hxz2HPRIbr99SyG7rxGPMdcAt9P5ixf+rOApt78
UeToTvTsfK5aRfX5V4VngOYzrSwtUZHq0+D7U8O12QZwuzD/1ZOFgvJh9FKp
/IngpY8lbu+rIWWbUTrQD+NkxWe59XNt4Jy1pc+toghER1PbJla70P1L3zPr
6l44sTlZJtg5C46dno+I2lKAH1kKw9nSBmCm76vo61c/wGNNV+u3djHstv/6
/fLIAKwe56VYvbiL555NL97mIYJWcf7rhJt90H71meJcx3eMdGTfkR87ApGa
6X3ixHawHFO5f9E+BX97MYhxn5mGrwYnF/WSU8Fh88mLb1hT8FWvF+N9uzmI
rtnb8MOgCwNNS4c/Zzjgj/Adj20TZmDt8diFGJUZ3Dsu6z1zoBBMROhiA2NI
UC4WtMv74xrekJrp3u/WBBnCEllitV1oT19zoPbsGlqJdHEObWsH5D/4OnuK
gqdEXee6u6ex5QzkfVVqhTEV4l2PphlMvZ1yJsy3C3csKE7TfNadST3gRfXJ
+/QF7zeqT6OGz9p7eDrh3xgXxVptDGvIysk29q9QbnbnVZnuJogfLq+Nvj+A
3YT8v+X0jfCFZZYvz7Ma7rFui+v72I7E7z6aTDVEaFbawqgzRYCti36TPxzz
MD70EhPffD/kpakOsOz5APVeYgKhzkVw2MmafWcKGb66nDB2dEvHO5cibG4K
EkGjWEe/OnkAguItTsVll+PZDpn5GOIorP5HlxfbSIQ0kiflrVAj2nYdbmEZ
noFA8sShefsSGB+5e7R9ZwvuELN4J719EdyMPjCWXe7EFvu4mC8JNejrKXh7
T+ocbPe9fEGU2o/Wd/Ykb93zF2LLPAXjSknglCP/+zTdBmreG9NKfNoGH39a
kT6fa0cFWZ6k/7hXcYepf5bgLBF6OERjZAPGscLDI6EwnIL7PR4zfXhFBEUT
1dtH90/hBYvvP8UPd6Oys+NWEarP8Uzt1IdUn3UNvpFnXr7Ccp0QVoYeIjDr
G9sE+ZHxz6ZfvlmRv1Fk0v3SdkI77Ddl6Gd3JKGIq0RXY0QNMO+/ztOeUw/t
8uGmv42a8Z6sKDvnyW4I3PSZ8cevAnh8g78gYG8uhrQ+qkxS74eUHz9lj8WY
o1x1v7N/ZAHErSk8XnkxCAHJxX5PrpTgL94nEQS3bliRGtT8IDUESrFfkuI7
WrHtUc05zV+jEMjf2v2osh9qAz76fbzYh1quDtKfq2fBWziRfaytAaJP7gkb
shtEZqdvP86LLIOyTIxX4EY7DiTfKKWPJGFqpJxZONsCnO/ZONZiv4CdXFf0
1sLc8Czd+N6JNSK4VTKs7DpDRzi82UdPOaATbty2O8zd3YSLgm7wmGsFuSYv
SBpG9kHSp63yv+4MIn9hz6XLCVNIF3XCKNmiD4IziPH2ZsN41PBAnO+vbryn
y2dD87klymid5vNV7FWXBqrPauXQ/oHcXiB8Zi64t0DE+u0SG4MnM9GDffQF
UaIb0meeVdJVtiMPe2TB+YNlcIJ1+4nDl5ogWp2PIdOuDvlPpm4bdOyAwY77
DQI9RRC24cc+QEzHmw0Bf5OT+kAvLuxZoG4Y9fxs4sjMIMC2MDrtINkh4Kc/
bZokVYdFz8KZQ0rbYXOtgrXC9xG4e8uheZtjL3bc2DvL5T4MMRYun5YPDUPF
mKQW/7kJ5Fr54T5yfRbm726x2DHYBR+2Eb3Kns2g4nYcb2tbhkv/ZcnnHWzD
PYGsfwacxhG0m3n86BbAsLSi5IbvMnbHMB2/NJSG6mAbs/9sN9xkexk/SE9P
UPjv8p7Aum5QvnTGP7++FnnNGw//hmUcizJqrL86AEXa8XKuDiTsuyzlfXVl
EldulOqNqg3A4Pw+o0vkXnxWLG3qwtyD/xgNdMhUn0qRXnstqD7t/E6fmKH6
lCx6+vxERx94MGi2WIq04KPru6R37SNgPNuT7BRxIsxGOvtXvqrHv9GXhWps
CiGwqvT4FZ4WYGZLeQ6Wpeg3edZC9C71vD1pL9V/UgL5vBKzbzwTkdJcMKGr
0AfaXlt5BC1i0Y5eJy+vOhNe/Jp/dbpyCDjmdGwtqH1TMctbwb3YCCkyLbpB
lDFo8/v1quvcEHJd0zXsHuwHkYyEOrWEceCMUpvmkJjD/fbvGXIrKWClsbMm
JK8fPuU3deVOruJ/bJahdIOLUPEXT2m1NGPzrdYrrq5zKD7N9mc6YhbkHtv9
915+HVkcwletxApxyqSLK1SjFSwvMV53SKUnKDVq+feIEeHJtMXuC/nFeCeO
o8kiaglF+87d6DIig/LOYMuO6BY0P2Du/Z5pEkOT1A/LGZKh3WCkzfJ1G34m
bDFcPduDNpJWJJrP4J3D+vepPjkPcXkIU31ueu9TZGHYD2LjbrNfrpTh7NpV
WTWHfDRyvXnA5RcROD/xWrHcKsQdm9dmd53OgwcL8iZPGVrhmt/QdQniP6x7
x7FrhtICW6uEOWpvlEKak9aJza2R+CnmibJ+by/kNFga3WSOR8cwp83T2Ylg
4Z7jc/LsMPjknRxwl2tDj3NTAo/9yuGF0rXWuvIJsO8yvsM3NYbBIEJ20+mA
rk+PDYfqpuCWGdGmr2gZzc8byt/7PQSZLk/JzaEjMLevyuugOyPBoN9aeOj+
NDQ5mz9Pk2lElgQ3XzbeVdy45qz5JHgcwjxbJdzY6AlCkk/qVY+X43Bk89aB
U7VwYetDZlt1BoLfWNfsBzciVI08FdqoT8OQW4e1rA4vYWUxd1lJJhkaXkxV
KT0qQ/0D57KYbk3gERaZ+G05ZCgvHxfWKq/A9pZO2UP3e/CjmaK0JdVnzw82
2wiqTye39kvnqT5vtt25e+RsPyR3vkx9u/4Vj/CXfnUpLUC6brpPT5OI8IaJ
YfHDswgkJad1C5ByoWbXI8ldEq3A3U//sP1UEIYyeTaQdrVAQ8Ob1MGIUmBK
tCep6B2H78OP+I786QX3vNeLzmy/MIK9XneGIxyIpw8NtfsMw23W0hvmP9sx
4SW78+JQIsww7Il5tzAJW0iSj+6aT+LB3w5wvJkAhj8U3jRJTgOf1JeAmqvr
2CT8r9Xmag3QJfC2/GaehAx/gcaPaqwE7rUUS875VvgoWib8arIO4801iDYn
6Ai7QoNijEMagW5HFDj5MxCiSh2uB6VX4t2/MkavCf/A/TenWngMA2GjfrKX
yYsIvwVDLIb1dGCGmdvCanYROdTjkiyCySDXwaR3lTMKzzh3Jm6wTuAWF+9P
riFkoD/rc5CgEYuxDfb211x68Iw4cxXN59/+Ev4gqk+5/t7fnlSfgf2ywpIJ
fTD2z2h0tCUHwjt4Jq8JF2LBsQccNieJMOHX/i80KAOEA88JOo7mgM1pZcee
oBaoWK5U7viRBH9NX71+2NsMEVpYNHu4FPqZjhg/vhUFb/lOqBhE9cKPGdHf
zyEee+RT5pJX/PAOzPGHfh4GHmJ6d9FqG6oKdujaGKTi81WRqIP7psDan/eG
+9gEOsssLgv0l+K7nSfZegKnQWo9/SDp4jrutLS6oaHdivZheba75aZgFw90
yoWzEqTLi8hn6PqQN+Z685psHS6Ovy7mPE1HSD6llvXjRzuqG2fqSrAyElR/
PR6w21GBGrwXar81xONHnT9MI7kMhOcNjFtZjhAh+gdbxaBaOlQGXDP06ltE
VhUXoU1zA5Cq40QpekKArga2/xSnxpF14nfT0NgAZBkfYHzygQBzwnyDcl49
yKsm40rzSc9O5zxG9fnxde/0TarPYrW+Qd7gXjCXzA2vVK0D90dpUvY+BXhn
n2ozc3Q3/ON5yn/saCUc0xEYmAxEkPj45G21UjM8q/15+U1iATC9KiggqrTA
VcH9z1uES+DUzZnuBvYkaDcKfrA1sxcYbErUgvNj8Ra++oD5P/HhgZ3Fgy+H
wa4p2bxctgWPPs9uPtBZiXln6uUPZE/Ch5KbonHPR7He4NmhQ6M9+DxLR3px
gAINzrskp64vI6nD6oOt/ATSH/pMn7BjAv56ZgvpzDES2hToRSTlFpDhMFdh
n1U93nESYjr7bwU9sj7+KTtDQdn3vnEqigyE2AuR/87YFGEww0Gdfybl2DH8
giwdxEAQ1Yu5fWxnDzziMIhiGy2GhMCxlJd0S2h6seTfXFs/yESPZx5/XA/7
RTJJXPwTmFRs/O40dT6YP3cXjxRogCGOPu0Dr3pwzPGtKh/VpzZf/TTN5717
7KecqD5DrgtWvpgngrA9Q+rgWjvoF/b927ech+WFzpq2bR1w4RSbMRuxCU6y
57TGUfIAyPE/fyg0AsFitfgCTzVYOnCUPFZpBUfFvoNND4tAoOf+SEx9Bqyz
N5qUzfXCxfK/cVZDYaiiIqTfppSGU9vpda32D1P3KZJ8d0Q9qqyO2h+SbMb8
l+1DZOMJuBSoprI5fwBLP7jsNvUdROOKO9wil6fgRUdn3eDEDNpq+cdri1Hn
24FgO6E9w8C/2eXBos0q/n4+wOdfvI4d0RWXQnobkU/RvuSuyCx+mbs9pLmw
gNE2Na1hvnQEekFFO7P5DFTXOsE/atOEF869ZHMSYyC0mbyz5d3fBT52e+sp
xFq4P//cLOP8ElrKKtBtOdUH0V1MExGfOkFg+0FWA48J3PatQjuMvQ+2DfXG
FQ13gYN0mY/9rR60NDPYa0/1KXDXVGmI6rN2knlMkupzz1vTHxGuXfBOLPjB
Wf1eyPwT6ZCZmIuR1ttvM3JT8064AGXIrAsCvCv1H3sXQbj5Uf7yl3VQXsos
uUBsAEWR+0L0/W2w8cH6TY10AfQrsy8kpCN0qmU+bzHsA3KJis/N83eRvfpj
jE5oDupFtVsHxw3ByNGvldXpZfhG1f2w+3gHvt3314v95hgQPSs9eQa70PcM
uKWeHUP2uLwIX/cx2HywTD+6fxjVyjxGtSsW8KHGapiGTB8c6omQlFKg4C8b
Hl5OdTpC0SfzfTrOLfi6qm/nisUQHknufEzvtoyBFir0ckfW8EJYDdOzVA88
V/Q88eP7DjRyNyjJ9qYndJorZYS8aQe9UyQD3bkmYItjGzxbvISeMWtPtLeQ
YKPIJ8b+dh+82+4Y9/XkJDZ36x+/lkq9VxUKIPBuP5SnCXJzH+1B4dyic5FU
n6bhVXU0n17hV84XUn32dK1WsP5rgVL4mum9exC+xEwxh06kIVg1ktYONYDT
5aUvf1R64cn6bKl0cjlouSpWf9hWCVdEvJw5j7UChyiZkWV/J4gXBafnPSJQ
62hYE5KaD5qm2vP3m/vgmudlq6reD9CpskVlr3MeDvQ9SM9hGIKNbmro3P0P
Ix9fufLcpgc/yb/jRMYRSPYvaemVoe6vwn5++nIT6L61PDqAcQhcgoS6nara
8RMn8wPu+gX84nhEjMDTAZw7N0598iRiNITm7Wpcx1d9JcI8qW1YSCAf3PSj
CWWHh39v27aM5/UFG6Pjl/DOnnK6EJNUmFPtp9PU6UGJpSGxrzV0BL2jk88i
DVpAsTVOuNe/HfgmM99b2yyjVOCm/nbzTgiTeMrc6TgE7Nt7bojsm8I1ozhJ
klIH3P7a931wijrXZXmcFSnduGooasRG9ZlYrKDkQ/WZcPzaw69Un19EDr+t
PF8LTtUf9nE2j4LoXUvxIO3vKFv/ZVX0dDlUbdW7oBs4ANtbXr5Kqq0FD6VA
LvvaAniZvPwxsKsDBFyW83O5ekBCzNS/6NM/KF/WlzpdVwi79+72ufOkH64d
DvDyufkTdtwr5LcVKsA6lzYWOvVBCDcMNwgXtsTJmjHlC7eI6DEin87vPgjt
23VfwtQvzNFJsx4kjWOqJp3KzxRq39r/Obcv6R+aTMzoMZycx5CTHNX3vetA
qUr3U1NgFvLUT76PdFtBXu6uvz23O/BEesGp+l1u2OYhnyZGvTcCvvzKWyib
R97bfKL6gcXgs3Xfz3/XiHjz846laU46AkOHbLz/iwZoKE1zrLftBvLJ8Ct6
F1awWaP8mjJHE1Tac00rhY6DWY/+0oX+KdQotFD7c6wBNofzBLIHT8LXpSsN
Qm+7kdkra4nmE532tdF8bjMvfP+T6nOue8bJ0zgL/muxC1WXmQJ6lsevBsTd
wIRZISGclAYD+tWx+dZDcM1X+SiXZhNcsWW54u2bAsSzsluCPnbDzg+PNWnv
bHdLWeufVf0F5eYH1cKbi6EikCeA9i4nsdvBq9kxBf4sreerRhVg5EN5B9o7
3rmxDjmPkjRgeFMcw8RLxB8jNf/94h4AqZxkGUHpLFDp25c0ND+KDFcNwmjv
hGe+mriV6eQBT3ZSP+0djDWvVetMcwHY1pMfqTGXAHP0tKnRnwVUKLC52hfd
iW89uL8wd1dBdFpAOAffHJ5QaVtvez2LxuW8srR3ucYHVuMMHESUiCcOMkWs
44PZg/R9XNVwZve7QHI2EUwrNJ7S3vFqhiXVKxRLwOajov2GNgWq6LKfRQ9S
sNXDZMnzeR6okSzVaO+EfG6Z1pMc3Wh1oFDZi+pz+JkWJ+1dkefXVsJLqs9h
a1JN6cJfYI6Mz+jv9YadURTfclEy2O/fXqxI6/Mgx+c/L8TAWtM4cWrXBhb3
KBnT+IHJIQYaryjGHUrjz66wPaXxm3OdKD+o/OiV20s03kbgL6WEyvu1SJ/q
pfK/zIpjaLw+65o4jc+hbH/9ncoHFPBwU6h8L2NAMI2XLzvl2EPluxStE2l8
24+0IQUqH/aC3ySOyr9drt5H4xkcrbVofLqx4XAHlXfkePKPxsssW6fR+Kuj
oa++UnlNXgcFGt8swbCTxr9tfJjQQuXVFQzyaby0Rfx7Gn/vjzt3JJXfbCil
QePv6tbQ0XjFoZm1eirf/TmhhMYnmQl60Pgvo+Wqn6h8s6SoHo1PtuRnoPE7
rZb5q6m8fvixchr/K8Tfm8brBoudD6Xy6YnESzRee7hGkMZXdpyDMipP8W8s
o/Gro5VfaHw35bvBeypfv0n8/3zj5jd6NL7o2dGEQip/wdK7mMYrEQjFNP5i
3+HgQCrv94JBh8Z/z0n6TOMzdJ+EE6i8k9crAo2PPXp3ncYf7+09GUDl3w3m
qvz//z9/skLj1wOOKOVQ+fxn9Bk03nV07iytXhNmcc99qfyusfEjNP7OL+G7
tH4Yvula+o/K5wi5/KLxpbWrgTR+W+wuc28qH/Lm6h4af1pMv4PG98Xy6WZS
eVN9tyga/1A1qJ/Gv3AoEPOi8i8F6DhoPFzYa88wWgaT57fvDZqYxC69yWP5
OxtAPXy0VsitCsZ/76q/ZzON33fnWYbszAKlN3PvRf0LwG9u7FjzzgF8JBr1
bD2QBCJeTvwswdmw9J/qb3OLRnxgFTKRaDoAVTbngmnfQyfwx5nWz/KS7m9p
39P/SdBndVMEFO/uZW4q7IdXrAcfBIv3AO8RNo68wHeQ0nL80yONCbhrvstA
4UwVaEQJKvt7h8LFwDdOj1engYfR7uZCXAn61NwZZ2P7DSUrlQdO7JiFHA1R
P+87w3i31MNZZ0chiL+Jy9uIn6bmtdM8ck1D2J1iH7hvJg9CXAt1vweMg41f
LdFcfxHLGoKu1VLntvq2WX2tDeo9uVwe7+S5gE9HpjaMFMog6rWK4BM1Ejzv
258uPL+Kceu2UzSffSe3mNHOr4lteSPtPE4e2FsoXN8IUc+Omk1nj+O7K/e0
AxOX0Gj3o080nvz5pQ6NV1WXHqfxv4czeyRO1kKh2rqynMckxqzfyTbHZbTY
Q6lS4WyEB3rSTVKxczjTG7Z/+N4Isp82P2xlXw56rMsPrwct4BFla8aM06Mo
+j0QnKNrQf5h9Z1Ix1n8eW/bQbor+fjw7Bdl2ZECyE3OOMN8ZB7bfOcWmjmz
MUpIr0yYWt8DMkYPLKj1nSJJ/PGi1lfY0EmMVq8EpokzfdR6Xbdz+0Kr1ye8
k2fxsxDhLdsfR5cpMP71ennrQCNY5XR2rJaUoyFTrPuE2RzwGh41YRAnoL8k
U+SxpyWo0hRZnt06DwYHrqcyNo2g/dWt+/fyvkXuQzsu2rFOAYeQ/bVLJ5bx
uMy9O9iWAzIk+fKaOhKYe5Lct2iu41lhCXN3jU5wDfBrTYofRq17rpnx/Qt4
t9ZMm+azIyv7Ku0+pM+9x0zr50AW7r9pJt3ANbvUx9RHQQLfJ65WvmHki5w4
xzTSDoKnzkTr8lAw4yLx9QO1MlyZd8ujncdXEZPLROrvLcst+kn7vbc5EgIF
IypwZtD0X2XqAFiFJpom2A2A0Yzq7v/2tmJb1onZfiUKZA8uplFSOuH4W0Hn
cT0ixjT33k+9tABS9e/jdQy+o+rGMufEFiKKy3xuVTm9BIlmjyZsqsaQcEfB
sjurDMX+FJ+pT5gCZfCCrHerKHE00Z/7UyT8u8WxK8GNBMc8r4eJ5m6gtTp7
CYFEhIdxQvBOcQBfxz1d5Hg5j89rNVlpHvYe2vv6G9UDT8tZAZoHLfG98QO/
e6H4u9dR4vcxdCxcXRwUHsKrPEJvz9KTYF/5F9nzfqMYQXw9L2dWjVh5zZrm
QXe0t6KL6iE98lcqzUPy3FdGQ4NmTDs+aeCr2w8HZi8Ene0dgrRrHoEbTP14
UDhDQGITBYq8BY/5cvZB+u+tZVuDxpDXViJp8eIivL/AYirH9Av26QenLt0Z
R3HdkXx5wjIcqTDJDHaYRDUzzppteXMYIpjn72SxAPGzs/Z3qVu2t1F3Br90
O+4/mue0fGsKqvK4RQOubuCTM0w7/u1bwHd8o77SV5dhO/vo7053CmqpVX87
1fUD19z4avUOE+Fw5743v6LoCOoah9RLK3vB9yb36U1fibjNbvb7+ztz2EAf
V0W7n1fCy+ljqd50FT7I/n8eHUlK5lnuB9ba9cS8lQG8ks5LGrEexL86crI0
P71f4jrbqH5YhP7k0vyUp7zjyn/WjWrkd09mDUlwUaPS9+qlMaDMaJDV34/h
ecNP6h15E5C0q/Du0etD8HZeoFFuzzTaDx6JPHJ3BlLqrcbOlZHgPW+sWhXD
IiYFv704qLsMorXNfsf+a8VV+hDW1vU1dNNMgYdGM7Agvy+oja0Z6LfZXD3J
14+mHaf9Zj3GIbK5y8T/OD3Bw+7vh8d2dIQbIeTrE+bzMH6misEscQZrZhSj
5LgI6H6RXcDDvwNm43jjo03oCaSirjzBTf3wtVYv8fymVpzVcJB/92EWIy8a
f6X54RI1b46i+rEdu6n0/31g7ESruwkZwEugre9uD8otEjqMpshYay/GTvMz
5JZ9o4nqR+PLpaL/7yGSHaM2Eb3IfODAA2ODNlDiHkr3sZ+ENPlP1yaMp1Gb
6Gz//PcglKbyPG4oGQdNBUPlrF2LKCIZaC80PgG6TRG6t3AQ8v9c2prBQk8Q
ctxuee3yPJQ5nsvo9GhC9lApRqZPDAQ59UgGD9IAaG/3O0l80wN/TcgXjr4e
waiu1pUtRDIcEb6k0lvAQLjrW1AhxMBMgOWETYXKIzCh0+/P2juHC2mX7UPe
lWCPpnF1k2MjuPm19kwyMhAy68jvipL6YXn+/Xx/dhV+9Lj8eYxlFt2D/Hxp
fjz84o58ofrReFiqTfOjURlyXG/LIAzXKsgJOTXgde7cln0fyXg9R3C9mOrn
q0De61ranpN84f97yCIheSTdpwLPGit6idxNg/KiH5LrQWOQ0q4twVDZjxx9
3qICdOVQOnxTR3RyCgyy9iWwms3h26RIIy+xNniodTp7ToIC+tF2ypkTq5gX
UOEUN0iElFn9poUd41DyUpPwOZmZkO+VqFnGNgJv9iu+UKDU4x1RtgWrE0wE
BeEnH9XUU7FyLEqK9UcvfDUq0XOSnERJ945p72tt4CGzKeg7OxPhrsGRo/Ry
rITWvJr1lS8pmCH667WL8gIyO01fujFfgQfEjoTbHi2BlTHP239fMRBGb/tO
erX1Q5Mom2/n+XRs2LF8yiBhBmUvP3anefs8IXH+I9Xbioe0Ic3brwgVpXvi
g/BIILElVZKAq2nKpkp3yJjqmcpJ6ytHPu9vFVRv1ha3/7/vLZLk+nIqKvDk
um0Yx+hJFPPaOtxINw7BWxoY5M8PYG2PqN2xiSC8/kTmxEM/Cpz/lfLM//48
nnry4eX199/wRzV7zKDFNEQpqOkJtK3jwOnX24VtE5Hz9NUESV7q/j4z8Hrn
IitBXG6y0Ws6HaOudz0k6tRh4fvA9q3VDAQvp0yWOscx5LPIYUiU7YVTNe/o
UlSmULjirFzH2E3Mku+UUs5iInh++PyF9wkzwbUiNvRowhSu2z5l49y0gIFb
Iw/5WldiaWLSHru2MBBT/zUZ84+B4Kxrf3PQrx8aJSxP5v78DoWOapFSbjO4
ZcTkLc1bNEhqhVC9nZc/YkTzxnzmkHJKDhku69s/iWj8BjsLv004apNxzPXQ
UZo3lwiG4WKqN/omn1Kat+MPhQ6fzS5DKcuEw9kf0/C3o+KN1ckx6OP4IXli
og9d4NvPoZVqzEpKZpd6QoEjk18TGeZnMXqP7AuZgh6Muihhbn5sGi46qFry
FK3iMN3zikO5AzgdFcYnlzAJeOTt5i+HWQg7z+ocVJufwlMX3wYWBNehxPaF
d4V5azi2ZdjgQOECdpXL6JqrdFH7/INd3sI47pfKlLTUa0fVlXN5dyKYCDzh
KYFiAXQE+5X4qh+uK0jPfavjwOU5HLh6cXtKTimy3ajJshmm9kmducqpJAbC
4+A6xtWqPnBPGft9PJWaCwc1p675zKDuzfhEmrfmmBnLIKq3376oT/Om2S+h
yNc4AOfHHoaf/FUBkhdEzm3RJaMNne8zmrcUy+2B+VRvGXnNBTRv+UDfHu1d
hIn73o5ufCnC59n3Wq/cop5TuwGbNDIRB8brbLy3dyKDi2uwQfwUtH3Zk8B8
jYKcn8+SdmWO4gsH8cMSsVNg8uM2U4DhAh6tlXW4GjiNPQpnGrRbRoGlu7R2
QJaeIHiK/6xd3QpqbrU67fiuAdmlbDgUZWZxKH+KVKa2iiKLxKhO4waQMiha
T2cewufqxsk/dw+hfXQZQYjASLg4+LXM4tMc1vgOCtetbOBxEktB4/YZfGDp
9/HqxTwsHTLn2uVfh0Uxt2rWbzEQpGMMLJkjeqFcVuXBV4dGUNoYYTqMM/h5
pohI8/ZzXrftNS2/9Kyeo3mbs7FjjrnbD+Lf1fn6IlpB2fN21JFHZDTfcC+n
efs6+L4xl+rtiptXNs3bhGapTqxlGwp7QWJDdS9m2pl2CadOgJo0p0WL1DCW
FYsYakdTsLjvTsvY7TGId/78lefeFAZ5Nxaad85jrfIWwQ/SZBgS+/Bj/fM8
vv4WZRAmTEcgH6qqEFRoxs2C080aM2T8LV9dLU9YRfR99fvrowKo+DyaXnqI
iJZn6usSzSZRRORs590bDATJOcUJNu1B/BpZkE8q2kAzr5GT5xgo+Hwb0632
Rwmoy3Ldmq+aOnf1zluPdtAT5tZs7yYuEuFK4aFnw/OdwNyXqWuzfxZzRFSF
aHtXriVfkR/Vz8IP41M0P5PSURvelr3QbLUSC/9I8NuFSdToFxl7PvXI0Pbq
YOJtchbVT9/EUjLNTwzpyxae3hr8Kf4xi5g9gPxrh4jhNqOQErSJPTqpG3kL
brSUK8wgZ1eJXss4GUgcrhELJn34SXT0eh73IrLuXWHSViPCZdu3+7jahlBt
s5XTqbUNfF+Zrno7vhVv0zmfkxesRc4x5cOLZhSc4cwOC6imI5w3Cos88qwW
/XNUZ4x3r2HKiy3R2X8n8LvQ3M2pV9Ewt8VCdwK78GAbndoraXpCwRsJUd0v
XRDh1es0/bkXbN83Gt0umUXrHywWNA/OL0oMfageMhsCJGkeGF9zJu7w6oEa
IU6OX/KDEByh0qyzeRDdit0jaR6S7ouN0vIpY9z3bzQPR6xHld/1ZqLFlFf+
PjIZTUrdfhUvDkJHff/KR4FyfL67R+S1wAwamJIGTHJJUP5OqD37Sj1a9dQn
/epcxvfnBv7yHQ0HQkf4bEBnPdYfIAgzaq7h0Zfjkj2f2vHEi8sf714IRnUu
sqGNCwVvmMWd2BOyjif9AtUf/iXAyuTP5QtiRHwfwCf91JqOoMn2S+e6SCtk
j76oPvWBDFzb8vfwfJtDgSyjf7Tfe8wh7ictR6vPP+X7/9w3PVWyL6QVKjbe
q3FWjUHde3Zh0dBBjFhbylC5WQT6lh0lwXUjQO+Qtd72oADKNEh3spJLILIl
h7lWZAIUw4xLf3wJxnTN//pD9uSBKYd50c6NXiClR28/69UO6ntlPBN648FO
4iT7Yn8jPlG1cPZfIsP70wFCd8lRYCJVZSYTRMbX5Q2blj/1QwZHzEz3+VCI
upVw6WY3Bb34bbLjnNrhFqtQYoJiJLyx+K/3v54FvO5e3bBrUzLe+L66tudp
LuzXFa6kX57COW+u7qCPzaDB6lK56XgKUKTtZ/85LuHl3J+hMgpjuH3WbZsU
NVfeCT5lTcuVPXr/PSqn5kqnuU+Ws5uLYe6//W9fek6h6otAje6RFdwepNt4
l5pb2Zo5+U2oudX6u/XTNGpuzdUu6Y6TqYRQ7zzGAR0iRmUKEn5eofbPru22
B6i5+MjD5GdHqLnYJSXfkJaLf/6SvXtNtw7uiZKqxLRGgOe9b6hh3Ty2O+zl
OkGti/fT3W2e1Lr81y+8QcvXm+Xzief4a4C7oGGS+zQF8o9Myu+6OoSltpN0
DdS8/1DTJ/scNe9bd4OMMzXvqwo8qK4XLYdz8ccWGu5QcwdD18qtQ1XoIBM7
r7+jEL7wql+gvScklC7oHG4aQul3nCzZ1DpGsVnV0eooFOvs00mt4+Edlu9n
/1B9PmqM1EuhQFmP1Pjh6HJ8YSXgtJ/qWfrZqDjN84s9z3TeUT2bHp7JdviZ
AemxV4euzg1gRwAKzrD3wTemJ3oalqmghVfdx8oaceVaj3a+JBkOJgTIRzmk
wujf+yE8C33wWKhHPimrE6q/FaTnVGXA9hupPOlfxuDUh0qXBZZSyLqlsGWC
+j251+mraN9jMv9ATob6PWFhPPaWMdHg1M7zco57FvLG2Xe+Te9C+WudFlM1
6WA/LG3F7D4NvDPGLbd9pnHR2O9LjGID3BvkSRTb04MaYUyaUmNruHX4+7nb
K40wvkbhbvCcwVpGj5WH32ZQZ98bxBf1cGh5bKQrdw5Hut5IUISo/z+6sV7T
shSNBhm5hffNAFfyqWsmBALc1n7Bz9tZjgu8TmKx9fOQ2GLlk0rsxGMDjSsu
mbm4++jrGDHCLHy7V3d3UmAWK49d5Z8LaYGrbarKD2U60UXQ21oiZhW7dmY+
1b3SDU/VFuuXr1A977A8+PDQNDJaSnfIsHfBrny1orcLFEzP3eISNNCFCk/U
Io6v1mPED5f0qdVRaLq1294Ve0GMye3yrdFO5BKJmVx8OQsC58Z3mgnUwAOD
03Suu0gYLWebq3p8CXT/uNaHZHagU7TGyDb6NpyZC8eJV/MgxZ2seIx6Pqpv
ZG7a2NUBas1vFC5KteIebfDn9l3Bs63oG2jVC+0njHTFH49gyUXn7NGdFExW
P/gzfmcvBO2OogSUj6FGaKehBjVnXl6XClUid+MOi40r24gjkH96RDxyjgz3
Zco6fn4cwh8fbrV+r5wFH2u3pqqvrWD2kGWrwb8JZNV+fr07cxlI20sLju1v
x17JkFPpXRRkNux1ei+5CMy/0l8Rw3IhTlrhd5bWIOZuJ210nVqAc9cVe5PH
FvGCOOPJ4JRpnJP9eaCFuAzfFfw/C72bws8BL01Ny7qAV6tr8ta9Bqwx9Tmi
F7WMmxLkC9lD++GjUa4gh0U/3nD1MenRnkKeU2tzTi8G0Nej2O6A7yCc37+6
PfDpKGhysazOti/hN64/Xu8756BCQHkz/1ItpApNbZLjnkbdO/d2TB6cB98d
FxX+6qzidER4zdrsCnq1ndeLpCyC2+HcoX1vp1H4ndTzw9964ETGqJCneiXG
bFY2eDCyhC/9TvN4TAzABOsmKUXoQl9fzhN2TyfxzMXtyNYwgrd6jb4JfySB
3ZNtx7cUToLStxuiOENHyHjMwen+YBIG7VQYSlg7wOxV/bbLVB9GR2N3ScpN
w5t3NxbUeekIipaOn4z6GQgpnWd5op2noXrzN+FbDbPYfJ3vss5NImwyEpVe
EcpDheBcEbvbSxg59Lkw+iMZlC7LH3q0px4texKXvv6YwIa5DQ9F2Xa0LRA0
9cnNA9fLh1q5qHnZ75OG11XnCcxQ2xH6UqsepnmYgvaGUWDvE9HciAJGwl//
dmXF0EaQH3T1Xw8igdXfsdBdf9dxYblFgb2qH5KHSd9keukJ7T+0BIO8WQgZ
4lMptaFtoPPG6k9f9jzemPZL0w0kAh+b6z6b8DjcqMkR371lCUcZvmi7p5Nh
BbPcXN/k4JltMouPpSawNJu4pzesHWNWDP2a/VywQOLHopbQFNjckzxgHDCJ
F/8sbGXxjMCWPZvemlB9XLbdkXJtiJHw0a5T8MxMD345lc/oTuyFCyxalR3U
Pf/pG9WkqOZY5J0q+l43zUA4UHgiR7aRhXDnFrmdz7EX08IIX96YUPdmGb0C
kXtEqKnmfbga+g1+rDLlnyYv4snehBIbAzLM2d9d3RP4HY4fuTSyaXYcW6dP
uPxrbsV7V+gJDRsFqHSwbE1s6xTUPk5TVPYZx4ku6azywGbs/EmXd8B4Gty3
LOSRt9AT3iyIa+p9msGT/yxXilOIkHcx93pIxDqWHtQvOfB9CG3ttvmEFzMQ
+IQ+F59XYiT4mh1nse2bx6/L4m339ebRq0uLd7CpB2xM+vqJunlwueSajTK1
b8ga6Zt5bQfg6i7Ljs3U+fP3XIK90+o4btzj70nZ0YSm1+fsd7vXoz2MideK
TkIv8dH8r/ohzDPrCvPk7Ud4e5L/nDwF5HmXgplWF9F7YEpqe+Qyxl474fDs
YStkvKLb5iO4iMf595jcl5hDfseaYu2n9ATRIdPAGu0VZOjefPH8y3V0pUyb
a5yg3p8//UVPHO2GrwGzT/bcq4SGSxUflYWXUM+b7Z67QD/sWpK/yOjdAhoM
x5bvqU3gt1iDcNv7vWj8Slu3UmUEU3z2u1H+TECFh3H+iNIkxnr6dfAMr+Iz
B7+ON0WVcNle8xjD9incVvH5hPPfJdyhxU/nK7qBkkzkNnWjKTw6XryvYT8d
4QA/msrST2O5Wa9C22QHrPizJUnaNcDypvPnNlyX0NVkz4KmQi8UDSzOjrcS
YS3f7tNo8wQ20jm79c40o8uL14cj/cdxhskg8p/KCJzkecNucoaEFoGf7kS/
W0Zh0kHeC9dXMGMncYxk0I1rqVqsj76uI4fMLe5EoSn8mnNr/wOWNticUlZ+
X78VNMSr3v7hXcbVHakhc496QEV0+4mjlAGQdtnTpZ8xieumH9LeOBeg6Lb5
qW/qE/inR33nSM0AMIeMC6vuqkXeRb/t+lIL+FCGTYhpazPYKnN/5CAUIl3+
pn33Dyxh3NhxuZ69i2inKqiUYt8EP++fFzUL74T4M3rjEW3LePtgZGXRTCs4
Tdxmc+IchTN3ml9HvJrCkT9Ct/Kp8136ei5/GnW+LzzlHV2kzveoenWfGOo+
EHFPNG8bdR/oS257QdsH0EHJX426P1ie/csxQd0fSu5IWtH2h3sxLdwvqPuG
jW4f6Rp139DRfyxN2zfmBHe2j9SGwoxC/CGD7XNou4reoqvlcOG4gFuY4A+4
cfvp86AIah31a/mvbu1EkYgB9i8HEFbPJA7IB89j+uqm/K1hc/j7ZHtasF4d
8DZYlApuJoII754HL2pWUHtBQivvSy3AmEqBG9cULElGz8gaU9A1LGc3S1wl
kE+mOn0+RoFXi4wLnfrd2HosoFEkLh493hzdE+Y4BwE8V36mbxnBQrErKJWc
CKKy4o8+j01A0afM4VqFJfyP+dQH1/pW+I83RkylaBTL6Cw0bHMWMf7BW2uX
5DaQCJ999yl3BjdOnxZ0SB5GmX/qa7qWzTjo+i9F//E8hAixiV9eTMO9LmaZ
WcebkOFK6L4jgotwO/XHBbOcUdT6j+4tE2MW7p4Neyz/eAroh6Yn919ZQRMn
ckUe9ACXOvlusf0gGt6OOmC7dwHfwne+wV0kkMt/9OYHzxTKab0d2hY0hEcT
bd3/cNdjmtCFY7yHB0DZpeNz9v5BMJ7kc3PhJ1NzGPm6yvoC3OLTWWhv1oUz
Q482fM6T8d/n/v7r4suwLzuTR55jAlPmW28bmjRgi2evz1L8FFTa+hheGVnD
5ACOEZFJElAeDYRKUHrx+Gb6ozHkOZzf5WZkOdcH55ofOaWrDOOSXJDpR8Ig
6que2K/r1I6Zhs37Ajf1QZrGTZaJiBFoG3OL01Ydwt/08xbtllOwMnzkY37c
AEwz615/H0LEm69inDK8J+FFBFdg1kM6gvi07US/Yx8oqP2J6IrrRCFuu2Kj
+VmU35av9bJoAIR6AwaOV/bi9dfvDtNJDCJ5dV7iFgcJWZB+Qd6yG/Rff0uU
WRoHOQ/j9713pvC0h5Ib5d8oiKs/z9omMAoFCQXaIs+pflunuFy+jUBzoPfO
HnoGAteeblV/6354r13j//JRA078iV7n15jFmos4lFhOBqb7Y7w7TNuQPu26
ewaBjN8KLa4dHOjDnILzmlIODZBknW3ZQd33IzRfv7zDPYuJ7hd5xD72Ao9r
2EDj7imI8xIpE5EdR5FZ5bFY2V7oG9TkY35GnbvjXz17G/vhp9xelsrvhSh8
ppr9eMMMqglaBGZLUfNrwHALk30FprBG+Xe+JOMbX0lZ0bkKXLgRmX/TPQ5G
eHbf12obgxOFQHdVbQD9zBsVyyUywP2kuORPPQpsjXCStT08j5nvG29riJTA
XilOQ51ZCjS8+FfNITGFdffH9EI2lcOgTf0TfXsmgixdn9AEoR8iLHT/2x8X
jLAr8XP+2xl8ITFvOcBZgabXNiUen4tDK2W5MFu2cVi/KRZwv6UfGTz0f82R
COi8VczHNoQCz+tiLAzpqLkqJOFu5rc6VHwk8HidOsd7KvLrL+RMYttXXl/m
qXI8nB4pvFbCRAi9wik+oNgP4u8HPJUpOSCvT8q/5TyDz99ckogllWATV7Xd
mygCLu8jh/BljEFlppbOzrBe1Kq46um9qxnlOX6VWIlSYPrbmVmfGzPY4xMb
G61KxswPLD1r7yiwEZ81wXFpFN0m2GueberDDxdILisqTASKAuk0WaUP2j5e
NjwgWwvaLZvMjn6ZQeTkJ5TXd6H60z/34mOJKJgsI5ZFnfv3XO0Dz+6YwHbT
7ADhTVPo33kopHplAmROiwZVnuzHpxfNPpcpjaF4BeFc4k5GwjEJWL/VQYJd
4Zef6GAreLmSVAhjM8h3LHPwiUMfcHmbPtrK2g2q0fIMZb5k1O7OP2uf04iF
sVHzp136MaS7athUeBwuzuin88j1o+Le0Bzir2lM3siuPx4/DDu8cfynRCvu
NTgo2Vk4hSrTi2XPQukJ/k6XlwNGesAvPkg1jbqXKeVZhDE9mkUz5iPaJtIk
kNGd1w581g8v+H4mvm4l4xElk6S/WsWowpDi89STjF2cFj2zqcPwaFAwuM6z
CeNPPKg7eXkGzbcquiqo9MP59WccbJI9qLotQFqVYRWvuziyRAyngtNS16WX
QwQsYTOgc/pMQV65niY7NjpCrrWgGiNbB3yvW3y1LaofGky+Er9JzyFXaT/b
Bc1OmBbulbu3PgzLjUKnMqj5oev+skCySQ429aSf6nq8hKU8QV17BsKwrdKs
IJTxL4oLKaWByQraRVh5SJmM407WUtHSxBQ4+nOo7bMQBUtdwson5NZQvJXr
UMBgIzglNPB/dhgC8na+sJ1y89gdp7j843oj+Jpf3yoaPQlMZ9bTgTKIPWlD
jwJDQ0BJV7zk8pFZ4NrhrMCaMIlq4VJ7xevz4Ntz7zesj4bggFaK+l71Fewn
cc1RBwbEJ8yIs/yrxOUtfC/fFawj7/AHGUW7FtgmJLBblDSFDu8DOKYN5vGU
6IUczpxKHNFpE3uSPA9MfhHdngIUdC5lCPiP9Q0sMWbZCEQOw9ucwWddfGvI
8fR37Y78Rvgr40A3ebEc75w/W865bR0r+LLMKox64K188bzNzTHkSYc6YuYs
PlZRlTja1Yee3YeGlnoXwTWJi+Xq2QqcK98+sMmahP9qg6V1fy0CU6h+tnXz
NJ7R83hG4EP0+2myGBg6DMr/9iSRpDdQXjY2l/17M/R/VupUfV2MVVubHmo9
XcNQO33hDJteeNG8h2I+TEaHs8IHBlxmcCvTW/XRzlr0Goigt5gehIlCrp6Q
HDoCI7tD1O39rXBRe7FJ4F8e7v/PpNN7bBXtSVuO/NXuh/YbM6G33EkYznDE
9VXYNKbzCT1jf0HBkCX639wxU/DzJL990tZByHGcbVR0bMP7v8ZSzuv0Q6zi
bv/AIXqCpuiJod7jbRBwxu5rrnQGXq4+WHLRaRWP8XzY3GE9AD/SdKadXVrR
i/+59XcKBc/WXXYIVp3HCI7T/8adhiDS5ttCV9UYLP5KNJ4/RURL1XFVV94u
MLmxVpw7x0AI9E9LeNzWBiI5RNaB0G94ULNGeER6FTedkicS5gaAtPuYep97
Je76Ltoe4kTB47MQt9TdgCMhxfomOqngU53q+UptAkrUma9up+49R+VWte4F
NwFJMD4b06bgYbWAy/fTvaiyu/y4aUQFTFGe/NDIZCSYtJYSBtjawZTF6dbl
pCeg4Jv0PG11BbfyE59fXRgA1x4G8ifuJLzNmXuM8yQF77Hpd5arLSMH3YHe
GzdKsS2FQzQjlwI1TOfoqBEcJ758IybfSMBHFufa/+NgIjw0cr/EXtYGCTuU
C+9NJkAEc+tj6+EVjK5T6TjqNACPLpXfOMGbBrtDt+TUilCwiEPJM61gAXu8
w3mBOocER2b15PgpsC/q5BPn/4g4e/+8TL9/I+rHy/wWb2Uk2N9Yy5QUbAO2
NBf50VdZkNI6TNCbW8HnEwZepMB+eGj8ZkFGtxpODi8wGspRsOyBKf0/3VbU
fxpo5W9OwmofnheOUoyEMAvvK4ubWsHQt3eFQCkAxurosRPCq+h0V3XhvXgf
kC2ehT1MovaXYvmt1/cpeJtF8C9nQyXeN+ZZDzEjo6IQZ8ZvKQbCNmH3pOLg
Zjj/byl535cyIHvULL+xWMXW45/kZE6QYK7aSu7yNhJcSH86zFlPQb/FAKLg
4z/48pv3sBvXMD5hKnGQZKYniJF2+R8qawSfzCGdIb9qcGKP6BaoXcXHig4c
Gve74COnIUdd/gCUBZsHnLOaxlTns9ejrxBQO6pAsXNoGc1SEygF+jMovY13
njCWDgcSdz81TRjGOIah0qG0DYw/zt6/8acejj1RmhI5Uwc5ga8qWnXXUO37
75tsi83w40LGxO3rI9BedPi3tMoMmtLJ2CtdrYU2uq76VxH1sI/flMt/dA13
TbtJ6qjXgXFRWnnAlSq8s6qRbCi8gSGpCepPExpgMjxPWCKlAl1JdLOvLNbx
x0hkz4m8Jki6XPGdEFyKj+NML/DmraGVp0WAwLMWaGWdZDl0thBzi+ctNQ+u
Yc/B04fFclth+u/fVfJqDioUNy0/TF5Fix7Jz1c+tIFv3nNDT/5kFFyo33xP
fxWvPm1oOLnRBknq05kZl4NRadJEYYV7FXv2+WmlzreBwvojRVnzCDjzfPGJ
9OQK9nB2yV9xbgPjzZ/iT7Glgo0KJ//L0RXUY239IBLZCjsrXthnDxDAQ/+3
8TjLKhYaFnzxuNYCht53hI52FsPM6ePe+5VW8fw1WZ3ezCawbK6YfCFbCWUG
ovOaYav44MuYr0ZRAwh+k77ialAL3vsTFAib15A+4/UxR786qG3edZeTuR6Y
jpm9mAtfQ7+Xt395L7miv6bJE7/5WXjH8bnck7MfBRrd1MRuJoNzaEi+3AMK
oM/IGAxT84tfSv2BmFpolu0/9s25Cn/7X3e9eXED7UbChRy6myDn8IzdzQAy
sr404ZT5vYKX97iOjnjU4cGL2tXcGQsQnebJOPa2H/n6UqszC0OQ/3Jx5yu9
aZgajIs42jiPOsdM8+4qpsCpc7d0FsWH4creHPNbYqu4V5duv+lxAhoHuh2a
2DEDhI9ct6FnAbNUStZeDLZCpE8T62OZAZxotXWWbV/G1ObPEWNZHbAQds2y
ffskxsCenzEvqHv+03jjJ+864ML2uD858X2Y5bf8Ppp/GbU/2Jnvu98JtelS
3VNHp1Hha8ppRaFJNOD/09/5tgOeqTXwfWacwYDLfdYsU33oKiS7oMLbiyTm
wXfZKvPgu69P6VxGHowesN4qSOlA03sOMVbzizAgpC7mQO7HQPNttZ2zLZhz
/7ZAe8kCmPl7/WYfpqC829jViLk+TE45VxuxaRnku22PRGsO4OjvfnFtxhrU
5LB58yd1Bl41rqhKb17C+18sokLf/cRY0VMCIWXDYN9493PsznXMsvmT6hDV
gp7KOj4bO2fBnSdJ5+zNZXwQsq87ktwFtcxmVh/Ye5HuIWP8HqslzMnXfBQh
QwJ0pITfihlGo/bm0fr/ZtHcaFtM2UAPxIcz2PTqEbGrXzqAs24R+c7frEqf
pd4n1/scyd7jeHT/DurmPY7cCgHTZukkWLBaS2RMnsBcBR06jg99GCRFmHxS
P4ICDI+SNduX4X2S92bvnAE0ftDMZh42iBkn//N7rLUEbOeMpJOHZvCwhtib
fyeIeImu/F3TsVkIvfq3NqBtBXfX3R54ElWK6YM3iWUbQ/Bwq3+Xqjgd4edt
z3b7xX5sFV6SaVuYgaFYthpuuzWcDeg4OVlOhJpE1dhXPF14ujN5IUJ9ETsK
SC6RL/rgwOsSZ43D/ZjgOlFbxjSDMy/+kdtekSA2fP6ejWUbPm0v6GKvWcDr
smGxO/+M4OBSzrDj32Ho9np2OtN1FKpGw2LEZobx6glWuTnlGYgus4/yP7aB
31rnGo5pN+GDlA92J+6QQeOTzU5DA3rC5Vbi8ptNk6h3pqtilnEaill0dnp4
0RECTTJ8hjf3widjx8KR302oYxw67mC+gJ7uezrOzfSD58eYVvbsLoy8WUpR
OT2NYWLFP6Vf9cK+fyqsmYN1uH2m/pfs5gW8crfg2kOHKeycHfVxvtQLHcnN
9FdFqHnX/HTJHOM0ct1lEIvcMwXCUzo3M23pCb47zpodUO/CD5VCQZhIgk+V
F3a5PWMgcA5fupGjP4tnOVOzj+8aBe9x2cNapgwEsxDVVYeqXpA90dE8LVeJ
8kevGj3On0etH5XVbIUDkDcUKn7kSgMGOAe9tk6mIFNc74w5XR/8j673Dsfy
/eP/raykIaNIIkKFJhW9KrRQSYoUSUklIyIyMhuUUVGhJAmZ2fN12XvvzW3v
vdfv1vc+vr/j+z6Oz7/P43Jf5327zvN8vo7rfL4esoqcAhFu2ZhzOvZaoNMM
0vF3KDu/nECt2x7txPcyELvX+DJmfBwyXj/fkH5+BmMeHZc0cOmChIMCjdlH
aIlOprts8LwDu7J3VgvW1oC4q+0zJx1aQnbLjm+isbMo1kIjVabfANtVArtt
umiJSgFLUWnOTljt8ZVkrktCydoT3Geuz2Dzx3ouBfoe2OQ5Rsv8PBNh/Z3+
a2rjmHTljT0TWyeEtxrnb97/Cydmsro7yPWkwIPBMKqOCVRJ0yq5LBUB8eFU
pyWtJqCLd1PWwo0FvHHvy3spzVgoZv458p68Lu6OOJrVljWBFonuq/U3M/By
v18DU9IE3Dtg3RXweA5bCgoOeekhJCwGEdy36YjeYxsbttmT8NLM394t1HFg
yid5XHaClqi+JPmIuDqHjlNC30yu5qBbeLFBmScdsdVSR/vrFAmKy2crj+h5
Au/V3JgjvDN42epRz7bCbhjdGbAQmOUIXJNiRYqi4xh776STZSoJBtghzikm
Biq72arWs8/gn9oPzGf2TOAz9oH9SrPVuH8de7XUzwmYCOw5fPb+PGZfD5dL
PtqCXDsOG7n8GIcA+9wPaWzjuF9m4h716XZcyDLKeC89AbrbLgYy68xikuK+
uePjzWis+rDMxpaOUJL7M+H5oANzY6sL/trnY5X4xCUJGjri/a1T/UTENLIv
sGT8JPvqLTtb/XUE6Qi6zCcH5x6RYPvVRQbHGxlgq5bAf5mL/Bw0UfeTOLqh
/217d0NcNtAfPBZiKTiO5T9ZvghRkUD8loZNQWY+NNyLEmUQnsHz9q9uWjuU
Yz9JiME2rQC9Xd8qubCOgHNa5i2Bo6OYztC1ge5BN74tH5c/9m4cNC9nDPo5
TSPJ6zhTh8IwDsY7TbUeGgM/ye+l/bcm0Zz2ULi52AhWDIV6Gb2nJVqyEqb2
eDfjta0pxx/ubsbQxknH1260xFUVc3sl/zGc7xRcN7A8jpKtE6+JAhpi9eGP
Z+0vOoBkdWS4ZX05/DhaxqYmN4ON536L2Q51gsEx23fJo1XwefDzdc8L4yht
f4+1qKUdrs6l5k8FV4ErU8wL+yczeOKvmjpvUi+KOOsZuhwYxrik5w6fOUZh
8Ta7TFznKPZbdAq2PZ5E0bs8gt5qg9DPceSw/M1BjA8Pec7KM4WJVs7OR8l1
xECfT1urcxUOXr9YFSjehUmf72spxdIQZ5O4Y/u1uzGgpYnkSt4XuYc0Dryb
pyLCEppL1QXbwfzw/k+rR+qAxfns5s6fM6ic5dPnIEsCZiJ4SMegBXqTw/aV
fx7HkLzW0l8/W4Fn86+HqZGN8KHhZfV47ww69B/v+XCsDWf7JwW69s5gG/Mc
vmGmIuZTZp9yXc3EDbc2iJpR92HNYTcOOR9qQkzDgTXTuBqzs2ertlyewbef
wCnt/Ar+GBVSaPDPw/LnrOrCSUtIv0Fd75FNN9rlAs2f7Gb47m75VnBLK1A9
58dTx2exw3bh9xRLO1zQH2mp1u+EocwThXu5JtB79fSH7D+NsHjCRJQvrB3i
LRbsLHzI6+fChtiBrXWYl4+KbF/m8dSfkTIpwVLQ8CfRJpo0oPz1t1QZjMsY
HH19ZOx5Nu57Z9CYDDn42VG3VJBqBk8JxZ4sJvuuz+6yH3be8YRgsYvqrF/6
0a7ySn2aARXhk2xOT+3ih5PSeTrN6tPYrsXb78K6iOuspeNLr9fDHs93NJMy
JHj/W79DnWUOH+1g6Ry82wjdUVBQxEau63MFgzPLJtBUXNLvR1YNaGnXbMhK
Jq9zRvvZIt7NoXnjuNTRw4F4jo/4ck9uFoXFT1is80+BG1FZZ0PsfiBvV9mp
jRXz2Fr35GGuWgmWnXiQ2d3/Bnd1vdEbqV7A4OkJ8GLrRmoTlfaHj76BdcGW
9/EX5rGs7DGzuirZBxGqkjZuCUAtYujHajKFxiZG47dC5pG/oNr0E1UO7Hlg
4cmi3o8FEjnf6nxWUJ/t8wkYq4Szh+Rtxnd0g+hNlkvn+eZxOZ9tqwtfFTgM
bcvj9B0CGx4XVcOiSQyZrGfXuF8NHGxZ4loOrShQxWMn5bWMg5Yhed9d62GA
Naa8Qa4Jr13J+MmvvkT2nzslzi+3oE9Sz12N4hkQ9tLjOFM5g6ORiroKknFI
zaGy8MN7Dv37H72nfjqLZ9pIDjrCuZD1SY75aP04bjJutuOhLgWV31EM6QtZ
8JP3zYkHxmOwXv2crjb3NL7+xNRqSV8Amenqff22vVAekPxV12oBo8RLzyqd
LIXWrhc/a9ZXQdH4w9ppWEETlqWPL16Uwe2GYKngpkowpNaYPMC+gq7e9+5o
PKsEmSAukW8pvcgtfnnh+6clXJdwVO+kbznUHTVVV5TpQ5flbwvWm5bR0uAa
i6RDBXR/Zf6mlzuN8hE7/jSljuH1AmrLrk/FoFh9l0N13wzW3e6PvDFbgfTp
hy+ynyiAFuWXddnKU+h8On9Xrp4DoDypI/BAAdRsjr4RrFgFQ5bSR1imVnBU
nr8v40Mt8MszU9EwtaB62ugkx8QSFvW8LNx6sRolXocbbuSbgTuBwbwq/tPo
H7N0jl88G162Cu53iaqEYQm3FaOoVTTTOaxXfn8APx6zk3n1dh7OlH54KF6e
i8baYwZsSwMo7+Ji8cxyAaYGpNfd9W7E51YKjHX3utCha3ftZ/FZcJyu1JUV
m0NbGenaHTQIb1ocSKdFKyBGiX+TzxEqwmg7jaHB3BT2Kunw6DrMQ1XFg37b
vATcoZu7FBY3jSO9U3tY9yzC9Hen6JnWHvwN1n7yHJN4ZHZX/2bJeQjvXnem
0nkGpSzNVzLujmGqyGehk2EzsGBpoNWkt4iCjCzPRybjgT3HtVXUvAQkBAyu
KrpSEeJKES2ec5MoHlKX8Nt5GL66PTlvttQPFzJkrb9rziNPkcymOWICqDQz
nHmm2sFD5lb9X84V1JJ58/in9QxICXd/dr/7Boz4HsZ+TlhF1Jx4V35lDiZV
SqQslPrQ013c3c5lEZdpbE5eOjQDVzh3llxOnkfW3ryaNydmUVAqaQPDq0lY
8qR9d15iFZVjnx2la4yC0+XRIUencuF+kcqOsRoqgpGrOtT86BxONt1hVT5C
gg76S+an1EfB8tpNiwtVq/h9d3F2w0gvOKTYfzF51QMFhGprtAN5H8vc1vI0
ZhikPp9r7P6OsJdOwPP4EB2hn6xYo3N7DKgPdXqINveT93XN8pNN1ER6bDT/
nPkwFPLM+9ZsWcaXSzcKdC2X0d0ml+6qQT/sORPB0G5BTVRud+764xIKkcbn
F9afS4ckB9cOPRZqwj1K5NzWBGoibuxtZvq9FDC1vV1SoTMA56Vzgjhk6IkK
dj7tN8UZ4FfFSP33eCGo02q/ceFjJOJ1xTS/NGbD+V+7xPgYB/FQwqOjwRfp
CD7PZ1tJ+7Ih+Hh889uXq/h2wc7uxHMqolKHY3ZIJhO26KkyniLvv6ps3SSN
oyGQmFQbfoY7FMIjzEMJUWrii02cRPBOauJZ5ChPyt9O3HFgjBoaBsBR8H2z
qus6InfrbkfGzj60r7Wy6bQtAq17QD2sw0AMCH9JNpYbxEnqayfF9g/ir8Kn
86+/0BLPXB96xZ/rRYUfVa7MxasoL1A0uTNmFTtDql5F7+pEG+KN34FxGoK0
vfmM60w4yNCdDWDl9EQnqvg4JjFqQuqMQUL8iyV0tUqxaLk7ibt+O2SYhPWC
BUk+eqM7NdErUnF1G8ccXjk5eSSgIROiUtkOXKmlIbb3VNd2XVhAS8/6sOGD
AxgQ7t1PU7GK7a8PB21ensE9tPqufvnLOKBwjE98eR4d/PSWfNUm8XPG9ne7
W6iJflf3IOoTsRAUNnrBTSAOT/h+XR5jpybM15noE0+mUNxdR3kjaQ41Dlrc
H71GArUzNJ/Vb80hS3T7h0cLy6iqN5WSuDkQNm22RjrfeRyTVlsqE6AinBaj
om3C+nCCJjBcoH4aA+28fN52LaHqRxnZsDcL2BZRFeKzfQLvbn/8xnd6Do3e
d4+OslIRZ+jpX2v1pcCvMNnL+cUZqHZZblNZFxVB47HPssN3CJm/WeVGTKxg
gnGuOXdhNOrrlPZ2XxnG0smWwBl98t+bDoi8FO/F/ood03ljfbiLIfiPJ/MK
NuhUL/vLzGKCj8+HkfQuRMb6J9L+C8igefp8jNwS5ueJ5XdHZMKUELf5Res8
nJcoWZb4TkWwd68TvzFej2F7wi7wmK7gRZ/HhssL3ZjkH+rGxVqNRe1PTcRV
l/D92L2qtOdTeCWlDDt/leHxx3Phe8n74qvDog3p5N+vr3rmvONIHlj9HRrT
vFmEXmcnt9ApUBEbRqxuOHdlwA/vR0oN7sOgGtJipdofB/WCL7WO70wBKrU7
Dem0c8jXJRK6/mk5ZqXxhLFxRUDk0AHlhouzaEe8CjQh7wMNLo8Hr+Vnw9+C
0iSd9+R9TneABy3G0cV11KDxWgnsNCi+036hBK85fQhRblnFk9ylV7+olgBL
kHSsV0QfehiNl0+5LaN9vJi7FXn/6nurxhBI3r9Md/KdOEjev6xdUzbJB5SA
w46V8x2FIxCkMrwS8WAKa46UVu+tzwLPrZ0qJ+6Pwdlx7Se/Xqfgjh8B6VJN
UZAIFVatDlnoasfHUtnZAyrPSzkKZmPgFf3ZpUTSa+gf2+2zdq6VT+ri+jU9
5aRo6Fr+0TPSwPHfefL6k140GxMhVW56WdUiC5mDFzxXtvWA1NvRHfE18fDe
xMdue2I0ti3yRNdt74HtAhOsg0F5UFpccNWDfxKNed7M6XkTUB8j7E3zEqGv
arXiXtsEvHKyuf8yZATVDy1ZrxgUQ//k5V28Mz2QfvFA4UXeBWwc3z7flVwE
XPXfvD+frYKDt00Sn3xeQYU6qaa1c60DMtMma/lE/Y21jWvnJ19NCUSv6S7i
wY/W9HASS++aXqDM8npN/zGxQXhNj2JTmlzTf1oUiN8wrwSlmrTdMyIT+ER4
4GHmpVl80Lb++suvlXCv57zFwu8RPOzFd9X48AIqqYXVylKVg4nz7SMGnTMo
k2Z75eejLuS7yL/1p2smmHrnXufkmMb5rzIp9BL+EBCjTpsamguLdCoOqtxV
sGn1Ak+e8io+O2Z251++dXwp7F8e8KDhv/OfKTwdx9d0xdvUi2s56KH9iv9y
rwa8L9Xt8jPgnanG63lmsp9Z33nhNgMVcWU+h3Pt+oKDalvXrletTft3vneh
6tPs2nl4+3V9i2v56BCV7//ytuIorxGRmwz0/JcFd20sB4YG749id6mIAMXE
xrXrIUQybi1fZvCt5N+56JwrbzPW9Fd1d+UCyTrr2J4ja3oTz7zUtsfz+DAv
7bP+izlYPNie+SbkFzZGsR/gfreAU5fEGnpgAQKvjB+Lf9eLpr22nh7fYoB7
hoiavl8I573eVgrGUBEXx26FrX1+wTRLRAD58x/tc/93Lt1ezdTn33l+oauz
a/nryDOD//LINNu/sxYWL+HO11H8lyNGof4FiwljbScIveqwVr1DTeCWn+up
rk3CueHR06ZB0bDTxqpxhyUN8XjMte0exzQofzARLuLoR6ZM/xFpw3A4W5e7
qiGWBb17+NYNTlIRMXP0bmv3ja+NF/xOvq+r4y6FtfvWVUq/WtMV5tnBj6w/
nOD9l6cujrkzPG8ThoscSucbgn6Dnr1msbx+P8T2CF86yJiBC3cN990oCIEH
ocf4u3cOgnEgPZfBZmri65cyx98ZzUCfGVbWVNQHJ6nd3+hKrSPk8oY5P/KT
4IP7+sbe1hyIoDGwPdVPT0xVDTxql+6Cmtf5DHlvBvC6QTDvCm8IEJuuOD8q
jIPFio4jtbzURNGC2L+8UrfY+ws+5HFmv6j6lx/xle/9l08P3myg8IWsTx08
9C8/rlZAHeadTk0MntL6bvSsHOPpYnX1uQdhdeykT50mPXGbej7YJKoaX1Nf
IaYliyGt52uGsDIjsdstKKpRtRZfxft9P3RmEDV8cxNv32IkMh83cf06noA1
XUKF0WKDSGca98O1JhRIt0gqp/vcwU24F5vFqYkakTuua+O51rtTwZs8HieT
o//yQRoVjt5r+umFrZc/kfW6hYZ/43x2OP/H6kQwXgx/2NK24Qeep6Lae+tD
P/w69JPtS+UqXsqVXiW2j+Av4VL6r0H9kG6o88C8lZagS2HUONc/geouZ8Ns
DuZD68sHiWi+jvBhd4qtS5rCqg23rm0uGcC6Rb+mijf0hMBy3fvGG+OYt2cd
RK4bxLnF0ZgKuWi43kJFNuKheK1EVE5FkJqwvHXg99o4w5uibn8gj/PrBO+/
XJie6qGUf89J5WFrD7LOMcz8rw/Ag4wzT8pSf2BP4w6mTYvRKCP3kS/6Rj9s
c3ENGmqYwK2pV31U743jXn8pzjDWEZCTqQ795TmHnCwCnH/+kOt87Y3vMoS6
Qd9XtM+zahl7JEPDLTMXUZ9+a63T40Q4KJvyzS+a7HPK2P1ec69g/Tef3Yxm
/fhK1e+JfkkCKBWzjFyPTUXfqUldWSpqIuXqxaq1ce5N+BPjRh6ndNXvf3nA
5Fzh0TW9zq6Wfi1HE5lN+6/vwSfj3TIPeCYx2sGgUG1yBYvftLjbCHvgn2c5
DjMNk3j7caV+2FsqIkGmeXKopxfDEx5KNR8nwD03w5WpORtrTsQLHM2mIrbO
m7KurVcamdusXMmfrzYg8S+nmbynUGJNz5TT51rLpyyfkP/Xn8HpRkDyuu1d
aPK7dx2X9Ao2LzHbtrOmo6lu8rmXMl0otEco4UTXKnanR3/mdOlBJuOPkwJy
OXAyVzx8LLgAPfTrHzqbURGHipJU/+XZ2c+1r+U+Hh+7+S8/a7FQbLWmi+zw
rlvrS2D82fVfH4nLRIv1vYBC4J5dDs91K8Y26Rh/8x1URFm/06+1669YRFGv
XW/at8i9dn2krXbZmn6yQFZ7LWeRs69w05oeH8gqeuVdEHD5RS8V32hHDVkZ
tZyzPfDw8kXOvlQC5hyjp7a3zmHx6j07zcQuXB7ZGNW3WAZKF+S+fnApQa5I
2rgQm1V8t3HivJp8AewpphKV05zEqRSvzQyP5vCEz0jg+OMicL8ebSQmMobZ
XF/yXikvolpPt8va+6B3n9MNol6WYNH5lbdr74M6Furn//XlcFCdW8sdiBly
/8uhZ/vZKgnEl8GpOCPNbu0esLL3cpzKnsdiNfE+Hs4iGBz+rL3TcRxkL+2O
3lQ8jG9QUPJBbSYoVjzedVp2FLgEG6mzr1iijaWC34GOMVwsvHbmWsk8vA7S
fccek4GTZi6t/MrjqLYzRXv63CL4lJWJScj14KLGtT6PcxP4YZdNEO3CNIxP
nVux/1kLqaXvRkNyJzHcI817sX0WtNse8jWHZsHki7et+51GcJyz/8WZV/OQ
vr7420aBaRRMDgixuj6A+WKRuR/J9axuZZOOYPw8iso45In/GsN8IxsLUdIC
OBd+4eEUHMNNC6yLmu1T6OfT2NkStwD8NWHqBozjuDmko0K+eBpDT/TKfcqc
gm3x/Tdv726GO/v792uNLuKr9Vq6P1OmIPCQERvJugqOTT3pszo2i/dTm06G
7JuDAwu3rF5unkOapx5DPXmTuDzQLp31chrEfvixup9axnLvt1OOjvNIxcSw
ky93HvYHBgjSMk6gqWbJY0PjFUwcLfeyq54FnfOmjYI7J1GgoM2qe3UVQx65
yEz9GYfYzPUKO9zrYUpEaPZnNTXx+ITWD57RAQi1VTjLdbcF7ETjqGXI62HE
OR2dbK5J4GtWtD9uuIhpd44z8pH3ZSaT1zNvvo3BjhqP9jJ3KuL4SKz6Qgw1
wcUkN7guYAru64bwxJ+ZQt4ke2k9ajpiW+T0sDTVGJj0UHtyak3j3Jar1YKy
tITOpw9E6+V2uB58S9aDaIcVUe6YKk46QqvScvmXOcKp0k28bZIkoNqnu/nF
PVpCbypzKPIMCQo7GcPmrVawX2rjK7a4VTTj9K7d/rwN3hb94g48SUM82E8n
Ote8jqjhZqlkI+/rRRs5fNarzSCNx59tL5boiQtHReYcuHIg3qD80iuWWcRt
1d0le+mIke0l5V5RlVjHvP0QLYkE7FskeL4+pSWoSH+mHz/owQ3VxxS/BJJA
uHtcSUKbjkhKQVKBaSV6pihS4Qx5/nLMVLhZUhFCW+OK2ixK8N0L8bR4BlqC
MTOb8F5mINxdLZ6/vNWJG96HyUadHsQXwyO3p3YzEMGJlkwp/DX4aoY74qLW
LL699K20+jQ9wXI5t7JEcADfX9h/X/30LHI83xe3skquH3vP2nVsGkfTo+/p
Vd90wOixJWlmGirCMe0byaNhGqsC6fiqTdtgRWDh1SNmGuLRuufXPw2Oo+UN
xSR/hlUsE2MM0bqwjNkzuXpjpcN48lA/28hrGiLNNs0g0ZCOMCp65p4zM4kf
P95VkEmcwdjbbCg3QU3M/8mrzdGbx+zev/t/NU1jP4daksr9RZQRf3ufRWMe
e+wlfU/0NUJ92H69Jx4zaOlHP/zYe5G8XuReTO2tgYRzfNuW+hew0FzsbnUA
uV7TPj2QdZzsw7QKD1kIzWAZISViEDuDmzvPTL+joSbiNaSCPkiuoJPPM7fx
A8t4N5H38I7iKdTf9OKJ5+M5lA02jBHTXUWWZbrCyeBJ/Pq85fYplTE8dDVv
53my73+rFDNX1tQKNFka/gq9ffjzt656+usF7LxnsO/P4QZovnb5S/7yAFbQ
PPxiO7CEqf5XDjnT5AMz+62bitNjeODtdFXm+DK22MfkHaqfw8FhWp0j0kN4
TSFZa/PRBRz9y541KUKuI6/vc5vvm8Cdj/mtd5Lr5ZyK5oMsbycw90e875na
Qdy27HtqYBMV0bFDP+q2zTiemTl31nimHa1OBcblGSwj7t9Ak5M7jZblwokX
OptwgiD8qu8u4Ka3tVoqtgtocNd8atPWTpTx9o2mllvFrRpG2ervxvDjbeol
e+467P6yO9doYBk5xyOF7J+O4s3f6VGVK0nwXTwyWsR9BE5f2CStdzcZVF4r
BUjT5cHEyxuyN8l1fFce5+ZbG6cxcYfRpaYjBHyUGBt/9GQCIzPvBvhiOWge
+Tp/dDwfZj6sSz3eOAo2xVtNDdOnMK3ripdSWBGoOx33zqXvAOuRwK0bg5dQ
M9JT7D5tJfzWfCbd/bsNP3z+u9FObgXlKqo23JEqBjOWgpATZB+y/O2bRSLn
ODa0/b2RoZcDQVPClzy5ZvHes4/yB6QrsGajRsta3dehnDe/Vvf9WSoy1CbX
fY6LoiFK7hlQUS0YGZjRAVvzrZd9xpZR2uHy4DujPyAotv/ATHgH6GbaXLPV
XEUpH9ZXM1PfMGmGjvbpj3awffp3ZtSIivg+1/XEKYL8/TOCqK5HLEBqyrNb
EoH1KNrPySzgn4L91rHv9eebQTS3akOjBDVRbvTN6lXwDPaH3ClRSB6Dz0VT
pjvO9IDFgOSHXCuyX6vZqC6YPwvKb4O0nCRqsfNm6a+wyRxcl3VDI9ykFr6J
tfwdbKEmFG5vSJAfIc+Hc8ZHX853gdqlBd3I3kH4QJLzKguhI0q12FKHS0fh
cceDpesuVTivf+J88pEitFQyfMsxUgSN8YfCte/REO35+gfnk1bQ9M9FWvPg
BDibIhOIMaPAUHdjz21kILqf9l9V/pEFmdS7dEI8KpDjoHZddmwxyu2j0aL5
HQXarvuMS6NpiHLlz3tpQpbxgPz2kJMbOlBJv1+iacsYCBn5H7CgZyC8js+Y
9UUPoLuIjdBjlQp0aaO1SWIuRNZPYbqT0wnosHf/MaVkGuKeN/9Qcv8cXqMz
TJ0aG8OC9VN08szD0N19xdj8Gw1xJmNkkjVxHrWU4+3T5iqRe15ibOB5Fk5P
9ZWq15aiqLHQ6EsrGsJt2VCXfd8EMm41uOzJPYPmEtUee8J6YQX1TcVs5vF1
b9SN2IhVDEtUsfvyvgZjElm2UMfFoIJLWNqOg3UImpIbN9PQEEZ2GwpFrYdx
KO9iyE0xKuLl8+6c2m31+OHdr+M/qt6AooJOdW5aM1o/r+q6fouaWO0IE/0W
0oABksUyNFwr6DNnw7pzfyPudsK26w9TgHVEOiKtrQ29L/bdOfydirB0l4zV
JfuWyK27zp8i+5aIJy7NU5ctUWrDMao08vN8fHKP99rzXFjgwSRGfp5tk+62
a5Cf/7yczabS5Oe/6ksAkUB+/tPjbrK36xXAfud33zg121Gm6UPfySRy3ep5
QE3Gtxwc/Df/uiTTh0xsQYlr7xGKJw7PHCPPx1G3wqvHyPOx1ruDxog8Hx/T
xW++PpgKDdk177dRjcMqDZN1B1ci1okFBvas1MCuG1mPHB0GYa5gw9tZ/3LU
jX1Pm/WyDrTYLhVn4BBoHv2Ytz+nFYvdxhJvrq+FS0lVbfx3R4BQeGnlcb8T
Fz7wjmZeiIF196+Jnq6IxiY336jNtj3AS3VpOo4tDrS/93v+6onGnkn/vG1K
PVD1x9XoKXUoVLrl6b/XqwEW4dbXHrJdcGHkpWvN+Sg47mzWe/xSLuj7BdKp
vOoGdXEJltfTf4Hl18kb+zoS4IOC5m7Xim5YZrCqKW7Mhj2ipomBw5VYtaWn
jYPUCTfeDM+ZFqRD31J5gNG9TKT70pulca0b5kpj5Q+/TYSFN/d8DpyLxrfR
otkjfd1wV85ueHpvMtRu2+6p6BWFD5Kb3JYSuqEp5bGLjVEhbDz7cSH0ezly
Dv4qn3lDgoCdYmGcWpmw8Gfsc5Q2gVI0c7+O+3ZB1kOXe/zxKWD8juUgo3Ik
3l1+uM77dTcMD2c+UNydBvJXFffuoQ1Hp9QnmxQ0ukFNaJVnw0ApbBdgEHqh
UYQmg/ulXXQ6QHPPrfu7GrJhfc+Rr/2iKag0sT3t/HwniISc57Z4mg6S8iGm
bxRCsdHoqIWPRDfIh/lE7vZDELAO2Jdw6DeG2UcxUzF1Q9DiqQ8u3BVwyXLr
HItzNlacscqVeNYOtx3dg8LTcuHhJpUj+5VjcXtkNedb407Y1t7vHHCFAMMf
VcwMuT+RxuL7ZFdXFxhIDZoKphOw/TrhYbnBH1WOU90Mze6CzGv3BRRFKsGr
wNGBaVsyOkXIRHI5tUGDxqX1Uyt5QF1tI1LCGYK9lux3zZk6wWZguGgTRwY0
urRVHNv7GW9d28AZGNwFgqb6K143MoBDJ2bWI8QNMxtfeW7z6ILX/leNxb9X
wj4Xv1Sv0kDMCWC8z+jTCnfr2alsP+XDg5Nd9a257nghZfzp3mwSxNKcNBWy
z4Bj1MG1yYQVuu62iJW36YKcaJ73ep8ywKqhron4chOORDh2Xzfqgvgsjq45
20pAIV+3tCNe8OnEpovj+1vBhm+w8YRtPpTpKs30+nlAaEz7B/efJOD/tM3n
lEcGXHkdyI8nnWDfaypOwwddcIPNu7rwWQYQsh2rZd4foFLzWslPnS5YtJzc
+bCsAjov94/QXY2DozkndpmcbAXuPuroivQ8WAqu74HaENgz6l5vH0wCTpFb
BhqyGRCwIEPEWfiCyE0n4ZV7XSCldyrDeoEAm1DlM8xeAeB9QKnP8nEXuAR1
2i16lMOZNxlJK8czoXz4cJJ5cStMuxtHKWvkQlvgjuSN9HFwQG9RsaOSBCrs
426TPgR0OvtuFykKguQJ30fM5l1g1GSlGStMQD49p554eSjMM04Eur/qguxt
I6r3v5aARWG6afuZAjjtt6uNv64NbGqGHGTvZMNb1Rd3bHVTYVyM/YrLrk5g
9n7t1yCLECBDs9vwSwToZept7ybPi4G35k2Lm9PhzKavV2s2REPauemKyvgu
MD1qdq5lUwGY2jvr5tmXgdydzJMCEe1w+JOuN01rBrTF0Lgd1syA0klv24ue
nSDvbBw5l06+3634xxxBf2GwykeZq6YLrgsviGheSoF1Ukw5xptiQS2yIfDB
LPl7GSqpe/tmgdALmTx7jUp4pKitGvqnA1iPHLsQVJ0G51djve61ZEFj9ZnU
sF1dwP2Qj5MnOwlUcgwWZc7HwZ3kX890d3SD5mfaDNvdiZCi6Jty6kI8CF4w
PhVxthuIg86SLMnJUMK6raf7YjUwrsjad7eRoM7EgXf9mQRQCnXyYn2XA+om
1z/WFHZBurzVGTHTePjAasiJGxMg/YBSWPHTbig6tZ1nR2IsFCqKfHv/OQG0
HWI3yf3oBrbDjNuav+aAYhGNy7mDE2Cjmv/sxdERjK25/5ovMRds2QSM5F90
gMN3ofDls8uoXjg3Xq5cBo6HUwQv5k2gmYOjMVP9LD4cJu16kpQPXO9zStzb
Z1E4bIRq0q0LhS0PntztkAhYkyJ+p7oDZKwfWIX/XMHmTi3qslOvwIy1NXj/
hQ7YYHaW4/FGKmLFmOdb5Go09tb/DnbWbYOq5xuMOSqpiEHev7Mzmp2w99zL
mf0y3Zgg4Ru0b1MFytCEfHR61gW1p6q41nH14OH823KnW1qR6+ZSfbZyF7wX
EpNor+7FeP+EjJ/XO7HBK/7YC8MFFCuct6tNnQc3s9s1Ss/rMGDgTdOu/Zl4
QN/edGqxAR6aeTlOvqUmGu58tDhiPY9yNm4rllRDMN4meYs41A/NH1OeMyjQ
EB1ltEER7lNQmiis0dhQjcee5n/aRF2AhXXsnNv0K+G7gL2a1B4a4kKFEn01
LqPZn8cuP+kaYGhW+5Cy4AjQPXQ7lfuRnqDZc/vOI/dOuHPPT1pOtxJN2Jvt
gsyLcRPTfaZFtUwImbOf2/+Bhnh4Ta62IW4FjW89yY+0KcZtTxO39hwcg84n
yx2mQwyE51Ze1VObajHGZY/WLokK7D1wQKS9qwhHT2xsD1h5hy2vgjQYkIbw
Ton7obyOQOnGgfxStyBU1VuxF7syCDbvrfrjQxbRa0Lw1muhAcw5z29suDgC
48Iq976JriOefppoTZOdwv5UtkezUxX4c3Vd4Y7Defi5P45mOSEHv48Y7ar8
SUO8EDF/5NSXjMea5KleWSWj1/YSwe+0g3DJYGWqK2Qajw2+SpGbnUQR2v1j
Qq8G4Hj5XY2XT1bRN9Lkk7rtMrLznzSUlapGifwN25Un0lCK7dTuw25VePcc
5/ZeeRriRsTpdfKNk/g09UcnjxwVkc/9uP1nWy1KTVvrt7H/QD4LJSkXuUZ0
xZg8zRhqwjq6TPbgqy40z1+imTRfRdbegGmnww3Ie6nnTbhPBLTTHP4o59OK
DBLKudarVMSBguQEpeAs+MzJ9J75QjvSipQG+MtQEQ/tNvx67fscMyTMn/4k
j+/lUaP0hI998G3qJcdJ+i/AGHrqUWlcNWozXrp2Or8XhLJYtY7sCgGtTw2+
itdK8TPD3bRm5V64QKvFczz3G1CxKVeMxjXik6ekVIuTvcDecTlCjzyPfn+6
rupBnkfv0+e0x8nz6OoP1e3BpFKgGtYRHTncjsO5jgo2iyv4/fktlxLyfPR/
MiKiQJ6Pf2ji+hnJ87Fg3jeKyrAY2F8uafDM9MBJabWTCuR6VLKy07KNPN9H
lZtp1ub7fucr4Vbk+X5yIlP04c1x/Ap3RdyaFmDLt+ebMaIBP6YG1xoVzCKv
8tdPyjgDH3Rue6bRlcDZovTInS3jGLJ3T/ho7BIedW05/q2+HD5HTiRqsjQC
X9YqrrweBJ2hCgeZi514SZGW13w5Bl6ukzfUm6mGXQ8a8h64doLQzbrcL9LR
cLCLtOQlXg6hA1FlBjFdwLjlsFnOFRJMTCxXzqr3oUkoRNMeLkcqEQ2Ojxad
cHrkg8DKrV5sq1NnDDauwx3xyTq2Xc3g2JYwLCXTA6UVuqsPuCpx+pCB2tY/
DQD6PEfPt/WB0CvjU7765Dpin8ByS3w93HAJ2uHVPgBDtn809KLrUGUhR0Mm
uQzkxRurLkkO4OEnAwpXJOpA9ZnZteLBPMj2YdROetWBs6fyUp/7dEDM4ODP
g5EEOK8P32p9rALzFIIYb051/d/3j7f/8/6RY3vnzEhfDMRy2Y9/tKsEs1uk
uxtpukBYdvG5Gt83sNvmUDG6RK5ffTq61C91Q6nFpvZjM7FQtZ//3bffHbB0
80hWU2MbJKrf9lcYeo8CwTbOFskk6Fy8JvH7FAk23pVkoLmcANvGbv4Ote+H
C3ZqrbeFqgC/5TwZvPcH47YFFn6bGITfFd4HLAvrQY/CCwuj8MIyKLywYl9u
p3fVseg83DmqeGoahgNsLzSI1qP3/Ql7Z8kf6PvJwKykcQpgsXXenncM07jY
LjmciIfgOywHbOiH4J68mfs95wX8/OdZ76dDuQCyHsxchrPYSnvzZXRhLWrG
brS8VlgHvzpefL0dPIlW2wNDWj7V4w8Zg8GcsFrIeiajInS7Bx9l/9o61lIB
dzTLpxlGy2HKzCdLsboVmbr5BXZntMLxiwmWQltzoXwmoP0YlCGLGbsHe1Qn
ZMWYn4uU+YiJb+jEJN5XQqPITNyBqB6gUrDy8qdCXH313b92lgRl+mKPsK8L
tI8m/e70LMagk7e4w+4PA7UAfeZgbBvEUjhfzyicrx8Uzhd7ocJTRv46pDvv
tTWieBaE9716JixVi+JnWrdlUlfhaIxx+urpWdBNfbA6YjOOpeawBzdGYcv0
zpnop8Pw4kpdDq/7EnI7MBzLONUOWwOnAyIYxnB38Pvu3q4G1LaNfr4vqgmk
pXcIzhwi4ZbddoYd6kVwObeiaFtVNWT6VNEqxTbgOaWQq/bMTZAntZlL+FMh
ZInlxRyPK0S/1MOt6h4k2Ge9WYm0PxpPxJwNn9hVAZyMeseoOfqg+e+iU+KX
Rhyy2fATtIZBjtjOxDvR+X95WwoU3pYnhbfl25VTfPBqL9I+5Os/RczD2Suj
Qn/I67HtXVePpcddmH4r9cNNhnn4ft/cNunmJGbWK9g72pfgyy0fwmgNhmE6
0/YY/8wKfs36YRK5tw34Txk0XqlowsPjqeV6E9nwO+/3Mm1EHWReYZn9s1KF
7rL36O+x1UPOVa4BNc5S+GXAntO9Kwc/0hhFvPTvgJkOZm5V+lQ8qSDdZ/Og
BPwSx/s3POqHfArHagOFY0Wl9384VofM3HZInZjE7Pai86K3F8C+0Dise7kM
aTQ9/sKucRQRFS+5ZDIPD6fTzUvLppH+vOf06R2NKO/1xlFNdxDO7KOfiKqg
IkzGigYCNnRDjsa6p+0FJDy4q2pl/+smzDyBz/aHtcNCMN91CdEqDN/o16cl
R4D6d6bAIvcG+PV4V2NUcxF2RWrzfKypgbPaM5LGZ8th2qAgnd83DU/tOlww
SWqHtNcu2te1MnH89y9Lo+Bc+HDjvl3hhwFgonCjBCncqKcUbpRsU/tkr/ES
eqv4hDhfnwP/M5FqXT25GDT5IthXax43bto/Ia48C1f3nrah65xD471ROpU2
JHzz4ryHXFkPPOOzdrp8gIYIubF+nSRvDyi71UX76Ddg/Vk+znmaZjSrJxh/
SnTAzzs+g5t35GDwvd7sQKlkIGrkVq+6NoK/YlikUXI6htuFTDFfqAbXQ39V
TOfK4YWa5k7qyUh88U54aUmjHU6wK6Ycl89B46eB9KZxqUCvbclqYDkItymc
Jm0KpymNwmm6WCtc1LqVltCIkmB60zsO/ob5BxhvJqHdtdt7fQapiPUrzW0O
bOPk32d/o7X8EmoRf+Mtanow4o1DZWhFK+z+eHx022NaolVnYVL4dQ9EP3Ne
SAorQq4OjZvXVZpRwGn9b9KBDvj+zIr4dM8ftbRmPpmGxcP2BN8P7yIaYaVT
sWx45RN63y6PTtOtgtslNyYP8VcA/bw+yfaRNTo/MDtkuqEd2Cj8o0oK/4iB
wj8qyP0blhlMT0z/aJIJ3FIP7PXOy8zX/fF187Cs/CgtcfKJ0q2LcXUQ2Jcx
fZl1FVMFu8PPbunHZ4H8TzItcmHBbTJgxxk6oqYvYfDWSA88CT3xWas3AL0v
vY6OpB/A1yHnVhV1euBc6PCt1Ru/UEz49dUQ22aUqu/nkE5sB7GhGJEk5SRY
sXEsWJcSB4qbHNmBuhFi46MrXN7HgEnBOYc9olVw8ONlli255aB5c89thdhg
0OmLarQYawNRCm+Ii8IbsqHwhhzvhTvkTNITJDXVohRTEkp1lZjqCDnir0jJ
Ek8uOoLj19P1n2634zG7549ip1fxsCkn/LDow9zuIqkHAjkouiCpz21HR8iP
bKjVO9cD+nRXOyQzCBDo7TTNmO7HOw2C3OtTumG0PFZM1JSAvQ8aNdVcmlHc
YJ/Fddc2eNEEQzd5S4DZMjv0unoCzJz3qQh7Uw9Gqy4snEy58EPhZz6tZxVw
L6gX/Corg+2yuelH9yZDl6FY8Xuediin8H1aKXwfRgrfh+j8panyjJYI/3hP
Jvb1DNae2ldlUvgb3Qu8fhczUBMOkrGqrP5TuMCuW11vuoIpmy5VaKzrRp3M
Rv3apVYcqXs37cNBRwxaXtCv5++GvIcCnzYtVkKT3Y1D9VsGcDzRwV/fvQuY
zCJrVxYqYZWIXJYzb8ZLzaZ8JtHNsJ/PccMO31rgOq8QcfZrCjS7PuKePl8L
hKFbBc9AOZw4QH/ohX817Cvnzzq8rQRiTtw57eGdBWJt3FuYLNshX4zlfOnJ
NBxijvv7RTgXmcf87wXID4IZhbNjQuHs7KdwdrxPMgzEkhbRrrXLaP+6FQyo
fPSHJyEdr1QsbJ7VmsO/utPKzcOLeOn+enuxe4vIyySrWD/UiskBWSEGBr0Y
oi/rEbSTPD/vGx3800iC5I9KTn/jWyDw2UTMwOlmbMl0ULYtq4cYoj+X5Ukr
JDCV7HW6kQFfk+xfUslUwZ+hG8fnzWohWYH7QM1N8n7/6DV1hlkB+HUW2D21
LACHQ/dlPDZ2wAnRJPsirr/IL5kUuTW+GB+UlJ7lUBgAZgrXRpbCtTGlcG34
/16oY6Yax/40k/fFvat4buXNJ1qzAjS3YLxceXkYkzb21nziWkHL336aTAxz
mOjfc3JLawVy7jIa7FcbQjzaOqBaS01EutyUeejcDoMFb3W6ZLtg0vNpqkhv
E3a98Np8p7gKTCJVuVsmSaDm5tk+YpILzh0fR02yS6Fo3HmrjlMT1P8Jb3PL
r4ddn/7+DFvMhmn2RpZ39qVgf6z4+VJjB3hHZr1INvmEuzLk9dp+lKNptjBr
AVs/2FA4Ml8oHJnfFI4MiZGV669ZO2YsPzVZVCX/v7ZIsJkxVCDXVRYt25RG
pJZ5l5c6soQpl+Z03m2fxmQaB8dHHjHoz7iZo+HGCP7Q3sx75xkVEex8pItv
fRHwdlUviRv2wNPrN+fi1EvgOKMG9ujnQHS+yR/dzjao+JpS+H68CUrPsb/K
cEZwqjSduiJVAfHMy2GO9SRYZz3MNfXWA7Pq1pd++NiJmkwp2/8y9AJ8uGjW
EBKFE98frjeOGsUbu7v3S5WTQJzCbblF4bZ8p3BbOmadVHjcU7HsmT19gfAi
7j+/1EB9oxqb0x57yOr+xiVV9+uM5LrFoVlDbqpsAm22//E/OpgMuw2/W9VS
jeDjmynbviqukEsV9UU3UiV47HBJ36s6CimFPNbM/o34LEDqOD3ZD8v11iWF
kP1w3HS9hibZD8uPWFRKk301s3QH4Uf21d+UlebWfPWlO632Y2R/7nLo1OsP
ZH8uOvvAdM2fA4WHsoXCQ+Gk8FAkH5XYeZD9bb6Qxt01f5vL2CAdQfa30gGn
GB+llwDZ2AemhQwg06ePvqFjdYDCpLN7uXLguQbprO1sB6pJnGl2lCKBTW5I
2sxwKjhFJNw68L0CJUNe71V41g03/+PPUyj+XFFTsg+uh+JELOcTm/4pCJbh
YGrVrMelysNcz4dr4Gqmr/5ISw/ub/NJ/WNeCcaFXudGP5WB2SUc4V9qw92i
j64OFrdBjaJQGsuebFA2Upx6drkc705bhtcLdsEfzqUvPQ+cYfId4xb+sUoQ
OXNT6HZFNxh8efEyZTQQk3flKU+0keCv1cPH6p0kiPyPT/aj+GR3DtETVn7V
+EWEd1fVy1kwlenhvWNbixLcDkY2Qk1gMcWQEZ5Cwr+bvbznzxeDb9oxIdfJ
Krgk1qOyfkMTPusT1N3c0wQL2QY8r6gLwKjN2UvQtRi/39/d0kb27yy7EkiM
D35i9o/CjlGBSjD1uCqxcrQXSig+9iLFx76n+NhviXIPWcO7MfGw3ZSp2zwc
/cytYjFWhSpTp1M/l7VCmaXizuruZnzZLbxl6VcOnJVQmZbZWAdx6fI8H81q
8Fvv4JAN1oPD1OSYbXcxhCgzP7FVyUPWzuno9dMdcHFrSMKAURxaR2YqWV4v
B61T0/Skz32Q/R9fukThq0aNfyQxSExgcsvYbW7dBVgOsRNksS1HkQf1iake
7dBr7KrcfLIaaafjPLuyCKhUefL+gVgD1Ol6dEaMlWL8JPv1bddq4evMHfEM
ogzeHDp4ORwycPnsqGeuQAeY3aV6U+NFXtbqSzezshfBQbYNx+nb+4GB4ieF
KH7SiOInDUe0cruPLSL1jL6PedEcrGocMu/alY/P6PV20BzvBr2bKoaVNCQU
+L5hac/XJixUtWey2dMB4mUe7h9O56H9fFBVVmMy8O8LWbh4txH2Hih6vts+
E9u7M7cv+FQDZz6TY3pOOXjWWU6T9sah63i/98bX7bDr3hMNlaAslFF/9aci
JguILV2WepMDcIviD3Uo/jCV4g/fh2+2S3xJQ4TL/ey5Sj0JO6pD3Vg7U1Do
0fDM+KEe+KXORkRO1GH1+uqafRubkXHxBJe7VAcknOYH+oZgpH0cVDUzFw/l
oWnxGUmNUKdgFcrq+xsNtItpg92q4FZmW+Z9st9zvRuZohfuiyV/Snskd///
fq/vP37vjO6BACoNeuK1IiGUxEH2T4/7Ha/9/Ym0q8sn17n0QOKlpDepdfl4
99qjLOJmM56bi2OmL22HhFrXHH6ROBh4+qJUNy4OlpyCHoZCIzQkFdL+Dg6F
+GxSYpdIFfBGWfNtI/vqlsC0ya7DvpC61cmjZ6IN9lB8GjPFp1lTfBrz8+Eo
BQEGwqvbr0FGpgUPFOxkurTeAV22fvx1XbUH3saI1kzGfMQdEh4BLfbNaHpK
Woivtg0Oj14JP7e1CFqzNAuvUSeAalbt5wcL9TBs+T0kmToLnBO9n3vqVYF5
6uZp3ovlENe/MXSUNQ4yjuPfw4ztUEnxV00Uf0VP8VcOpBuDu1jpiG9Bsq5u
QtP4ue/vujbWQBQp4d814tsNUi1j4rR7suB0797PH982Y2YHw3DW9haIUxzT
vO9XA9ypp6U6yOu+VcnNLZuHauHPzUnxd6Ol8Dg1lpZaqRpE/NWKdh4vhUxz
T1PtoxmQnDfmq3qlHcwp/seI4n/EKP4n6nfw5DqVZRQpczl//skyvrH/Yusl
mIqHrtXrf9XuglcGBUxCV6vB4cPMI8unzXi4eZvcyM0GkNz3+Nu0WQsoJ3m5
Hqkg4Ej3u5/SbNXQ6bgYOL2jBphFN/WkN9WAcchY78mRQuBjltmVqJEHRtyd
ZowV7dCW1SNXfDkJl13f7xGqyUfJYTFP1bEB2ELxM3IUP2NO8TO785SPaspO
IPubTMswsp+5ytZ/x+90Pn5W6hO59oUEvSd7mcU2toFMn0h3ilQzXj1ltzPa
uhpEY45USdqSwHt6/EdgYg5I6oQcs9Yvh7nGbDq+K41AJ9d7tIW7Hn5Uj1+J
zMiFdeuE/3KmFQNHvfgmr9cdwBmhU83bH4pN4Q5ukqGl+PwXH8Hf3A/OFH/y
leJP/lD8ydWZlLJlHRJuFvVj0QxawdBQ29wGl3Jc2PjJtzuzGPT1ZUVs6Xpg
+GibIGoXA2vu6Lu2/jx4eDLPOqWtFdbvu7dOh70JPkxF19gUZ4D9LXMR+ffl
IO8Ut9xtQgJ5in+4TfEPPyj+weIYewdtRRa2rf/CNfdlEc+aFfXxLlRh+sK1
sz+tUiDp1+OA6D39sHRMm83jVSUItdyKd01KhqNy2Zf9z3XAEZHy6eelreCV
LriirZ0IZ3YIqb/jqYR0/UO2Ne864dh/OGg8lH1/97eA3b1XM8GET9k6vG8W
+X/8lTF3rsUBCncs+Pv/yx37X3o+hTvm+h/u2P/SzSjcsWP/4Y79L72fwh0b
zf8/3LFmCnfsf+nMFO7Yy/9wx/6X3krhjj2mcMfOUrhj/0s3oHDHhCncsWYK
d+x/6ckU7hgPhTt2lcId+1+6KoU71vUf7tj/0lso3LEJCndMicId+196BIU7
Nv0f7tj/0usp3LFz7/8PdyyDwh37X7oehTsG2v8vd+x/6UDhjp0K+n+5Y/9L
j3F7dDhanwB65Tk2bZ5hrF/kGmlubYY9UdzUMhzpkHMmM9wsloS9gw19tvad
QNf8svJJaxLIH7pI/6eiAuO1Und1FHdDOYUvFsj9//LFfsnxzvTRR8DxyecS
ZssdEFh/ycbTgrwOX5SqEklyBMsr1dsjX5HIdeCtjyo/O8AkW1HwLmMMFIu+
sOBt6oebdunFdQVVYJP46IrdrRQYoOriXuP6JTqM7s0UdoDuMQWxt4Y/sNHw
5phC1CB4qUg4O9LVg11aqUpNUgqwRsyaH6iZAEONpww6hg2YS8np9FNyOvaU
nM4WyntPJcp7T0vKe0/HlMV7xuT1coi1I1vw2wDoKxrnWRjNo8ZB+pxqzyJQ
5dYPEf5BHqey4mxt4xxWR8ScVo3MgkOx9m8KhwagPn6LseiveQztFDcJ/FgF
u9mv3POfH0BrF7VFdalFPFV0fqXWoQaOMyfdXTgygIZH4ryPpC7gS0o+t4eS
z5Wh5HMr8hT1Qs3qwIJdp2Xz0iSaZ4bkRm0fw+aLDUvTT2th08XfQvE7pzB6
zvsB6716FKRwxK7/hyO2jdpd6GDeX3whNEPDfGAIqE6XsXl+aoAXlPoiglJf
FFLqi6LlWu2yyAJkEoeDTBeGYVFTkUkrpxWYJhZPUWem4tiDmH0XvKZhNOdS
edpUHYZFzn9Vrk1Ak5P6PnrW0xCeFj9UpD+G0w2Oee7z/qAYu9t1LnoIfigu
c1WdXMSMOwMSbn3vQMN7y1tj0hAccDF7oGC7iMnWD4vZvjWC5fXJoM/BvShc
66d/8PE8DrwsEQngagaGAKkG1bQe9OPUXFKln8crlL46ZZS+OnspfXWyRi78
uiPbDtzcyuxUz8fw6py4QJvECKYc2hg5vbkB4vyFDwQfmMSlU2y3iZx65PrA
5mjt3QZUAmxHZsnXC+74XfSJaECq2f/DKROjcMryKZyyzMjb4ztoszCPI0T7
PrkOyj+ZaBrj1w1nndqucXIV4vSlbLqy5yS4mH5A9+zmXtjL+PdvvV0Z7n/I
O2NiNQzTYnfVy6+1Q9J/6qYgSt3UFxPYvXG1Hr/JRlAXWAyDcOqDzHndTrio
5nZxMLUBvWXflctyzIEKL30690gNev2n/48Wpf+P5q4jkk4xiLr7uu5/+zkM
DiZc1rv1l9E+kk/RyDkTrc1lO8R/D8MV3YmDlxOX0eL800PCg21gm3iJa7m2
EwUK2O9emJvFM61nbnC9bIdzS+GfVGtJSPeeX/NL8Cxuo/TtmaL07RGl9O1p
aJoMbLjeCWIWf2W9pAbQZ87zl1n8EFpFeV/eHtUOwwsuJjZio/j70+qxcoZG
FGvXJnW3k2Dfu4SX+zYM4MA8VdD19EbMo/DRNv+Hj3Zw/Ex8w4dyDFDd9N00
pwMMsar59Ls+GFGqlA6nr8aH2p+oRIh2+H2RJ495/QBIPj3ayE72R80r4SQ9
6WGojVnRULftgipKnahIqRM/UupEId7vLIMbO/Hvky3VW/4MwtHscL7tk71w
n9JfKJnSX4iW0l9omZemJH+pEg+Gblj5OzoEfQ+fDOSOrWIUJT9+jJIfD6Hk
x413GyjAw2qsaXes4YgdAodR6+sCAlREhzpPnUlzB4TW/54RcGpDfbUJO4Xa
Gby2RVTC7wQJAsMr/KINW5DFW5BD9ssMJrDELYWbdkGlwYOi56s9WPLs0T7S
riHc++xiIe+NbsgbWa4cau7EpUuGA00/BzGZwlOLofDU1lF4atqP1QUOXq7D
j2yz0UxFrRDhfSLtqz35e/+5tt9FtRETKx79OPuwCehNhjb6DAwB3/GN9taJ
XZiRqlEfWD0ApCptI5X/j67zDsf6j/6/TYqirRBJklIRmqeEpCgpSoWKiqIo
UipJZVZWomGvkD0j587ee8/7dtt77/G7+37fn+91/VyXf8/1dl73++W+z2uc
cx7P7d2QT5xzVxHnXAYi//KJ0F97SuivJRH6a0c4Uuj8QydxW9Ii24W8afi+
6eWaxvAC9Mz0/H35UjO++Tx205muB0oC0+Kc1OlJvkSfOwPj/9/nztOTtos5
vgWP7PN/5v24GwQTNbZXvqEnRSfMvQvjp8IGn+916wVrUOV68ZT67Djeqr+U
HXmVCmKa1kr1zFXIMuqhEFw8jguurf33mDuAr/KqaHAJGWVJdxaSDvXi6JtL
f3TedUCrBf+JrrAGLN6UPnmG0oO1hP5aAaG/dprQXzt/v5ET6JpQXeqdcLJ2
Dex7L+4fJjMAhTYO+74ebMErHu84M3+Xw0P75t8NNwchT0hStIS9F81Cvmry
xLZDf+ThC/LN/SBP6LLxErps6oQuW4OH3PrFKDrSQKe86d+cceAu6w/KK/mL
8qzHm3lV2lDg5Ja7q6+3QbXQgwXbCAZSKtF3n0L03acTfffGVm/FzJva0M1p
va7qEyqka21x+1LNQNrr8duzrooKsSb+jMw3i3BS2OdvjdY4WgtYWRgNUmFl
WqrK4K48/PrFkuvniXEUXXBwD23ogC+1cUXZDVUYd8WIPs+jB5+p/3DqWtkJ
M3Kjr/NFS7GLDrcVaPWgHqHL9pXQZWskdNkEXO5X53Zn4RaNY6wkSjwcp547
tDqlFw46QNrDA9moVRDm+UYiGtYbClulNvfClhu7v6QYkbHoQoqQPl8BlBs+
j/q5Zwi8d2qO+g2T8ffwRunmLgSrrjP5Th+GwHacd2iWcQh/3ZnMHD3ZAOSV
N22PMgzDBULHDQkdtxRCx63xNMts5i5mEu8KOufPh7pB0TLw3c7wSDxdvK38
2FQnhpQ3zz0erAGfv7JNAfmMJGmCJ8BI8AS8CZ4AnftGq1n5Lny62dpc1qoK
nk1Z+JR2MJJu0+u2O69ugzE9iYwZgWS0LtsadmxmDLsf3AkeXNkGa+Nb33lm
R+HN4ujoU91jGKDU79e8qRPWGJSEme3Kwp2buFUlD/RgfSCL00emTui1ebLw
/nIcngrolNjL3YNphI6bwxIdNxa/cxaPL2XjB7r0IN0j7+H90/XPGrf3gfPX
MtUIgWzcX+DP2OfzGsU0LH9n7umDvQ8n4lm3UnBjbi2lj8EXfNJEOR0LhyC+
+ogHdw8Zb9mdPVzoF4EjumxO+Z1D4EXou1EJfbc1hL7bH5HzPlQVVlLfoNlq
tuhELMXjOTFxDsgiFDa0Q6IbG2u8g5s3/IRjJT8DrA2ZSCEED8GK4CGcIngI
2yWuvRMR7kZOAekiDdVnwG3vIlZqxkRKykwO8ayhwtvFiKSnij7wMu2ev1je
GM4/tjj7JYkKXlevKk3cjoLXXgWVIZlj6JTqnXCutAM+vn9yXbbeFBaZQjkF
FrqxXqYjtvhFB5h/yRMlVSdATdBQXcR4Ny0O/K++mx+h70ZH6Lu5Xfcd0yvL
RHV21vul5lG4IiahcA9tPqciS2+27cjEQxsr+CsF4lHctHybEncftB+rblx/
nYxMiWEc1kYZeEVNdPeq5iHwKwsJVOxvRunzJaaGScUoEL55NCNyCJQJ3bdO
QvdtmtB9+71DaGLHN2ZS3MdoNSmzITy6WtZRl9kdi2QD2re87MStpi4v8j+X
I2Xuh//9B7T5JHgOHQTPYRvBc3ATTuwt5O5ExtHe3dl7qvDuYsi5ozpMpK1r
Wg5rS1AhWHWNX695JqwIsn74gjafm+4ePek03QrX+Dr3+Nrkwmeu9PQjZWN4
/aSrrSR7B9ia9YTGcWcDv0SoZNRUNwbrL/xeZd4Omqwfv2xXLwUfhlZeCdYe
NCd037oI3bdEQvdtZX3iGotXfzExtbFrdP9fZHx3QWF9ci+YjAw/09Qn4S7G
F1z7TmRgQdcdm+2feuH5K7VY3beNuH1ij3jR10okr8/5vVJ7CFzjkiV93eqQ
sqtzYvFCHc7OMKtXNw8C3XOvelO3LrTwWXQ1D+1C9nYGzSHrIbhO6MRJEDpx
HYRO3EDCfQGLIjpSjO7alAXuWWwKqNqW8ysOez4z/Rjgp+Jhz7UX5Atbkf20
yd6wHEbSGMGpCCU4FRcITkXeTOm5yIetGCaS/bejlIp3H41y6/5kJLVs7BK6
t70VNuT/PO6lVA6BOjyf982OoVnb8VqJYto5qU6t5tDpSnCz6npvv3ocpa5N
papltYHkkwYfV+8qYIgLuGch0IMT8qt+GQ1RIXndptWjXfVQrP90gEmxBx8Q
OnHdS3TitpXZWyocqsYcwwEhZr0mnOx+Ej+TPwAqlJlP1p/KUVXKfCPnbTJG
JmZuZ//QD7Vb38dqiFAwSO606bHpfpSQj3xwJqgPfhL6cU6Eflw1oR8nMu/G
n3B8AvvbFGbT7BZRmO+zz2HrTIw45ptxTLAeDZJ3Dn3z70ZXHU7We6EMpC6C
s7GD4GyUEZyN76nuqbcta/GemNfKSYUedIi04NCwYiApVHl1BviTwauQLFsp
Ug/yG/3um+uMY72Z3Zsr+8kgU5Q00LehEezZnb9ceEP7f/zeoyMw2Qo/Qt0d
fvCQAa+kfLax6EGp9H4Ly2oKeJTvHX+V0Qo1D8ZU51N7kErox3US+nGthH6c
WC6JPuheEe4Q+eO1L4GCe+9J6dLv64Od/AlqNu+ysIaJ2aQvrBUfP39y+0ta
D+wUkTQ3sWzGuzUHez4XDOCI/taBZ097/y+PKbckj1kmpMjae64CmaDyiOL6
ISxQl/iUQO2EFkKHzpPQoeMgdOg4VFqEWX260MTxSuOcwSJGs+FNWfpifP7h
bEVWSR6aqV3T89Lvx/cjf1w5L9KTEpbwRmwJ3sjtKykJfvbZ6P5JzmBNRD9W
TC3mJu2gJ2XKjcY81WgC+aQBNc5WMjC/rDqaOD+OZy9STspKNIKSt0u8Je17
mvHU/YDl3gns+b1BudaeDC+U7skIPmqHXeq2aqEcvbgzZXzkEH8zKBaLm+0V
6AItD7OfOx/24jtCn479wf+vTyetRW5cdzYF7Se17706TUVewTGPcNlu8CQp
U6kZwdhOjvaw+0jFpltvG/syO+HbmPCbN6YleF7xlVPGjiEs7/vY+iqRFseX
5FUDiXvL4AvfxG3ICXjOoS3rTNMgdpWybxm+QgUjK6mwuvFy3LN4eqNr0xxy
PmUNyigqx486fWPxcqboFHSW4v14AMfOvGUX6FrEYZYqCVdxFxD0pAaU3x/A
IEvz1EDXRaQ2ZN2g166F8sHg699etoFNnIjs27oJlBxIGdsyVg1FO8YpSVfb
YeCquITUFtr/PyDqiVVaPSwopEvlV/fAn6g9Xo+ovbjOJGyLcEc1HD54UF3f
qR/ufGDjHn3Qh5VHc94xKOZBrbimjWJtB5jcsxtruVpM26dmK4hWp0PLgWfr
GB+Qoez27+N5dY1gLQpCWYs/ga/lj3s0czlqluncfXCgEz528BX/UYoCryM4
xLumHOHv5EN7mr8/rDL5Eq9sQC18IkPBlooFQ3eCfc51gERJz/HeqSgIVohh
KzxKxdeWt7cGtrSBk+n197V7AtF1QSeM8eUg/gnRbss90wpbl+R/vxP3t4es
e3iY6xPgZ539no1l/VgbU1Os9KsZ3sU2xI/3psDwh763ueb9yBjn+ONpRhNI
ERy5FwRHLp/gyH0t+FDTI50FLaUPjcIM+vELpTbVXHce40V3fRePyIEnWmQL
9j39ePOCRUnN5nlU8/R14DhRDsc5+eoPFHQC+wCbyrO5SazpvnDA730paPG/
iAugnSfHqr0uW6hOIbzVrhR5Xw562euETwkPwSHHU+N+nP1YtaSvXIroK+85
YytZ41IAipO9M8K+3XA63vdxTf0U7hJp/tGQXAa/Ej8s2DANweAUv98V63pk
YrHY5VySAVtWmxaoCYzAeSm+tSW0c74EUa87RNTrbiPqda8KXg+ZbyXBRwH6
+csWI/DXR0am2b0ObeWrHWdo89aTuHgthzZvCduDMv7NmxirhG5OUCLk24om
Jiy2Yl66W3rD3jY4Rt2fdXNHPJDWuZxlZyhHZboVKRwXO8COuH/rJu7fXIj7
t+lpepihjftC78dJddq4/KSMrAbauKvZ06X2+/oAUxWp6ARlFPZ+7R4VG6zF
TVeMDbwWYyDUmFV03H4U4meFFXJ2DOI4vXrDRqdKmPHlMzLw7MGfP0t1badn
cGW4O7uJdyXcTBffyUEZw4z24dgw2rpSEL969wvWcsiMZ3OZth3HYmtlTuX0
GjxI6NmpE3p2/ISeXSxzxt103gI86v9s05TzBHRpr/Jgl6/Bofr1FHmOTKxV
+XFizRaaXTSs9vzfIVzEOqcsrQaoWct2mSzRiRqebAe4ZKbxTn9Rbr9zMwTc
tHXIvjyMLyXtxR/5D2BWtKF/mlMj/CjfEJlfNoybPwxtdFeqwyn3dWZiZypx
vZ9/R97XflAccihZUUEBQULPjoPQs9tD6NlVcbd+U+Gg4Fl27w6v1il4YPTb
rW++ElVYhxRPHm1C3ogvdaUnp6Dh+qtArWu077nF99fKR8kg2C7qxK9BRS8/
n9XlJZPYxyLVNxrRCoI7xaaqm3px9ePjpgfY+5HjINcNtWYKVNV/axJ270P7
P/OdTvfqUedUQcg1FzL2/mFeU+/VB8dfHgm6dqAD9Ak9uyBCz86F0LOrti7M
EjMZQFLDc0cHpRmQXVP9ZrqjDOMKfJP5Jmn/PzFpB0/zaWDVFctIej2Ggjz3
XBU5aOvsvhSPwufNuHr0eOmRxAlc9elqVVVfG2zPnDxscr8d2WxkuY+Qe3Hr
VragF2KdaMUpyNkE3TCuWjagM9ADhp3Sik/5x3HgYp+dduEUrPBInfh5ehK/
/Uju/nuMCtCer8++rhpbGMYM37aN42HTcxealTqA//FOvxGfZry543qg/spe
zN/bfs9YsB81t69x3c9AhTsVNee07QbhkkZw76r4eRT81nWvhfa+663XdJe6
zSBz+7s4DyoVhrjTzinKF6Bm+cqLF8+PIw/Lh6mrUx1gVcasGLxYjlwvTHdx
PO9BtivM1g2/yWhndTP+rXcWGETdqrC8OQTHODHFLHgIpeIa7FLrKqBzz1wT
1XsYXoY8UU2MYiBdTdxmvEukC0R2s3/sKJvHiS0sWr6cbTA4xnPPfjQOgyNn
UXN4DBnE6Y9kc3fC/Ryzo71nEH/tuMMZuq0HD5lrcf/ipKBRr96aQjEHPMVo
NkCinSMOH9qyJfD0MO7YnvLyrpMvBjtJFqh8H4HJrW+SAoyZSAF+dC/oz0Rh
kk6hH1/JInL7zToM5lKhda/MkIB9CAiHzDrZZo+hwYmdBQ9DafvEYmGB/hMh
0GNwUMWctp+/pzsTFNvZguc21I+dEMnDyNjCrTcLhqA9UTxITGwI3wl9ra8J
qEXbUP2iiCcjsNlz19T2LgZS+jo3of7SfrS67cf2yWIRvdaJLapspMKqgytO
Nr/OBm/mP9enC8cwWtZhE39WO7RknXNM1ykAW3ovq1e0c1nNoTUOqVsakOGX
c3omWw3KXDJkqxSlnUNnnFj6N/Ui9URlA1a2488knk+PJIfBxlg9tUR/HoH7
u86uhSnczDDcEMk2j9/JR95FTFPASbl3m8qZCqB7Fdc1zjSO7oHNDgrabZD3
qQTXytVCnOir+T0SPdjR3jdmwdCG1d+eZptp9WGZVKRggc4A5PzlFvW9Porf
9FREGz7M44vhteKykdM4J/qO1fg+GSbsPCwMtjXACz8R29FH41hImto9fL8V
7k56GgcYUUD095kQ4689mKrY86OuohaFD3c38fwaxLTK59SI8G7YMHDP5Eh5
Gx74IVT2qWQes9a3cMq/nMBjXRrXnuQ0QrjIcEXEFQoYP7n56vv6CTxp7Lhn
MagFyhLOnl2f2wHHT1OS9x+lff8pvp1ioll4tODoxmtbhzA64JRNx2IbMBG6
adyEbtpTQjdtU/PLM9WkAgy+I+S7LXgW63NtuY5SRvG6/g8DalgN9N06e+Ic
7Xc87JKBhdMT6L2W55x0ay2MhWjXi0r0QW3bgyKtHX3op+t8WIe2vljO8+av
pK0vq7xHa/+tL4rldBKZtPXo2nnwSaStR5cvmtT/W49GCR20YUIHzYbQQXP5
GK9odzkIdqWCwQa1aWz5vGi98WcVPktJOmF8MRm06CIrTY2msFd6r+pj6jB+
SCvZ0aNXBl3Kksfu7+mCPob4H5eFp/Cemt9DS95SiP/dL6pRNQTCY3Jn/Wj7
4say9O79zIW083wucxP3MMh8kmFgEK7HLrePWkX7a2GcV8RDY6YLhwqjOIQ4
ZvChXb4ucNaDClPL4b2bRvGgy2TCaMAgpn/SuW3M1wwj+1kSeC+0o4SpuJ7m
syls7eROTRSmgP/gFv+IQ4PY++FWTXM2bdwQQ+s4vyJ89mbXz/W7WiFh/e+9
HsWdcP0pZ/iTwxRIVuNgOH6ego1D2a0Shydx1fmvg7H9VJi8dfCSsGcXCgsr
u4nq9+EqF1b10Ogq1Izt/ebLS4aAU7oMIrk9wKvh/8CqjYpTyddSjsr3QgC7
sn2DfReYTYhJrE1qhekAuvI0pXocuyt3MF5+Aj/y10fdjmuHqbZH7r/VWnHV
zp6wxw96Md7T1G4qsQEjyYU728zrQFls15+Pn/uBp+mLYs+5Hjwu9OBv4esO
GD1ea1mj1A9nVzBbkn2o4JZX+3esvgwvvnjwPtxlHC8G7Ii2iO+AN3O3pyKx
FtcKyuoKpfRgevvCVxVOMgZMGVzZI1kK3/Tfhh5sH4Tj17tKk94Nooql81iv
axO0bfPn+Z4zBIIKAaZxrG2gyPUkNa8+HW0GVtb+2TyOj2TZJEM2dEL0w7tT
qsn52P+xOptCOy+mzx1kVLiTjbHy94+4rguAcA05Bhe2PpDkesZwhJuCMoLh
5i+V4+Dxly+BN6Np8cT+3LqLe4bR3ul6ayCkQ6qk3oU6GIGYo6GpT6apQJXz
RYcdzrhTmelgUtUYlj/Lnvv+LQv1c1temf70Q/aDZ+VX0M6DYREfJ3UjyCjD
sDinuTsF7a6Xc3/sHIK9zll+vUND+LgSboUfL8C8tjnVmxEjULt+C9ebl1Rg
lf6mZxuXCk3llky+GWN4ZUeez+xgOmp0nRZ26UnBy1WSen/7eiHOz1RerqAJ
J+htjn1jL0ch4Qq6dw5DwC17GUxXDKCFRrL0Y10Kun9dLHQfHQZP9h9b97q3
Qkf5LubHbsWg7Gs1GdY6hgrlwfYeIzXo62fA5/CoAdHf9U+t5iA4KOk67Yvp
RIl1A+s+venGE1PyzydPDcH6j/WkTScp0PJiDd/6ozVwQnDnaWnJcZyW5Hlp
aU6FP/5BWz5+bAIHnshtm3V6cNfeLLgSVIo1IsWbb22i4FR5TU4ypQ++MGpO
NkmQsVsnLPbbvQG8/2i9q/7qPrB1PPdgbKAZfuVYMhqPNkPHeT4sSxnHsq+1
A+elKKC9T0777OY2cL5c9/wytQcTtJTkHrn8xUa3LPVwJipOv1l1TZu+B1Y4
B3p+fF2Geu0f/vTzD6EEPacGo3IntNceOkl/ox5GnnCkfRelghBf//gJywl0
i8jR7H/RCI8tL8gaWXSD7sq5xOKgXrz44Wi2WFQlHO792Onr2QGNa/I+6L+f
xJeqRdoyuZWgelQj+NzAAAR0JJ90+t2HLIn/q4d1gtDDYiH0sD4s0cliJuz0
ZtTBi9/+Al94c89FmV6Qk5ZvP9MwjWpsLZ/WBP6G9WLuE9eyesFOJzyTenYG
ZQg9rG5CD2vR/n/1sM4R9l7CTkfoZGmtTJebf2aMeVlU1gOc/bAq8MqrU39n
cSTTunx2LhDVTTd5uKj3Q0e6yKnIM3O4eH8+rcu+FVcoRgfIbJuGQxKUasvg
Shwl9LBSCD2sxS//q4c1S9jTCDsdoZPVcexmP9uRLLz259C5Lv9+UB7Q4ahm
XkDfa2rMSbTf57NC2zXeNv2Qc2TWtzBgAbetvShjXV2Fz6l6akce9sGGuOin
51ToSNrX5Z/uiK7F3dwfxn1ze+GnZ0yRXyAdyXlJXimZyCs1vRvbe9eWjEaf
D7XYNXRBffkIaSCCnnSDU/cwWwMFa665ZhvbdYJKlEyaAgsDSYHIs2wh8ixX
iDxLkYX38Xt32tHQ0V7nmVUrBLD8vP91noG0Sd8NBm51oG1Dc8wDCzJwyaxb
O3eakXSJyCOkEHkEJPIIm0qtmO7bdWFNoevlCMYKiHsgvjBKx0Ti2OuwnjrY
hbvHeA4MYAFUqW+Ljd3LRPrv/nwl/P/358rhBs+4ObpxYs35+mflfsilyXbD
5CUTiRKiuCshoQvra+9+6tdCNLfh3PztDRPpv3vj/iX3xjnFPm9ZvDpw/OID
v+qkGjQ9Oa31UpWJpHSy+0G5ezu2VOSVVvs24jqm7F0eYkwk7iOv6iWTKZgk
8yReKL8Nb6R3vFezYySlXV01OXWEjBPOfGIinh3oov3R7pIcI8nCcV/M1bpq
HFrktqxv6sEVZYlMLzQYSNvPNe5Ms6nATtIsT1hHL0rxjw800zOQWgQvVH49
l4GSE722OZ39uHtuYv7eNB0Jq1xV9lQl4247Xd1LRwew5NErN1FfOlI+oQ91
gdCH0ib0oaKW6EbdIOxrmuLaWH0CgIuUy7nx+gCGr8oV23tiEZVr5a7qv46H
xZT1zSA8gE0qOwO+fF9A9Zj2qi+XauC+kdYFuNONB/U6SMwKMxgqFvX+QGo0
jD67vD7nVB8cavEs1EmfwauyUjnxrHWglWZlN+fQhY6eekOJVdMYxDkTd8W8
Cd7UWxtdKmhHByHUXAyaQgWibqGSqFsQI+oWHIk8ftqSPH5c2kN1Qcl4tG5/
Yr/Rjra+Gt9yZK6dwxd7+gUOpDWD6VqK/ueKNlz1IMOYTXkKVx7yfca7SIaV
nJHSquUUTJ8w1Cq5MYnriXz9LJGv303k628Qee1kIq/NQOS1u1SDhdRESvHQ
mZuXrp/rh6aDh029FRfR7f3LNRsfU2D8mFStYwEZXajucekbJ3Ek3yV3wqkV
jhnys7ppNCCnic+htzoTqFLbdeq6Pe17a1AY/lSW9rtysSr4FN8HmSkl0l+m
O/EpS11ah28X8DDZ+0y97wX9pwksITYNKLDRoSV5uge2+ZRt75mnI1mYdV1t
bmyFs24zC6+P1eEZrut3e3dP4AVcMJByoELcZ71Z2e5y/PJwKyktcByVNBnF
K6YHcOWxnQL8ZS3Qkfnm5wX7IQhVKlv4kNOPggdN/i4ytYKUx1U7H7YhuF3/
8I88HxUPPi+Z8l7RATvXcxpmX2Mg/dRbHfg2jgretjGdsYWlKPE4a9bq9Tjm
f7kfbEbfBqwiLBV+Y5m4J7VkB2XHOI7R7WJ3XD+MawKZXDel50A4yS6lhHcE
vD35dhiUD6FxTIlwAJRBwuuTz4OLhqE91H69LXSiTmXoJvRoBJ7wh+6hjowk
xuhfmfyraPvs8x3X7f6S0GjTzGNDznHE8DuX1Gnjekyutu5v9cGpU0F+jxvG
sMBgXk39+DA+CXBXmFdLhvd9Zx4G3hgBudb6V+5nhzF3V3Nurew7mIzad3rO
YeT/6plTltQz+xHxJ4nI33ET8afmis0Kca5hHKVsVVB1zkJjhcV5hugReGxN
t/Dl6DDK+IQ5I8RhUN/ddWPBI7DCrnr7ul3dqEbxG5jf9hdaT9iRedSYSHkc
2XTNg1RIWP3sxut3J9GeUyk/o3QMnx7UYyL/43D8yqOmfUsC8a9q4gdp+592
f4VTf/KGcOPfs0wWD0uRJWV0bDZoBGSE9kaK3x1C5ZSCIZGxKgzjN61ZYz8C
IkRd9PYlddHniXjYRsTDeSIemktnf+76NYCeUt67TfaQ8dKQxjwvzwgkxF/k
76saxB5RRy7V0w0oxGK4tlRzBITXGAhW7+tCe/f9re0O+ZjB9nZF+wta3O6f
EDC/Q4Xz0Sd3fdEjweqTBeGlmWMY1a/vRp/cCiFtAuymzoVwpm9yy7rGMXSe
WT/bpNmPHrLBSaecW9Hs7T4j0bxhGJJ5+aSb0osqzRx2/XltGGHd9/a2/jAU
EfXVrUR9NRNRX32DyFvtJ/JWnUTe6lhu/fer99vw3W3NBzZ+ZJzTiG6+vcBI
unw3nSvQuBUueQv7cpwtBc2n0Vs5esbwhqJhR58xBeQ+yZUHnqgGL+8HIrt2
juOh+gpWnYIOzKjy1Xqs3IPJ3x+YFNEPQXRL06rGkTZkKL40r5vSi21hruwe
gwNgQtRdPyHqrkWJuuswIk/0icgT1RB5otvHhBM3aDbhoh2p4qJ0FzZw/vkW
Oc1A8uNoK3rMSYGggt1SXlK1YHXKrHOr7DiemjRhzzZqAeG+5lOWdM2gyqJv
mxo8jq+yshToDpaiHJ+CyUXsQ77itfFPQulJ60qGxUXvN4OJdqcndzvtfGza
5FJVOo4ntb18Ny7Ug8Fe8kPrxFZ4oikopXybFq9+sz4PkWlCCYn24ceL8xh0
Y5c/o2UZ3tx8aH/6sWr8brIyPUB2HvXZijW33CpHljmX3565oWj88tKNRf0B
FFcj0bWdoSPdDYqweJ1YB+ztj07FfqdCV8Uh1lPfJzDFV/fjBbMq+OHff8d8
XwfYbJv/ZnlzEpv1W7ImJ6JR6A7dI/f4GXT4lGlkHFWJ57fdvmS8/RVk7wtN
e5w/jX8aPY/evFqFHib/ex/+mrgPLyTuw43bJTlebSGBtLTr99bKfuT7vE6P
Oj+PjAlag/ztFRChUiInSd8JKYvy92zDJzHmGuWAYGge+NmKfd8z1Q0HznA9
urRyGt8bPcxSfl8Gq+sPC1tE9uIAr63Ci9+zqLZFWPr041IYo3CXBDP1odyV
Z68L52fRhKhj7CHqGIGoY+znMdy5sysP8jKFXtwZn8DDIbpvzqyqQQuZnhou
g1J4ZJWteohhAg9Se58t2tRgObOc7VrmbozbfHsrtXcaLvZ+lJbcXYEb6iSc
Ot36sFdk207P/TPQKufdM6heju+9WoN7snrQbWdvSh3XDJxvqmOdTy9H5pGz
CqrKY3jpY7hu85kZeNHck+E8Xoz9u89oXXk3gf7rhwWq6GbgYGL9ILmwEMOW
qddiJ/plti/pv/6vPod/SX1Oj4d1rl/4PJ57qL6quGQSUjYqnAsOysLnn849
nuKmI12UfOuhZDcB227bL7DwZKDHkrqms0Rd03/90deX9Ef/V6+SuaReZVJg
51PhAEbSrRdNK8sThkD2jSNrdmMC6q2xskmNZCKFKnI6rhbsg1aRdaTLG2Lw
v7qg3CV1Qbk2lP7KLhZSmvPqDPmKUgiVn8vOifmKpCEn509HWUmcMUqXPzt9
B+Gpo4mfjjrjf3UvskvqXuyEdoqIxbGQBnYI/t1yuANRt2t61QkbXG1/8w03
Kwup8qzgqJJFP66Ku2Ux5+uMv4h6DzOi3kORqPegIyt53KpkICU+sqcfKJvE
kLxTfD3lYcgzJXBH2pKetNZxn6HixhnMzxa4aHgxBkOW6FbwE3UO+8ubfSiP
Z9Bt4sfpDe8XUC31Vdz5IBJebaIa+/hM4o2CqVbp04toWAWhb49k4ASRxw8k
8vjniTz+6jb/3/YOg7gvwuj52fpFpM/SlS/yz0dxp6r2nQ09uDjCyFXzdRFV
EsxOkLoLcYTIawsSee1KIq+dReRhi4k8rB2RhxVP13J/vzIOHk3e1Gisn8JV
zZ/5ssersIDQZYgldBmA0GVoIuzRS+zpT2oSb6/Lh7wct2fbe/pQ7Xb1vH/p
HAY4OGnYRxVD4qbiy+GX+/BuS+a6r7JzuMH61ck1yr/gx7aT5r2ryrHnRrPR
C+bO/9NZaF+is3CZya/J+14K5O3+6HrwN+2cfTaldtinfdl+h+XqxilL6rSt
iTrtYWPR+3edy2Ew+aukrnovrmHUOBRmPovqmwJPOlRNIR2daE+r9TR4StaV
G7zLx/I1inQNyvSkRHWr+IWhMeDfcjTV6y0J90x18JK5sjFk8xXvlx9iIWkj
f2ZIUS/QldyPjbqejS8s2Ck3W0PgmLWslPRcL9xl23by/ldmku3X8roo4Q44
LnTms/+dMMxcoWHYfYGVdH3t5HkO3QLcwHr2h2Tte2QzCdx83DITY4O6OrVL
Y9B5zf6Fj1v6YPMZ7/enBJlJf9caKJdvGcHiytt3hOS/oX/DVGnzBAkZp+Ym
Wo+kY1h8ysqagF64QqzjksQ6TiXW8ceSNq6fNtGRZuNjJ7rGZtF+VPv1yNZE
nGbnylajjqFSlsmK+uRFbDQ5YGuSk4WT0TtkXph34Gvzocjo/Yv4drXajco1
JTg8t/t+PX8AqD2Viw01oOK67LjMe27tUMPykPLaoBAu68Hlk359yMP0cT/V
dg47WQ68an5UBGeM0n76ne4GdvMd8olhU5hK5D37l+Q9X2VxJXbsHUKHZ0nu
a67PwBtR8uUVj8twjOBdjxC862SCdz1J2AcJe9IS+8gSezgRn2WWxOfDBL9a
n+BX7yL41ccI+13CLkbYDy+x//f8f3GYbkkctid41AkEj5qP4FF/IOxRhJ2X
sP/3fOyS5/+Lt+lL4i09wZc2IvjSfwi+NBNhv0XY05fYDZbY/4vD25fE4d0E
Lzqc4EXbE7xoccJeQtg/Efb/nk9d8vx/9XjPltTjMQr9L+f5HsF5NiE4zwyE
/eEydsMl9v/iNnVJfRqJ4DbnEtzmRZ3/5TanEvZSws5A8JzTCHvhEvt/8fwn
Ec9ViHi+huAtSxC85RqCt7yKsB8k7LXL2P97foCI80JL4vwZgrf8muAtpxC8
5eNLOMyJhF2OsL8i7EmEPXVJ3Y4NsV6cJPjG5gTfeIzgGwvKvTXluzOOWr+u
1N7cPQPt45QT4u1FWETwhDsJnvAPgidMejy1fmX3AkZ6iVy+LjUJ9nRUZbZb
mahEcIPJBDdYm+AGB+381vR8DxOJvPKwuUnzAFh/D2W6/zAOmwg+sDHBB1Ym
+MCWDx8bXuFhJWmNyqzoykiHaRYecontZywiOMD7CA6wKsEBzikPE12hx0JS
dlBSLOvqxufxFuuHVBzxFsH7VSN4vyUE71eeYXTmixgDaavhaJkL/TSarC6x
MlodhY4E15eZ4PpaEFzfS9JfornZplGd4/QM5/ACcpow9JoM/8Uej627Sbv6
sf4Hj4siaREnH28/apVfgMVe6wM4f9ZhVfDIBzP/eXTTEvNyGCnDF0v4usUE
X3dGQnlanrZPdjmdtzqUtk82JzXv/rdPXst6TyOQvhKa9S9deOs7ANkqPn0e
KfX4IOSlkLJIDUhGPf171rYPcpzuXihnbcDleGL7DuTYGf6MgNrJrbPf88qh
av6Bq5RFGwjzM8nImYXA4IU4l5SuctjGc4LDoLgNdCUMWXqcw+C+oUtuR305
NPmygXtAG/ztiZu4WZQOT49s9lFJKMW1vJ+bWZ+2QWJlBmuDRQbk06O19lva
uTvwmqe4Stuy/YnLre/L9SWVWEtUMlFygPH52847kUXIahJg6A9UWBvDxSH+
OBdQekWh0LYiDHF2qXqwhbpsn+Ny/pfr32HviFcqZyoEl4ZJiZXJuVi7pkfp
/H7a+dwlg/vQ00L4UP+zdRVbLj4uuCBfwN26bL/kcv6X61uJMN5vp7a9BHa6
QN2ZqnR0THOr2K9GARJLyOvdT0pAIv4uZ+LKdHTOD/jCdYSybN/lcv6X6++g
CO6XBc9SkLOI+PLncxK2yJZmlP0kA0Vust4pqhQCRNlkTrcm4N3nh8WtPMjL
9m8u53+5Poh3R/1HZzeWgbIeXfBVg0CMFjM71ihNhrv7N/gBXxm4eXaW/KD4
olbJHnqPPeRl+0CX879cH0GphBbz7tVl0O+173HQogNwpLSD9XwLhHIMeoQy
lQE5WE0yeMtn4KFzSVCZbFm2n3Q5/8vV1ZssDD9NsSqF0b1bF756RgNT/lTA
8YUWeGb5oq/vTilc+HDF1PhyLJSL562WZiQv25e6nP/l6s+f3N2v29xZDPkS
FcciRBG2T2jdHJMhw5t0aOxwoe3zH3PUkO+QQONjtpGEHHnZ/tbl/C9Xp+3w
jtd1ZU0BJEUeiTNozYIEi4WdvmFk2MF68esD3QLYHG+bYeeTDdQTby93/CEv
2ye7nP/l6pY/Oe5iSyLngCJjlbfJ8wJgHrRiiblMAZ2j302LLuaABtu0SxJv
Iew+efF4ihFl2X7b5fwvV/c76qFyfZgnA9IiNu3Yt6YUrDtdep9ItkKKe5ss
l2k6pGj+lDG9UAr06TclitVal+3bXc7/cnWwfAWVe5vPpAAlotqiN68MDFpu
kq+dokKGwD7/HzXJoBOn3Jk0VgbUP2PGiveoy/b/Lud/ufPdGsWnMaub22CH
6uUETRcqZsbW9d4ybcBfyk8ZNh5pAyXfxbLgsXbUx44rddINKMQr8+gt8wy2
2Dbpe4hP035fLOMD6nlYRXB0geDoThAcXfqA5zd/d9GTntvlWFxjGoPsrTEv
Zx+noSLByzUleLnjBC+3jbV7nR0dC+mcvsf54N5WEMmKPuaiF4x3CC6uEcHF
5SW4uH9+D47pyrKSWPIHtNssqtDrE/dmkRFrjPT/whOhnYVUnbE66yfBqDIr
xWO4pw8sCP6tG8G/LSD4txPmKwVtfjCRfj7MSHwZPooDUU3rLv/0wYKK9lhp
i3Q8v++YYszWNIwbycvhauqFswTnVorg3IoRnNsDRsHe/BkLqCTAyGj2Zw4f
fQy47f4tGQVqFCIvfBrF7SIGn/7WLqLMWLzrPtYcPCAjlGOt24bbj98Iah5c
wDOSz11EV5XiiXFlhlj2K6g0LDe0XqoM2Wq7wy3dumCRXUjlZ4ENpJtpPdSz
LkNJp0C+N8e6INZMeEUdvQ8EFqe806spwylxW9OspE64p1Jz5/5Vf9i36d76
6Z4y5LH5VrXFsROse37Ktu8exrvGr8Rf6tHOcZLnjblnS7HqwCvVcd0YuNSR
sNj2vRzEvN5t6d/VBtvCTq44uJcKmY94zkrJdKMO94moyNp6dE/ZkaL+lApa
TRs3dOp2oaC2+sz0cD0yqKhKB85TIZDtjZ5wRge2cm5Vfy/QgJbdXNZnxcnw
1FZy84mRNsgY2BncVNuAMTebvjplNMDXauUtXau74T7vtneGjxuQ9wRfL1tn
PfjY0N+sInXDVDFTcJx2A674+6l/HWM9TK4zVxYy6YGrzoMVW882YI7y54GJ
7bXwl0GcTKnqhbpelxsS/A2oEtWj8Sm8EBTo9+vYGHQjb+dRXYEV9TCS1ndU
JLUc2MR9NrDfGsZTvGf3fUuIAflfF/pZP2fCuzcq3hcvN2MSK73do7VUsOGb
E3OUfA3jQtceb2AmQ6aRQMVbHirIKQ+cSM/zQiWRpJoggx44tzLA7s/WehA9
oNNUTQrD57p/VsgxjMDtzLuDvbMx8HSfTccp3Upoei424XqtA22Gs5gzZarA
MoiDN125Hm7uYDgbkdSPts6yZummVuB1seyhwJtCcIi2mXd0aMBP/IcuFZym
gJzo5Lu/0z9A5HbhmuiiLODiiBnxsOoAlpAIyPodjRePzljw0+bbwkR31d3N
7TBfqmfudDULf9M12J+P7IV1T+L4ROtbwECSse7fuJzBt/kjaeOmJCdXXaGN
e+n27w+3eeog7Fh31PqFVmSQY7pYcqoMOM2eJ8g2t8CY0yTr/K8u3Bgd/dPP
OBCfWpz7FmVfBn1V517bsdTiVp/KJ1GGLXCUvfWr76XnUDFnYP7sSSZMnz3B
PryvE2q5AoYZWDJQyjZgRvVWC9z81it59WgnvD956N0pmv8C17Uh//xbNjor
pdD8C1Vv9x72aYQCDumZDz3NaOROvxPECuG5/dqDXD0UuB7jP0hJoaJNz7Nf
zWFxeN/vxde2HZVgGBtn2j1Zgd0XAl0ScxshQc+YpCH1ARcoVuN7z6XDGItj
c29NJ6Tmejc7zRai43u2Ce7uRsgli9vyG3aD12VJn3/+C9cG6bXS/OfOlsj2
0PyLmj4sGdnaAiH7DonzRdWgd97I4WtSOZC0vzz18nEqbFDQT79Z04QffLQ3
TexLxZfNJ6fsN1TDmBGXxDGuEiw/8rY4ya8e9i6GHSm3ywbD2gccHEfica+1
/cP611SQ/EHxeijvg8Vt0a0B2WkgOhmvkWDUBQLkEhWx1RWYoSobRa6phaFp
2T1ljr3QV2v1yuxPG2759k2Ib1MX8Pf2Kh5o64H6+p6bddrDSN906pBY7Chk
cgdGkFZTwOuYs/5jsxaIkzCu4PcvwovXy3a7L0yjxVHRypSidqg/caG6MrQZ
G9LLpoddB1FpNLKg9287CLjs9PjpREajBQXLy/wtePboWxF12vuWZxvo36K9
r6e5x2b6/amoFu9Q4aNOhp2jLGme+qX4UfVkSrxVBsS4GjlMs7ZBSeYdl8sv
K/FBWQHbvWoSFtyryZ25VQOeD4IzHWOzMFklXfrPTC04u/H6maTlQL/YJgM+
3l+4XWPzyMVtVBC+PlDNJxCMLrv3Ks8HJ4K3+JOEkP4uSKVLL0muq8ZLPtN3
SiUrINVxeAf1ST/cq/RcJf61G/3X3uEDdSoErS1j+f5nAAx3HH/NqkCG3O1G
9gfGMnCr24YPxlbTmGJr4NP8sgNeH87YNdpcifqFr5S/Vg6glvaele40+5bB
b2WxX6qRLebbabJKC06lDYz/e6+kLvXFf++1RfWzqiHtvb7uYb5ZGUeGK1wN
cgsX0nFO5+W+G8MkKPcpm3yo2Qbq1R+38uVk4+uHD2XSYtNR9s7k8HruWnjB
O3zTc1MSit6W7flQXAOmxZvOKxnnAlfeps+sr37gD3d+tcG6VjBktFOlPAtD
TWrt4jfOSDjWsHC1RbkbWga2ece/rMOQyadpNXdyIfauQvHkzAB8uxOc+u1W
P/qUbjTVEamDeitJdia2YWDxfq3noTWLUmnUZ8zkDjjBvDnx1alecF81eGdx
MxOJb178V/jBYTh10szUrrECZTV+Wv0snMOn64x3fHXuBbNFcaqwLD0pGw3q
76flo3hZLXvS4WIQaiw6d02dgbSu/PCqZlsyjK1dW3hjNBaznnkZ0O2a/nc/
r6qQ2gFcrAmnDNOzca/4d9L0xQF09HRdG4cdsNFuZGpoKBeTYgR+dhi1IPv2
XTqPaPNmc+aS87954zl+SzPj37ydYd/qqEqGMNPGGmnHOHBzftKW1f4HNvI9
rh7MogLrWdXesI4k+O5nMnZHMBNbx436mKJqgL912ky+5Bdgvqr5Jko1XMji
jgn9FYagcmR3UY4VirHW/uL06gbDoYdVO1Z0QNUET5gApsDzvPfBl21a0Di1
X2aI5r++7fLdcJp/44J1U/dp/osMhVvZ97ZA1s5Nj27I5sIT09V1Dl1pYLqS
o1u0sxUSqxl2bf5ZBCuMW7hrszKw7Uxx1PngasjSkY0JZfgLzjvr13rx1oBU
1k3bsE3tEMu9p3pEvxT+7nm9ba9VC2r8bDu9m+bnal7Fn39+ZnIO8DXR/HxY
2bQnjr4Jym88sneeK4e3YuEMvVMkmPIJf+DhR4GPukK3RjRrIISS5ngmIh3L
xTyGubirYP0ZiajwE/kwuXVPLHt5DTTIcjRqkaig0NZ2Sq+hDj4+Dz9vR5t/
rmi+nH9+XkX31f3z06ApFKlC80OeXP3RdEM9bLsaec8rrA6ch8KLND5kgOOP
J9FM5BaQ+a7ya7aiBVavlQtpLSJhtImql/ZwOew5yn9+q3UZrM/fuZuBrg4c
Jhjeh858QKtVEpYfd/zG9jXlVUx9tH2OcYH0irgSLL3FU7n2Yh26/NJz0zXq
hx22/QqW4xTgkzL+NBJGgcSQh9eUab9Hfd4V15hp43qv81efo437UP/PcCdt
3HXH9/+10K6Gvy6utg6ryfBC58VLI4UcMLkc5J1u3QAkkIXGbW0gdOOEft+m
VIwXOcNPr1AKDv3cL7xdqoBB5m5z8c96UMtnll+UTAd+Vv9gU/q/sKX5nsqj
N1SQ+fzkxklBC5gy7JDWaEI8+d73SfiDLtBqYFF0XJGFGzWeMPFYN+HQ+BEf
qXe9MKuy3Z4uohaffQ3Zf0KpHy/3OLC/qKLtJxOSYo+NtaFunsTeVZxT2Jy+
rpVxngxtl95q2j+og8E+5a+bsQYUhbL3RdDNoDhV23APNxlenrxztle5HXjZ
6gMOfxnEhN12tyPOtUBUnvkvOvMOaD59vt2arwXbDmQeyqC9b2E8XdS/913I
vPZgkva+gWJPW7ULaOv4uzxjM34qBIscGDt2shCkZ3fWqK2ohsjVLvHTKl0w
c0Nr1ReHOBQybxbasT0fWjcffyghUQc8m+PeBZY1wiNBw5BBHYT18o8zE89n
QFmkl8qBWSoI5VkZ75nxAp4bXxq+MKRjhobxoy9VnaAXslHxTGIsNilTn5On
WnClJW8Sg143ZGeJWBnU5OFNo+2rEpUHcEOnRot8Zwdsu2/ElXq2CjlPGq/j
tZ9ErkaPV+usa4G59X/1tgKW6G1pL6O3zreMDhcWvv3t96AaHhc/5RvwbAA3
wTKbSf8Z9ORPDxZNqQcFJ9cbWVndYBrUoLnxwhC63pqVPmRcB/tyfyo91+iF
+y81NLc3NuM2+7XXLtHmbY3vxtMztHlz8d8e4Eebt1/ea2s67HPhYzjzB67R
dvCQZHTnUC2D57tmtqlFpUPC7eh2hVONUHKl95WpeQsMqt9ewZyXDJl3TrN8
Zc6C8XMfnpFs2+Cd7l1mOqlw4LRjHlaADPzhaiD1cG8n/OZXivNiewMZjApu
8npk3Jsca3tUkrbPSXpVmGPth8knLvXEJfZjfCTvfvcDVDD6YRfdzRKDA2EX
MhcmxnGlUf/N489LYcXp4+YH66NQbraqyHfVLNoUjJ067dKAJ29QAgsWPEH7
9F6n836TqNu7qbbn2QRyf4i/G7mQA3JmF207tci4plsXTbsXsXN1h63iaDn4
GOVn7u9ohr/PIg1NDGexIdKFR2C+Ag7wbsp2OTwAXl+8SW50w9i6jufuKEc5
SGl0tnzbMQSsRp5Pkt80o4V1jFz002JgkCwafmnQBwqjfWfP8AZizP39zkMO
WeDH5zjAakZG0M5i2vmuFbg/5PFw30qFk4JqA95auZh2hrtjh3c7VIcIXtt/
IwI0Ke5R8gJ/YetWZfrs8XbIP9znEs3vAE82zde8etAEe3l4Y498o8LLdWc5
J159Rb8NYuu0BLvBWqp/88U1jXCf4LWOEbzWWILXuvUdgxKHxTM4+vGPST/r
GLykW6fS/G4Yr4Yz6viHpEOII2Nf1OF2iP6cS6Xaz+GL54ze3oMVEPJ5t+eC
djWerpm2ltyxgLXGSl6hBbXgelPaSYr293/VZbff9xjDbTy3EuI1akB25MwV
qftjOBvHohhyjYKXz3dHeChVwD1BFg9B6jCWJMzklbe4wEML00AxuQw4/DDi
kfOLAuQyKnspatAG+6WvxNx7EQZs08w7j+9OBH3Vbd1GdzvgYZlWk2VhEA44
XMnOqakH/fBryE1qh6q6Ey3uSuk4YribRTGdFtdmx0ssf1JAfkndMjtRn/wo
j+EDN+sn6GRMMd7q0w0efzpNmzbM47onEaWb0ithQvwF3eD5fLx9VjZ/1doF
LNuQcrtAowXcpbInjHX6kDMRysjJYzi8uT3Lk9oC1/eyHywXHsYj++RhGqmY
0dOsaRHWAKd8TxqXHBzEJB6uRunTSej0W7Hw7UgE9Hd8OijiFQJ5/R98d5l2
gL2ElJJFSAKu5tA8rstVAySjV9F17p1gEz7MthZKUXHhll3Ork5wGrr/Nu96
O+w6Uyp7Y7QV7pyf3fV6vhfr60IiqYnteLC2z7OFhQKZUUGe35R60CeoOrp1
Wy6u8tqazf/mD87d1x5WMC8HmWaOGxsWuuA9wWs9RvBaJQleq1nS28N5dO3A
T5GyKxEjo9M5FyhWqcKp8T83X7J1wObDzziPqVajvkNrlydDHcpzdl6p76+F
zRu89UR0IiGNx/0tP2sViKifzVttXwC2WpzcEud84aUKGdPTKGDpHxhadcoV
hYd/NbU46+Md0QuGBqQuuNuTXXEpvxqveoR4OtWG4985umcS1oNQS/qd0Hu9
DwOiSvz0+/6iT7beqxC9kf/jjvos4Y6KsJc+KLzPQLI6Rrl6XLkG/wo2eE3E
0JPY6+QFh07VYtz+/ta50Qj8q7FDWtKEkeQXwC0bf68JhsvGdkmZxACsUUj2
0Z7Bi58tXxfntIO/kULCyN0UkHvTWibCOoSZ8prmnQc6YC5BXdNwNAV6FlK2
zqtQ8Ovqu6SPAm2wcp/EMXbNZGivc/0gO5OLnvGXu0eeF8GGorlCf4U44JUO
WpsxSIbaUNfm5/tcQYDPQuzOuCPWqJ6kuNR2gtvp3ad3jpShU8H+tqyJdLyV
/yXH6OEARB2pzywO6cRvtZZO1jXV6Ncqc0u8Yhg8zhattrrVDjqsxvVkx1Jo
b38bdLSPdj4+SalXcKWCvR3j4tXYYngxncDwNKgIKxkDVvp7h4JdqWXXx7TX
GPfs7nGV4Q64aSkT5/8hD+/furfKyC4fzfufue+d74PAB5kuxvtaUd+x6HXt
bjJ+e6vdyJA0BKP9X1ZqCrZBC7tDnsDKehDekfSHLaINmZqv3mF1bYVre8/t
LvhUC6yiRRHJi6XIk2Av+Gw/YuH+9wnsR4oxm51O9sHdXriWOdHjv4ECxiYx
g/z0FCj9dPrzS94K5CO4oOQlXND2p2U656PzwDVeTnDdo0yQtqB7muG/iNs/
dDS4vAqFuheVnrY6/iD5uzLqLm2/bh1encqukw1xA2s0z9wgwaWo+gZPHjrS
JY790uvq/vVTDP+6+jYAy5o1+e91z+P6OL7IPk5XyC+Xrooc/wnb3rSvTnGi
7QccB1X1drmiqrbgr9uGIeBRMtSV974LXn8Oh2eYDRZ79knw/viOP5v573ee
oyOVSasMsIlFQvy+7hqtFjdcfenTm6G0Dphi7Gz0uJgPp0aV57b6RGN1pR7/
dtrnWRs08PsAVwWsj2UPTvf8Cxopp8J29cyjsurnzTMDYcBy5z6TUn8kvj9J
iQ1f1QnXrybY9ghHwmOloaHw8hQ0uDApun+mA4qf9Uae3lMON0znJz/XD+Gx
5iuClzoQqnsZPxT9KIDJEvoLp0S68E0C3Vbu+QY48ayg871vBuyO1Ahf/NOA
6jvWhga7UWF8e7n/v/vbbRxyn//l124dbvn07562nOAiNhFcRCeCi2jmEQNb
zcIx01zgvKXtCOxgP9ZDprpCBNffoH/66do+17RDVQJg0YO3Z2jLIupneJT/
u++ibLb0/XffdYvh8bBjQgzs9nM88W/c0C0XQv/l196OqPzP/fB809UWetVc
9NpzPL/vxwDMu4vFdNPibF104b6EFWUY4x7AW1I6Bgc5LVbty/MB00NmOv/G
fTY8F/6TNi79gYeL/8a1fLGLPLelGSTyxO7MpAzhvuTB3fHqVbhXTan93/38
9qbLIxTauLKXlYP+jeveuEPvIFMBhnPTn2Td1AY6zF2KSZc6QPnEgvxb/1qU
26jz9uuTITjI5RMSKkaGX06PntDLUVDk3bzthYYJ+HRf2fzdihDo3nj30ZWV
rdgsDzIMv6fBv5eJV2xTN+qW6ji78ZbjDe8MIVPjEWDSDrDY6DSLgsI65z3u
ucNhpXtuL+5R4JLshRKdgcX/4+MpEnw8ZoKPd5/Bii6WgwoVdZ/pLrzsxUMx
51v3G/TgutHkuk+0c8jzg7HhRQK9+HI1z4Q4XQVu26N36d/7XmHefaeR9r5u
C8rJ/8MbnA34sTgzip+/7nzRlDwBb10pgQL1ZbDzikVZwpNx3G95rzrXYQoY
Tr2VuaEVChlRW7TpnSewwal93cXuGfCpfm5+ML0P5bQOzxvvGUeFwRnnJwPT
sDHfY9RGkLZPKFYT+jdu6cCH3FrauH0XP/9PXiZojc/3w1iP/dfW3BXWIYNI
8ZmNDAO9cKk1YTiaFncYfzE8TVekwi+z868ulvZCItss9Td2o6tQz871pv1A
0dy3byN2Aenbnlt1tHPLqtHPpQEhQ0AnEHKcdKcDblcHturIdWJxMv3aUa5h
0JT+4jbyjo70bRn+W+wyPDc1/ntDck5tkGkkYzs/VI9rxGfwy91R1Nf4Urnz
SAesn/+hUnGOjHoLTnMaLN14NLdBp1yc9j2ykRhIcyFjRjdrRBVrO2rl72f9
Nw+jgVO5lbR5+Px97n/yjBoKduFTH9uxj9M/msuGDN55+33Xjg1AWQW92QDT
AGY/fRn1/WEHyDnkfLg71Q92hmm2h2jfczOGW79/0L7nT5vmVYZp3/Nfj7NP
bSvugIPMeesbA6pRYN/p081sVEx9e6qUA6qx0Vt2tUtfFjDtjauTuzoAsa9U
3xdRelBjpayD6t4a+MGT/tBubggcl3DMKATHLNjcB573doDV2YQno9O5uPHQ
Gwnn8xScnXi04n/ypzyvThXS3iukx+B/8olrtX9//Pc5az+bFbjTPqep+gmN
f5+zblWqyL/nJzYaceXSnq/RUPifvGTf0cnTn7bO4vnCt9rmSpPY8G2VRvSp
VlAcqWv2vkJHKnzvK/L/6vrueKrb8H+rCC0lREYhSkhlVFxEolKJ9JSSldGU
iFS0yExkZBRSUUQRmV0nm+y9neMYx957/fQ8n+/39fr2e/Xv+w/O+Zz7c9/X
dd3v8WPdAn6inK78MTmMFlt/nf/9d3ZE1gn9vmfMlO//93k6ET5Ouwkfp1LC
x8nZ6csXZecW/CJsMcyd1YjsPBxVLieG4an3TympVUNoNTNybkNeL7bXMpcv
xg3DoKVc7dbHkygrNqU1dHQMK3bmzVvK9MHqy6q0Ehs6knKF7Z3wpHl8167S
0dtRhWsWdVaklfRjYmTjJY+eASzRfMAydp2R9GlH70k3cRLW0YyeevlUIp/0
czuKLgPJ/i/+SxcDD3QvynRA01ta/u6qBqibkhGVOEVD/m8tg7+/b2nZYPjv
e8aPSVL/vr/jTsay0Ww03Ho22a0wZQ53W0lq7kqtgOqpbM/ktB40XjfDOdy5
gCuPuhfS+XyEIxeTQm4Z96LiS9sLbop0JM5HxU9iUvvRvvQs2/1zNEycLdLe
LLR8vr577qC7eRyrbaWP/d6f7ZMDT/6+T7z85ui//IQcxVO6dWWl+E/H9rts
CVTsK0/rq6b2weiMuhf/SCU23vbte6rdjV0fLyWdyemDgNUHlFb2tKL0C5UG
34kRfLJJ88vYZxqEJQUJyEdS0GKdqJvHmXE8vPv4V6vl/TZKIaj0iHYd7jh1
LP63P/bTVqXU0w/pSH/zHcr+i49Q5OovxsZ9rbA1e5VgjjAVnhQzBhVZjuHd
2eL7v88L8S2Bda7L6/PWK0/R3+uTN8U/PV6SDHebs66vvdAFKRHBUQosPei6
ZqPNnTVkYNWrZnUO6QJTDh3LbJZO9M7cEv/7+ZiqHvjx+94zIFvk33NkjbfM
gHRULsKefdmdN3uRdq1s3m8DDTRVbo8P8ZaiJdcWFWOJEczkeiTBqtgJZQkc
ltxaVXjGJ1oDzScwoX7P6DQzGeQ/1+b8/pwChw8+fbb8OVflRG74/TnvRufG
BKaVAPXcZdespD7grp2xFnS/AQp6BY5flvvTnHhZhd/96U8dpvfSy/2pohvH
asnSfFjFRt6fxtIJp95Uv1M3qIKD7NvS47zCcIzts+HWqT5sWDBfvY+uAxwI
v51XhN9OGuG3w7Anud750FcMSDEQ0dk8gV3dFifZ1arBZOb1wxGDSniHbs9v
HxiG1ihxwx1nKJi6i6Y9t6cM+oKatJ05ByCR/kLShHcySnj/+u76JhrNh1KY
ogUm4KI3jb79RguqTMmPXnv9Eg4rezTMmoxBjluEi/KGMTwnffdSfns91PCp
mTjrjWIgQ/pJ3TVjmHhK2VW3pxaekvct9JwYx1nzVxUPb7Wg+IsH7b1rylHi
Gp/nV88xuDVOzzJNnwNKk6u1HvNU4h1L3xUG9lMQ9vjgulthzTitQF/2Tj0f
y7k4gxVgArbHJLpI+I+joquK9txmMkiYLtFdEBjCDZLss5XLfa32ebbp67xt
YEvl/xW6egTfMtVy9qxuRdbrTPmfblRjb3FOX9VYH3Te4G9PBSrYGjZzex1q
QwFufGgcOA7mY9wKl/zLgWykdOHZm3ZM5qr/1mw/A2SuTsVMrybU0DoXdv1O
Ex6wNhk8GDUJ/MccxEceTeI9UF8696AJDnyJe9sRWoenWVXSlK7M4V5G4Tw/
bIf1JLm8oM89aNm95l3UwjBepTxj1bBtB5pvrDD/YB8mVi6dlXvaijp04Z6T
ZvSkm5WnWKOUB2Cw8U6ii0IzKDbsaqmxZSSZCvQLnT0+Alq/JGY4l3/nLeZ8
pwV3N+JH2W6/MZ8vaODA4b1r+zDQVDsGLbYP4cgWnjte8dmox76WQf3lKFzj
E4p4so6JFMYh2yl5vgFfvi9zC6e1Az/b2RVzTMyk/eNkmvrmFly9TvyOs/EU
tk8IhqxUJUO1fPWs75VvQNN5Zr2VOo3Fnh6rMtd2gSD/riWz7HSwe3k7IHZo
ABuW9N3nOepxQTDwXf7DAjS4mLyNbWIIbrZsOSPr14+y5Ev37l1oQtfCzbO1
YqNgvTdt7MCDNgivOBD1TCgHjEsUOYfGp3FDpzSjg0QnbHv/44l5cRlcFdy+
M4VlEMeNlR2rHlfjD+tpw3V3q1BY44ytzOQgDOgzGMtw0bBds9o0jLETvUg7
N79dPh8lbq9dVBGeQvWUnXstpyfQd837VIOD9KS4w7VxnhMtkPvruIVkVgmQ
tUdUmHfM4IWSpLt93VQwSXkZK1NSD+YasndsdAcx5CL9/GPeOuwMEs6zWu4H
OEfiRR9bD2HysU1Hjk++ws+uLYtNIhMQKE5PbqX04OVug928H5PAMlfo02LQ
IGTU0zzSFqaxrD4wv7atDur38pyuVe9HvSpN5eSpacRVKz9zGC//P8FVC+fk
xtGMvuStZUsPGrl/OnM3qwKZXqioXxmaWN7vybKC5ekotJ7U8eBkOWbybiJd
dZyCiSuilcFqfZj+vYgttC4OP0ZkX5I9NAwXX6xMjc6bRX/HvDeqVS2Alf21
r/xp6CiXeCLk0RQWXq5swN1kGAl3L988O4wHXcNZKytoOBKsdKskswQpdz/H
u77uhB75kI/z7Z1wXLN2Wu0bBb84XooVfzYFDtt7Vzy5/hbZY7Zpa7hTsHPx
580Wxxm4I8bSdoF7AGu8dx6O6i3GLJHW79EJw1CQF2Rb0TWP2pob91eJUyDz
xSILNboDHzBSJ1h1J5H9QY2UEjMVDHfq8suW9KHPqtYd/zDT0CBVxa3csQVX
rH0UxVtCgaj+/VocvX1wKrjtINujPvRikeCIuDAE0z6TJt2fu0FDb6syTY6K
NhXvq+5vHgR3PvFmlpX0pPp5qrRALxU+KspnnZVuwPRUh1NFn8fxyBrSx+iD
XXBZj2HfpB0ZDW5ZLeUudCHzk++OPK0UTBJSVp+bboJxSxPpiR+D8C0ypyrH
fARNdlm8pa/tga8um2cv3OkHuWmNU0Ore3DH+BMZJQoNvjv2vz5vykCSjwrb
d8yvA1ZEXot1Ea1Ak9ZLrAUi45i/tkvsn+W+P+FSQHP51VpUqVB/qh/bhUfP
hdoYinXgBtW+ILa+CpDdrTFh5DEMI+vcW3WsxnHpUtX5L7so4H22oZPdfBhU
rJ9qWpMGkCHfqt5u+Zw9oXZU5MZrRlJtWRpnQ30HdCbyu900y8Kj6obi2gVj
qG3jv75Gshu4SCIL2REFOGX0Tv+xbRemLUxWPjj6C/2H7vuCVgTynkkNeLlq
ADiP7H8RutSBdF8jsqQ803CDptRZjlcjsP/wduX7Oyaxb91+mUH6Yvy8NrRR
/+ko2DLHGO5jGsYNzof31Z/IweySxz/rCplIuxt/Bmdpd0Cv/JdVXl6pMDte
oDjnNIYdrDyhz9sKUGTTVJwxfQaWHBYMbq/rhwCzdsFzp6i4jRrNyNZaib9Y
tl96f2oErluQ60L3j+Oh+A33qLuoyOBae2nn8AjoGn8Ta8N+tHY/yaQrRUYP
6QOvWeyZSO4Zje6LnlRYu4+9d469GNJO3D6u6TuGHm92cUdeJ+NYQYnlXfsW
dJqXt4x+Ngw6Ry5erCte7ksXLS5U9S7Xj+zvYuovDcODw0UNr/m6kX4NXYEg
9KCg+yce8yBG0vWcGudRq3Yo4fMeVX1eAw5rTxWaFI6hBf3L0ZPSHTAdHxh4
eKYBepuaFLfe6cItgnEHJUUq0PWJT3SvfSfKSOt3L7b2gfjaifttbmTUSd6Q
XiU0htHnV0ZsCe2GjXNf6Vcun48GDgc0TquPYBqNeaaLjp4U9qjLV1C+FRzG
6PkdedtBJYb1x+Yv4zjCXB/cvZUMTfoBKiXOXSA0L9gnsdSFk09wX6XfT8wU
ZVsxmLW8ziTcNAdqaXD77vdgJ5kK/P4wuMdebQwNv73cwTXfDvcWWbRlXeqx
munNtvm7c9gmLwbbIBbs9j7pHFVPxKJ7rufFgkYwblv7me5TS3hwhN/ZNqwB
bu/yhcXlfcPy4rfatxYTyFXq8FHHqRG8zofuajPtAznJrZerrbpx3a93pjJX
ElHZaugp/foZdFJgb3q3KhJLpMR2RW6IwBKvjEs2tFm0PynzIWTdAGpFWh46
VZQGet+PCi4un6O3w97IaLbOY7d+m2sFazWoUAUSckdpkJveGzB2dhIDvnx4
6CZfBdEvxLi3SgxDkeGFxs5VNCxY+6wrMaACOujJUs3vv6PCqW26n5cWkWHT
+rUjx+phv53O2KX6QdzWIC6l5juF7/P+m1ezMP03r35OzKvpiXn1TWJebUHM
q38R82pXYl69mZhXX+zP/XaSox1XnGK757VtGnxESxq+s5Dw88NjV3V6W9CB
z/aG56cpcK77dHL9cp3jXaPjLzH9DldkdaZb+XVC0x4H1giPJaRMjpilOFXB
22pOV8pIAup6yz0MuryIkh+dJ+c2N8Dqpf35ZvUVuEHE08PKZR6HLMxUWJMp
oHhxfcA9xS60yeowkZ4fx4BDTYyJju1QaBT2pDqdhupqzaffnhjFY0w2z4Br
Gh+/vEy9YFWKvL9EakfkRqEn+2DiWeMa+BJyX1Tpxyc4Gx76bq/jAupwGt/3
6O+AV4Y6CunaaSDy0Hw+6Ogoaq5QjJFdPqcKa89puHk2YPGRuTr/FgbS0A0N
Cw2PalDzezzOrJoKIoZbqWNBC/hg09sHYyebwIBBnK2wtQBOOVE6gl/P4s/k
jLW3x9shaM17Z9ewWhilLs0HeY9iDezYkxdLBaYSj8spCvXAs2H9CQPlYZxV
ZaYpmzUDF/1KmY838lD9s33CrO4cptlSY6glLbBxvejK1JoYPFcV2JIUOosc
0kfdLjjWgFfj5Sv6OlZwZIX/7ufLn0fmqFHmfEgdFKpfLLVdrstNHhs9ytGb
wztv+t01cqtgf5Tkuce65fBse6wCafUCmhM4PYF7E3hUtfTH4VuVIE+fz/nj
Uz2opAc/4XSbR6bcz7ev8ldAkN4HYaHuHDjXbMX+1mx5HWolfV955QNmR+6/
ulV1AqKDjmQn61Pw9NW3h8E4HBN2uel815gAyQPCLAfHunBN5BWzHpEISAyP
0BUPHoXBjQHfq16Po3GIwpb5qS/AOaQ+d8R7GLpOS8cqvZrCY8KewQJtNZDb
lxppkt+OxkpNdT3O83hJ6HFfr3MFSp/UKl2fMgWvk10Y+3068CKBSxH4RwJX
0qbbbiRPQqMXT3YPco9BavBaU2ibwi0ErkfgBQQ+YhNz4fbLJlDm+hCfGUNF
9Jj1e8szi0sEfp7Akwl8OiFFc7U8GY27Dh4aNJyAEloVK3l5XaxUPzC527cd
u3mUpNsTZsDZ2ElWypyyXLfuH6qJrkfqzNV4sJoAYZlQrfwz05g1e3foyKsW
aK2M8jlR24yclmqsp+VnUTh56PyLmUGcl5OKo5aPg65u6RvrwQVsiV1IQ+sS
PLnHpElnjAK3t8x2Gd2mJ3Wh6FI5OwXWCsoWOMxVIPvagQ1rPkzj7W0m+9Md
OyF1cwnr/agW/NTZcGrLxDD+uFa4mtNwBl+dcz6+RN8DdVXqtA+aDKQd5g9v
yC2/Z0efWUfWvKSC0Xr9hnBrRhJHMaPM2D91mN6hXfFdoQoe/Mw7FNbGQLpq
Kvg6qpcC3e5Lq2N3pC7XQ83cJ3AKtz+wbn52vQukkvNsTcdy8YiUwMNnMIyD
BXt53zp1gqhCwFnPX9koFrvqXuDzUWwj/Bx6CD8Ha8LPoZ1RnG+3/ji++Bhr
8zOlENUkb8pIxI1CrLwL/RaHefx4ojDIb0Ul4tXGKdYlRpL4xU/X1syOYbLv
XaEzJwtRbtYx+2Y1E0kiT03jiC8F+le+ny/lSAbxY1kG8TZTqDY6NBmmMY4C
j1vdLb6NYaz9P3bMagwkadDd6c5NhvBCZfcHM+WgQucYZk6awpNlbHYTcWSc
uJj4hcVjGgV3VPEZtS/g6HZ6LROmaKSf/6R80oCKqlq9hdpW9KSa7X7N36ca
gY/Fq+z08jpKcKep6kVPY65cZYZMSxuQDGO4M1M7wOx0cczU5DBeml39rXdj
HeYV4PENQTNoEDNYJi9SCoYEXkjgOwncNLydMeV2A2roudP9ZFnAgq96g8P2
OWhI4GoE7kzg2l43GtMgFyOempWK0E2ivOg3peKgeRQk8BcErkngwj6qLwUM
fcFf8ui5NUE9+LTyVH3mDTrSE+//8J8E/pjAGR4cTC7VqwcBXy+GMcV28I26
RjnHPo2sBC5N4M8I/MYWdmqfcSPQvkDhrw00IOeJRGeVjeJVAm8l8F4Cz/9B
ub77QwJaGUqnS5VMYlzeVnXBmALg3bNJScMgEVU2PjUcuDCNvsLbFXP/iYKR
jQuRJ+QS8dJ1BfG3iTP49vgxvXfiJJQoHVzF8TMO7fxp/EUqc0j2K7XesPye
RnttP7vF4QOi9ccM3r1zeKur02+OowdjJuTyqBsewZYrwe6z+dPo+cLoWI3X
OFIUk+L0rnyANMHjnKlqk6hzWl9wr9Y0Wj0KkGS7ngQDQU4/nQdGkSFM/avy
szlkEOJvpVrnwnhwnlf0WAdKMe0XcHdeQpJK1nMp/SpQ02pSzlJtBz32Ey69
B2YxJyrm7CvOavj12m97OAyAneLwhW7tUQTKpaF9/Mt1RUr1OdnwXvhk/OnB
1NI4/nCiy6dOVMPrq8qLZyVaUZI7zln62gL2OXzMD/Osh541ieUNak2oe+pn
5NZz82hStfTScHISzc9uXLGpbRZ6hJvaixwouEpFcYyaM4rmu1o5Z5qnYJPt
yhtfHGewea3UZJL8CPJJcBu+s56EwF5urbimOQxbr9Sll+eCjjPj+XYbayAz
K0D83jwdSWZJadUH9xlMfH2jpOh8JySXMLiC7ADc4Ri6dmb9JK6bco8xe9gO
J1u3WA4PDIHjo9aK4YMLaOvve2ryFg0aCn/wF9fRoHJsLGWbEx1p64jGtgsf
+8BWiO+ZpG477C/qFj6uzEAS4w4U/Jw/CLQpttOxhpWglHnObdc5JlIy1al9
1mMEFAffyMQGUNCjs4PpwGomUqjdxvGTr0fgOFdr2pu5YSzes1jqOreEN/ws
jHg6B+BojPKHuJYlXBQqH9Tt+IqL7DS/pdI8GCpOFbJNpie9SBDdr/syByhT
74J3PP8GV3/qNIpr0ZFOr+q9KyXehyOjenvYNehIjWxvJF8vP8/rq9nPNrJ1
4mNVjRjlm/Pofn+LWuztGdwV9eNO7Uw7Pg8aYCx9M4s+wyfcOsvmMD8065CM
6Hd4aD51pVivGpsyCs7UzdKR+DpXSJ0dqcfP22M1+WwW8VDI1ZsLs53IS+Cx
BK5L4PiHTjOA0GmWVU9qPB3Mh/yE/mGD878wQH2Mg+kYHWmGwCUI3J/AZea2
vw62KILNA/vdhQLq8NVtndn2lXQkx/rL/u9SS+FNiqeque535Aq/NR3ydgk/
VbxniIhKgwbTASUzqWwMF3abbyztBCOLsfQNYykQEDxQe4cuA8+N72VrHesE
C4aak4ohScB8va0/hf01ulGtyar8XXCrNvRo8eECGFIzjV9v0gRPvz074iW2
iCWyrANJlBJQ3TMX6DqZC6FhRz420S2hW+I5xoxPeSC4QufJGd4qWLekyZev
vYTJBF7L9B++nsAP1d2wrbyaBEecj//jc6cRdqWwiaawLK+zxaOCv+eoxdPF
p6NPvIN2l4F/56ibVzan/76nMDwl2B65jFeVnJP7jYvXHukavkVH8hG8uyCc
X41fBw22W/MMwnOfOqfHy3WlJKWYyl9bh7qbTq16frMbEuZSHiTuW0Ha+MFt
dXNxIwrJZ3kKjDZCas71rn92spByPl/mnfFoxdwbXNoOURRsUZ/eMl7GTDKW
l3Qd4mnFprwr3Du8RpH5Dsv+XpUE7Ng88d7jgCuaCp9K956nJ+3xtZPQTcgB
oS2qYkV+QZDRvpL5wCU60nG2hED7O1H4LOJWLvfke6woldmu6tYDH7tDXAVC
w9HkWpHYHs5ErFQ6N5JyvAfuosg8g8gocieMJNZKDOEO4ePc8a1D0BmSIO5F
P4FPIo3ZrBhG8UiDcFKwyAA8OS6m6M06jR2RPSXBoeOYczZWyz2PBgOr4OGh
yQUsulvBSKufQQ6RD/dtDldC9XOP6SuRdKQgbRcLU8kFNBaBObvl9/Re2RbO
eA5X3HK5JqP0VQF651tstEuiJ1lHdBX/fv6nFfy3vVh+/gMn2/69zxrmLlb4
/XuNWgnnuS/jT88J/fu79DGftvh5eBSzxQTN41LHQd2f9fM5kxZgj3Lho/wc
x0RpRvK+mCko1U4KDxnMhdSo6a8my+ffNH20kd/zWbD0dzuRd3gEr3nH37ti
tPz+Sd4baU2tRkqHiNw2VkbSLe1Z4YvSLCQunSvMS76tyC+2/aC9Wh+uELfe
NeY/j+/UDxxlDJ5GPstrB8s2N0PT1wOW2qUzuFdryDVz+fw7RGt2uVC5hGZH
T5TWfVrCQtG1elfM57H0a6H1JMcE7qou+ZbD3IVp1CcthlozeA2L8z8otUDy
05yMTSM0vGUTe/hy4zzGZd+zW5GYCyKqZHLEsx58nxCos2lmeX0LfeW3gRFk
mb+gZFQziQY+j+CbyywM+dS4HrhQj5r3Ja4xdGfiRed1CvZHmmH1eKsp7Qg9
yW196lK9YB9WXL28ioeHjnSGtlD93qQe0zorhe/0vQLTw0NVqaoteCSp4c3L
w/Qk+Z/qSRcXa+EOFkkZ6fSAxuoYfszMRe9sDQ6TQzFwuq0/gUs3D+T4mk+a
VHTCVFpF1cj1QtgrdDmseUUd/nS+mNt3vx1uBXKup+4iwb6Lny5kTP9ECcdF
8XTh5X5d7dHAxM406OPZ7Hs84AuapzV5z3/vhAsEjgRuQeCqSSsvvucugcOz
1S7f1CrxmFK40ZEcCrwyqpImJ2VBhpyo+SUOEu7J5dz/wqUDXHdTbo29IMGE
eGHGeq/vSJYkB3yf7YCyg0sb9dUqob3nypqMwXxkGQ3exOvdBtw+3b6iLtmw
ga/Ztb8uDp2YOdUFdneAywfDk1Y/quGyspL0R6ssnJu2G6TZNAOzLTnY/Uct
vLr1jCXuUDKeVggScAhpgOObBL0PrsiFlw2T41ERL/HRKczZFk8FtoceNoeC
0uHa1mdhdpO68PXA2/lNup2QNvNCjtuiFrbf5Ml/uzsWAgrNPm7+Xg/3nvJX
pR8tAK4ddgl3nN7A9muf9tBHtIOIDr9zY18OXDETm41VCgZ9ETmS12MqbPx+
OCzGKx0cn3zr/7zfBxwTB5g6VTuB/pPUo2LJashJbI8NImXC01k5O4GfjaDC
PnWt2SYfGp1MdxctfIYt9SL8YfHtkPzqfvy94Ap4wpPSGcqQC1mDuTx04i1g
teO7wvC2PKgZmR2YWUiCAv2Qg9mN7RDLz3bjy6FsCLifeLTK7SvYjfy4X7j8
fQ/XPH2hYfMLvphL5zkvlYPmqVw+Tv82eEHoK4//oa/cS3kdyLOfBBpUuyCG
8DS4MTUze06mA14XOI0thefDiZYHFz5410DG8b6SyN42ELQU5OLLSYXLuTfm
FDWSwCDtva3Zlk7gJHBFAjcmcMZaNW6XyZ+Q6rV4KUusEYRIsp65t8mQPiBq
73omBQp4fwhZHSbB6AETddP5DhCLuOJOv1zvOShtSL4p/gkYvixdZi/qhGdn
VPh8l+u9ZClZspkPBeo9ck/ctFpAYQcZJeEnKUCqSZcyrKaA0gPz+58jF/Fc
9cTUNo9FZKor3vTmWBWunOyl/0d2GPI4SFp3i5lJPY5qTx9uaEUNmadDpyUq
MHvdJ4ZRl19oxxesNRAXgfGR432uyEAiV45xU1ui8Usd5K/DBkzV1ewx0+yB
5ErFYSvj8OX9fi4qv6Aad1+aaIv26wbxwFRdY9WPYPKwxsflcwEabNzIbf9P
NxQ2bNrE0O0FZpszuKq/teCw6SdxR6Nu6Je94LimJhgKv5Rv2vmtDts0jMrb
X3RDcPxoigF7I/BnL9dOrn1wrr/iieJRKoYQuACBXyNwKVHF/Gx9CjxeP92w
KrMXeS28BYT7S1F2xaF3MTytUM/2S8a1pRMEWyiuscdqMFbrscr4thbIKlM8
krO8XpUCSC2hr0pRwuRr6K6OOjCQtxbbvbsXNlCp8QxsFegtsW2hJbke9Dw+
bAkg90K/U4y+xde6v+JFIWs32Jd/woNpmR1DtiOwMNqU/YqLBJL2gaxOtBpI
9hZU33+ehonx6nRrasphYBuHokNuCQY+92aNlRqFgNDF7+vryiG0Yv/tSeFK
TG5Rs7lfPwnanAWtajIV+Fz1g5JeVhPE9L/yLjrZiVPTmVk0/lyQuhxdfOh2
NRjSXjpJPWpBmc10ZY1fG2E+5wbfM/pCsG1zCRDxLMawy8ItbVPtoLLm+9qV
Jk0Y5VF/OF5wFKwbJMytJxtB+4byOPM+Msi7k0e35VLwgoCZC+/jb7BOSWdb
sms9aF5x3sqZ3IAKfnNHo/pqYK70jJXfFAWoTTVh7381YcUXPX7u1gfgv0lO
M6q3CYxa81KtG5frT1MPTcGgCnhaolPbuIcKcwkv9/OEVeElpjWe9iKx+Nb0
c62nayvEVtrFHNcuxfEzbXjA9xdcfVv88vWOTIz5BSsfhv0E/T3rLCvkemGO
3U8vaJwKHBfzCm118nC/qGPGUGY6pm7QFZ3YRYYzN0SKgyN+YujZdMrjxRxg
IvLrfxL59beI/HrB8IItrJrzuJFn94nrrRU4F10jVckzAnlrHuy8+ogMqTtW
UUULCuEgz+PwjoRYeB7GnbTSqw2On+b2uV1SDRuG3Tk7zkeA0OTm5gXlelBY
ZxKmyVAGDwKq9G5qVILba781g9tbwGF83kqesQUMbAZ935/xBWWS47DFl1qw
/L4iSL6uBmjXWKYGP1fAPlhNMk9qAOcJ7Qsfs9phV33Em/APTmAvpsC0U6Ya
9J98HfC72Qz+ooIZIhEVUKRo6DPMXAOaE+nURfFu0Gu+d6hH1RJKPRjPvI8q
B9XCFRSGEAqU8N7P95SohDMPArsuW6SAwFvhuIbkQLSZObDWvrATCnnelbk/
TIPtm2tDaja6I1nCVi3zcSfUjpaJFhumgerqdXpZcuEQWaezeHr5HDH3pNnd
PJgCOwoFH8pf+gD5a0Nldj3phIzANq5yVjPIkvPTHdOhQITrS/dvnu1w4sKe
ASdKPYgb0AoFGcZwwIBlleujEez4I/+3kMj/zSNybzcRubdXiNzb/8lnfE3k
M/4g8hmPjN/rZtjwHb13eroK0iXC9Ud2EcocvXDHoFxfjdaMm1zjz8iv+AWV
TjK1pJdDwGhOfesw3gVye4sd7a/ko2es0yEGxX6s482kZR79jp93V7zgS/bC
+RVMaU0OvXA/iq035FcLvjuqYaVWn4AnOO+E1LgNw+LukIb3h7rgBlm+6AhT
Bsj50cSKu/vQPy9fWrY6E2kn2Eg96xOx+wX/+8d7+yCayI8zIvLjPhH5cf+T
D+VC5EMJEPlQ94gcpVkiR6mCyFHKY2O4aHQlG0zD7k8GnGmF6BtqbPZTLVDy
RChFOtsCduBd6XNTFMzRZIszmOqChCtBWy43VIH59XaFVYxDcLJqm9HwlSGU
JnJ8YokcH8aZ/3J8NMxujo6TvNHCh5vfoWscRJi7ec5Q+3GR8NNmI/y0jxN+
2hp7S/K9m8kYdEh3DQPnDFhsv1hy3Hf4r77Zf/NhTvIcOCwS5o+rCu1MUixn
sfPp4YvSXsN/9Tn8H59A0z98Ak3Mvk7G+TCQOqdkc3oyhsGkFVpOs8+gJOFr
xzD2n6/dA8LX7m++ZB3Cwuw2lStISuo2mkWBTRju/Ilp88AcSh/jspkVWcQz
pP0+BTpz+DKD74cG4wy+UMq4FiETDVOhLrdZXH/BHN1c0PG3ndBQGWrIS18K
isoip0udknFG1stV04MChgW2ol/xF0xJjUgIPIjEHRLGkVSGdlCmPFHdZ5kF
jRsv264K+gWfdj6elP/RDl/IfShwMB0Sbt6rmkgoBIuvR5i/sndAlv4T9bHH
NlDXOviszLcYd+Y/qpe6R4PzhC5ejtDF8xK6+HYZk41HXfIgwmTX1nESBT2f
7F480UMByyK3E5w9CCrqm9dmG1Rgb7xA2BT/cr1N8HVz2P8vXzehg5OlfO9b
KNt4K6ZkphKEFNgWTm/rhPvvph1nCkzQ4Z0749e37XCgX79Xa2T57xP6kVFC
PxJF6Ef8GvmfcRXVQ5LG+xNjbmO4ZDewJ79vCNuJ/WHtH/ngQ9ICOZTSHFCk
HfjnPVc5ZhvUzrMsUkGK4Pee/oPfS14ydNtT54h++3e4bvpZCRVibcpBel3w
9Y3ybrY1KXi+rjPdaakdXg3fvYZyHaClvDO74FczDFWc2cN3uAtFklwOz9dM
/+++xE3sS6eIfWkPwe+taP6//F5L07QeLYePGO82dX+goAIqJEwxernOWVmd
VGtdnoy+zK9HQlnLIU79yFJmNg3uEroJWUI3sYfQTbDXuiQ/cVvuYzRnP9bZ
k/HTqDSS0ptQaNzmmeiRLuC9a+407lCLBuCwImNzMzaPiFiu2toIDUqXWK5b
fwHGFq6mTLEq0ErgKi+qLwf/liNreCXfwzYeb477Q22wYuo/XmUdwauMIniV
K9xCdafKcjF2V5gy35cQHOL4lDkp3Q/jeW0x3GVklBW2+cZ0KAmfVxh/qaEN
Q+9biayNJl0QHXUnsXhXBtxfXJdyYaIHh3pvFAvVdcLZ666JJg/TYUEpmfLa
oxklNx8X091ZDvNbJja15SYD3dt9LNxryNBO8DY3cv/H26wleJutTzMn7HOz
8Z8Rugf2176j2xgvtwlzP+Q5u0YLLfcHN98HV+30KgLmRj8jtdrx/83rNCT2
2zBiv60z5pEI7e6ACN7Yw+bHy2FKaN2bE07NeJPgef5D8DwzCJ5nkv7DRL4X
VBgfbzy9Jb4BJL5H8K1crh8+8B+oWRr4jtouw/qMMYU45xG/5W5FL9jPrg9b
mUeB1WLzF328KLD+tohpAE8zriN0B01/6A4YpM1oNaI10OZ854XZxW40yzfX
oNtUBa/XbQjVomsEt92r604WUrG9rTLmJpRCyUPyO/sHVXBaZagmOKkJoexl
5MV/muGeB5cTS0gLeI3bJISsI+Oj3RZOEn35EPBQPjXOsBbmKUWsnLRavDv4
uOCkXQNcCaREuKwjg0JGW/Jn33p853RD6DFdNuy1eXZK2qkeLlQKcbwgVaCk
4aJxv2gdaNiHrtRoXK6v0pfO2dNXoO+xuPVjcT8gP4T8Gjsa4Bl9ayg5qwD7
H+a0ChnXwD9rPt4vdCqH4+suerGop6E/0z4LugwyCB807X4E2VhWdhtGknJA
WRoNPlX3QlK5tj45hYqfuk99c5Vfrs9Ls48+d2Yg8aTrH86Uo8Ax2e9yxjNZ
mGH1RsEjIhU29HkqK4U2QsKoWNVqv3S09ORh89lWDUtZ/+hwraiA0xFqFMfb
sRj4KURl7UkyMLOr6l94kovZnaSPJnfS4GWh/yNLnz5g/KM+NCbqQ29hHWRb
Xo+R3nVPq1gK4Zdk9v3sxGRQ3pRhoUppgSXe8Vbd11WQEF0pf+VLKjBFLZqR
5eugUfve1OW7JaATMLn60PZqMHjzLD6nvRHapMjXLno1ggOvTm5n7g8QKU6I
DWquBh7biCrMrAL9mtX7M81rgOXtPUXa+jo4pkcT9ookQ2AHG5flumy4cPqh
qTG1Ag6Nc5J8r9dD+B5HemfJOvguUpj25HwlnFQ24FjbSIUOhXS7lXQFsDNI
ZT36F8P0Kf+UxPhmyJX5yjj7sAHIWzOs2H9kA9OqHaXsIWUQLHVrXQtnO/jP
GOv36z/EqMtFmfMsFRg9q7XCHGlwxH7P5iLF1zj48lz71tuDyNzaNZvDT0ea
DuP0zxDOgY2Mwbo1UmQYyDEIFjdthlTHxJFwoR+wd91ZjqirFfAZ4upt59rh
q06CVpiVGf5DN1kZ9YKKPJJRcfUfu0CSqENiiDpkmMgT3E74itgTviKPCF+R
IkIn0kToRPwJnch2goe5g+BhPiJ4mNscSrGjPg+ttwpEVYgOwIsDMuJMTS3w
9ad3r69kJZYyyR4ekZkC2Z33CpuzazHOViNw7ekCfBBVWnw1qB2elZaXXkzs
AmuCV7mF4FVaEbzKhT9yRhSJuuimSIj+TToyrr+cJeR1dxqqIn035gf+PU/E
UIy7XlS7Et9NZsuf0qKAEN/mD6bHe0BlbP7pJFc9Nh3UDfnG0Aqsj4OVbVr7
ILlgJW34Qhdq9T9Ul6zsga+WfrcNzvRCHeGDsdT8nw9GIeGD8TfdQeUe3Use
4l0QKip5xG4tGU8I1OQzb+3DenbnaqvsPrzxbu9Wk4YOkNKSDbW+OQhuBG//
4x+8/b/VUbSQlS3MEvPY5P9Ze6RpBl9VtusJRc7/tQ4cj/x4Vf9aNY6k7isK
k2jDMLmkt/7Sg8C41ushh/UvTPQp1teap+CW2E2xYjV90HrvhMm7b41YXxO1
8+n1IUSXXb+KDveCFKErNyJ05VRCV/43/nZj03VIkCZDopqG5RRvF0y7GvCa
Cvch6Z3vxvGpX5jRffPbnOgwuqle5tRfPhduErxlX4K3nEHwlkVB4WR8RCv0
yjxz3tQ3jOVOxtO/ghuwY9W2M7dqa9BT8WXpwcABcDB3iT5/th0u0c3w862g
gqhrgtx91j6syy667tTWj9d0Wd4KKLRDnlkzq1BGH85lqHlpuzRiA3HfTf7j
vvtvusVOgVd+DapMpIlY/7iR8AZ8QykQPTe3hEuDAbWBR4bwV+TYvtaGFpQx
tKx5eXAUPDz3VOXqN6LU0n2P4t312FtfpDu/ehj6RwSVPTR6scWSbqduVRfG
HpX2N5sfhrQVu+5Pi3WAZyyz/62ABqA/L26zR7EX+QndOjuhW+cldOvXCf11
P6G/3kjor31epRXIFtviId+D4YvPxkFVQbtMaGzo/+v7Eom+L6Tlnfi8MhnZ
nE+oPikqARm7b7NL64ZBoa7oYzl3NxQbLRykDeWj1QFbGZGDvahC9Fluf+Tw
OvzRZ2UQfVaULAtvU0wV2HDGu5q+HoIkB9+07OU+qGPa9mkp4yscyraonN87
AK/P2L1PY5pHPWL+xkjM31YR8zfN7VOT+wS6kDXPfPHivkbc0xjDrqzMRPqb
3upvuqFbUl4+O/KocFnuvh7ngzL02lDEevDmBP5N3/E3/cL00K9s59UNIMSh
sSlldcfyebOv/2zaJO4eM/Il33uAmw+gKfXbDHqIXGx85jP61/7r3aupVhfu
cRwwuXJvkHkG9j4N1F7TNfnXvgzcDyTsN6Mn7a32k1ugDsEEb1Vf0Od5FCf6
snnCb1yb6MuKrkk8Um7owiZbMTuF0QUUJ93qUWmeRFtCd7OD0N2UELobesLX
RYbwdVEjfF1q//A7fUn4nc4Q8zErYj4WTszHthP6NQFCv+ZL6NfECX1Z1B/6
MgtCb9X4h97qf/z9NIn580pi/ryN0Ndwlf+nr4km9DV1hP6l+A/9iw+h+/hB
6D78CN1HH6Eb2kPohmoJ3ZDRX/zQpDIf/cgcaoXdgqqb6U51QX9LvAh/WhNu
5uxef5erAV4Zn8yv2tYHe7LVu9/sa8L/B2joT0k=
     "], {{
       {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFnXncF9P7xuczM5/ZHmQvZEtSUgkRqZSismbnS7JH1izJnn3PnjUJ2bIU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           "]], Polygon3DBox[CompressedData["
1:eJwtnAf8TuUbxs953/fMn1GREpWRkbKKilQkRNNooIWIdmlqI+2prUEq0uDf
QkNIRJSkklFaUto7rf/1dZ3P5/d8fs997ueM95xn3Pd1X/fTcPBZfc4sBUFw
chQEFf1/Og6CqiQI5uvgwZJPyYJgnsoDkuMwCIar/prKg5JTybumQVCqCoLr
db6qwenSLVSZJP120nfXwRWcI7mn9FN1/bKu/5zk3SRPkxxLfklyB8lj1HaV
yjuSj9H5z0i/lfSLkaU/Q7o3VB6RvL30/+n6PXT/99VmV8mPqv3fKo9KX0/t
z1b9GuleLAfB7tK/oef8RMdOl35vybdLPl/6M6SvJvk1vYTPpD9D+qN1/s66
VzNd/wYdu0D6BpKbS75R8oWS5xbvZweeR+13Ur2r9JfrmudLf63+X68yV9dv
KXmizjtV8rGSp0o+QvUbVOZJfk9yP9VvUVkkeY3k2Xqe6yTPkdxd1/9CzztK
8jXI0r8p/W2Sl0g+mfej+ljer+Qnpb9V9dtVlkruJLm+nq9VHgQXq36WSj3J
u0u+SPUzVBpL/kjlb9UvURmr93ukfk8D/Z+v61+h/9tLbqbf8aLkx9U2k7xa
8sl6B//T86xVfSjvV/oL1X476XfQsSckr5T+K96l9OdJ/ly/50vJ50s+Uvfb
rOv9pTJA8nLpu6o+WWWg5He4n663u673rs45Tsde1PXWqz5C9R7SN1XbXaW/
Rceu1PU+VfvW+n2Xqf6r9E2k7yD9zdJfrmNLdf4G1c/R+UOlny/5Jr2vBXpf
R0l+RvJH0g+Tfh/J7+l5P5d8tuSuOj+X/Lvk6yUvk/5GnXuzykKd30b6lrp3
bd3vSh17UMeG6/8UlW9VL+ucE1WfoLJa8vdq/4Xu94DkdZJv0/XuUf0+lQ95
Hul3UP0ZlVjtTpA8UPVnVRLJJ0oO9TyPS/5O7efo/GNV/59KRfo+0u+i59lL
ZZX0V0n/ht5PEz3fvWrzvo4N1f/JKhtU/0ft/9B5j0r+WvJ0tb9D9btUVkg+
WPrBqj+ksl7yb5Lv53eqfCx5sOTjVL9b5V3JGyV/r+tNkvyZ5Im63tGqz1Ap
63hv6Q9R/VCVBtKvoD/Sl1Uy6U+TXNKzH1Tlc1qrzY5691fxzKqPkv4qfd9y
bh39aXfpR0s/VfI4yYv1fi6QfLHkVrwv6S+TfKfkkyS/L/2Fkq+Q3FHyVNWn
qfwg+VrJw3T9EZKfUPlRx3rr/9MqTJ4HST9I9Zkq1SseY3uqPkulpuSxkk/S
/XpKrqtzt+b5VH9BpVrFY/AE1Z9XySWfLvlnPc8lkm9S+76S+6o+XSWUvpvk
d/X/TsnLpR+pxxit7/mSnvE+xqLkKp3/p+55g+S3JHeTfpb044v5/SH6gspc
tbkx8LzWgu9f8vy2Rm3XqnSWPFr616RvJf0myeNZN6T7WOVbyQ9LflX6ZtJ/
Knms5Fslt6U/Sh7DfFhcb5XkQfQX3XuFyst8B7XvIN29Kr2lf0lyrvre+t5L
9Tv2VfuPi+dfq/om6R/Que+qvMJ4llyWbn+1Pz/2+KuWef1Zp/r+Knurfo/K
kbr+s2r/nerfqxwleZ7kl3TeTow3yedL/lC6xrpefR17T8eukbw6c/14XW+0
2m9P/y7kI6R7U2Wa5Pa8H+lmq2yl73S19I+p/b8qU6WvL/0U1UPGqOQWkvvo
3LdUni3WwyNVX6rylOS9WB/1+z9jjpT8jOQNqnfT872ka/yrYxMkf5kVdd3v
Gl2/oXRrJZ8qeaHk9pJ/Lr7XQ2r7k0pcrEcPFO+jLPkhyanqNau8brJetpJ8
h8qhOv9Jnb9E19tH19tc9LeHi/m7ms6fwXjVeb+yBkv/qvR361u9kdsOYP0/
Q/p3dP5OartRcg2dO0qlpdr3ktxM9UN0/z/V5iq12UryJaxh0veRfh/VD5O+
rPdyj/RPs07p+ndFHl8fFPbEXmp/itrvzrOr/b+MKenv03eZoLZ1VN8O+0Xn
nqFydMnr3Qbpv6dvSb5d8uHYM2r/rspJkg+UXF3Xe11yb76n5Fd1/rWSy7rm
nzr/Z50/VufPkD5Q/Vv6evE9fpD+R+YwyZOk/knnfS354qI/xXreC1jTWG+k
31b1K1X2ZPwwH6t9D/qX2tZUmV/YZ/Wkryv9adIvlb62dBskLyrspwbSN5d8
vvRfSH8Yz8J6zf0lD5D8k+SLJX8v+RTJv0iuqXN76veu17EuOnanfuu83P2a
/vyTfv9parOTrt9U8n2Sd1L7ntJ/KLmWdFeo7CF9f8k76Nx6KtVZ2yRvJ91Y
xrz0wyVfovv/onudJ/1v2KOS50oerP71KdOu2h6s66/RsfZqM0L6RaqXVP9c
+tcLe3RnXa+Z5Eeke0zlG51/Keuhnm8bnTNGBTv4QLXdTdd7SM87Rfqt1XaN
dL1C96E+av+WnndZxc/3XOy+cGDob7JW7c+V/E3g9/MUdpLk3VRvIf3FrJWS
D5e8j+SZ0q+TfGjo3zxb8qeSj5DcQXId1t7ItnAnySsknxl5rGDvnpr5/d8Z
+ft3Vf01lUl6voZq86SuN1O6FqH70A96/gXSnxr5/bSSvFDyZLXfRfKZut4i
yROl3wH7RfrXJT8sfWPpP+FbSPdd4D7TUfXlrFXM3fq/J+9f/4+X3B5bRvc/
CHtcbbfR/c/W9X7R9T6R7nq+n+TROudv1Qfpm5wp+Wfp12P36lgdnfsla1xg
e64dcwXzieo9db2WkreObat2K9mPqanyntofpfNmxB6be4WeM6qp/VuR14K2
kqdLP19yu9BzTg/df5nuv6Di/plgu0u/B2u19LurPke6w6Vrq/8fSH82YyZw
/zsr8/z2sI7Vl/ysrr9c9c6h+3wXXX+p9K/q3CMZf5J/k/y15Hsl35V7/npQ
8o7Yszr3edUPUL2l/o9Q+26R3x/vpw/jQ/WpqvfU/346932VT4v3e6L0kcpC
1XvTJ1Lb8jdi56r8p+e/UvrNgefP7bHXVS6R7lKVX6W/NPLYY/49Rbr3dP2P
pRunY9cxttTmD7U5mfPx3aS/IPJ8cnXm9f17yQOlf1D1lSofsR6yvqm+XOVD
yZdIHqLrv41NInmU5HGZ1/cfdf5xzBGSP8BfiTw/vaP321llUmgfYX89y/6x
1y58iLdV31Pl7tBzen+d94+uPZP+q/8n637769gH2Gs6tlnnXy75j8Drw7fS
z829TrA+/Cp5seTTI8+nHSW/KfkF6btIbid5ieSnJO8h+XLJ6yX/K3m25Isk
fyx5c8X2x5t6tl2wvULbJB10/7aS7wxtkyzDHlO5RXIfyYtVrxfbljoMm0Dt
G+F/YHtIfiO2rzU69BrdAn9NzzpR92ug+10g+SPd/1fJ0yQvje3L3Rza5ro+
sz34j84ZrmMj1f5XyV+p/T30R+ZWtT8ztE3YT/pvpX9d+uOkv0znfyP5A9al
0OvlpqK/sz7+p3OflK5R6Dm5g/RfSP+E9G2kfxb/RfWWqjdnTpT+c+mn6Vhr
HTtA8peSnyvGxPOMndxj8gjGgPQbsSclHya5v+53ta4Z6lov0idiYxUV1V/G
31D7r7AfizF9EP53ZGwjo0/xbRhDqr+C/aZ2T0huGHqNOw87IjI2koRMGPr2
khuHXmP30/U36PrP6rz9pY6kf1n61tI3lT6Lvb4dIv190m8f29Y5QvLjgcfF
l6y1xfig//4u+XDJsyRvwn5IPPaZP27Xvdaq/KBjB1c8P/ykeq/ieq9FXiv3
Lt4X8/WHkvfCn2RMMFZV1iWezyv6/1Jk7KKJnneEvu9mPeP4yHjJOfq/ujif
a7IWfCp5v2JN+KiwLw6QfIbkY7GFdCzQubPpo8X3W5V4vWA9+Uj1jkX7JPZc
wVwzUu2Pib1W/yt5Vuj+/YnOv0VtttaxyYw1lUox503S8x6ITxkbD5kl3X+5
58RF0o/S+b9L/knnTyns0eVq34r+VrE9sVByU9WbVWxPvSm5heq74fPp+qHs
hWo6vkLnd5YcSI4lLwk8X/+Ue34ZVcxvzDdvcS3JgyX/WNgTIyQ/qOfsrvKY
nrUWPpeuVxt/TOf0w55kbVPbC9V2mOTTivVgVdE/dlTbXyL7VvuWbC+dq2ND
tLY2VJv7db1/dL99dY8H1OZSnf+H5J+LNaSt5E8lP1TMF3vib+SeP7AnHots
KzRRfWfWxGJ+uVXHttGxo3XdfirPSTdT5Wr6cmxf4FmVcZJ7S35G9eeZk3X+
d7r+wsJmmBx57duJ3yL9BJ45MpYIxjZO7f9U+790/AXsQdX/LuZX8KiZ6HLP
8YyPa9V+M22KOb+2fv8P+CAV2++9Ytum2HqPq/zFe4mMLWJDv1CMh0XF+LhZ
538oOQYzov/r+utYn6R/hN+v+qGRxyXj8ZzMGBnY2C4qh6r+gs4Zovoi5kC1
f1LHTmEuwQfLbINhe9Gme2bMC6zrVWyIKuNhvL8j9QyDmRulP176Abrn79L9
lhmL6q9jT2X2KfElucc/qj+v9oNVrwGmI7mvSkfph+vYo5nHOGP7RMm3qP6+
2j8gfQ/Jh+CbSj5J9dfV5m/JT0g+QXJ1XW8Ic7PkQfgvep4e0j+Z+lrz1H48
63fqd3WIjrWpsr9/r3Tt9Xu+UP1zlZel7yv9v6rvx/fVtXcpG/sZmBovAgPq
KN1Vkp9S+43S/6H2D0quK31etm98s+TaFfvI1dT+AJVtmP+kr6l6Z5VazJWS
Q9X3Z45QvZnKrrrevqx/qh8OZpMbAwL76avyleobM2Nt/fS8v6j+Mz47c53k
H+lvYAKSj5HcVs/zYGZ75YDYenxwfO9I17sB+0nPe7Pad1X7AxL755ybqV9N
SH092tbWsfdUP0HHIj3/W2AC3Cu1bdWl5P5Ef8PXbsj3TP28/6l+lK7RnHcJ
vo0PrDa3Sf5G+pJ0NdTmLtXb0qdUP1xlZeY5ibloGd9Y7d/NXG9XNrYKHvRv
aIz1ROnfl7xc+q907J3MGBTYEzGGm1J/73+wzbFnqox/LGNui439LKcPhMaA
eN/MYcxd/IZ20o/L7S9XY+7KjIGBRYBJdJT+EzALtW9d9C8wErAR7jkjM6aD
r801zlP96cxjoVnJ4xmfBVu6W8W+Id+Ad4+PiL0/E0xa+kY6NofviQ2t+v0l
40u3S65ZMqYCnj2J/lnyGH60GB/4zvVLxr8nMqeWjKHw/e+XvK3kzvga0r8k
uZ3aNwajYqxI3hd7SXKrKuMD+I+fsG5X2d/Gv1wb2b5brvY34euWbF8vlHyF
5P1LttdfT42l7Veyf/lUal9kR8mtq+yf99f1NkXuD3z/k/F/Sh4rzTOPRcYM
8YYOOvYFeJLKPqoPYYyXjQHzrv6UXFX2O1uQeU5hLplY8m9nPCVlv4P9dP9Q
cmPGo97H4sxzGnPZlJLH+la5xyZjfpp0vVVqlh2T2Cb3GKDv91NpJ7mUeW4h
BvNA6vkzU72/SpcqzwGM/VN0v05q3yLz3AGG30n6XyWntAW3xrdJPXdcVDYW
+Z/0q0NjkszP2CTYItzjbewFndNU9VfB0CTXVblN8iWSP9G1jlUZW7bPTWxp
V7WfUHaMaW3qNYS1YyTvgPlHx84pe45/RPJ3kk8te47mXK5RpWeZwDfNbC+O
iozvTFR9dW6f+w7Jp+vcNZI3Fj44v5V3xLvhN4PH8pv5rWDKzL3bSh5Y9hx8
q9q3kHw/8QLp984dEyEW8knZ8Zk24BV8b5Uq5madM0b19iq3Sl9Lx47m++t6
B+rZq0tOdK07wV5V3y63fXOyypfggKxPZWMKbaX7PPXcPkVlPX1Fx3qXPad9
kboNOjDzLqrfkdqW27Hi+XyiyrTQffDrzM/EswRl2y/YzB0Kexf8cDyYl+Rr
Cn8cGw3bDBv+GNUPx/6q2MYFX2+PfVg2Jk5spknuWBAxGnTEaIjN0Ia+vyf+
StljYA/VD5L+IF3/5bLjebxj3u0DZbcNMus4J5J8lOTFxKfK9r+Hpn52bPbG
kvtLv7LsmEPKu2c+5l70+QIf7Ao+AP7Au2TNlNxZ5RDWU12vM7YjPhq2sI59
rN+zBB9RuiT3tYhJ1Va9PeOh7G/M2l7J/Wys8Z11fiZ5T8Zj4rUuz903WPPQ
sQax9tCmjuROut70svvgqZLvlX4G46Vi/7FXbuwGf4/Y8W25n5UYMvgZNi22
bBMd68b7zW3/N1d5N/Hv20P1lao3U/0xlUaVLdDuFn8Sn6Z9Yc/2yG1DYzvv
qmPddb9RuetLiPVkjqE8LP3oknGbbxKvNaw5x6jtsbl9OfxD1s+tdI0LYsdA
8tjzAPPBuRXH5y4HMwsdEwLvvE1yqeQY3rM6v47OrxU7Jhrp/3XMS6FjNrVj
r9us38R4mK+3VfubYseEV+v7jwKjDB2T/0ryFbHXdtb4u2LjF39jr4AxSz+z
YuwTDPQLcGAd6xk65jpP9Sdir11gcMQ7x0j+LnSf36j6RrU5OnTMGLz688T9
DZ/yO+krxGNDY/S/Sz9W8g+hYzjEI6+V/GvomOoq1R9Um7qhbdQfsZ30++7R
sW25p/RDYtu22LgrVD8+tu2NDQ4e/XPhT+Ozg49/J7k7ti7frrCnriswhkn6
PzS2rU/M58nEeP322KoqK6W7TW3y0Db8/3LHi7eKHT/cpP+/ST9E9VHS/636
pTp/PFhpxfH9i9VmfWgOQHf6jkod1tOy8aS3pJ8b+JvAdzgBOXQb4gcnxrbN
eSbw/690zoEVj/G9E8cwiF38XuBNxHywr34tOT5LxyeWsa7k+DQxDOyplZJX
69xGiXUHqLwjuW5iXceS42rE0GhPTI3fiv/6Qcm/GfybmByxuBUl+7dwCOAO
0KZJ4hgX9/+o5Hhqzdixyy9L7hvgVetL7iPNE8cwiV1+rmOfYdMlbnuQynzw
uMTXQgZfJgZE7OerkscNeDN1xg9jB1+QazGG1mXGQ4mDjg3cF8FG15TcJ7GN
sZG3jR0zJT5cv8Dzvi8Z3yYmNEnn/liyPwN+QRyX+G2D2Pg3uuvAJ9V2j8Tn
sr7eHhsP5NtUsMfwkWLbu8QE6WvgW7XK7nOHxcZG8JWeDr2+Y9PAa8CHbJ04
Zsj8xPOCry6X/LbkStk2KZwW/BdiiBNi46+Vwn/oFBtrYK18MLQtjk3eMnZ/
mqT/h8S2JepI/hZ/S/r9Yvsg4I3r9BvHBP6GV4Df6lgfHeur8hC4s9ouDM35
OTN2vKWr2i8PfR2eiWfher+pfp9K9ZI5G3/EfkaejRg5vuQO2FixfcqfYr9z
3jUxvF9i+xH4E8Q04Qdgh2CPwLnA/6hX5XmQ+W9XPcss1o3QHKS7Y+PR8zD7
pL9H9Q6xsaIqyWepPjty7Pid0P5RC11vn9g+8WDpqqtspbYPS39/bPwbrgw+
xhDpaqhsje0nfcPYfYK+QMy3Kz5LYvvoMj3X4NjxT7hLC/hNqt+Jrxw6fnla
4m/EtxmADc29I2MlYCbwjehD9J3jsDGITyWu78AaS9+Jbdtj478s3emJr7V9
xfPk3RVjscyXI2Ljq8Tq3gyNTTTU738mMkbB3AweRGyTOXqQ5HsjY/Ov8Qyx
8VrM6jn0b8ajzn8kso92uOQGkqdF9qGOAk/V/cOSOST9pG8k/XORfarhut7j
kWOZS3S9q1Qv6ZscjS1XsS+IT3hwbB9/fGw8n9h8pGtOj+zH4s8S4/+f5NMl
vxWaA/cEvo/Of1rHdwltf+1CPFPX/lbysZn5B/US+2gnSG5a5TkKjOCZ3Pyd
tRXbjIMy89Wq854C+z+55FMlL2UNys3X4j3zfj+N7VfjX8N5g7+En4K/Agfq
N+y1KuN+4H2vgidK/35ozh62J/yARZFtUPhu50i/MjRn7WPV50jXNjRHa3Bm
/lyN2JjSwazn2NmhOThX6vg3OnaBdF/r2NDMfK7tdHxyYD4J8Q+4BwRsD2f9
1fl/hfYpGkueUTHWBuY2JTdfDBwR/PCR2Pjk+sA++Av05di+NDHSS2LHY0+R
/jPJl8aOx57FeiF5r8h2LPYsHKFO4L6SN4Tm5GX6/WlibsIqMAfp50n/YWjO
0cjY8caerF86Vkttt8Gvl/yF5Dtix3vgvsR6phrSVU8c6/9I+gtjxxOPDcxp
gS8FxxFu485l+7fwk+CBgUkx17WK7esy5/G8VfpmI/RM5wb+PZnkYZKH4MMT
+5A8lLlB8r7YJpKHSz4nsH8O/g/PEn4ltgSxAHx1bIqRqn9c4Pf4ONha4KmT
S7a5eB8J+Ce+UfH9t5J8NraM5Jf0P8J/w76SfGKB10MuJZ7bQ+1rqn6W6rcE
jveGxXh8Hzk3JgQWdFrFvKIaqW0l+EU74puBT1Y8volHTamYC/FkyWsJsW+w
BNYU8OD7K+Ym8BvgA7ygY8OYn0q2heEHUMcmfjH291xa2Dd5Yo5iD7Wfy/iP
3T/mgKWwJiXmwILPwvkB6wLzWhK5Pf3jsthcNq5JfGmqrrerqtMl10zMWYWr
uqjkcU58jd/CeGdeIR5FW+YX4t9wauHSLij610WxuYyvl+xXEB9Hh38BL2zr
1L4F/LDnY/dH2rYr2ZYn1se9senB7sDwZkT+PeN1Xj2dfx3fNfB6uAN4Br4V
7xzcMnFsm/jfwfp+PRmzktsy3nPHW5clPkY8/O0iPoOPeXdkfguxmEbF+fhY
S4oYzaOR+UWti+vdpv8LEvt2+HjzEj/ftRX7cLdXzC8hVoKL/1dk/gu2/Q38
/sh+4p7F/bGvwJXBmu4PzQ/AL8Q/JL4GFtBbz9O4wATwFefoGecnvh9xozmJ
sQYwh3GR+SvEmmoF5nEsTuwv4kMeV8Q3/kocz38u9/XuwJeW/o7c/KO7JG8r
eWNqfgvxsa0kb5L8ivTDI/Nnvpb8cu73wvuIi/FxQ8Vj8CvVX8od3yG+9mri
33Jzxc8MXnJObi7Ba4H5Bn8X9hnxNfzv03JzCRZLHqH6EXofdVPbH8MLPb45
HBHm81rSnYdtp/aHSd5G8kjmksDYOfwssBUwdNbv2tJfIPlp3g9+nOSLJL8S
eD4+LzZ3jTHH2kQ8c2bJaxTxTTjLcJU5xtrRK/FcyhoCdgeG94rOaVI2PxuO
MNzg3cvmb8PR7h5YP1f1I3WsednjG9/szcht8dHgi8IhZrzRhrWhD3217DUC
7iv3h+vXoMB7wDzhrcJXhV+KbwhXu2u58G2lO6BsHxdb87DE2BA2J3xSOK5w
W/crmw8MhxzueNuy+bdwsJlf4MxidxyfuC32B3xTOLFwYXlG1uqTEt+bNRv+
L5xluMrdysZKwUzh3cK3BXvYBhu/bAwCfjEc4ImBj7F2D9GxnmWv4WB7YHw7
M+eVzZeGgwz3GBlbbVhiPBabDVsWftEHgW3acxLH+xm7YILwrWZJf6bkq8vG
KuBT4UuCWeDbE78fVraPT/z/Vtb/sn0kYqeMFbBFrnd+4V/XCJ0zAH8b22t0
4G9wUWJ+F/cCs4X/CUcZbjK/ERylHPtdgafAj4bDC3e3Q9m2xAAd27tsm+Lf
yNxWsPkRodfnxRXPvXDQG7CWxPat4XjCjYSfCO8JvhOxAGIC8NTgpxELICYA
Lwk+UqvIfZa+Sk7EdonXMNYuOK1g/WD+8NTgp30X+X3CXYPPg20Hn2F2yTYe
/AY483DlOQZ/ipwS4j2vlGw7wqeijg35GHhmlXEZ8Jhq+EaxY1/kW2B/gBnw
POQI/BCZIwc3Dj7QMUW89dvEGAzjn4WG2CGcb2KLxBjhucBvIV5GPB3e/9DA
+CEYI3kUJwfGmoi1E0sDc4JfDwcb7jXfBGzqy8jfCowKbBOM85jE4wnsbVVk
LBIMrrHkRbFjnXB8+kn3W8XcHXz+NqylsX13ONLMb8QI4S3BV8LeAaMAi4Az
SuyXGDC8J/hOgyLHBYkP4uPX1fEFsWO1cIAGSvdfxdwhOETMp2AG3A9MftfE
mAfXh/MNFv9cZiwSTJ61izVsvt5NI/2fmdkmxxYfU3L8mHhZk9A+zV+sH7lj
ESdU7E8Rn2om3duh4xPEn1vo/Hq8P13/wtz8W3xRfCF8IvIt1sX234ivwaV7
g/el+qzU3AA4AsRqsZmwlYjZgo2CkRJbXKbfuhfrXWouEZwiuLpRZj4gvEDi
L1lmbjk+D74MPs0+oTnP8JHhBMIFhMO3Nb5V5jq2OPEK8Gj60iE6VkP6JPN6
w7oDX2x2ai4YHGd8MXwyYlFrpK8luU7m+Rc7j9yalpn5WPCyeN8vZM5V+Y/v
K33rzN8SX6FaEY8iN+G20P4V8XrGzubQ8XHicczFt4b2f4kf4sstBh/InP9D
rIA1tlHm/CBidazBqe53ieQGoX3hbSRvnXn9wm6E/0A8H24m8SH4vXBkhweO
OYI1gznDb/4B3zhzPg6xnvMrxlrAXHi23WLH+4nHwd3vEDq+gTPP2sc3qYB9
58Zq8f3h28AxhlsMZ4Z8rG6ZfX9y1u6U7oDMWMjKwHydh3XshdAcFWJvrPGs
3cTg4AKAUYFNwQmAu9wlM9YBTwTfGh/7z9A5YfuzPmfGYiaHjmcQr4Lrflfo
2OMylRklxyDhR/fMjFXQ54lXEC8D25soub6uv1dmviJYEfkKY4vxxzH43XBC
WKvIwdtR7TvyDkJjScRWyd/6uuQYK1gBmMHPobFSfG/6CH2DXI/ZmWP0rIV3
lsyXPym1700OHnzzAal9U2LKYBNgFMSGDoyMdYF5EWtvEzu+Bl/g9tCYGNgF
GMY3obFe+Df9U/vScKCJRxHvwdfEpybeRHwIX/ST0Hz/I1L7vnCs4V8Q38W2
S0uO5WEzYBsQ0wMrYH5irJADRr7Clal9acYU3+691Ll5fEPw2oGZsVkw2v/0
m46X/JPkcbHjoytTx0rhoB+TOT7O2rcp9G8jfs5axG8cW+Bf00Pn4JELRj4Z
uXzkhI1JzO9aFTgmBTYGP2pm2RgZuYLk+5ELSM4guVjYT3DVycmaHJs/Nats
jgBcdvKzyCWD007uIPYmuX7kEJKLRT4ZuVnkZJG7Rb4QuVjkcJGbxXpGbhk5
WuQKkk/IuydncHzi9YxcL2KADyfO3yI3bEtMP7E9Qy4hOWDksmGPkvtFTtuL
ie01bHM4N8Tn4eR0TPwNyY3B/sPWJ0eGXC/iBVcGzvl6KrE9i68IB4hcLPLb
+PbkZJF7hb3dFzyo4vghHKGjEvcpcuOwp8A6yJEjdwp7G+yBHKqDeT/6/2fZ
OVnkdYGXjA/N8SEXC3v4qsA5WeRygbfji5DTNUy/dWvwx4pzOvGP8OfIVcTf
G4b/mjp2c0bF/uZr2OcV+8RwC+HiE1skxkguGPEIsA1ywsglw94GGyGnDCwU
TJS1FhwRbif8T2KDxKSwg4gf4qtiD8HNJB9hn4o5muQnvBOZy8YxuMlwlKdJ
HqDjR+TO7wDHAb8By4Hv36liTAf+P5xOuJkc+ywx3xOZmBx8eDim+L7tKp57
4DNhuzIHMbbgn8AtZozBF1+QGpsh5wS+wYrUXM9xgWOPxCC35Asmzg8ZlJr/
CAcFPvrS1FxIjsEPfzs1VkHOCnyKJaljMUMlv5eYr8+z4aODK4ARgA2AL4Ab
4G+DJYAfwI9vF9uX7QeGRPxYz/RbYj4tWDD5C8dWjEHBl4fDi+7QimNpcNUP
qjimRuwQPj06vtemxBgD34s2g3LnM4Ezgy9vTMz/JdbO+cQ+4OvzLPjYYCHg
Jzw/mAjcVfJD2lQsky8CZgFWwTFip3DzidXzveC7N4nNlTyyYt4wnGT6EzHn
E3LnSxF3Id7yR2J+PG3hIJOf1DU11olNBXaOzYetd0ZsrB2bA1vjlNh83utV
/gjNUWNtwQbC9mGNOUnXvjc2Fww8nfxxbC5sLfDOpwt7GwyWNQL/h/w2+hb4
OGsFNgq2CWsG/hPzOH0NTtONqddM1kriLYxf8rHhFq0JbK+D4YPdY+Nin5O/
CNYMXk3+HWs0azPxG/JTWGdYb+DL4L9gF7C2wLEiXgJPDL7Y6sD2NvmVrL/g
9/B5r5b+x9CYN/7NVbHXFjBn/DHyC1lbwIiJd5HfDlcMjijxZfIJ4WZhI9fX
+9kxt20NRki8gXx7uGnY4OtT50yRq0L+Cfg8+dO7lcxJB98nHx/uGzkvxC/I
T4Q7iI2Pv0j+PLYYcy72w4uZbV8w0Ya6d6Pc2AFzOPE28qPhQjKnwmcih4zc
qBMDxx/It29Tsg0OP4B8bLhk5A+wdmPzYuuyhl+uc/ep8p4A5O/ADyCfHK4z
nMR1qfcEIDeqS+D4FfGmp0JzeOBl7xWbb0rMrX0R35iCzyb5l9TxomGxfYzf
U/dh+i428L6Z43H0UWyuNpltWGxXbPLdMuMXxASxyQfkni/g7JNvskfm+Ccx
RGykP1LnixJbIqegdcFHuC8yx3pt4U+B3X4p+e/U+CoxJb7HvpKrVTnH60Dp
N6e2N8F+yUH4M3X+KLEeci7+Sb2GsHbQH/5NPWYZq/hI7TLnl9K3yUGBH0U+
MbHMPwPvv4C//mHs/Abip+QXwzWGk0n+6Jb4beL8FfI5uDbzAfE3+JGvZrZ1
iSG/rPormW3luYH5W+R0kov0RmD/lvg12Cqc2lmRY7zEdonfwS8hZkqs9KDA
fBJiLMRWiBf2yuxj4lsS3yQ/F58GX4Z3Dt+cb41vCccR2xwfA98CGx37gHzt
+arXCOxLkF9wYGyfgrkPnw9fjzlwauS+wnzH9yNXH74DsRNy9uHXkD/dvWSf
7rPUOa7kVrEGkytDzsxJrJ+Rc13gLMFV2i1yrgocI7hFe0TOfSAHogFzRWSu
PnwjsPSdI+fOkEND7skukbn9cPzJpdkpcm4KOSrkyrSInDtDDg25PG3BvlPn
1JJLWwsbXPpHU2PH2DCMN3LamEu+DpxvfXHmXDn2/IBPDR9yU+AY47DU6z25
YWByzEeHpZ4LyJlsnnv9JrcLjgu5QeQIkevTJHJuETlGbYrYB7kL5DDA7T82
MneQ+QhfBg7hwZn5q1tyY0Nz38BswGrgwJEPOSN1biM5suTHwnEntsweI+SP
0ofoO+xpwtwAJkF/od+QS4BPgy/zceRcKHKiTsO+ipzbAEdwS35k5FwQckKu
Y72PnAsJv5hcgUMi5z6SA0muVa/IuSnkqJDrcEzkXCxysqawXkfmc+KfwN2E
A0YuCTklF/G+I+cWkmM4VXLvyPgTfBP2IoDf0LL4/Z8Hjh+0K/CKDYHfyU2s
FVXOgSa/Er4Y+f1wy8l/aKrrN8ttW8HRwHaDP5rGtuHgKxF/g0uMzcdeIviz
5L7tXNhu5ANujmzDkTuDT48v3y12rgvx4P6FfQffjXgU3GV8uN0YL1WOEYBn
bUid403uHvl28MHI5yd3lvxE8DDmavAG+BTwO8jPhttOTil8CfLje5WcUwff
g/x1uP3M1+2L+WpCyZxFcmngo6PvlHj+vDtzLh45+uQPskeO/rbkkMHHJV+C
2Ck5z+QOgUmARfSNzccnhxzuBWYH8wP2Ob+FnET4guBz7GUCR4+9d87LzZ0g
r434DuOTb0kONPEbcpz1KFtyroj3NE230HG25MSRS0NOzeuSj4+cK0POzELJ
J0TOrSHHhnzQOqm5lczfcNunF+/7+tRzNTmk5JuQz8JaBeeB/Ar4t6wdcGaI
RzVhjQ6cw0X+79mJY7fY0K8njs8R+8IfOjM3ftdJ8vUVf2swK7AqvjnYEpgS
WBIY09lqf3XqWBQ5rtiC2ITE41dG5gYTgyL2RLwAe4WYMbHiG8veH2Woyun4
qmXjdY/nXjuJrcKdIJ+HtRoOBbmufXPb09jVjAd8Pny9W8t+dzekjn3xDsE2
wUjBRsE4sdfImSFX5uyy8bIncuczwzW7jrk+t+2Nvc9eOuypA7cDrJdvRUyQ
WCDfjLmwf25bgznxbtaS3L4E/gm2CD4Mtjs2Cf7Vs7n9d2ITzKc35Z5fyAkj
P58cI3KLhuv5BuY+H/+GHEX2Zhifu07eImsrayz8pUaR+9fNKs8HztliPrtR
5bHAOXfMn/fmnv/JyaI/M17g82wbGQt/ODdfCkyc+eGR3O8TW47xt0n3o0PD
M2M8PZbb/ya22iU2PreAJsX8PEZlYOCcVbiajDnGGlwkcr3gc7O+kvMF9wAO
Au+WnEHWfmwAxgs5hnel1sNNIOccfJk9IbDFFkTGs6fltsWeLub763LP/+Rw
M59fr3J34Bxb5usbcs//5ITj++AD9eT3F+PzltzrATlt2K7YsLsE5ugw/1+d
G38lp5DxOzv3/EGOHLYiNiO2LtwXYsn0H/oKOXOsP9dSAufgs15dkzs3mhxG
8l1vZj6uOGbGfH5W7rFGXjm53K+l9lfJXe2aeE8Q8v/gguFLMj8zV+BTYiti
M5KvDVeP2DDjk/mEXHS4HIzPKyV3ibwWsSaRfwz395vYe8qQ7whXltx57BVi
A+QRbpt4TzH2T4CrTC731NR8N3K6sbWxucl9ggOM7YcN2FRy/ci+OPYouQT4
5GAj+C/kYoCR4Ivgk7A/BNzoD2LvgUa+Ilxifj/5Ldi68CaJxd2X274jJsfz
kR+F7wSv5L3Ye6yRfww3mFjPo7n5fe8Uvxc8ibUWXiS2LfZJM8k7Rh6P2JOs
FZdF5nI+mdv/gtNJLG9Cbn4TMT1seWx68h2JwWHLYtN2lX5h5L018Bexzcj1
hS+Pf4Wtd1bkvRLmSh4QeM8EYov35OYnEWMkN35OMR7IkSe3f37qfAhyVtlL
Y17q3Ff6K++P/MLmgXk5YANgBINYCyO/H/Id4ePAy9myl0Lq3HJyzNm7Yklm
/g48HrjU5JsQLyduTm7+i0X/J0cfrsSU4vvDmWAvjGdS2+7kuRLLnpE7tkJM
G24JHBPwlgaRuRR1c8eHiRPDxYDjAfcCTsbI3PwIuBJwJog1Ts+NrxJzZK+O
6anxJrgexNvOzd0WngV7dXTPjQ+CE7IXx/+K8c6eHHAzJqfmbsDRgCvwVO7Y
CZwBuB2PpF5P4XiQq7oKGyFwziqx0Um5c2eJkZLr8670dwXO+SEXCfuOtYyc
JPzJczPngrMnEf4rOa5wJdjziPUQTA8sb0PiXBLwANZWckrInSWHFv8HLjbx
uqrM+3HAPQJ/JweS+C9x4AGZ82FYi9kDjXziPjo+umLM/MXccwZzBRwTuEXs
98feYXCM4K6xvxx7i8Fhg9vG/m3s1QXHDVsCm+KKxPtvsV4QMyJWBNcWbgn7
i7F3ExwTuCXsJ0Z/gGNCPvNROmdMxZg8/atd4U80jMw3q5/adoFTw94K5OBh
v8Ktuj1zfI9YKjYne1uAYYJdgg2y1wYYJ7Zv18j+/cjMewcQUwKLApOCb7pH
7FwuYhbEKsDy2M/vtsx7pRATIl6zZ2bfHo4yfB/4dr0Cc+IYzz0KuU3k8YV/
B5bSMjJ2BoYGP3Hv2PEx4m9LJPeIze1jfzX635CivxEjJDZ4RGR/nxxT+NjY
0HBXyW8aHZhHwV4h5CDiL7xc9Ecw4XHS94y8twk5VeRSdY+8Nwg5jPAj4EnA
9SRfGn4wnM+LMsd3ya0D42LvC/bAIJ7TN/L8Q7yS+O7ekffmYI+ORyQfHZkr
yX6L7J0HZxKuJPvDsfcanMnqqfdnY+89bEb864tUdg6cQ49/fbnKfoH3gCB/
iPyjLXtXVOzfX5HbP2dPC/z3i3P78+Tc4/9elttfZ48M9kfj/YNdgmGBRcER
By/dgpum3j+KvQGxafE/x+b258mxZ68gcjrBC9mzCbxhdG7/nfkT//9KlUMD
76HB+/ow9d6N7BmCr7a0+B7sy4Cvt6L4vuQM0l+XMQYD7xHD93orNb5NbhPv
d7Xk5wLvgQKecVVu/IE9OMAzzs/NVYOzRnxiTer5CfuFvSLIrwIPYc+PgQW+
T64kMTzwjktVWgXeM4T5GZ8IX2hk4vkUnx9f/43E832rYr6uFzl3EvwUW5wc
SuZXfCh8p1qRcynZrwpbmJxKuKjs58XehHBSiY8uSh0vWlOsd+z5AB5wQGSu
K/sNsrcfnNfjMudrX1oyBoz9RE4euXidI+8lRI4x+C17prG+sT8AeOw/xfrK
HjTwC5pFXk/IYYPfWDcyn+CK4vs1jb1+tCz8wx0i54uzhw++Mc/AeoGPiG9Y
u7CX8GHxXetE5mLCaYDLQOwEbBaMFj52c13//8+n0dM=
           "]], Polygon3DBox[CompressedData["
1:eJwt1nmUjmUcxvHH2GY46pRsLSiMNDEau5rUIDGWkIqE6ignoqIskZR1tFrG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           "]], 
          Polygon3DBox[{{2289, 2678, 1308, 1189, 1188, 1434}, {2370, 2369, 
           1607, 1287, 1288, 1608}, {2284, 2676, 1301, 1177, 1176, 1419}, {
           2295, 2683, 1314, 1199, 1198, 
           1450}}]}]}, {}, {}, {}, {}}, {{}, {}, {}, {
        Line3DBox[CompressedData["
1:eJwVzskqxXEYx+EXx3wDthbuwD0gbNwBG+MZnGOeWbgAG1fgEiyVIkMoR6GQ
oVDIUChDhucs/j2f3u/i96/tSLeliiKi3beQiFgtj+gsjciyiytVETk9rzfZ
zQ32cN22pRf1Lnu5wz5u2/b0ks4zyX2meMBlHrGhOiKtD3WGx1zjKRtt/fpE
Z3nGPC/ZZMvpCz3AK57zhoO85lDhbf9xqx/1PYd5x5HCW7YH/a2fOconjhXe
sr3oyrKIN467vXKC76xx/2Sz/5h0+9BT/GKd7Zcttmm3Hz3DP9bbSioiWm2z
bsV6jglm7P8quUG1
         "]], 
        Line3DBox[{1171, 2075, 1985, 1987, 1986, 2750, 1172, 1306, 2757, 1186,
          1313, 2762, 1197, 1319, 2763, 1206, 1325, 2764, 1215, 2795, 1332, 
         1224, 2800, 1503, 1912, 1504, 1913, 1720, 1518, 1519, 2770, 1724, 
         2062, 1532, 1916, 1533, 2776, 1728, 2065, 1546, 1918, 2883, 1547, 
         1260, 1363, 2782, 1269, 1370, 2784, 1278, 2812, 2070, 2071, 2072, 
         2895, 2073, 1603, 1903, 1604, 1693}], 
        Line3DBox[{1173, 1415, 1416, 2751, 1174, 1307, 2758, 1187, 1446, 2823,
          1447, 1705, 1462, 2828, 1463, 1708, 1476, 2829, 1477, 1712, 1490, 
         1491, 1716, 2862, 1505, 1660, 1506, 1721, 1520, 1665, 1521, 2771, 
         1725, 1534, 1670, 1535, 1729, 1548, 1675, 2855, 1549, 1732, 1561, 
         2839, 1562, 1736, 1574, 2840, 1575, 1740, 2864, 1589, 1590, 1286, 
         2816, 1605, 1923, 1606, 1694}], 
        Line3DBox[{1175, 1417, 2819, 1419, 1176, 1432, 2821, 1434, 1188, 1448,
          1639, 2848, 1450, 1198, 1464, 1646, 1466, 1709, 1478, 2830, 1652, 
         1801, 1800, 1713, 1492, 2834, 1656, 1806, 1805, 1717, 1507, 2835, 
         1661, 1811, 1810, 1722, 1815, 1816, 1666, 1820, 2851, 1819, 1726, 
         1824, 1825, 1671, 1829, 2854, 1828, 1730, 1833, 1834, 1676, 2856, 
         1550, 1733, 1840, 1841, 1680, 1563, 1737, 1576, 2841, 1684, 1578, 
         1741, 1591, 2845, 1688, 1593, 1287, 1607, 2846, 1609, 1610}], 
        Line3DBox[{1181, 1864, 1865, 1632, 1430, 2754, 1182, 1443, 1638, 2847,
          1444, 1193, 1459, 1645, 2850, 1460, 2076, 2077, 2078, 2054, 2053, 
         1211, 1328, 2765, 1220, 1335, 2766, 1229, 2801, 1341, 1238, 1347, 
         2773, 1247, 1353, 2779, 1256, 1359, 2781, 1265, 1366, 2783, 1274, 
         2079, 2896, 2080, 2081, 2082, 2897, 2083, 1983, 1982, 1292, 2817, 
         1619, 1700, 1620, 1622}], 
        Line3DBox[{1293, 1378, 1601, 1283, 1373, 2809, 1275, 1367, 2807, 1266,
          1360, 2805, 1257, 1354, 2803, 1248, 1348, 2802, 1239, 1342, 1230, 
         1336, 2797, 1221, 1329, 2792, 1212, 1322, 2790, 1203, 1316, 2788, 
         1194, 1310, 2786, 1183, 1303, 2785, 1167, 1298, 1411, 1623}], 
        Line3DBox[{1294, 1379, 1602, 2814, 1284, 1374, 2810, 1276, 1368, 2808,
          1267, 1361, 2806, 1258, 1355, 2804, 1249, 1349, 1240, 2767, 1343, 
         1231, 1337, 2798, 1222, 1330, 2793, 1213, 1323, 2791, 1204, 1317, 
         2789, 1195, 1311, 2787, 1184, 1304, 1168, 2747, 1299, 1412, 1624}], 
        Line3DBox[{1295, 1380, 2049, 2048, 2815, 1285, 1375, 2044, 2043, 2811,
          1277, 1369, 2039, 2890, 2038, 1268, 1362, 2034, 2033, 1259, 1356, 
         2029, 2028, 1250, 2774, 1350, 2024, 2023, 1241, 2768, 1344, 2019, 
         2018, 1232, 1338, 2014, 2013, 2799, 1223, 1331, 2009, 2008, 2794, 
         1214, 1324, 2004, 2003, 1205, 1318, 1999, 1998, 1196, 1312, 2886, 
         1994, 1993, 1185, 2755, 1305, 1989, 1988, 1169, 2748, 1300, 1905, 
         1413, 1625}], Line3DBox[CompressedData["
1:eJwV0L8rxHEcx/E3Hb6hTsrgusVZ8JXBj7oyKcVCCMUtR13ddPcn2P0HN5kM
FiT5sdkwGiy3yZVStxisPL7Dq9f7/Xy93p++fSeOmzuNnog4oJG+iBqd9Uek
QxHrPLFXqWWewcr8LxdRwVJzAZvmv9guVjQvDEQ80Dx18Q18NInY1D3B8jqz
/I5S+tRZ08nrdGVBk/gtlagtX5Evuh/W+Zb/2AuyGxqnN51lbFD+Je+Y9/Fr
WnW3x191lvBEp6Pzbt7GL2mLnuRz2IfsJfsed8/8Hp/iTfyRX9lL2TvyOnZh
PseKPIcdYa3sn2FjvBc75Yf4P1bEKSU=
         "]], Line3DBox[CompressedData["
1:eJwV0L8rxHEcx/H3Fc6ROvkxKINYlLIZ/MiPUvJrOIn8iqMTChNFCovFX8Bi
skhI8mthZDQYWFktBqvHDc9e79ePT9336rJrmdVERKygvDAih+VkxElRRBft
REo2h1ZZG/+I3lKehnwKVcUR+3yTTbdu0f2AHP4KIkZtKm32+FqbBXqPefzo
h/UV+l2+0vu0zZz7FrP4sumzSdvs8An9DL3BND71Dd712JTZbMt+3ZP0GhN4
s2mXleq3+G/3OL3CWP5bvX+1aZGnbDZl7+4ReoEMnvXNsqR+g39xd3g37D7H
EO5sGuU1Ngf8ut86QAfRj0t9vf5DnvJ2iZ7xp/JaWiTLyo7dR7Knkojq/P8s
O8x/E/0HltkvpA==
         "]], Line3DBox[CompressedData["
1:eJwV0Lsvw2EYxfG3USRsErMYbOIvEMFqkIhFQiQViVsqEgaLxVKXlqKudalb
3RajYLHaNEGiqxhNLhufDt+c8zznPL83+dXHxrvikRBCHKnyECYrQ0jSvooQ
nlBAY3UIO9EQsvYD5me8IG/3R6/sR2iV3hst4loW9a1b2YQ5wc9jDjeyTrqA
e3mLuymdRXOq9D4edLrpEh51puXL/ArSpZ281V0Pv4pXnRmdNX4dGRR0eukG
PuSz8k1+G1tocF/U6ed38KWT0Mnye9jFuzxG91EmS6LW3YH5EDl86gzSI9TI
0zjmT3GCX/kQzaNO1u4+Q8/MFzhHxNvD9BJNsm1846f0X2XNbtpkHeYcRvkx
3OEf7ilBRw==
         "]], Line3DBox[CompressedData["
1:eJwVzjEvQ2EUgOGjaUl6BxFiI7XYGgPShE5i1MUPMHRXf8KOHbOFwShYbNKx
QociREM0FCVEJJ47vDnnvu/97ncnqmvLtb6IWMFmLmJxIGLD3EKjP+IC29mI
X3OH28WVfTqJaJp7Wjizzx8g4Vv8NQ61nHbMn+KGu8URn+fPuZL36+Ydf48z
bVDr5CMu+SYe+Dbq2ojW5h5TuCc0+DG+x33hmeugxU/yGXsWL5h132v6Pa2o
DdmHMcp3zTd0tRlt3F7AOz7ww5f4on3O+1NmD5/IuLes/fnvec9lfKdnkGgL
2pK9glX7Omo4wT+wCDsE
         "]], 
        Line3DBox[{267, 873, 227, 874, 2286, 269, 875, 229, 881, 2291, 283, 
         882, 231, 2591, 884, 294, 885, 233, 887, 307, 888, 2592, 235, 892, 
         319, 893, 237, 898, 331, 2322, 899, 239, 906, 344, 907, 241, 913, 
         2329, 357, 914, 243, 921, 370, 922, 245, 2608, 929, 383, 930, 247, 
         934, 395, 935, 2609, 249, 939, 406, 2357, 940, 251, 942, 416, 2364, 
         943, 253, 950, 433}], Line3DBox[CompressedData["
1:eJwV0L8rxHEcx/H3qfteuRtOOYuiszD5MbjuklvESN0fcMNlU5RisFgYLAbK
YiAlZUAGi+GUohRZ8RfwD5xEeXyHZ8/X69Xn0/fTt9xaaSxnIqKJRhKxnYtY
4BPMY0Z/5TrX+RDTmMqz7UWu8QQfoN8+zlXbE1d4iPdQxqT+wGNcSu86v8u9
GLXd8wi/dUck8g6yGLa1eZC/sxFbcocH9Fu5j7/0TfmTS/qN3MMf+ob8zlXf
K9qu9UL6ftu6XLQ/y3nbhZ7jO31VbnOin8tdfKVXnF/SL+WM7Uz+w6N3H9sW
5SP+5VP8YF9vpv+C19yZxRz+ARHTLa0=
         "]], 
        Line3DBox[{1621, 1926, 1617, 1699, 1616, 2866, 1745, 1600, 1692, 1599,
          2865, 1743, 1587, 1687, 2844, 1586, 1739, 1572, 1683, 1571, 1735, 
         1559, 2857, 1679, 1558, 1255, 2778, 1544, 1674, 1543, 1246, 2772, 
         1530, 1669, 1529, 1237, 1516, 1664, 1515, 2863, 1719, 1501, 1659, 
         1500, 2861, 1715, 1488, 1655, 2833, 1487, 1711, 1474, 1651, 1473, 
         1707, 1458, 2849, 1644, 1457, 1795, 1704, 2760, 1442, 1637, 1441, 
         1790, 1702, 2753, 1429, 1631, 1428, 1863, 1964}]}, {
        Line3DBox[{2085, 2280, 1298, 2084, 2281, 2747, 2211, 2086, 2282, 2748,
          2212, 2583, 2584, 2585, 2749, 2283, 2213, 2626, 2740, 2750, 2214, 
         2087, 2708, 2751, 2215, 2088, 2819, 2284, 2676, 2818, 2089, 2285, 
         2752, 2216, 2373, 2496, 2497, 2407, 2727, 2860, 2217, 2374, 2498, 
         2499, 2408, 1749, 2218, 2658, 2586, 2587, 2286, 2468, 2219, 2556, 
         2500, 1786, 2409, 2469, 2220, 2375, 2709, 2753, 2410, 2221, 2376, 
         2710, 2754, 2222, 2287}], 
        Line3DBox[{2091, 2677, 2785, 2090, 1304, 2092, 2627, 2755, 2223, 2628,
          2629, 2630, 2756, 2288, 2224, 2093, 2757, 2225, 2094, 2758, 2226, 
         2095, 2821, 2289, 2678, 2820, 2377, 2290, 2411, 2679, 2822, 2378, 
         2501, 2502, 2412, 1751, 2227, 2379, 2503, 2504, 2413, 2867, 2470, 
         2228, 2659, 2588, 2589, 2291, 2471, 2229, 2557, 2505, 2506, 2759, 
         2414, 2472, 2230, 2380, 2711, 2760, 2415, 2231, 2381, 2847, 2292, 
         2232, 2096}], 
        Line3DBox[{2098, 2680, 2786, 2097, 2681, 2787, 2099, 2631, 2682, 2886,
          2632, 2633, 2704, 2761, 2293, 2233, 2100, 2762, 2234, 2101, 2823, 
         2294, 2416, 2235, 2382, 2848, 2295, 2683, 2824, 2383, 2507, 2296, 
         2417, 2473, 2825, 2728, 2384, 2508, 2297, 2418, 2729, 2826, 2474, 
         2385, 2509, 2298, 2419, 2730, 2827, 2475, 2299, 2590, 2268, 2591, 
         2476, 2477, 2386, 2510, 2870, 2300, 2420, 2478, 2479, 2387, 2849, 
         2301, 2421, 2236, 2388, 2850, 2302, 2670, 2237, 2102}], 
        Line3DBox[{2104, 2684, 2788, 2103, 2685, 2789, 2105, 1069, 1999, 1070,
          2000, 232, 2106, 2763, 2238, 2107, 2828, 298, 464, 1646, 299, 1647, 
         465, 300, 1648, 466, 301, 1649, 468, 303, 1470, 305, 233, 470, 1650, 
         306, 471, 1651, 308, 1121, 2054, 1120, 2108}], 
        Line3DBox[{2110, 2686, 2790, 2109, 2687, 2791, 2111, 2634, 2003, 2112,
          2635, 2705, 2887, 2303, 2269, 2113, 2764, 2239, 2114, 2829, 2309, 
         2422, 2310, 2115, 2830, 2311, 2423, 2312, 2831, 2116, 2610, 2304, 
         2611, 2305, 2877, 2733, 2621, 2558, 2306, 2612, 2307, 2878, 2559, 
         2560, 2511, 2313, 2424, 2314, 2871, 2512, 2622, 2561, 2270, 2592, 
         2271, 2488, 2117, 2513, 2832, 2315, 2425, 2316, 2514, 2118, 2833, 
         2317, 2426, 2318, 2119, 2765, 2240, 2120}], 
        Line3DBox[{2122, 2688, 2792, 2121, 2689, 2793, 2123, 2636, 2794, 2741,
          2124, 1079, 2888, 2308, 2272, 2125, 2690, 2795, 2126, 1490, 2427, 
         2320, 2127, 2834, 2321, 2428, 808, 1966, 1024, 809, 963, 810, 1967, 
         1025, 811, 967, 1935, 812, 813, 710, 2429, 2796, 711, 1026, 814, 893,
          660, 2128, 713, 2872, 2430, 714, 2129, 2712, 2861, 2431, 2323, 2130,
          2766, 2241, 2131}], 
        Line3DBox[{106, 1230, 107, 1231, 108, 1232, 109, 1502, 333, 110, 1720,
          568, 111, 1721, 569, 112, 1722, 570, 1233, 113, 486, 1234, 114, 488,
          1235, 115, 571, 1236, 116, 344, 117, 1723, 572, 118, 1237, 119, 
         1238, 120}], 
        Line3DBox[{2133, 2691, 2797, 2132, 2692, 2798, 2134, 2637, 2799, 2742,
          2135, 2638, 2639, 2889, 2319, 2273, 2136, 2713, 2800, 2324, 2137, 
         2714, 2862, 2432, 2325, 2138, 2835, 2326, 2433, 2563, 2562, 2884, 
         2139, 2564, 2565, 2389, 2566, 2879, 2734, 2140, 2567, 2568, 2390, 
         2735, 2880, 2569, 2141, 2515, 2516, 2434, 1812, 2517, 2142, 2570, 
         2571, 2322, 2490, 2489, 2143, 2518, 1813, 2435, 2520, 2519, 2144, 
         2715, 2863, 2436, 2327, 2145, 2693, 2801, 2146}], 
        Line3DBox[{2148, 1342, 2147, 2767, 2242, 2149, 2640, 2768, 2243, 2641,
          2642, 2643, 2769, 2328, 2244, 2150, 2716, 2770, 2437, 2245, 2391, 
         2717, 2771, 2438, 2246, 2392, 2851, 2521, 2522, 2439, 2480, 2694, 
         2868, 2660, 2593, 2594, 2393, 2595, 2852, 2247, 2661, 2596, 2614, 
         2597, 2394, 2738, 2853, 2248, 2613, 2523, 2524, 2440, 1772, 2249, 
         2662, 2598, 2599, 2329, 2481, 2250, 2395, 2525, 1823, 2441, 2482, 
         2251, 2396, 2718, 2772, 2252, 2151, 2773, 2253, 2152}], 
        Line3DBox[{2154, 2695, 2802, 2153, 1349, 2155, 2644, 2774, 2254, 2645,
          1092, 2775, 2330, 2255, 2600, 2719, 2776, 2442, 2256, 2397, 1535, 
         2443, 2257, 2398, 2854, 734, 2444, 637, 2063, 1135, 916, 987, 917, 
         2064, 1136, 918, 991, 1950, 989, 990, 737, 2445, 2869, 638, 1137, 
         920, 921, 639, 2399, 740, 2777, 2446, 640, 2400, 2720, 2778, 2258, 
         2156, 2779, 2259, 2157}], 
        Line3DBox[{2159, 2696, 2803, 2158, 2697, 2804, 2160, 2646, 1356, 2647,
          2648, 2706, 2780, 2333, 2260, 2601, 2883, 2334, 2261, 2401, 2855, 
         2335, 2447, 2262, 2402, 2856, 2336, 2448, 2602, 2603, 2894, 2337, 
         2604, 2331, 2615, 2605, 2836, 2737, 2338, 2606, 2332, 2617, 2739, 
         2837, 2616, 2403, 2526, 2339, 2449, 2731, 2838, 2483, 2340, 2607, 
         2274, 2608, 2484, 2485, 2404, 2527, 2873, 2341, 2450, 2486, 2487, 
         2405, 2857, 2342, 2451, 2263, 2161, 2781, 2264, 2162}], 
        Line3DBox[{2164, 2698, 2805, 2163, 2699, 2806, 2165, 1097, 2034, 1098,
          2035, 246, 2166, 2782, 2265, 2167, 2839, 386, 512, 1680, 387, 1564, 
         388, 378, 1565, 389, 380, 1681, 514, 391, 1568, 393, 247, 516, 1682, 
         394, 517, 1683, 396, 2168, 2783, 2266, 2169}], 
        Line3DBox[{2171, 2700, 2807, 2170, 2701, 2808, 2172, 2649, 2650, 2890,
          2173, 2651, 2707, 2891, 2343, 2275, 2174, 2784, 2267, 2175, 2840, 
         2349, 2452, 2350, 2176, 2841, 2351, 2453, 2352, 2842, 2177, 2618, 
         2344, 2619, 2345, 2881, 2736, 2623, 2572, 2346, 2620, 2347, 2882, 
         2573, 2574, 2528, 2353, 2454, 2354, 2874, 2529, 2624, 2575, 2276, 
         2609, 2277, 2491, 2178, 2530, 2843, 2355, 2455, 2356, 2531, 2179, 
         2844, 2358, 2456, 2359, 2180, 2896, 2671, 2672, 2181}], 
        Line3DBox[CompressedData["
1:eJwVzTsvA1AYBuDPpFjc1g5W6VCDAVMHG4POGAyaJrSp/oeiaN0W2kr4EyLh
37gUxazVxNPhyfe97zk5Z2armC0MRcQq+4mI2mjELxV73exyYF83e9xzKG+Y
m6yMRaRGIl51VR50f+Q4km/NtDtX7ixwrEvKi/ZrlpiVT/TP9hcavA3eZNlZ
zdm4dybY1uWHIybtdX1bfqdJX/dpfnDqbEqeZl5+4pEzfcf8Gvzt7Zb5wzfn
zu7cn9PfyLv2HS70a7o9e5kSGS71/xKGLqk=
         "]], 
        Line3DBox[{2210, 2372, 2817, 2726, 2209, 2371, 2467, 2866, 2725, 2208,
          2554, 2555, 2466, 1859, 2553, 2207, 2494, 2495, 2364, 2582, 2581, 
         2206, 2552, 1858, 2465, 2551, 2550, 2205, 2549, 2876, 2732, 2464, 
         2548, 2547, 2204, 1855, 2546, 2463, 2545, 2544, 2203, 2859, 2370, 
         2369, 2846, 2202, 2368, 2816, 2724, 2201, 2666, 2667, 2664, 2746, 
         2895, 2665, 2200, 2279, 2360, 2893, 2657, 2656, 2199, 2744, 2815, 
         2655, 2198, 2723, 2814, 2367, 2197, 1601, 2365, 2366}]}}},
     VertexNormals->CompressedData["
1:eJwUl3c81H8cx5UdSrTMBkooKUlJbxIykopCizJSUaKUNIRoWGUkKUIoInu/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      "]],
    Axes->True,
    PlotRange->{All, All, All},
    PlotRangePadding->{Automatic, Automatic, Automatic},
    ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.47374151225*^9, 3.473742900609375*^9, 
  3.47374300621875*^9, 3.473743046203125*^9, 3.473744788015625*^9, 
  3.4737452039375*^9, 3.473745829484375*^9, 3.47374586903125*^9},
 CellLabel->"Out[184]="]
}, Closed]],

Cell["\<\
The first method yields the best and the fastest plot. To control the \
coincidence of the image spheres we choose four points {v,w} of the parameter \
region, evaluate them with each of the methods to get four points of the \
image sphere and calculate the center and the radius of the image sphere with \
each quadrupel of points; they must coincide.\
\>", "Text",
 CellChangeTimes->{{3.473745374640625*^9, 3.473745402765625*^9}, {
   3.473745480453125*^9, 3.473745619640625*^9}, {3.473745697875*^9, 
   3.47374578990625*^9}, 3.473745829484375*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uuu", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Pi", "/", "2"}], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Pi", "/", "4"}], ",", 
      RowBox[{"Pi", "/", "4"}]}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.473486028049994*^9, 3.473486134159369*^9}, {
   3.473486167206244*^9, 3.473486212862494*^9}, 3.473745829484375*^9},
 CellLabel->"In[185]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     FractionBox["\[Pi]", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["\[Pi]", "2"], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["\[Pi]", "4"], ",", 
     FractionBox["\[Pi]", "4"]}], "}"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.47374171240625*^9, 3.473743006328125*^9, 
  3.4737430464375*^9, 3.473744788234375*^9, 3.473745204875*^9, 
  3.473745829484375*^9, 3.4737458711875*^9},
 CellLabel->"Out[185]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pts1", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"subspheremf", "[", 
       RowBox[{"s", ",", "t", ",", "u", ",", " ", "p"}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"uuu", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"uuu", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473741718171875*^9, 3.473741729484375*^9}, {
   3.473741768015625*^9, 3.473741821203125*^9}, {3.47374187471875*^9, 
   3.47374188159375*^9}, {3.47374194540625*^9, 3.47374203228125*^9}, {
   3.473742081453125*^9, 3.473742095046875*^9}, {3.473742130296875*^9, 
   3.473742147765625*^9}, {3.473742186*^9, 3.4737422029375*^9}, 
   3.473742274484375*^9, 3.473745829484375*^9},
 CellLabel->"In[186]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.29174179749349294`", ",", 
     RowBox[{"-", "1.0875694758395587`"}], ",", "0.07362701487643947`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.7569944948061855`"}], ",", 
     RowBox[{"-", "0.4295045885600194`"}], ",", 
     RowBox[{"-", "1.6998755479531669`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.45609821777959436`"}], ",", 
     RowBox[{"-", "0.07105428673848485`"}], ",", "1.0296928098110838`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2685622595674855`"}], ",", 
     RowBox[{"-", "1.5133172452628072`"}], ",", "0.6167236076139861`"}], 
    "}"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742276453125*^9, 3.473743006359375*^9, 
  3.47374304646875*^9, 3.47374478825*^9, 3.473745207328125*^9, 
  3.473745829484375*^9, 3.47374587165625*^9},
 CellLabel->"Out[186]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.891285292694997`", ",", 
     RowBox[{"-", "0.45578534400760606`"}], ",", "0.1553617095229604`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "5.188864460317143`", ",", "8.049565514339623`", ",", 
     "14.907393684025296`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.3999737262595578`"}], ",", 
     RowBox[{"-", "0.6204854141331858`"}], ",", "0.693747708264646`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0.7766975395539887`", ",", 
     RowBox[{"-", "1.8855266448791568`"}], ",", "1.2860128865383988`"}], 
    "}"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742276453125*^9, 3.473743006359375*^9, 
  3.47374304646875*^9, 3.47374478825*^9, 3.473745207328125*^9, 
  3.473745829484375*^9},
 CellLabel->"Out[163]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pts2", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"subsphere", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"unit", "[", "3", "]"}], "[", 
         RowBox[{"{", 
          RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}], ",", "p"}], "]"}], 
      "[", 
      RowBox[{
       RowBox[{
        RowBox[{"uuu", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"uuu", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.47374228665625*^9, 3.47374230821875*^9}, 
   3.4737423659375*^9, 3.47374239921875*^9, 3.473745829484375*^9},
 CellLabel->"In[187]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.6330817233938848`", ",", 
     RowBox[{"-", "0.03905158951323929`"}], ",", 
     RowBox[{"-", "0.15455677049881708`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.0779996554014127`", ",", "0.012151351757908452`", ",", 
     "0.6918690498700852`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.10688043225981055`", ",", "1.0115432409122713`", ",", 
     "0.009355019002293114`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.3259644372141492`", ",", "0.30845652438264964`", ",", 
     "0.3344565782852352`"}], "}"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742400703125*^9, 3.473743006390625*^9, 
  3.4737430465*^9, 3.473744788296875*^9, 3.473745209015625*^9, 
  3.473745829484375*^9, 3.473745872640625*^9},
 CellLabel->"Out[187]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9854402225078398`", ",", 
     RowBox[{"-", "0.052833350197923`"}], ",", 
     RowBox[{"-", "0.09784472834507119`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.027139910243026023`", ",", "0.042102561596142056`", ",", 
     "0.12008102636373226`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.05200958500491086`", ",", "0.924310571761462`", ",", 
     RowBox[{"-", "0.3028809496038891`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3061435942451275`", ",", "0.2617847450027314`", ",", 
     RowBox[{"-", "0.08548937206184248`"}]}], "}"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742400703125*^9, 3.473743006390625*^9, 
  3.4737430465*^9, 3.473744788296875*^9, 3.473745209015625*^9, 
  3.473745829484375*^9},
 CellLabel->"Out[164]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pts3", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"spheremf1", "[", 
       RowBox[{"s", ",", "t", ",", "u", ",", "p"}], "]"}], "[", 
      RowBox[{
       RowBox[{
        RowBox[{"uuu", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"uuu", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.47374228665625*^9, 3.47374230821875*^9}, 
   3.4737423659375*^9, {3.47374239921875*^9, 3.4737424341875*^9}, 
   3.4737424889375*^9, 3.473745829484375*^9},
 CellLabel->"In[188]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.6330817233938847`", ",", 
     RowBox[{"-", "0.039051589513239296`"}], ",", 
     RowBox[{"-", "0.15455677049881708`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.10688043225981052`", ",", "1.0115432409122713`", ",", 
     "0.00935501900229309`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.0779996554014127`", ",", "0.012151351757908452`", ",", 
     "0.6918690498700852`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.32596443721414914`", ",", "0.3084565243826496`", ",", 
     "0.33445657828523506`"}], "}"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.47374249096875*^9, 3.473743006421875*^9, 
  3.473743046546875*^9, 3.473744788328125*^9, 3.473745209484375*^9, 
  3.473745829484375*^9, 3.473745873328125*^9},
 CellLabel->"Out[188]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.9854402225078399`", ",", 
     RowBox[{"-", "0.052833350197923026`"}], ",", 
     RowBox[{"-", "0.09784472834507124`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.05200958500491086`", ",", "0.9243105717614619`", ",", 
     RowBox[{"-", "0.3028809496038892`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.027139910243026016`", ",", "0.04210256159614204`", ",", 
     "0.12008102636373104`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3061435942451275`", ",", "0.26178474500273136`", ",", 
     RowBox[{"-", "0.08548937206184352`"}]}], "}"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.47374249096875*^9, 3.473743006421875*^9, 
  3.473743046546875*^9, 3.473744788328125*^9, 3.473745209484375*^9, 
  3.473745829484375*^9},
 CellLabel->"Out[165]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"center", "[", "pts1", "]"}]], "Input",
 CellChangeTimes->{{3.473742499078125*^9, 3.473742508109375*^9}, 
   3.473745829484375*^9},
 CellLabel->"In[189]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.163665553182481`"}], ",", 
   RowBox[{"-", "0.18128425558435662`"}], ",", 
   RowBox[{"-", "0.7174793506395275`"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742509453125*^9, 3.473743006453125*^9, 
  3.473743046578125*^9, 3.473744788359375*^9, 3.47374520965625*^9, 
  3.473745829484375*^9, 3.47374587334375*^9},
 CellLabel->"Out[189]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.613185396900298`", ",", "4.053874834144129`", ",", 
   "7.507573916964044`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742509453125*^9, 3.473743006453125*^9, 
  3.473743046578125*^9, 3.473744788359375*^9, 3.47374520965625*^9, 
  3.473745829484375*^9},
 CellLabel->"Out[166]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"center", "[", "pts2", "]"}]], "Input",
 CellChangeTimes->{{3.473742499078125*^9, 3.473742521734375*^9}, 
   3.473745829484375*^9},
 CellLabel->"In[190]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.1636655531824796`"}], ",", 
   RowBox[{"-", "0.18128425558435626`"}], ",", 
   RowBox[{"-", "0.7174793506395271`"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.47374252296875*^9, 3.473743006484375*^9, 
  3.473743046609375*^9, 3.473744788390625*^9, 3.473745210625*^9, 
  3.473745829484375*^9, 3.473745873375*^9},
 CellLabel->"Out[190]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.6131853969003713`", ",", "4.0538748341442465`", ",", 
   "7.507573916964252`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.47374252296875*^9, 3.473743006484375*^9, 
  3.473743046609375*^9, 3.473744788390625*^9, 3.473745210625*^9, 
  3.473745829484375*^9},
 CellLabel->"Out[167]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"center", "[", "pts3", "]"}]], "Input",
 CellChangeTimes->{{3.47374253959375*^9, 3.473742545515625*^9}, 
   3.473745829484375*^9},
 CellLabel->"In[191]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.1636655531824809`"}], ",", 
   RowBox[{"-", "0.18128425558435687`"}], ",", 
   RowBox[{"-", "0.717479350639528`"}]}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742546578125*^9, 3.473743006515625*^9, 
  3.473743046640625*^9, 3.473744788421875*^9, 3.473745217578125*^9, 
  3.473745829484375*^9, 3.473745873421875*^9},
 CellLabel->"Out[191]="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.6131853969003145`", ",", "4.053874834144157`", ",", 
   "7.50757391696408`"}], "}"}]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742546578125*^9, 3.473743006515625*^9, 
  3.473743046640625*^9, 3.473744788421875*^9, 3.473745217578125*^9, 
  3.473745829484375*^9},
 CellLabel->"Out[168]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"radius", "[", "pts1", "]"}]], "Input",
 CellChangeTimes->{{3.473742554578125*^9, 3.473742563296875*^9}, 
   3.473745829484375*^9},
 CellLabel->"In[192]:="],

Cell[BoxData["1.8882300544198953`"], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742576578125*^9, 3.473743006546875*^9, 
  3.473743046671875*^9, 3.473744788453125*^9, 3.473745217609375*^9, 
  3.473745829484375*^9, 3.4737458734375*^9},
 CellLabel->"Out[192]="],

Cell[BoxData["8.795282783089776`"], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742576578125*^9, 3.473743006546875*^9, 
  3.473743046671875*^9, 3.473744788453125*^9, 3.473745217609375*^9, 
  3.473745829484375*^9},
 CellLabel->"Out[169]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"radius", "[", "pts2", "]"}]], "Input",
 CellChangeTimes->{{3.473742554578125*^9, 3.473742585*^9}, 
   3.473745829484375*^9},
 CellLabel->"In[193]:="],

Cell[BoxData["1.8882300544198936`"], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742586859375*^9, 3.473743006578125*^9, 
  3.473743046703125*^9, 3.473744788484375*^9, 3.473745217640625*^9, 
  3.473745829484375*^9, 3.47374587346875*^9},
 CellLabel->"Out[193]="],

Cell[BoxData["8.795282783090023`"], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742586859375*^9, 3.473743006578125*^9, 
  3.473743046703125*^9, 3.473744788484375*^9, 3.473745217640625*^9, 
  3.473745829484375*^9},
 CellLabel->"Out[170]="]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"radius", "[", "pts3", "]"}]], "Input",
 CellChangeTimes->{{3.473742554578125*^9, 3.47374260446875*^9}, 
   3.473745829484375*^9},
 CellLabel->"In[194]:="],

Cell[BoxData["1.888230054419895`"], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742606265625*^9, 3.473743006609375*^9, 
  3.47374304671875*^9, 3.473744788515625*^9, 3.473745217671875*^9, 
  3.473745829484375*^9, 3.4737458735*^9},
 CellLabel->"Out[194]="],

Cell[BoxData["8.795282783089824`"], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.473742606265625*^9, 3.473743006609375*^9, 
  3.47374304671875*^9, 3.473744788515625*^9, 3.473745217671875*^9, 
  3.473745829484375*^9},
 CellLabel->"Out[171]="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.5.5 Further Examples", "Subsubsection",
 CellChangeTimes->{{3.4736911413125*^9, 3.4736911431875*^9}, 
   3.473746266125*^9, {3.47374647078125*^9, 3.473746472125*^9}, {
   3.473746656375*^9, 3.473746659953125*^9}},
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{"unit3", "[", 
  RowBox[{"0", ",", "0", ",", "0"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[197]:="],

Cell["For Abs[p] > 1 we get an error message", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subspheremf", "[", 
   RowBox[{"0", ",", 
    RowBox[{
     RowBox[{"-", "Pi"}], "/", "2"}], ",", "0", ",", "2"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[198]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"spheremf1", "[", 
   RowBox[{"0", ",", 
    RowBox[{
     RowBox[{"-", "Pi"}], "/", "2"}], ",", "0", ",", "2"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 CellLabel->"In[199]:="],

Cell["and for Abs[p] = 1 we get a point only:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subspheremf", "[", 
   RowBox[{"0", ",", 
    RowBox[{
     RowBox[{"-", "Pi"}], "/", "2"}], ",", "0", ",", 
    RowBox[{"-", "1"}]}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"spheremf1", "[", 
   RowBox[{"0", ",", 
    RowBox[{
     RowBox[{"-", "Pi"}], "/", "2"}], ",", "0", ",", "1"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{3.473752914390625*^9},
 CellLabel->"In[45]:="],

Cell[BoxData[
 RowBox[{"unit3", "[", 
  RowBox[{"s", ",", "t", ",", 
   RowBox[{"Pi", "/", "2"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[47]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subspheremf", "[", 
   RowBox[{"s", ",", "t", ",", 
    RowBox[{"Pi", "/", "2"}], ",", "p"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[48]:="],

Cell["\<\
We may plot the sphere in the intersecting hyperplane by e.g.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"subspheremf", "[", 
       RowBox[{"0.4", ",", "0.3", ",", 
        RowBox[{"Pi", "/", "2"}], ",", "0.9"}], "]"}], "[", 
      RowBox[{"v", ",", "w"}], "]"}], ",", "3"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"w", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473753093328125*^9, 3.473753099171875*^9}},
 FontFamily->"Times",
 CellLabel->"In[49]:="],

Cell["\<\
The spheres generated by the following command all have center {0,0,0} with \
differing radii < 1:\
\>", "Text",
 CellChangeTimes->{{3.473754157140625*^9, 3.473754237328125*^9}, {
  3.473754292484375*^9, 3.473754305453125*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"Random", "[", "]"}]}], ";", 
  RowBox[{"b", "=", 
   RowBox[{"Random", "[", "]"}]}], ";", 
  RowBox[{"c", "=", 
   RowBox[{"Random", "[", "]"}]}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"subspheremf", "[", 
       RowBox[{"a", ",", "b", ",", 
        RowBox[{"Pi", "/", "2"}], ",", "c"}], "]"}], "[", 
      RowBox[{"v", ",", "w"}], "]"}], ",", "3"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"w", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]}], "Input",
 FontFamily->"Times",
 CellLabel->"In[97]:="],

Cell[BoxData[
 RowBox[{"uuu", ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Pi", "/", "2"}], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Pi", "/", "4"}], ",", 
      RowBox[{"Pi", "/", "4"}]}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.473486028049994*^9, 3.473486134159369*^9}, {
   3.473486167206244*^9, 3.473486212862494*^9}, 3.473745829484375*^9, {
   3.473753964359375*^9, 3.473753969859375*^9}},
 CellLabel->"In[99]:="],

Cell[BoxData[
 RowBox[{"pts", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"subspheremf", "[", 
        RowBox[{"a", ",", "b", ",", 
         RowBox[{"Pi", "/", "2"}], ",", "c"}], "]"}], "[", 
       RowBox[{
        RowBox[{
         RowBox[{"uuu", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"uuu", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], ",", "3"}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473741718171875*^9, 3.473741729484375*^9}, {
   3.473741768015625*^9, 3.473741821203125*^9}, {3.47374187471875*^9, 
   3.47374188159375*^9}, {3.47374194540625*^9, 3.47374203228125*^9}, {
   3.473742081453125*^9, 3.473742095046875*^9}, {3.473742130296875*^9, 
   3.473742147765625*^9}, {3.473742186*^9, 3.4737422029375*^9}, 
   3.473742274484375*^9, 3.473745829484375*^9, 3.473753502453125*^9, {
   3.47375355853125*^9, 3.4737536185625*^9}},
 CellLabel->"In[100]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"center", "[", "pts", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47375366134375*^9, 3.47375369534375*^9}},
 CellLabel->"In[101]:="],

Cell[BoxData[
 RowBox[{"radius", "[", "pts", "]"}]], "Input",
 CellChangeTimes->{{3.47375370040625*^9, 3.47375371259375*^9}, {
  3.47375381134375*^9, 3.473753824875*^9}, {3.47375409125*^9, 
  3.473754097375*^9}},
 CellLabel->"In[102]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ParametricPlot3D", "[", 
      RowBox[{
       RowBox[{"Take", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"subspheremf", "[", 
           RowBox[{"0.4", ",", "0.3", ",", 
            RowBox[{"Pi", "/", "2"}], ",", 
            RowBox[{"i", "/", "5"}]}], "]"}], "[", 
          RowBox[{"v", ",", "w"}], "]"}], ",", "3"}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"v", ",", " ", "0", ",", " ", 
         RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"w", ",", "0", ",", 
         RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47375432240625*^9, 3.4737543338125*^9}, {
  3.47375437009375*^9, 3.473754393375*^9}, {3.47375442425*^9, 
  3.473754514484375*^9}, {3.473754595875*^9, 3.473754622546875*^9}, {
  3.473754754375*^9, 3.47375478665625*^9}, {3.47375485421875*^9, 
  3.473754885125*^9}},
 CellLabel->"In[109]:="],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[110]:="],

Cell[BoxData[
 RowBox[{"hyperplane", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"stb", "[", "i", "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", "4"}], "}"}]}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[111]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ".", 
   RowBox[{"stb", "[", "4", "]"}]}], "\[Equal]", " ", 
  RowBox[{"%", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473755053109375*^9, 3.47375509928125*^9}},
 CellLabel->"In[112]:="],

Cell[TextData[{
 "It follows that the north pole stb[4] of the standard unit hypersphere ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 " belongs to the sphere"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], "/", "2"}], ",", 
    RowBox[{"1", "/", "2"}]}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{3.473763551984375*^9},
 CellLabel->"In[134]:="],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"subsphere", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], "/", "2"}], ",", 
       RowBox[{"1", "/", "2"}]}], "]"}], "[", 
     RowBox[{"v", ",", "w"}], "]"}], "\[Equal]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", "w"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4737612489375*^9, 3.473761306515625*^9}},
 FontFamily->"Times",
 CellLabel->"In[135]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"subsphere", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], "/", "2"}], ",", 
     RowBox[{"1", "/", "2"}]}], "]"}], "[", 
   RowBox[{"v", ",", "w"}], "]"}], "/.", "%"}]], "Input",
 CellChangeTimes->{{3.4737621045*^9, 3.47376211309375*^9}},
 CellLabel->"In[136]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sterproj", "[", 
    RowBox[{
     RowBox[{"subsphere", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], "/", "2"}], ",", 
       RowBox[{"1", "/", "2"}]}], "]"}], "[", 
     RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"w", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[137]:="],

Cell[TextData[{
 "Since the sphere containes the north pole of the hypersphere ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 " we got by stereographic projection sterproj  a plane of the ",
 "Euclidean",
 " 3-space. The next example is the standard unit sphere in the 3-space (the \
equatorial sphere of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{3.47297184703125*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", "0"}], "]"}], 
  "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[214]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{
   RowBox[{"subsphere", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", "0"}], "]"}], 
   "[", 
   RowBox[{"v", ",", "w"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[215]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sterproj", "[", 
    RowBox[{
     RowBox[{"subsphere", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}], ",", "0"}], "]"}],
      "[", 
     RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"w", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47376395609375*^9, 3.473763968890625*^9}},
 FontFamily->"Times",
 CellLabel->"In[139]:="],

Cell["Let us create a configuration of spheres:", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ParametricPlot3D", "[", 
      RowBox[{
       RowBox[{"sterproj", "[", 
        RowBox[{
         RowBox[{"subspheremf", "[", 
          RowBox[{
           RowBox[{"i", " ", "*", "2", "*", 
            RowBox[{"Pi", "/", "5"}]}], ",", "0", ",", "0", ",", " ", "0.9"}],
           "]"}], "[", 
         RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", "\n", "\t\t\t", 
       RowBox[{"{", 
        RowBox[{"v", ",", " ", "0", ",", " ", 
         RowBox[{"2", "Pi"}]}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"w", ",", 
         RowBox[{
          RowBox[{"-", "Pi"}], "/", "2"}], ",", 
         RowBox[{"Pi", "/", "2"}]}], "}"}]}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", "5"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472394107067989*^9, 3.472394125703874*^9}, {
   3.473763997078125*^9, 3.473764024125*^9}, {3.4739186418125*^9, 
   3.4739186914375*^9}, 3.473918777234375*^9},
 FontFamily->"Times",
 CellLabel->"In[42]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["3.5.6 Sphere through four points via hyperplane", "Subsubsection",
 CellChangeTimes->{{3.47369115715625*^9, 3.473691159078125*^9}, {
   3.473746688421875*^9, 3.4737466899375*^9}, 3.473764217*^9},
 FontFamily->"Times"],

Cell["\<\
The following Module combines  stereographic projection, hyperplane and \
subsphere to get a parameter representation of the sphere through four points \
of the Euclidean 3-space: \
\>", "Text",
 CellChangeTimes->{3.47297184709375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"sphere4pts", "[", "pt_List", "]"}], "[", 
   RowBox[{"v_", ",", "w_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", "\n", "\t\t\t", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "pt", "]"}], " ", "!=", "4"}], ")"}], " ", "||", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", 
           RowBox[{"pt", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], " ", "!=", " ", "3"}], 
         ")"}]}], ",", " ", 
       RowBox[{
        RowBox[{"Print", "[", "\"\<Incorrect arguments!!!\>\"", "]"}], ";", 
        "\t", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\n", "\t\t\t", 
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"invsterproj", "[", 
         RowBox[{"pt", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"i", ",", "4"}], "}"}]}], "]"}]}], ";", "\n", "\t\t\t", 
     RowBox[{"b", " ", "=", " ", 
      RowBox[{"hyperplane", "[", "a", "]"}]}], ";", "\n", "\t\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"b", "==", " ", "Null"}], ",", " \t", 
       RowBox[{"Return", "[", "]"}]}], "]"}], ";", "\n", "\t\t\t", 
     RowBox[{"Return", "[", 
      RowBox[{"sterproj", "[", 
       RowBox[{
        RowBox[{"subsphere", "[", 
         RowBox[{
          RowBox[{"b", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
          RowBox[{"b", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "[", 
        RowBox[{"v", ",", "w"}], "]"}], "]"}], "]"}]}]}], "\n", 
   "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[126]:="],

Cell["This gives, of course, the standard unit sphere:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere4pts", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"stb", "[", 
      RowBox[{"1", ",", " ", "3"}], "]"}], ",", " ", 
     RowBox[{"stb", "[", 
      RowBox[{"2", ",", "3"}], "]"}], ",", 
     RowBox[{"stb", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", " ", 
     RowBox[{"-", 
      RowBox[{"stb", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}]}], "}"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[127]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"w", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "->", " ", "All"}], ",", " ", "\n", 
   RowBox[{"PlotPoints", " ", "->", " ", "50"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[128]:="],

Cell[BoxData[
 RowBox[{"ptslist", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"1", ",", " ", "3"}], "]"}], ",", " ", 
    RowBox[{"stb", "[", 
     RowBox[{"2", ",", "3"}], "]"}], ",", 
    RowBox[{"stb", "[", 
     RowBox[{"3", ",", "3"}], "]"}], ",", " ", 
    RowBox[{"2", "  ", 
     RowBox[{"stb", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}]}], "}"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[129]:="],

Cell[BoxData[
 RowBox[{"pts", " ", "=", 
  RowBox[{"Map", "[", 
   RowBox[{"Point", ",", "ptslist"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[130]:="],

Cell[BoxData[
 RowBox[{"grpts", " ", "=", "  ", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PointSize", "[", "0.02", "]"}], "}"}], ",", "pts"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.47239443258566*^9, 3.472394440355082*^9}, 
   3.472394546399192*^9},
 FontFamily->"Times",
 CellLabel->"In[138]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere4pts", "[", "ptslist", "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[134]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"w", ",", " ", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "->", " ", "All"}], ",", " ", "\n", 
   RowBox[{"PlotPoints", " ", "->", " ", "40"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Opacity", "[", ".3", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.47239447244447*^9, 3.472394498009863*^9}},
 FontFamily->"Times",
 CellLabel->"In[135]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sph4pt", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472394515615709*^9},
 FontFamily->"Times",
 CellLabel->"In[136]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"sph4pt", ",", "grpts"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[140]:="],

Cell["The next three examples return only messages...", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere4pts", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"stb", "[", 
      RowBox[{"1", ",", " ", "3"}], "]"}], ",", " ", 
     RowBox[{"stb", "[", 
      RowBox[{"2", ",", "3"}], "]"}], ",", 
     RowBox[{"stb", "[", 
      RowBox[{"3", ",", "3"}], "]"}], ",", " ", 
     RowBox[{"stb", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}], "}"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[141]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere4pts", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"stb", "[", "1", "]"}], ",", " ", 
     RowBox[{"stb", "[", "3", "]"}], ",", 
     RowBox[{"stb", "[", "3", "]"}], ",", " ", 
     RowBox[{"-", 
      RowBox[{"stb", "[", "3", "]"}]}]}], "}"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[142]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere4pts", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"stb", "[", "1", "]"}], ",", " ", 
     RowBox[{"stb", "[", "3", "]"}], ",", 
     RowBox[{"stb", "[", "3", "]"}]}], "}"}], "]"}], "[", 
  RowBox[{"v", ",", "w"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[143]:="],

Cell["\<\
If wanted one can insert sphere4pts[] in a plot command and get the picture \
of the sphere through four points by\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pt4sphere", "[", 
   RowBox[{"pt_List", ",", "opt___"}], "]"}], " ", ":=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"sphere4pts", "[", "pt", "]"}], "[", 
      RowBox[{"v", ",", "w"}], "]"}], "]"}], ",", "\n", "\t\t", 
    RowBox[{"{", 
     RowBox[{"v", ",", " ", "0", ",", " ", 
      RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"w", ",", " ", 
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", "opt"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[144]:="],

Cell[BoxData[
 RowBox[{"pt4sphere", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.5", ",", " ", "1", ",", " ", "2."}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", " ", "1.5", ",", " ", "0.7"}], "}"}], ",", 
     " ", 
     RowBox[{"{", 
      RowBox[{"2.", ",", " ", "1.", ",", " ", "0."}], "}"}], ",", " ", 
     RowBox[{"stb", "[", 
      RowBox[{"3", ",", "3"}], "]"}]}], "}"}], ",", "\n", 
   RowBox[{"PlotPoints", " ", "->", " ", "50"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[145]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ttgr", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472394795170335*^9},
 FontFamily->"Times",
 CellLabel->"In[146]:="],

Cell[BoxData[
 RowBox[{"pts", " ", "=", 
  RowBox[{"Map", "[", 
   RowBox[{"Point", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.5", ",", " ", "1", ",", " ", "2."}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", " ", "1.5", ",", " ", "0.7"}], "}"}], ",", 
      " ", 
      RowBox[{"{", 
       RowBox[{"2.", ",", " ", "1.", ",", " ", "0."}], "}"}], ",", " ", 
      RowBox[{"stb", "[", 
       RowBox[{"3", ",", "3"}], "]"}]}], "}"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[147]:="],

Cell[BoxData[
 RowBox[{"grptts", " ", "=", "  ", 
  RowBox[{"Graphics3D", "[", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"PointSize", "[", "0.03", "]"}], "}"}], ",", "pts"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.472394821889786*^9, 3.472394852555806*^9}},
 FontFamily->"Times",
 CellLabel->"In[150]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"ttgr", ",", "grptts"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[151]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4 Stereographic projection", "Section",
 CellChangeTimes->{3.4734004473125*^9, 3.47383938096875*^9},
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell[TextData[{
 StyleBox["We want to visualize the geometry of the 3-sphere ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 StyleBox[". By stereographic projection we go to the ",
  FontSize->14],
 "Euclidean",
 StyleBox[" 3-space ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 StyleBox[". Then we apply the 3D-graphics tools of ",
  FontSize->14],
 StyleBox["Mathematica",
  FontSize->14,
  FontSlant->"Italic"],
 StyleBox[". For this and other applications we construct a module for  the \
stereographic projection in  dimension n,  and another for its inversion. We \
show that these maps are conformal, and preserve k-spheres. The maps are \
applied to study spheres and tori in ",
  FontSize->14],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{
  3.472971846578125*^9, {3.4739174704375*^9, 3.473917471046875*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.1  Definition of the general stereographic projection", "Subsection",
 FontFamily->"Times",
 FontSize->14],

Cell[TextData[StyleBox["Here is a definition of the general stereographic \
projection of the n-sphere \\ north pole onto the n-dimensional Euclidean \
space. We put the north pole at the point  stb[n+1] and project onto the \
equatorial hyperplane; the north pole N itself is projected to Infinity. The \
geometric definition is: The point x \[NotEqual] N is mapped on the \
intersection of the line x\[Or]N with the equatorial hyperplane H:",
 FontSize->14]], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.47340331390625*^9, 3.4734033364375*^9}, {
  3.473403370890625*^9, 3.4734033944375*^9}},
 FontSize->12,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False},
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 RowBox[{"?", "sterproj"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[115]:="],

Cell["The definition contained in the package euvec.m is:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sterproj", "[", "v_List", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "=", 
       RowBox[{"Length", "[", "v", "]"}]}], ",", "l", ",", "w"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"l", "=", 
      RowBox[{"null", "[", "m", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"w", "=", 
      RowBox[{"v", "[", 
       RowBox[{"[", "m", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"smoothing", "[", 
         RowBox[{"w", "-", "1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "<", "m"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"l", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "=", "Infinity"}]}], "]"}], ",", 
       RowBox[{"l", "=", 
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"stb", "[", 
           RowBox[{"m", ",", "m"}], "]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "-", 
             RowBox[{"stb", "[", 
              RowBox[{"m", ",", "m"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", "w"}], ")"}]}]}], "]"}]}], ",", 
       RowBox[{"l", "=", 
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"stb", "[", 
           RowBox[{"m", ",", "m"}], "]"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"v", "-", 
             RowBox[{"stb", "[", 
              RowBox[{"m", ",", "m"}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", "w"}], ")"}]}]}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"l", "=", 
      RowBox[{"Take", "[", 
       RowBox[{"l", ",", 
        RowBox[{"m", "-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     "l"}]}], "]"}]}]], "Input",
 Evaluatable->False,
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Examples", "Subsubsection"]], "Subsubsection",
 FontFamily->"Times"],

Cell[BoxData[
 RowBox[{"stb", "[", 
  RowBox[{"1", ",", "3"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[116]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{"stb", "[", 
   RowBox[{"1", ",", "3"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[117]:="],

Cell[BoxData[
 RowBox[{"?", "unit"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[118]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"unit", "[", "2", "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"s", ",", "t"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[119]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{
   RowBox[{"unit", "[", "2", "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t"}], "}"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[120]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"testvec", "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], " ", "=", " ", 
  RowBox[{"AppendTo", "[", 
   RowBox[{"%", ",", " ", "0"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[121]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"ParametricPlot", "[", 
    RowBox[{"%%", ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "0", ",", 
       RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "Pi"}], "/", "2"}], "+", "0.0001"}], ",", " ", "0", ",", 
     RowBox[{"Pi", "/", "20"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472366756833981*^9, 3.472366763466512*^9}, {
   3.472366804013916*^9, 3.472367006228715*^9}, 3.472367133618051*^9},
 CellLabel->"In[122]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472367028350012*^9, 3.472367079907961*^9}},
 CellLabel->"In[123]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"testvec", "[", 
    RowBox[{"s", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", " ", "Pi"}], "/", "2"}], "+", "0.0000001"}], ",", "0"}], 
    "}"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[124]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{
   RowBox[{"unit", "[", "3", "]"}], "[", 
   RowBox[{"{", 
    RowBox[{"s", ",", "t", ",", "u"}], "}"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[125]:="],

Cell["\<\
WARNING! Without any message sterproj gives  incorrect results for  not \
normalized arguments:\
\>", "Text",
 CellChangeTimes->{{3.47340419325*^9, 3.473404206453125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", "=", "4"}], ";"}]], "Input",
 CellChangeTimes->{{3.473404374625*^9, 3.47340438565625*^9}},
 CellLabel->"In[137]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{
   RowBox[{"stb", "[", "2", "]"}], " ", "+", 
   RowBox[{"stb", "[", "4", "]"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[138]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"stb", "[", "2", "]"}], " ", "+", 
     RowBox[{"stb", "[", "4", "]"}]}], ")"}], "/", 
   RowBox[{"Sqrt", "[", "2.", "]"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[139]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{"null", "[", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[140]:="],

Cell["\<\
The image of the north pole stb[n,n]  is the infinite point, e.g. \
\>", "Text"],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{"stb", "[", 
   RowBox[{"3", ",", "3"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[141]:="],

Cell["\<\
The other basis vectors are \"preserved\" in the equatorial hyperplane, e.g.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"stb", "[", 
  RowBox[{"3", ",", "7"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[142]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{"stb", "[", 
   RowBox[{"3", ",", "7"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[143]:="],

Cell["The general formula is: ", "Text"],

Cell[BoxData[
 RowBox[{"vec", "[", "n", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[144]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{"vec", "[", "n", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[145]:="],

Cell["The elements of the equator remain fixed:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"vec", "[", "n", "]"}], " ", "-", " ", 
  RowBox[{
   RowBox[{"n", "[", "4", "]"}], "*", 
   RowBox[{"stb", "[", "4", "]"}]}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[146]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"vec", "[", "n", "]"}], " ", "-", " ", 
    RowBox[{
     RowBox[{"n", "[", "4", "]"}], "*", 
     RowBox[{"stb", "[", "4", "]"}]}]}], ")"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[147]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2 The inverse stereographic projection", "Subsection",
 FontFamily->"Times",
 FontSize->14,
 FontVariations->{"CompatibilityType"->0}],

Cell["\<\
By its geometric definition, the stereographic projection is bijective. The \
following function maps an arbitrary point of the equatorial hyperplane to \
its preimage under the stereographic projection:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"?", "invsterproj"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[148]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"invsterproj", "[", "y_List", "]"}], ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "=", 
       RowBox[{
        RowBox[{"Length", "[", "y", "]"}], "+", "1"}]}], ",", 
      RowBox[{"x", "=", 
       RowBox[{"Append", "[", 
        RowBox[{"y", ",", "0"}], "]"}]}], ",", " ", 
      RowBox[{"u", "=", 
       RowBox[{"y", ".", "y"}]}]}], "}"}], ",", "\n", "\t\t", 
    RowBox[{
     RowBox[{"x", "*", 
      RowBox[{"2", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "u"}], ")"}]}]}], " ", "+", 
     RowBox[{
      RowBox[{"stb", "[", 
       RowBox[{"n", ",", "n"}], "]"}], "*", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"u", "-", "1"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"u", "+", "1"}], ")"}]}]}]}]}], "]"}]}]], "Input",
 Evaluatable->False,
 FontFamily->"Times",
 CellLabel->"In[9]:="],

Cell[BoxData[
 RowBox[{"invsterproj", "[", 
  RowBox[{"vec", "[", 
   RowBox[{"y", ",", "3"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[149]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", ".", "%"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[150]:="],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
 FontFamily->"Times"],

Cell["Simple tests", "Text"],

Cell[BoxData[
 RowBox[{"invsterproj", "[", 
  RowBox[{"null", "[", "4", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[151]:="],

Cell["Lines are mapped onto circles", "Text"],

Cell[BoxData[
 RowBox[{"invsterproj", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "t"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[152]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["2", 
      RowBox[{"2", "+", 
       SuperscriptBox["t", "2"]}]], ",", 
     FractionBox[
      RowBox[{"2", " ", "t"}], 
      RowBox[{"2", "+", 
       SuperscriptBox["t", "2"]}]], ",", 
     FractionBox[
      SuperscriptBox["t", "2"], 
      RowBox[{"2", "+", 
       SuperscriptBox["t", "2"]}]]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", 
     RowBox[{"-", "100"}], ",", " ", "100"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "1000"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[153]:="],

Cell["A circle is mapped on a circle, too:", "Text"],

Cell[BoxData[
 RowBox[{"invsterproj", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"1", ",", "2"}], "]"}], 
    RowBox[{"Cos", "[", "t", "]"}]}], "+", 
   RowBox[{
    RowBox[{"stb", "[", 
     RowBox[{"2", ",", "2"}], "]"}], 
    RowBox[{"Sin", "[", "t", "]"}]}], "+", 
   RowBox[{"stb", "[", 
    RowBox[{"2", ",", "2"}], "]"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[162]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", " ", "\[Rule]", " ", "200"}]}], "]"}]], "Input",
 CellLabel->"In[163]:="],

Cell["We control that the functions are inverse to each other:", "Text"],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{"invsterproj", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"stb", "[", "1", "]"}], 
     RowBox[{"Cos", "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"stb", "[", "2", "]"}], 
     RowBox[{"Sin", "[", "t", "]"}]}], "+", 
    RowBox[{"stb", "[", "4", "]"}]}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[164]:="],

Cell[BoxData[
 RowBox[{"sterproj", "[", 
  RowBox[{"invsterproj", "[", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[165]:="],

Cell[BoxData[
 RowBox[{"invsterproj", "[", 
  RowBox[{"sterproj", "[", "%", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[166]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[167]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["b", "2"], "+", 
     SuperscriptBox["c", "2"]}], " ", "\[Rule]", " ", 
    RowBox[{"1", "-", 
     SuperscriptBox["d", "2"]}]}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[168]:="],

Cell["We remember the warning", "Text"],

Cell[BoxData[
 RowBox[{"?", "sterproj"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[161]:="]
}, Closed]]
}, Closed]],

Cell["4.3 Properties of the stereographic projection", "Subsection",
 CellChangeTimes->{{3.472367669465853*^9, 3.472367672886674*^9}, 
   3.472372693363315*^9},
 FontFamily->"Times",
 FontSize->14,
 FontVariations->{"CompatibilityType"->0}],

Cell[CellGroupData[{

Cell[" 4.3.1 Invariance of k-spheres", "Subsection",
 CellChangeTimes->{{3.473519180234375*^9, 3.4735191831875*^9}, 
   3.47357905778125*^9}],

Cell["\<\
The stereographic projection maps hyperspheres of the n-sphere onto \
Hyperspheres or hyperplanes. It follows, that k-spheres, being intersections \
of hyperspheres, are mapped onto k-spheres or k-planes.  The image of a \
k-sphere is a k-plane iff the north pole of the stereographic projection is \
contained in the k-sphere. We shall demonstrate the first statement in case \
of the 3-sphere. Any sphere contained in the 3-sphere is the intersection of \
a hyperplane in the 4-space with the 3-sphere. We consider a random subsphere \
as the intersection of a random hyperplane with the unit 3-sphere, find its \
parameter representation, and plot its stereographic projection. Evaluate the \
next subsection!\
\>", "Text",
 CellChangeTimes->{
  3.472370173965382*^9, 3.47297184665625*^9, 3.47340489434375*^9, {
   3.4734051066875*^9, 3.473405131171875*^9}, {3.47340516546875*^9, 
   3.4734052089375*^9}, {3.473568072125*^9, 3.4735681055*^9}, 
   3.47356904234375*^9, 3.473569395453125*^9, {3.47356950671875*^9, 
   3.473569524703125*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["A random subsphere", "Subsubsection"]], \
"Subsubsection",
 CellChangeTimes->{3.473569109359375*^9}],

Cell["\<\
Evaluating this subsection one always gets a random sphere in the Euclidean \
3-space and calculates  its center and its radius. This does not prove, but \
confirms the statement.
We first define the equation of such a random hyperplane. The next cell \
produces a random point of the 3-sphere, being its normal at this point,too:\
\>", "Text",
 CellChangeTimes->{
  3.472370173965382*^9, 3.47297184665625*^9, 3.47340489434375*^9, {
   3.4734051066875*^9, 3.473405131171875*^9}, {3.47340516546875*^9, 
   3.4734052089375*^9}, {3.473568072125*^9, 3.4735681055*^9}, {
   3.47356904234375*^9, 3.473569099515625*^9}, {3.47356940521875*^9, 
   3.4735694933125*^9}}],

Cell[BoxData[
 RowBox[{"normal", "=", 
  RowBox[{"unit", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "Pi", " ", 
      RowBox[{"Random", "[", "]"}]}], ",", 
     RowBox[{"2", "*", "Pi", " ", 
      RowBox[{"Random", "[", "]"}]}], ",", " ", 
     RowBox[{"2", "*", "Pi", " ", 
      RowBox[{"Random", "[", "]"}]}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473494027799994*^9, 3.473494043581244*^9}, 
   3.473494076518744*^9},
 CellLabel->"In[96]:="],

Cell[" random distance parameter pn, 0 < pn < 1, is obtained by", "Text",
 CellChangeTimes->{{3.47340522665625*^9, 3.473405261484375*^9}}],

Cell[BoxData[
 RowBox[{"pn", " ", "=", 
  RowBox[{
   RowBox[{"Random", "[", "]"}], "*", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "^", 
    RowBox[{"RandomInteger", "[", "]"}], " "}]}]}]], "Input",
 CellChangeTimes->{{3.47356959971875*^9, 3.47356961878125*^9}, {
  3.47356973553125*^9, 3.473569763875*^9}},
 CellLabel->"In[97]:="],

Cell["\<\
The radius of the 2-sphere defined as the intersection of the hyperplane\
\>", "Text",
 CellChangeTimes->{{3.473405323875*^9, 3.47340536396875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"normal", " ", ".", 
   RowBox[{"vec", "[", 
    RowBox[{"x", ",", "4"}], "]"}]}], " ", "\[Equal]", " ", "pn"}]], "Input",
 CellChangeTimes->{{3.4734053780625*^9, 3.473405405875*^9}},
 CellLabel->"In[98]:="],

Cell["is given by ", "Text",
 CellChangeTimes->{{3.473405424921875*^9, 3.473405429203125*^9}}],

Cell[BoxData[
 RowBox[{"rn", " ", "=", " ", 
  RowBox[{"Sqrt", "[", 
   RowBox[{"1", "-", 
    RowBox[{"pn", "^", "2"}]}], "]"}]}]], "Input",
 CellLabel->"In[99]:="],

Cell[TextData[{
 "The parameter representation of the corresponding subsphere of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " \[Subset]",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["E", "4"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is obtained by"
}], "Text",
 CellChangeTimes->{{3.4734055590625*^9, 3.47340560065625*^9}, 
   3.473494692190619*^9, {3.473568263609375*^9, 3.473568367640625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphn", "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"subsphere", "[", 
     RowBox[{"normal", ",", "pn"}], "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.47340563778125*^9, 3.473405684515625*^9}, {
   3.473405765578125*^9, 3.473405788515625*^9}, 3.47340897515625*^9, {
   3.473409246375*^9, 3.473409259859375*^9}},
 CellLabel->"In[100]:="],

Cell["\<\
Here is its image sphere as a  Plot of the stereographical projection:\
\>", "Text",
 CellChangeTimes->{{3.47356840009375*^9, 3.473568422171875*^9}, {
  3.473568533671875*^9, 3.47356858296875*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sterproj", "[", 
    RowBox[{"sphn", "[", 
     RowBox[{"s", ",", "t"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "80"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellLabel->"In[101]:="],

Cell["\<\
The projection distorts the surface of the sphere,  but under this \
transformation the coordinate lines being circles are transformed into \
circles  intersecting orthogonally. Sometimes, by numerical reasons, the \
shape of the image appears as a deformed sphere. To calculate  thr center and \
the radius of the image sphere we choose four random points of the sphere and \
apply the functions center and radius\
\>", "Text",
 CellChangeTimes->{{3.4735684791875*^9, 3.4735685164375*^9}, {
  3.4735686086875*^9, 3.47356881009375*^9}, {3.47356995353125*^9, 
  3.473570072359375*^9}, {3.473570497984375*^9, 3.473570523734375*^9}}],

Cell[BoxData[
 RowBox[{"rv", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"sterproj", "[", 
      RowBox[{"sphn", "[", 
       RowBox[{"s", ",", "t"}], "]"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{
         RowBox[{"Random", "[", "]"}], "*", 
         RowBox[{"Pi", "/", "2"}]}]}], ",", 
       RowBox[{"t", "\[Rule]", 
        RowBox[{
         RowBox[{"Random", "[", "]"}], "*", "2", "*", "Pi"}]}]}], "}"}]}], 
    ",", 
    RowBox[{"{", "4", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.47340946534375*^9, 3.473409481296875*^9}, {
  3.4734095148125*^9, 3.473409528609375*^9}, {3.473409560953125*^9, 
  3.473409634515625*^9}},
 CellLabel->"In[102]:="],

Cell[BoxData[
 RowBox[{"crv", " ", "=", " ", 
  RowBox[{"center", "[", "rv", "]"}]}]], "Input",
 CellChangeTimes->{{3.47340965078125*^9, 3.473409693015625*^9}},
 CellLabel->"In[103]:="],

Cell[BoxData[
 RowBox[{"rrv", "=", 
  RowBox[{"radius", "[", "rv", "]"}]}]], "Input",
 CellChangeTimes->{{3.473409701046875*^9, 3.473409721296875*^9}},
 CellLabel->"In[104]:="],

Cell["\<\
Now applying the standard sphereplot module an undistorted  representation of \
the image sphere is obtained:\
\>", "Text",
 CellChangeTimes->{{3.47357010865625*^9, 3.47357022475*^9}}],

Cell[BoxData[
 RowBox[{"sphereplot3D", "[", 
  RowBox[{"crv", ",", "rrv"}], "]"}]], "Input",
 CellChangeTimes->{{3.473409729953125*^9, 3.47340976921875*^9}},
 CellLabel->"In[105]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The random points  method", "Subsubsection",
 CellChangeTimes->{{3.473569168953125*^9, 3.47356917396875*^9}, {
  3.473570608421875*^9, 3.473570622*^9}}],

Cell["\<\
Using four random points we obtain a parameter representation of the image of \
a subsphere under stereographical projection:\
\>", "Text",
 CellChangeTimes->{{3.473494481284369*^9, 3.473494568706244*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"subsphere3Drm", "[", 
    RowBox[{"nn_List", ",", "pp_"}], "]"}], "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"par", ",", "s", ",", "t", ",", "rmpar", ",", "cc", ",", "rr"}], 
     " ", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"par", "[", 
       RowBox[{"s_", ",", "t_"}], "]"}], "=", 
      RowBox[{
       RowBox[{"subsphere", "[", 
        RowBox[{"nn", ",", "pp"}], "]"}], "[", 
       RowBox[{"s", ",", "t"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"rmpar", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"sterproj", "[", 
         RowBox[{
          RowBox[{"par", "[", 
           RowBox[{"s", ",", "t"}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"s", "\[Rule]", 
             RowBox[{
              RowBox[{"Random", "[", "]"}], "*", 
              RowBox[{"Pi", "/", "2"}]}]}], ",", 
            RowBox[{"t", "\[Rule]", 
             RowBox[{
              RowBox[{"Random", "[", "]"}], "*", "2", "*", "Pi"}]}]}], 
           "}"}]}], "]"}], ",", 
        RowBox[{"{", "4", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"cc", " ", "=", " ", 
      RowBox[{"center", "[", "rmpar", "]"}]}], ";", 
     RowBox[{"rr", " ", "=", " ", 
      RowBox[{"radius", "[", "rmpar", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sphere", "[", 
       RowBox[{"cc", ",", "rr"}], "]"}], "[", 
      RowBox[{"u", ",", "v"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473409884015625*^9, 3.473409961359375*^9}, {
   3.473410009515625*^9, 3.473410089453125*^9}, {3.4734101225625*^9, 
   3.47341021821875*^9}, 3.473410253921875*^9, 3.473410444078125*^9, {
   3.473410482578125*^9, 3.473410507546875*^9}, 3.47341204390625*^9, {
   3.473482823846869*^9, 3.473482847065619*^9}, {3.473483098815619*^9, 
   3.473483106549994*^9}, 3.47351808440625*^9, 3.473574226046875*^9, {
   3.473578029171875*^9, 3.473578034671875*^9}},
 CellLabel->"In[174]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphere3Drm", "[", 
   RowBox[{"normal", ",", "pn"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.473412093921875*^9, 3.47341212246875*^9}, 
   3.473518095265625*^9, 3.4735742260625*^9},
 CellLabel->"In[175]:="],

Cell["The corresponding plot function is defined by", "Text",
 CellChangeTimes->{{3.473494751096869*^9, 3.473494770784369*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphereplot3Drm", "[", 
   RowBox[{"nn_List", ",", "p_", ",", 
    RowBox[{"u0_:", "0"}], ",", 
    RowBox[{"u1_:", "2", "*", "Pi"}], ",", 
    RowBox[{"v0_:", "-", 
     RowBox[{"Pi", "/", "2"}]}], ",", 
    RowBox[{"v1_:", 
     RowBox[{"Pi", "/", "2"}]}], ",", "opts___"}], "]"}], ":=", " ", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"subsphere3Drm", "[", 
      RowBox[{"nn", ",", "p"}], "]"}], "[", 
     RowBox[{"u", ",", "v"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"u", ",", "u0", ",", "u1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"v", ",", "v0", ",", "v1"}], "}"}], ",", "opts"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.473482362940619*^9, 3.473482629190619*^9}, {
   3.473482720393744*^9, 3.473482720878119*^9}, {3.473482922909369*^9, 
   3.473482939518744*^9}, 3.4735060330625*^9, 3.473518113125*^9, 
   3.4735742260625*^9, 3.47357442984375*^9},
 CellLabel->"In[176]:="],

Cell["\<\
Of course, we obtain the same sphere; the image is always free from \
numerically caused distortions:\
\>", "Text",
 CellChangeTimes->{{3.473495025065619*^9, 3.473495042159369*^9}, {
  3.473577857703125*^9, 3.473577909953125*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"subsphereplot3Drm", "[", 
   RowBox[{"normal", ",", "pn"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473494792878119*^9, 3.473494822174994*^9}, {
   3.47351787928125*^9, 3.473517899453125*^9}, 3.47357442984375*^9},
 CellLabel->"In[177]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473518161234375*^9, 3.473518182109375*^9}, {
  3.473574551015625*^9, 3.47357455265625*^9}},
 CellLabel->"In[178]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The 4 points method", "Subsubsection",
 CellChangeTimes->{{3.473574693421875*^9, 3.47357470415625*^9}}],

Cell["\<\
To avoid the random points we evaluate subsphere at four given points. To \
this aim we first define a help function\
\>", "Text",
 CellChangeTimes->{{3.473495108659369*^9, 3.473495177971869*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"subspheremfL", "[", 
    RowBox[{"u_", ",", "v_", ",", "w_", ",", "p_"}], "]"}], "[", "uu_List", 
   "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"subspheremf", "[", 
    RowBox[{"u", ",", "v", ",", "w", ",", "p"}], "]"}], "[", 
   RowBox[{
    RowBox[{"uu", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"uu", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473487527424994*^9, 3.473487555690619*^9}, {
  3.473487601831244*^9, 3.473487682831244*^9}, {3.473487857831244*^9, 
  3.473487871159369*^9}, {3.473487975081244*^9, 3.473487980487494*^9}, {
  3.47350490546875*^9, 3.47350497771875*^9}},
 CellLabel->"In[116]:="],

Cell["We fix four points with the spherical coordinates", "Text",
 CellChangeTimes->{{3.473495662831244*^9, 3.473495672534369*^9}, {
  3.473576254078125*^9, 3.47357627525*^9}}],

Cell[BoxData[
 RowBox[{"uuu", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"Pi", "/", "2"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Pi", "/", "2"}], ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Pi", "/", "4"}], ",", 
      RowBox[{"Pi", "/", "4"}]}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.473486028049994*^9, 3.473486134159369*^9}, {
  3.473486167206244*^9, 3.473486212862494*^9}},
 CellLabel->"In[117]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Map", "[", 
   RowBox[{"sterproj", ",", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{"subspheremfL", "[", 
       RowBox[{"u", ",", "v", ",", "w", ",", "p"}], "]"}], ",", "uuu"}], 
     "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.47357600534375*^9, 3.473576042328125*^9}, {
   3.47357613475*^9, 3.473576145828125*^9}, 3.47357622528125*^9, {
   3.47357632646875*^9, 3.47357634984375*^9}, {3.4735766755*^9, 
   3.473576675984375*^9}},
 CellLabel->"In[146]:="],

Cell["\<\
Choosing the last Output as the right sede of the next definition we obtain a \
family of four points in the Euclidean 3-space being images of the spherical \
projection of the subsphere  corresponding to u,v,w,p:\
\>", "Text",
 CellChangeTimes->{{3.47357684190625*^9, 3.473577028984375*^9}, {
  3.473577233703125*^9, 3.4735772661875*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"u", ",", " ", "v", ",", " ", "w", ",", " ", "p"}], "]"}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sphpic", "[", 
   RowBox[{"u_", ",", " ", "v_", ",", " ", "w_", ",", " ", "p_"}], "]"}], " ",
   ":=", " ", "\n", "   ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"p", "*", 
          RowBox[{"Cos", "[", "u", "]"}], "*", 
          RowBox[{"Cos", "[", "v", "]"}], "*", 
          RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"p", "^", "2"}]}], "]"}], "*", 
          RowBox[{"Sin", "[", "u", "]"}]}]}], ")"}], "/", "\n", "      ", 
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ",", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"p", "^", "2"}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "u", "]"}]}], " ", "-", " ", "\n", "       ", 
         RowBox[{"p", "*", 
          RowBox[{"Cos", "[", "v", "]"}], "*", 
          RowBox[{"Cos", "[", "w", "]"}], "*", 
          RowBox[{"Sin", "[", "u", "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ",", " ", "\n", 
      "     ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"p", "*", 
         RowBox[{"Cos", "[", "w", "]"}], "*", 
         RowBox[{"Sin", "[", "v", "]"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], "}"}], ",", " ", 
    "\n", "    ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "u", "]"}], "*", 
         RowBox[{"Cos", "[", "v", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "p"}], ")"}], "*", 
            RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"p", "^", "2"}]}], "]"}], "*", 
            RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ")"}], "/", "\n", 
       "      ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"p", "^", "2"}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ",", " ", "\n", 
      "     ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "v", "]"}], "*", 
         RowBox[{"Sin", "[", "u", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "p"}], ")"}], "*", 
            RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"p", "^", "2"}]}], "]"}], "*", 
            RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ")"}], "/", "\n", 
       "      ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"p", "^", "2"}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ",", " ", "\n", 
      "     ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sin", "[", "v", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "p"}], ")"}], "*", 
            RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"p", "^", "2"}]}], "]"}], "*", 
            RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ")"}], "/", "\n", 
       "      ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"p", "^", "2"}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], "}"}], ",", " ", 
    "\n", "    ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "u", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "p"}], ")"}], "*", 
            RowBox[{"Cos", "[", "v", "]"}], "*", 
            RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"p", "^", "2"}]}], "]"}], "*", 
            RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], ")"}], "/", "\n", 
       "      ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ",", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sin", "[", "u", "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "p"}], ")"}], "*", 
            RowBox[{"Cos", "[", "v", "]"}], "*", 
            RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", "\n", "        ", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"p", "^", "2"}]}], "]"}], "*", 
            RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], " ", "+", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ",", " ", "\n", 
      "     ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"p", "^", "2"}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "v", "]"}]}], " ", "+", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Cos", "[", "w", "]"}], "*", 
          RowBox[{"Sin", "[", "v", "]"}]}]}], ")"}], "/", "\n", "      ", 
       RowBox[{"(", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{"p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"p", "^", "2"}]}], "]"}]}], ")"}], "*", 
          RowBox[{"Sin", "[", "u", "]"}]}], " ", "+", " ", "\n", "       ", 
         RowBox[{
          RowBox[{"Cos", "[", "u", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", " ", "-", " ", 
               RowBox[{"p", "^", "2"}]}], "]"}], "*", 
             RowBox[{"Sin", "[", "v", "]"}]}], " ", "+", " ", "\n", 
            "         ", 
            RowBox[{
             RowBox[{"Cos", "[", "v", "]"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], "*", "p", "*", 
                RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{"2", " ", "-", " ", 
                  RowBox[{"2", "*", 
                   RowBox[{"p", "^", "2"}]}]}], "]"}], "*", 
                RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}], "/", "\n", "      ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"2", " ", "-", " ", 
            RowBox[{"2", "*", 
             RowBox[{"p", "^", "2"}]}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
         RowBox[{"2", "*", "p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ",", " ", "\n", 
      "     ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"p", "^", "2"}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "u", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sin", "[", "u", "]"}], "*", "\n", "        ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{"1", " ", "-", " ", 
               RowBox[{"p", "^", "2"}]}], "]"}], "*", 
             RowBox[{"Sin", "[", "v", "]"}]}], " ", "+", " ", 
            RowBox[{
             RowBox[{"Cos", "[", "v", "]"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], "*", "p", "*", 
                RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", "\n", 
               "           ", 
               RowBox[{
                RowBox[{"Sqrt", "[", 
                 RowBox[{"2", " ", "-", " ", 
                  RowBox[{"2", "*", 
                   RowBox[{"p", "^", "2"}]}]}], "]"}], "*", 
                RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
        ")"}], "/", "\n", "      ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"2", " ", "-", " ", 
            RowBox[{"2", "*", 
             RowBox[{"p", "^", "2"}]}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
         RowBox[{"2", "*", "p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}], ",", " ", "\n", 
      "     ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"p", "^", "2"}]}], "]"}]}], ")"}], "*", 
          RowBox[{"Cos", "[", "v", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sin", "[", "v", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], "*", "p", "*", 
             RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", "\n", 
            "         ", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{"2", " ", "-", " ", 
               RowBox[{"2", "*", 
                RowBox[{"p", "^", "2"}]}]}], "]"}], "*", 
             RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], ")"}], "/", "\n", 
       "      ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"2", " ", "-", " ", 
            RowBox[{"2", "*", 
             RowBox[{"p", "^", "2"}]}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "w", "]"}]}], " ", "+", " ", 
         RowBox[{"2", "*", "p", "*", 
          RowBox[{"Sin", "[", "w", "]"}]}]}], ")"}]}]}], "}"}]}], 
   "}"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4735764285625*^9, 3.473576575625*^9}},
 CellLabel->"In[26]:="],

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"sphpic", "[", 
   RowBox[{"u", ",", "v", ",", "w", ",", "p"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4735760753125*^9, 3.473576084296875*^9}, {
  3.473576582546875*^9, 3.47357659790625*^9}},
 CellLabel->"In[143]:="],

Cell[TextData[{
 "Obviously, sphpic is a direct definition, that means, it is based on \
functions built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " only, and did not use intermediate constructions, e.g. the help function \
superspheremfL anymore"
}], "Text",
 CellChangeTimes->{{3.473578294671875*^9, 3.4735784515*^9}}],

Cell["\<\
We define the center and the radius of the image sphere applying the function \
center and radius to the images sphpic of the sphere points with these \
parameters under stereographic projection\
\>", "Text",
 CellChangeTimes->{{3.473495749534369*^9, 3.473495895909369*^9}, {
  3.473578213828125*^9, 3.473578215640625*^9}, {3.473578506125*^9, 
  3.473578511734375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"centerfct", "[", 
   RowBox[{"u_", ",", "v_", ",", "w_", ",", "p_"}], "]"}], ":=", " ", 
  RowBox[{"center", "[", 
   RowBox[{"sphpic", "[", 
    RowBox[{"u", ",", "v", ",", "w", ",", "p"}], "]"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.473486289081244*^9, 3.473486394299994*^9}, {
   3.473486460206244*^9, 3.473486484784369*^9}, {3.473486819237494*^9, 
   3.473486881174994*^9}, 3.473486923409369*^9, {3.473487025643744*^9, 
   3.473487064940619*^9}, 3.473487097659369*^9, {3.473488141753119*^9, 
   3.473488165003119*^9}, 3.473488229612494*^9, 3.473488271221869*^9, {
   3.473492583721869*^9, 3.473492598284369*^9}, {3.473505001125*^9, 
   3.47350504309375*^9}, {3.473577312234375*^9, 3.473577328265625*^9}},
 CellLabel->"In[28]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"radiusfct", "[", 
   RowBox[{"u_", ",", "v_", ",", "w_", ",", "p_"}], "]"}], ":=", " ", 
  RowBox[{"Norm", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{
      RowBox[{"subspheremf", "[", 
       RowBox[{"u", ",", "v", ",", "w", ",", "p"}], "]"}], "[", 
      RowBox[{"0", ",", "0"}], "]"}], "]"}], "-", 
    RowBox[{"centerfct", "[", 
     RowBox[{"u", ",", "v", ",", "w", ",", "p"}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.473492989846869*^9, 3.473493162253119*^9}, {
  3.473493259534369*^9, 3.473493267721869*^9}, {3.473505081609375*^9, 
  3.473505101390625*^9}},
 CellLabel->"In[29]:="],

Cell["\<\
This way we have the possibility to study the images of the subspheres under \
stereographic projection as functions of the parameters on the 4-dimensional \
manifold of the subspheres\
\>", "Text",
 CellChangeTimes->{{3.473495980596869*^9, 3.473496070003119*^9}}],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"radiusfct", "[", 
    RowBox[{"0", ",", "0", ",", "0", ",", "t"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", ".01", ",", ".99"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473489430159369*^9, 3.473489517174994*^9}, {
  3.473489568674994*^9, 3.473489572393744*^9}},
 CellLabel->"In[150]:="],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"radiusfct", "[", 
    RowBox[{"0", ",", "0", ",", "0", ",", "t"}], "]"}], ",", 
   RowBox[{"t", "\[Rule]", " ", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473489600987494*^9, 3.473489644237494*^9}},
 CellLabel->"In[151]:="],

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"radiusfct", "[", 
    RowBox[{"0", ",", "0", ",", "0", ",", "t"}], "]"}], ",", 
   RowBox[{"t", "\[Rule]", " ", "1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473489600987494*^9, 3.473489644237494*^9}, {
  3.473489710018744*^9, 3.473489719690619*^9}},
 CellLabel->"In[152]:="],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"radiusfct", "[", 
    RowBox[{"t", ",", "0", ",", "0", ",", ".8"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473489430159369*^9, 3.473489517174994*^9}, {
   3.473489568674994*^9, 3.473489572393744*^9}, {3.473489805721869*^9, 
   3.473489849815619*^9}, {3.473489898862494*^9, 3.473489919549994*^9}, 
   3.473489994096869*^9},
 CellLabel->"In[153]:="],

Cell[BoxData[
 RowBox[{"radiusfct", "[", 
  RowBox[{"3", ",", "0", ",", "0", ",", ".8"}], "]"}]], "Input",
 CellChangeTimes->{{3.473489932346869*^9, 3.473489967112494*^9}, 
   3.473490007034369*^9},
 CellLabel->"In[154]:="],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"radiusfct", "[", 
    RowBox[{"0", ",", "t", ",", "0", ",", ".8"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473489430159369*^9, 3.473489517174994*^9}, {
   3.473489568674994*^9, 3.473489572393744*^9}, {3.473489805721869*^9, 
   3.473489849815619*^9}, {3.473489898862494*^9, 3.473489919549994*^9}, 
   3.473489994096869*^9, {3.473490077862494*^9, 3.473490095034369*^9}, {
   3.473490217674994*^9, 3.473490219346869*^9}},
 CellLabel->"In[155]:="],

Cell[BoxData[
 RowBox[{"radiusfct", "[", 
  RowBox[{"0", ",", ".3", ",", "0", ",", ".8"}], "]"}]], "Input",
 CellChangeTimes->{{3.473490159378119*^9, 3.473490163831244*^9}},
 CellLabel->"In[156]:="],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"radiusfct", "[", 
    RowBox[{"0", ",", "0", ",", "t", ",", ".5"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473489430159369*^9, 3.473489517174994*^9}, {
   3.473489568674994*^9, 3.473489572393744*^9}, {3.473489805721869*^9, 
   3.473489849815619*^9}, {3.473489898862494*^9, 3.473489919549994*^9}, 
   3.473489994096869*^9, {3.473490077862494*^9, 3.473490095034369*^9}, {
   3.473490217674994*^9, 3.473490219346869*^9}, {3.473490253534369*^9, 
   3.473490259690619*^9}, {3.473490300768744*^9, 3.473490321409369*^9}, {
   3.473491533971869*^9, 3.473491542221869*^9}, 3.473491679909369*^9},
 CellLabel->"In[157]:="],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"radiusfct", "[", 
     RowBox[{"0", ",", "0", ",", "t", ",", ".5"}], "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "Pi"}], ",", "Pi"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473489430159369*^9, 3.473489517174994*^9}, {
   3.473489568674994*^9, 3.473489572393744*^9}, {3.473489805721869*^9, 
   3.473489849815619*^9}, {3.473489898862494*^9, 3.473489919549994*^9}, 
   3.473489994096869*^9, {3.473490077862494*^9, 3.473490095034369*^9}, {
   3.473490217674994*^9, 3.473490219346869*^9}, {3.473490253534369*^9, 
   3.473490259690619*^9}, {3.473490300768744*^9, 3.473490321409369*^9}, {
   3.473490386456244*^9, 3.473490395018744*^9}, 3.473491453596869*^9, {
   3.473491715971869*^9, 3.473491722643744*^9}},
 CellLabel->"In[158]:="],

Cell["\<\
Moreover, we found the center and the radius as functions on the manifold of \
all subspheres, parametrized by the angle parameters u, v, w and the distance \
p.\
\>", "Text",
 CellChangeTimes->{{3.473518362578125*^9, 3.47351843959375*^9}, {
  3.473518474484375*^9, 3.47351849940625*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"centerfct", "[", 
    RowBox[{"t", ",", "0", ",", "0", ",", ".5"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "Pi"}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", "Red"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473507137734375*^9, 3.47350724971875*^9}, {
  3.47350728784375*^9, 3.473507293078125*^9}, {3.4735073700625*^9, 
  3.473507384046875*^9}},
 CellLabel->"In[159]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"centerfct", "[", 
    RowBox[{"0", ",", "t", ",", "0", ",", ".5"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "Pi"}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", "Red"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473507137734375*^9, 3.47350724971875*^9}, {
  3.47350728784375*^9, 3.473507293078125*^9}, {3.473507341375*^9, 
  3.473507357671875*^9}},
 CellLabel->"In[160]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"centerfct", "[", 
    RowBox[{"0", ",", "0", ",", "t", ",", ".5"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "Pi"}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", "Red"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473507137734375*^9, 3.47350724971875*^9}, {
  3.47350728784375*^9, 3.473507293078125*^9}, {3.473507341375*^9, 
  3.473507357671875*^9}, {3.473507404125*^9, 3.473507418703125*^9}},
 CellLabel->"In[161]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"centerfct", "[", 
   RowBox[{"0", ",", "0", ",", "0", ",", ".5"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{
  3.4735074811875*^9, {3.47350752434375*^9, 3.47350753221875*^9}},
 CellLabel->"In[162]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"centerfct", "[", 
   RowBox[{"0", ",", "0", ",", "1.", ",", ".5"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4735074811875*^9, 3.473507506234375*^9}, {
  3.473507540265625*^9, 3.47350755853125*^9}},
 CellLabel->"In[163]:="],

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"centerfct", "[", 
     RowBox[{"0", ",", "0", ",", "t", ",", ".5"}], "]"}], ",", 
    RowBox[{"t", ">", "0"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4735074811875*^9, 3.473507506234375*^9}, {
  3.473507540265625*^9, 3.47350755853125*^9}, {3.473507588625*^9, 
  3.473507595875*^9}, {3.4735076336875*^9, 3.47350766315625*^9}, {
  3.47350783753125*^9, 3.47350785134375*^9}, {3.473511004890625*^9, 
  3.473511036265625*^9}},
 CellLabel->"In[164]:="],

Cell["\<\
Based on centerfct and radiusfct we got a very fast subsphere plot function:\
\>", "Text",
 CellChangeTimes->{{3.473518802078125*^9, 3.473518862671875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"subsphereplot3D", "[", 
   RowBox[{"u_", ",", "v_", ",", "w_", ",", "p_", ",", 
    RowBox[{"s0_:", "0"}], ",", 
    RowBox[{"s1_:", "2", "*", "Pi"}], ",", 
    RowBox[{"t0_:", "-", 
     RowBox[{"Pi", "/", "2"}]}], ",", " ", 
    RowBox[{"t1_:", 
     RowBox[{"Pi", "/", "2"}]}], ",", "opts___"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"sphereplot3D", "[", 
   RowBox[{
    RowBox[{"centerfct", "[", 
     RowBox[{"u", ",", "v", ",", "w", ",", "p"}], "]"}], ",", 
    RowBox[{"radiusfct", "[", 
     RowBox[{"u", ",", "v", ",", "w", ",", "p"}], "]"}], ",", "s0", ",", "s1",
     ",", "t0", ",", "t1", ",", "opts"}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.473505563265625*^9, 3.473505571921875*^9}, {
  3.47350562040625*^9, 3.473505895546875*^9}, {3.473505955984375*^9, 
  3.47350595678125*^9}},
 CellLabel->"In[30]:="],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"subsphereplot3D", "[", 
   RowBox[{".4", ",", 
    RowBox[{"Pi", "/", "3"}], ",", "0", ",", ".5"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473506062515625*^9, 3.473506066046875*^9}, {
  3.47350615509375*^9, 3.473506158171875*^9}, {3.4735063921875*^9, 
  3.473506405*^9}, {3.473506878125*^9, 3.4735068871875*^9}},
 CellLabel->"In[181]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.4735190695625*^9, 3.47351907365625*^9}},
 CellLabel->"In[182]:="],

Cell["\<\
Of course, we obtain the same sphere, but the old function subsphereplot3Drm \
needs more than 100 times the  time:\
\>", "Text",
 CellChangeTimes->{{3.473495025065619*^9, 3.473495042159369*^9}, {
   3.473506783390625*^9, 3.47350686603125*^9}, 3.47350698640625*^9, {
   3.473577604515625*^9, 3.4735776056875*^9}, 3.47357889925*^9, {
   3.473578931921875*^9, 3.47357894809375*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"subsphereplot3Drm", "[", 
   RowBox[{
    RowBox[{"unit3", "[", 
     RowBox[{".4", ",", 
      FractionBox["\[Pi]", "3"], ",", "0"}], "]"}], ",", ".5"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4735065336875*^9, 3.473506572015625*^9}, {
   3.473506609921875*^9, 3.473506675703125*^9}, {3.47350691159375*^9, 
   3.47350695821875*^9}, 3.473574429859375*^9},
 CellLabel->"In[183]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473519015296875*^9, 3.473519019171875*^9}},
 CellLabel->"In[171]:="],

Cell[BoxData[
 RowBox[{"unit3", "[", 
  RowBox[{"u", ",", "v", ",", "w"}], "]"}]], "Input",
 CellChangeTimes->{{3.473506519375*^9, 3.4735065240625*^9}},
 CellLabel->"In[58]:="],

Cell["\<\
With the old subsphereplot3Drm the following plot commmand works,  but very \
slowly only. Now, with the new function subsphereplot3D, we get the picture \
much faster:\
\>", "Text",
 CellChangeTimes->{{3.473492413862494*^9, 3.473492490190619*^9}, {
  3.473517299640625*^9, 3.4735173978125*^9}, {3.4735776806875*^9, 
  3.473577729078125*^9}}],

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"subsphereplot3D", "[", 
       RowBox[{
        RowBox[{"i", "*", "2", "*", 
         RowBox[{"Pi", "/", "5"}]}], ",", "0", ",", "0", ",", " ", 
        RowBox[{"1", "-", 
         RowBox[{".5", "/", "i"}]}], ",", "0", ",", 
        RowBox[{"2", "*", "Pi"}], ",", 
        RowBox[{
         RowBox[{"-", "Pi"}], "/", "2"}], ",", 
        RowBox[{"Pi", "/", "2"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"Opacity", "[", ".2", "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.473483266846869*^9, 3.473483283424994*^9}, {
  3.473483326690619*^9, 3.473483509049994*^9}, {3.473517256640625*^9, 
  3.47351727021875*^9}, {3.473517404140625*^9, 3.47351746090625*^9}, {
  3.473517522046875*^9, 3.473517538015625*^9}, {3.47351760684375*^9, 
  3.473517639296875*^9}, {3.473517674828125*^9, 3.47351769296875*^9}, {
  3.4735177273125*^9, 3.473517741359375*^9}, {3.473517803640625*^9, 
  3.4735178290625*^9}},
 CellLabel->"In[172]:="],

Cell[BoxData[
 RowBox[{"%", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.473517484125*^9, 3.473517495203125*^9}, {
  3.473577763625*^9, 3.473577767625*^9}},
 CellLabel->"In[173]:="],

Cell["One remarks that the image sphere are always undistorted.", "Text",
 CellChangeTimes->{{3.47357870865625*^9, 3.4735787133125*^9}, {
   3.473578780109375*^9, 3.473578825875*^9}, 3.47357902225*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3.2 Conformity", "Subsection",
 CellChangeTimes->{3.47357910728125*^9, 3.47358085784375*^9}],

Cell[TextData[{
 "It is well known that the stereographic projection is conformal: it \
preserves angles e.g. between intersecting curves. For the proof we need some \
simple facts from differential geometry, see e.g. Alfred Gray [",
 ButtonBox["1",
  BaseStyle->"Hyperlink",
  ButtonData->"G1"],
 "].  In  subsection 4.5 about tori one can find some confirming \
illustrations of this property. Here we calculate the coefficients of the \
Riemannian metrics and show that they are proportional at the corresponding \
(under sterproj) points."
}], "Text",
 CellChangeTimes->{{3.473579189578125*^9, 3.473579215703125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "[", "1", "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"unit3", "[", 
     RowBox[{"s", ",", "t", ",", "u"}], "]"}], ",", "s"}], "]"}]}]], "Input",
 CellLabel->"In[184]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "[", "2", "]"}], " ", "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"unit3", "[", 
     RowBox[{"s", ",", "t", ",", "u"}], "]"}], ",", "t"}], "]"}]}]], "Input",
 CellLabel->"In[185]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "[", "3", "]"}], " ", "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"unit3", "[", 
     RowBox[{"s", ",", "t", ",", "u"}], "]"}], ",", "u"}], "]"}]}]], "Input",
 CellLabel->"In[186]:="],

Cell[BoxData[
 RowBox[{"vprods", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "i", "]"}], ".", 
     RowBox[{"v", "[", "j", "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[187]:="],

Cell["\<\
The coeeficients of the fundamental form of the unit 3-sphere are\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[188]:="],

Cell["\<\
Now we calculate the images of the tangent vectors under the differential of \
the stereographic projection:\
\>", "Text",
 CellChangeTimes->{{3.472370568091653*^9, 3.472370570494678*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsp", "[", "1", "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{"unit3", "[", 
      RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}], ",", "s"}], 
   "]"}]}]], "Input",
 CellLabel->"In[189]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsp", "[", "2", "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{"unit3", "[", 
      RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}], ",", "t"}], 
   "]"}]}]], "Input",
 CellLabel->"In[190]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"vsp", "[", "3", "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"sterproj", "[", 
     RowBox[{"unit3", "[", 
      RowBox[{"s", ",", "t", ",", "u"}], "]"}], "]"}], ",", "u"}], 
   "]"}]}]], "Input",
 CellLabel->"In[191]:="],

Cell[TextData[{
 "Their scalar products give the corrresponding coefficients of the \
fundamental form of the ",
 "Euclidean",
 " space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 " under the coordinates introduced by the stereographic projection:"
}], "Text",
 CellChangeTimes->{3.47297184675*^9}],

Cell[BoxData[
 RowBox[{"vspprods", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"vsp", "[", "i", "]"}], ".", 
     RowBox[{"vsp", "[", "j", "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"i", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "3"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[192]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[193]:="],

Cell["\<\
We compare the coefficients of the riemannian metrics of the 3-sphere \
\>", "Text"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "u", "]"}], "2"]}], "0", "0"},
     {"0", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "u", "]"}], "2"], "0"},
     {"0", "0", "1"}
    }], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellLabel->"Out[92]//MatrixForm="],

Cell["\<\
and the Euclidean 3-space under the stereographic projection. Since\
\>", "Text",
 CellChangeTimes->{3.4729718468125*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["u", "2"], "]"}], "-", 
     RowBox[{"Sin", "[", 
      FractionBox["u", "2"], "]"}]}], ")"}], "4"], "\[Equal]", " ", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Sin", "[", "u", "]"}]}], ")"}], "2"]}]], "Input",
 CellLabel->"In[194]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[195]:="],

Cell["\<\
it follows, that the Riemannian metrics (i.e. the fundamental forms) are \
proportional with the factor\
\>", "Text"],

Cell["(-1 + Sin[u])^(-2)", "Input"],

Cell["\<\
whith a singularity at he north pole u=Pi/2, corresponding to the singularity \
of the stereographic projection.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.4 Example: Tori. Geodesics on the flat torus",
 FontFamily->"Utopia",
 FontSize->14]], "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.472366384697806*^9, 3.472366386799321*^9}, {
   3.47360520484375*^9, 3.47360521309375*^9}, 3.47383932915625*^9},
 FontFamily->"Times",
 FontSize->12],

Cell[CellGroupData[{

Cell["4.4.1 Tori", "Subsubsection",
 CellChangeTimes->{3.474009463609375*^9, 3.47400967496875*^9}],

Cell[TextData[{
 StyleBox["We define  the ",
  FontFamily->"Times"],
 StyleBox["flat torus",
  FontFamily->"Times",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" as a direct product of two circles in orthogonal planes of the \
4-space, producing a surface  in the unit 3-sphere. Obviously, its inner \
metric is flat. By  stereographic projection onto the ",
  FontFamily->"Times"],
 "Euclidean",
 StyleBox[" 3-space we obtain the ",
  FontFamily->"Times"],
 StyleBox["Euclidean torus",
  FontFamily->"Times",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" as a surface of revolution. Its parameter representation is (with \
0 < c < 1):",
  FontFamily->"Times"]
}], "Text",
 CellChangeTimes->{
  3.47297184715625*^9, {3.474009513921875*^9, 3.474009525796875*^9}, {
   3.474009556171875*^9, 3.474009565953125*^9}}],

Cell[TextData[StyleBox["sterproj[{Cos[t], Sin[t], 0, 0}*c +\n{0, 0, Cos[s], \
Sin[s]}Sqrt[1 - c^2]]",
 FontFamily->"Courier"]], "Input",
 PageWidth->Infinity,
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[141]:="],

Cell["We define", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"torus", "[", "c_", "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{"c", " ", 
      RowBox[{"Cos", "[", "t", "]"}]}], 
     RowBox[{"1", "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["c", "2"]}]], " ", 
       RowBox[{"Sin", "[", "s", "]"}]}]}]], ",", 
    FractionBox[
     RowBox[{"c", " ", 
      RowBox[{"Sin", "[", "t", "]"}]}], 
     RowBox[{"1", "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["c", "2"]}]], " ", 
       RowBox[{"Sin", "[", "s", "]"}]}]}]], ",", 
    FractionBox[
     RowBox[{
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["c", "2"]}]], " ", 
      RowBox[{"Cos", "[", "s", "]"}]}], 
     RowBox[{"1", "-", 
      RowBox[{
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["c", "2"]}]], " ", 
       RowBox[{"Sin", "[", "s", "]"}]}]}]]}], "}"}]}]], "Input",
 InitializationCell->True,
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[31]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"torus", "::", "usage"}], " ", "=", " ", 
   "\"\<torus[c][s,t] is a parameter representation of the round torus in the \
Euclidean 3-space with shape parameter c; s,t are the surface \
parameters.\>\""}], " ", ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.472971847234375*^9},
 CellLabel->"In[32]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"torus", "[", "0", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[142]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"torus", "[", "1", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[143]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"torus", "[", "0.8", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0", ",", 
      RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", 
      RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"PlotPoints", " ", "->", " ", "50"}], ",", 
    RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
     RowBox[{"Opacity", "[", ".4", "]"}]}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.472395468052083*^9, 3.47239548594084*^9}},
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[144]:="],

Cell["gr1= %;", "Input",
 CellChangeTimes->{3.472395376127438*^9},
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[145]:="],

Cell[TextData[{
 StyleBox["Th\[Epsilon] torus as submanifold of ",
  FontFamily->"Times"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]],
  FontFamily->"Times"],
 StyleBox[" is locally flat :locally  isometric to the ",
  FontFamily->"Times"],
 "Euclidean",
 StyleBox[" plane. Therefore its geodesics are the isogonal trajectories of \
its generating circles. Their images under the stereographic projection are:",
  FontFamily->"Times"]
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.472971847265625*^9}],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"kron", "[", 
     RowBox[{"a_", ",", " ", "c_"}], "]"}], "[", "t_", "]"}], ":=", 
   RowBox[{"sterproj", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Cos", "[", "t", "]"}], ",", " ", 
        RowBox[{"Sin", "[", "t", "]"}], ",", " ", "0", ",", " ", "0"}], "}"}],
       "*", "c"}], " ", "+", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", " ", "0", ",", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"a", " ", "t"}], "]"}], ",", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"a", " ", "t"}], "]"}]}], "}"}], 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", " ", "-", " ", 
        RowBox[{"c", "^", "2"}]}], "]"}]}]}], "]"}]}],
  FontFamily->"Courier"]], "Input",
 PageWidth->Infinity,
 InitializationCell->True,
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[33]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"kron", "::", "usage"}], " ", "=", " ", 
   "\"\<kron[a,c][t] is a parameter representation of an  isogonal trajectory \
of the meridians of a round torus with shape parameter c; a defines the \
intersection angle, t is the curve parameter.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"kron", "[", 
   RowBox[{"a", ",", " ", "c"}], "]"}], "[", "t", "]"}]], "Input",
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[147]:="],

Cell["\<\
Since stereographic projection is not an isometry, the curves kron[a,c][t] \
are in general not geodesics on the image torus in the 3-space.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kron", "[", 
   RowBox[{".5", ",", " ", "0.8"}], "]"}], "[", "t", "]"}]], "Input",
 PageWidth->Infinity,
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[148]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"kron", "[", 
     RowBox[{".5", ",", ".8"}], "]"}], "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"10", " ", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", " ", "\[IndentingNewLine]", 
   RowBox[{"PlotStyle", " ", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.472395511752128*^9, 3.472395544089609*^9}},
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[149]:="],

Cell["gr2 = %;", "Input",
 CellChangeTimes->{3.472395445932607*^9},
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[150]:="],

Cell["Show[{gr1, gr2}]", "Input",
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[151]:="],

Cell["gr3 = %;", "Input",
 CellChangeTimes->{3.472395617253672*^9},
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[152]:="],

Cell["Now we show the torus by a family of Meridians", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ParametricPlot3D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"torus", "[", "0.8", "]"}], "[", 
        RowBox[{"s", ",", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", "0", ",", 
         RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}], ",", ".1"}], "}"}]}], "]"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473774048046875*^9, 3.4737740659375*^9}},
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[154]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"tnet", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472395704977543*^9},
 FontFamily->"Times",
 CellLabel->"In[155]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"tnet", ",", "gr2"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[156]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"gr4", " ", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472395722676727*^9},
 FontFamily->"Times",
 CellLabel->"In[40]:="],

Cell["\<\
Here one can see that the intersection angle along the curve is constant; \
this will be confirmed by a calculationin the next subsection. \
\>", "Text",
 CellChangeTimes->{3.472395795043722*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["4.4.2 Proof  that the intersection angle is constant", "Subsubsection",
 CellChangeTimes->{{3.474009694484375*^9, 3.47400969634375*^9}},
 FontFamily->"Times"],

Cell["\<\
By 4.3.2 the statement must be correct. We check it once more. The tangential \
vector of the curve is\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tgkron", "[", 
     RowBox[{"a_", ",", "c_"}], "]"}], "[", "t_", "]"}], "=", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"kron", "[", 
       RowBox[{"a", ",", " ", "c"}], "]"}], "[", "t", "]"}], ",", "t"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.472786513624918*^9, 3.472786546406637*^9}, {
  3.473774481828125*^9, 3.473774487234375*^9}, {3.473776137921875*^9, 
  3.473776138125*^9}},
 FontFamily->"Times",
 CellLabel->"In[196]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"tgkron", "[", 
     RowBox[{"a", ",", "c"}], "]"}], "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"c", "^", "2"}], "<", "1"}], ",", 
     RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4737761464375*^9, 3.473776194578125*^9}},
 FontFamily->"Times",
 CellLabel->"In[197]:="],

Cell["\<\
This leads to the explicit definition of the tangent vector of kron[a,c][t]:\
\>", "Text",
 CellChangeTimes->{{3.473776269859375*^9, 3.473776329796875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tangkron", "[", 
    RowBox[{"a_", ",", " ", "c_"}], "]"}], "[", "t_", "]"}], " ", ":=", " ", 
  "\n", "  ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sin", "[", "t", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"c", "^", "2"}]}], "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", "*", 
             RowBox[{"Cos", "[", "t", "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"a", "*", "t"}], "]"}]}], " ", "+", " ", "\n", 
            "        ", 
            RowBox[{
             RowBox[{"Sin", "[", "t", "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"a", "*", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}], ")"}], 
     "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", " ", "-", " ", 
           RowBox[{"c", "^", "2"}]}], "]"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"a", "*", "t"}], "]"}]}]}], ")"}], "^", "\n", "     ", 
      "2"}]}], ",", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"c", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Cos", "[", "t", "]"}], " ", "+", " ", 
         RowBox[{"a", "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"c", "^", "2"}]}], "]"}], "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"a", "*", "t"}], "]"}], "*", 
          RowBox[{"Sin", "[", "t", "]"}]}], " ", "-", " ", "\n", "      ", 
         RowBox[{
          RowBox[{"Sqrt", "[", 
           RowBox[{"1", " ", "-", " ", 
            RowBox[{"c", "^", "2"}]}], "]"}], "*", 
          RowBox[{"Cos", "[", "t", "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"a", "*", "t"}], "]"}]}]}], ")"}]}], ")"}], "/", "\n", 
     "    ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", " ", "-", " ", 
           RowBox[{"c", "^", "2"}]}], "]"}], "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"a", "*", "t"}], "]"}]}]}], ")"}], "^", "2"}]}], ",", " ", 
    "\n", "   ", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], " ", "+", " ", 
           RowBox[{"c", "^", "2"}], " ", "+", " ", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             RowBox[{"1", " ", "-", " ", 
              RowBox[{"c", "^", "2"}]}], "]"}], "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"a", "*", "t"}], "]"}]}]}], ")"}]}], ")"}], "/", "\n", 
       "     ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], " ", "+", " ", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"1", " ", "-", " ", 
             RowBox[{"c", "^", "2"}]}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"a", "*", "t"}], "]"}]}]}], ")"}], "^", "2"}]}], 
      ")"}]}]}], "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.473776005578125*^9, 3.473776025375*^9}, 
   3.4737760588125*^9},
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"tangkron", "[", 
     RowBox[{"a", ",", "c"}], "]"}], "[", "t", "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"tgkron", "[", 
     RowBox[{"a", ",", "c"}], "]"}], "[", "t", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4737763669375*^9, 3.473776433953125*^9}},
 CellLabel->"In[200]:="],

Cell["\<\
The tangential vectors of the parameter lines of the torus are\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dttorus", "[", "c_", "]"}], "[", 
    RowBox[{"s_", ",", "t_"}], "]"}], "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"torus", "[", "c", "]"}], "[", 
      RowBox[{"s", ",", "t"}], "]"}], ",", "t"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.472786424483065*^9, 3.47278644407147*^9}, {
  3.47377453115625*^9, 3.473774534421875*^9}},
 FontFamily->"Times",
 CellLabel->"In[36]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dttorus", "[", "c", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[177]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dstorus", "[", "c_", "]"}], "[", 
    RowBox[{"s_", ",", "t_"}], "]"}], "=", " ", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"torus", "[", "c", "]"}], "[", 
      RowBox[{"s", ",", "t"}], "]"}], ",", "s"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.472786360626459*^9, 3.472786376611333*^9}, {
  3.473774505015625*^9, 3.473774512484375*^9}},
 FontFamily->"Times",
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dstorus", "[", "c", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[178]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"kron", "[", 
   RowBox[{"a", ",", "c"}], "]"}], "[", "u", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[164]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"torus", "[", "c", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[165]:="],

Cell["\<\
The parameter representation of the curve kron[a,c][u] on the torus is s=a u, \
t = u:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"kron", "[", 
    RowBox[{"a", ",", "c"}], "]"}], "[", "u", "]"}], "\[Equal]", 
  RowBox[{
   RowBox[{"torus", "[", "c", "]"}], "[", 
   RowBox[{
    RowBox[{"a", "*", "u"}], ",", "u"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[179]:="],

Cell["\<\
We show that the cosinus of the angle in which curve kron[a,c][u] intersects \
the parameter lines is constant along the curve:\
\>", "Text",
 CellChangeTimes->{3.4737755920625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"testfs", "[", "t_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"dotnorme", "[", 
    RowBox[{
     RowBox[{"tangkron", "[", 
      RowBox[{"a", ",", "c"}], "]"}], "[", "t", "]"}], "]"}], ".", 
   RowBox[{"dotnorme", "[", 
    RowBox[{
     RowBox[{"dstorus", "[", "c", "]"}], "[", " ", 
     RowBox[{
      RowBox[{"a", "*", "t"}], ",", "t"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4737743553125*^9, 3.4737744006875*^9}, 
   3.4737750556875*^9, 3.4737755278125*^9},
 FontFamily->"Times",
 CellLabel->"In[189]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"testfs", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"c", "^", "2"}], "<", "1"}], ",", 
     RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473775231421875*^9, 3.4737752340625*^9}, {
   3.473775265078125*^9, 3.47377529653125*^9}, 3.4737755544375*^9},
 CellLabel->"In[190]:="],

Cell["\<\
Clearly, also the angle with the other coordinate lines is constant:\
\>", "Text",
 CellChangeTimes->{{3.473774909203125*^9, 3.47377492615625*^9}, {
  3.473775702796875*^9, 3.473775757546875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"testft", "[", "t_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"dotnorme", "[", 
    RowBox[{
     RowBox[{"tangkron", "[", 
      RowBox[{"a", ",", "c"}], "]"}], "[", "t", "]"}], "]"}], ".", 
   RowBox[{"dotnorme", "[", 
    RowBox[{
     RowBox[{"dttorus", "[", "c", "]"}], "[", " ", 
     RowBox[{
      RowBox[{"a", "*", "t"}], ",", "t"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4737743553125*^9, 3.4737744006875*^9}, 
   3.4737750556875*^9, {3.473775102765625*^9, 3.473775117203125*^9}},
 FontFamily->"Times",
 CellLabel->"In[185]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"testft", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"c", "^", "2"}], "<", "1"}], ",", 
     RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473775231421875*^9, 3.4737752340625*^9}, {
  3.473775265078125*^9, 3.47377529653125*^9}},
 CellLabel->"In[186]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"testft", "[", "t", "]"}], ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", ">", "0"}], ",", 
     RowBox[{
      RowBox[{"c", "^", "2"}], "<", "1"}], ",", 
     RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473775231421875*^9, 3.4737752340625*^9}, {
  3.473775265078125*^9, 3.47377529653125*^9}, {3.47377534878125*^9, 
  3.47377536721875*^9}},
 CellLabel->"In[187]:="],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"tesft", ",", "testfs"}], "]"}]], "Input",
 CellChangeTimes->{
  3.473774985734375*^9, {3.4737757874375*^9, 3.4737758289375*^9}},
 FontFamily->"Times",
 CellLabel->"In[201]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["4.4.3 Again: the conformity", "Subsubsection",
 CellChangeTimes->{
  3.473774985734375*^9, {3.4740097101875*^9, 3.47400971271875*^9}},
 FontFamily->"Times"],

Cell[TextData[{
 "In this ssubsection we show, calculating the coefficients of the \
fundamental forms, that the map of the flat torus in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 " to the torus in the eucliden space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "3"], TraditionalForm]]],
 " induced by stereographic projection, is conformal. Clearly this is a \
consequence of the general conformality of the stereographic projection, as \
proved in section 4.3.2. We show it by direct calculation for the tori once \
more.  Here is the parameter representation of the flat torus as a surface in \
",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "4"], TraditionalForm]]],
 ":"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"flattorus", "[", "c_", "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", 
  StyleBox[
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], ",", " ", 
       RowBox[{"Sin", "[", "t", "]"}], ",", " ", "0", ",", " ", "0"}], "}"}], 
     "*", "c"}], " ", "+", "\n", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", 
       RowBox[{"Cos", "[", "s", "]"}], ",", " ", 
       RowBox[{"Sin", "[", "s", "]"}]}], "}"}], 
     RowBox[{"Sqrt", "[", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"c", "^", "2"}]}], "]"}]}]}],
   FontFamily->"Courier"]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[202]:="],

Cell["We calculate the tangential vectors of its coordinate lines:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dsflatt", "[", "c_", "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], " ", ":=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"flattorus", "[", "c", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], ",", "s"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.472786843126978*^9, 3.472786856895379*^9}},
 FontFamily->"Times",
 CellLabel->"In[203]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dsflatt", "[", "c", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[204]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dtflatt", "[", "c_", "]"}], "[", 
   RowBox[{"s_", ",", "t_"}], "]"}], ":=", " ", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"flattorus", "[", "c", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.472786890058733*^9, 3.472786898063608*^9}},
 FontFamily->"Times",
 CellLabel->"In[205]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dtflatt", "[", "c", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[206]:="],

Cell["The fundamental form has the coefficients", "Text"],

Cell[BoxData[
 RowBox[{"ggft", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"dsflatt", "[", "c", "]"}], "[", 
        RowBox[{"s", ",", "t"}], "]"}], ".", 
       RowBox[{
        RowBox[{"dsflatt", "[", "c", "]"}], "[", 
        RowBox[{"s", ",", "t"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"dsflatt", "[", "c", "]"}], "[", 
        RowBox[{"s", ",", "t"}], "]"}], ".", 
       RowBox[{
        RowBox[{"dtflatt", "[", "c", "]"}], "[", 
        RowBox[{"s", ",", "t"}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"dtflatt", "[", "c", "]"}], "[", 
        RowBox[{"s", ",", "t"}], "]"}], ".", 
       RowBox[{
        RowBox[{"dsflatt", "[", "c", "]"}], "[", 
        RowBox[{"s", ",", "t"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"dtflatt", "[", "c", "]"}], "[", 
        RowBox[{"s", ",", "t"}], "]"}], ".", 
       RowBox[{
        RowBox[{"dtflatt", "[", "c", "]"}], "[", 
        RowBox[{"s", ",", "t"}], "]"}]}]}], "}"}]}], "}"}]}]], "Input",
 CellLabel->"In[207]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", "%", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[208]:="],

Cell["\<\
The shape of this fundamental form shows that the flat torus is locally \
isometric to the Euclidean plane.
The tangential basis of the Euclidean torus has been defined with the \
initialization:\
\>", "Text",
 CellChangeTimes->{{3.472971847328125*^9, 3.472971847359375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dstorus", "[", "c", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[209]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"dttorus", "[", "c", "]"}], "[", 
  RowBox[{"s", ",", "t"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[210]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dstorus", "[", "c", "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}], ".", 
  RowBox[{
   RowBox[{"dstorus", "[", "c", "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[211]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Together", "[", "%", "]"}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"s", ">", "0"}], "&&", 
      RowBox[{"t", ">", "0"}]}], "&&", 
     RowBox[{"c", ">", "0"}]}], "&&", 
    RowBox[{"c", "<", "1"}]}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[212]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g11", "[", "c_", "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], " ", "+", " ", 
       RowBox[{"c", "^", "2"}]}], ")"}], "*", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], " ", "+", " ", 
       RowBox[{"c", "^", "2"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], " ", "+", " ", 
          RowBox[{"c", "^", "2"}]}], ")"}], "*", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", "*", "s"}], "]"}]}], " ", "+", " ", "\n", "     ", 
       RowBox[{"4", "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"c", "^", "2"}]}], "]"}], "*", 
        RowBox[{"Sin", "[", "s", "]"}]}]}], ")"}]}], ")"}], "/", "\n", "   ", 
   RowBox[{"(", 
    RowBox[{"2", "*", 
     RowBox[{"(", 
      RowBox[{"1", " ", "-", " ", 
       RowBox[{"4", "*", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"c", "^", "2"}]}], "]"}], "*", 
        RowBox[{"Sin", "[", "s", "]"}]}], " ", "-", " ", "\n", "     ", 
       RowBox[{"6", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], " ", "+", " ", 
          RowBox[{"c", "^", "2"}]}], ")"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", "s", "]"}], "^", "2"}]}], " ", "-", " ", 
       RowBox[{"4", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", " ", "-", " ", 
           RowBox[{"c", "^", "2"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"3", "/", "2"}], ")"}]}], "*", "\n", "      ", 
        RowBox[{
         RowBox[{"Sin", "[", "s", "]"}], "^", "3"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], " ", "+", " ", 
           RowBox[{"c", "^", "2"}]}], ")"}], "^", "2"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", "s", "]"}], "^", "4"}]}]}], ")"}]}], 
    ")"}]}]}]], "Input",
 FormatType->"InputForm",
 FontFamily->"Times",
 CellLabel->"In[213]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"g11", "[", "c", "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}], "]"}]], "Input",
 CellLabel->"In[214]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dstorus", "[", "c", "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}], ".", 
  RowBox[{
   RowBox[{"dttorus", "[", "c", "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[215]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"dttorus", "[", "c", "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}], ".", 
  RowBox[{
   RowBox[{"dttorus", "[", "c", "]"}], "[", 
   RowBox[{"s", ",", "t"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[216]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"g22", "[", "c_", "]"}], "[", 
   RowBox[{"s_", ",", " ", "t_"}], "]"}], " ", ":=", " ", "\n", "  ", 
  RowBox[{
   RowBox[{"c", "^", "2"}], "/", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", " ", "-", " ", 
      RowBox[{
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", " ", "-", " ", 
         RowBox[{"c", "^", "2"}]}], "]"}], "*", 
       RowBox[{"Sin", "[", "s", "]"}]}]}], ")"}], "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.473777416984375*^9, 3.47377743240625*^9}},
 FormatType->"InputForm",
 FontFamily->"Times",
 CellLabel->"In[222]:="],

Cell["\<\
Dividing g11,g22 by the norm squares (1-c^2), resp. c^2 of the tangent \
vectors of flattorus[c][s,t], and substracting:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"g11", "[", "c", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"c", "^", "2"}]}], ")"}]}], " ", "-", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"g22", "[", "c", "]"}], "[", 
     RowBox[{"s", ",", "t"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"c", "^", "2"}], ")"}]}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[218]:="],

Cell["\<\
and this proves the (well known) conformity of the map sterproj in this case. \
The  proportionality factor of the fundamental forms is\
\>", "Text",
 CellChangeTimes->{{3.473777658125*^9, 3.473777658328125*^9}}],

Cell[BoxData[
 RowBox[{"Simplify", "[", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"g22", "[", "c", "]"}], "[", 
    RowBox[{"s", ",", "t"}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"c", "^", "2"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473777338453125*^9, 3.4737773463125*^9}},
 CellLabel->"In[221]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
4.4.4 The isogonal trajectories of the meridians are not geodesics of the \
Euclidean torus\
\>", "Subsubsection",
 CellChangeTimes->{{3.472396823203184*^9, 3.472396825336859*^9}, 
   3.472787000821801*^9, 3.472971847421875*^9, {3.47400972265625*^9, 
   3.47400972678125*^9}},
 FontFamily->"Times"],

Cell[TextData[{
 "In this subsection we again apply some facts of differential geometry, see \
e.g. Alfred Gray ",
 ButtonBox["[1]",
  BaseStyle->"Hyperlink",
  ButtonData:>"G1"],
 ".\nThe last  result confirms  that the stereographic projection restricted \
to the flat torus id a conformal map onto the Euclidean torus.with the same \
parameters. .  Of course, it may not be an isometry, since the Gauss \
curvature of the Euclidean torus does not vanish (Theorema egregium). The \
isogonal trajectories kron[a,c][t]  of the parameter lines are images of the \
isogonal trajectories on the flat torus being geodesics. We show that the \
curves kron[a,c][t], in general, are not  geodesics. To this aim we calulate \
the curvature vector of the curve kron[a,c][t]. The unit tangential vector is"
}], "Text",
 CellChangeTimes->{{3.472396728517342*^9, 3.472396729571367*^9}, {
  3.472785264579395*^9, 3.472785265465636*^9}, {3.473777847703125*^9, 
  3.473778133578125*^9}, {3.47377818009375*^9, 3.473778274859375*^9}}],

Cell[BoxData["Rules"], "Input",
 CellChangeTimes->{{3.47383199321875*^9, 3.473832000734375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"tkron", "[", 
    RowBox[{"a_", ",", "c_"}], "]"}], "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"dotnorme", "[", 
   RowBox[{
    RowBox[{"tangkron", "[", 
     RowBox[{"a", ",", "c"}], "]"}], "[", "t", "]"}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[41]:="],

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"tkron", "[", 
     RowBox[{"a", ",", "c"}], "]"}], "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", ">", "0"}], ",", 
     RowBox[{"c", ">", "0"}], ",", 
     RowBox[{"c", "<", "1"}], ",", 
     RowBox[{"t", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472785362849318*^9, 3.472785364704102*^9}, {
  3.473778333796875*^9, 3.473778391734375*^9}},
 CellLabel->"In[42]:="],

Cell["We simplify a bit furthe by hand and define", "Text",
 CellChangeTimes->{{3.473778661125*^9, 3.473778683359375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "tkron", "]"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"tkron", "[", 
     RowBox[{"a_", ",", "c_"}], "]"}], "[", "t_", "]"}], " ", ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SqrtBox["2"], " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Sin", "[", "t", "]"}]}], "+", 
          RowBox[{
           SqrtBox[
            RowBox[{"1", "-", 
             SuperscriptBox["c", "2"]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a", " ", 
              RowBox[{"Cos", "[", "t", "]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"a", " ", "t"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"Sin", "[", "t", "]"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"a", " ", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}], ")"}], 
      "/", 
      RowBox[{"(", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["c", "2"]}], "+", 
              RowBox[{
               SuperscriptBox["a", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"3", "-", 
              SuperscriptBox["c", "2"], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SuperscriptBox["c", "2"]}], ")"}], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "a", " ", "t"}], "]"}]}], "-", 
              RowBox[{"4", " ", 
               SqrtBox[
                RowBox[{"1", "-", 
                 SuperscriptBox["c", "2"]}]], " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"a", " ", "t"}], "]"}]}]}], ")"}]}], ")"}]}], ")"}]}],
        " ", ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SqrtBox["2"], " ", "c", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Cos", "[", "t", "]"}], "+", 
          RowBox[{"a", " ", 
           SqrtBox[
            RowBox[{"1", "-", 
             SuperscriptBox["c", "2"]}]], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"a", " ", "t"}], "]"}], " ", 
           RowBox[{"Sin", "[", "t", "]"}]}], "-", 
          RowBox[{
           SqrtBox[
            RowBox[{"1", "-", 
             SuperscriptBox["c", "2"]}]], " ", 
           RowBox[{"Cos", "[", "t", "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"a", " ", "t"}], "]"}]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["c", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["c", "2"]}], ")"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "a", " ", "t"}], "]"}]}], "+", 
             RowBox[{"4", " ", 
              SqrtBox[
               RowBox[{"1", "-", 
                SuperscriptBox["c", "2"]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"a", " ", "t"}], "]"}]}]}], ")"}]}], ")"}], ")"}]}], 
       ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox["2"], " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["c", "2"], "+", 
           RowBox[{
            SqrtBox[
             RowBox[{"1", "-", 
              SuperscriptBox["c", "2"]}]], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"a", " ", "t"}], "]"}]}]}], ")"}]}], ")"}]}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["c", "2"]}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SuperscriptBox["c", "2"]}], ")"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "a", " ", "t"}], "]"}]}], "+", 
             RowBox[{"4", " ", 
              SqrtBox[
               RowBox[{"1", "-", 
                SuperscriptBox["c", "2"]}]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"a", " ", "t"}], "]"}]}]}], ")"}]}], ")"}], ")"}]}], 
       ")"}]}]}], "}"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.4738329315625*^9, 3.473832931640625*^9}, 
   3.473832983734375*^9, {3.4738330205625*^9, 3.473833049171875*^9}, {
   3.473833083609375*^9, 3.473833105171875*^9}, {3.47383314646875*^9, 
   3.4738331526875*^9}, {3.4738332255625*^9, 3.473833291234375*^9}},
 CellLabel->"In[38]:="],

Cell[TextData[{
 "The normalvector of the regular curve kron[a,c][t] of the Euclidean 3-space \
 is proportional to the derivation of  its tangent unit vector (see A. Gray ",
 ButtonBox["[1]",
  BaseStyle->"Hyperlink",
  ButtonData:>"G1"],
 "): "
}], "Text",
 CellChangeTimes->{{3.472787070557786*^9, 3.472787071870253*^9}, 
   3.472971847484375*^9, {3.473834096*^9, 3.473834106265625*^9}, {
   3.473834140953125*^9, 3.47383414175*^9}, {3.4738351100625*^9, 
   3.473835121296875*^9}, {3.473835456*^9, 3.47383552384375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normal", "[", 
    RowBox[{"a_", ",", "c_"}], "]"}], "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"tkron", "[", 
        RowBox[{"a", ",", "c"}], "]"}], "[", "t", "]"}], ",", "t"}], "]"}], 
    ",", " ", 
    RowBox[{"t", "\[Element]", "Reals"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.472785750278442*^9, {3.472785782650997*^9, 3.472785815365753*^9}, {
   3.472785855114894*^9, 3.472785917204227*^9}, {3.472786133019876*^9, 
   3.472786164954703*^9}, {3.473834154*^9, 3.47383423134375*^9}, {
   3.473835137125*^9, 3.473835145921875*^9}},
 FontFamily->"Times",
 CellLabel->"In[39]:="],

Cell["Now we consider the isogonal trajectory as defined above", "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"kron", "[", 
    RowBox[{"0.5", ",", "0.8"}], "]"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{3.473834272171875*^9},
 FontFamily->"Times",
 CellLabel->"In[79]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"normal", "[", 
   RowBox[{".5", ",", " ", ".8"}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{
  3.472785738704326*^9, {3.47383429859375*^9, 3.47383430025*^9}, {
   3.473834403515625*^9, 3.47383441796875*^9}},
 FontFamily->"Times",
 CellLabel->"In[80]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"bincx", "[", "t_", "]"}], " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Chop", "[", "%", "]"}], ",", " ", 
    RowBox[{"t", ">", "0"}]}], "]"}]}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[81]:="],

Cell["\<\
If kron[a,c][t] would be a geodesic, the tangential component of this vector \
should vanish; but the following calculation shows that this is not the case.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ftest", "[", "t_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"dstorus", "[", ".8", "]"}], "[", 
    RowBox[{
     RowBox[{".5", "t"}], ",", "t"}], "]"}], ".", 
   RowBox[{"bincx", "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472787262742646*^9, 3.472787276848183*^9}, 
   3.472787412270585*^9, {3.473834481609375*^9, 3.47383449753125*^9}, 
   3.473834978921875*^9},
 FontFamily->"Times",
 CellLabel->"In[82]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"ftest", "[", "t", "]"}], ",", " ", 
   RowBox[{"t", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472787198792356*^9, 3.472787202979794*^9}, {
  3.472787289247943*^9, 3.472787336331311*^9}, {3.473834537859375*^9, 
  3.473834542578125*^9}},
 CellLabel->"In[83]:="],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.472787444944274*^9, {3.473834661828125*^9, 3.47383467209375*^9}},
 FontFamily->"Times",
 CellLabel->"In[84]:="],

Cell[BoxData[
 RowBox[{"Clear", "[", "ftest", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[85]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"ftest", "[", "t_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"dttorus", "[", ".8", "]"}], "[", 
    RowBox[{
     RowBox[{".5", "*", "t"}], ",", "t"}], "]"}], ".", 
   RowBox[{"bincx", "[", "t", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472787471547335*^9, 3.47278749112058*^9}, {
  3.47383529709375*^9, 3.473835321203125*^9}},
 FontFamily->"Times",
 CellLabel->"In[86]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"ftest", "[", "t", "]"}], ",", " ", 
   RowBox[{"t", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472787198792356*^9, 3.472787202979794*^9}, {
  3.472787289247943*^9, 3.472787336331311*^9}, {3.473835341109375*^9, 
  3.47383534153125*^9}},
 CellLabel->"In[87]:="],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.472787518036667*^9},
 FontFamily->"Times",
 CellLabel->"In[88]:="],

Cell["\<\
This shows that the isogonal trajectory cx is not a geodesic.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Clear", "[", "ftest", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[89]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["4.4.5 Graphics and tests with random kron curves", "Subsubsection",
 CellChangeTimes->{{3.47383561634375*^9, 3.473835619546875*^9}, {
  3.47383832234375*^9, 3.473838348515625*^9}, {3.473838683890625*^9, 
  3.4738386895*^9}, {3.474009732890625*^9, 3.474009736703125*^9}}],

Cell[TextData[{
 "Evaluate this subsection several times! You may change the definitionof the \
random parameters aa,cc under the condition ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", "cc", ")"}], "2"], " ", "<", " ", 
    RowBox[{
    "1", " ", "and", " ", "the", " ", "Range", " ", "for", " ", "the", " ", 
     "curve", " ", 
     RowBox[{"plot", ".", "  "}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "The generated graphics show the kron curve, its position on the \
corresponding torus, and two testfunctions for the tangent component of the \
curvature vector."
}], "Text",
 CellChangeTimes->{{3.473838711609375*^9, 3.47383881296875*^9}, {
  3.473838843859375*^9, 3.473839088*^9}, {3.473839123859375*^9, 
  3.473839278375*^9}}],

Cell[BoxData[
 RowBox[{"cc", "=", 
  RowBox[{
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "100"}], "}"}], "]"}], "/", "100"}]}]], "Input",
 CellChangeTimes->{{3.473835790171875*^9, 3.473835808515625*^9}, {
  3.473837215828125*^9, 3.4738372179375*^9}, {3.47383728615625*^9, 
  3.473837292984375*^9}, {3.473837369984375*^9, 3.473837381828125*^9}},
 CellLabel->"In[95]:="],

Cell[BoxData[
 RowBox[{"aa", "=", 
  RowBox[{"cc", "*", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{"{", 
     RowBox[{"1", ",", "20"}], "}"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.47383581465625*^9, 3.473835836328125*^9}, {
   3.47383703234375*^9, 3.47383703675*^9}, {3.47383709565625*^9, 
   3.473837098453125*^9}, {3.473837391671875*^9, 3.4738373925625*^9}, {
   3.473837423828125*^9, 3.473837456640625*^9}, {3.473838461671875*^9, 
   3.4738384706875*^9}, 3.473838535375*^9, 3.473919293875*^9},
 CellLabel->"In[96]:="],

Cell["Now we consider the isogonal trajectory as defined above", "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"kron", "[", 
    RowBox[{"aa", ",", "cc"}], "]"}], "[", "t", "]"}]}]], "Input",
 CellChangeTimes->{
  3.473834272171875*^9, {3.4738356880625*^9, 3.473835694890625*^9}},
 FontFamily->"Times",
 CellLabel->"In[141]:="],

Cell[BoxData[
 RowBox[{"grkr", " ", "=", 
  RowBox[{"ParametricPlot3D", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
    RowBox[{"PlotStyle", "->", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
    RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.473835945328125*^9, 3.473835977828125*^9}, {
   3.4738360201875*^9, 3.473836094828125*^9}, {3.473836232203125*^9, 
   3.473836289296875*^9}, {3.473836643828125*^9, 3.47383664528125*^9}, 
   3.473836696890625*^9, {3.47383673559375*^9, 3.47383676265625*^9}, {
   3.473836793203125*^9, 3.473836794984375*^9}, {3.4738371340625*^9, 
   3.473837145078125*^9}},
 CellLabel->"In[142]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"torus", "[", "cc", "]"}], "[", 
          RowBox[{"s", ",", "t"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"s", ",", "0", ",", 
           RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"2", " ", "\[Pi]"}], ",", ".1"}], "}"}]}], "]"}], ",", 
     "grkr"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"Boxed", "\[Rule]", " ", "False"}], ",", 
   RowBox[{"Axes", "\[Rule]", " ", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.473774048046875*^9, 3.4737740659375*^9}, {
   3.473836458765625*^9, 3.47383653846875*^9}, 3.4739201154375*^9},
 FontFamily->"Times",
 FontSize->14,
 CellLabel->"In[143]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"normal", "[", 
    RowBox[{"aa", ",", " ", "cc"}], "]"}], "[", "t", "]"}], ";"}]], "Input",
 CellChangeTimes->{
  3.472785738704326*^9, {3.47383429859375*^9, 3.47383430025*^9}, {
   3.473834403515625*^9, 3.47383441796875*^9}, {3.473835701671875*^9, 
   3.473835707125*^9}, 3.47383804515625*^9},
 FontFamily->"Times",
 CellLabel->"In[128]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"bincx", "[", "t_", "]"}], " ", "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Chop", "[", "%", "]"}], ",", " ", 
     RowBox[{"t", ">", "0"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.473838062796875*^9, 3.473919349765625*^9, 
  3.473919454375*^9},
 FontFamily->"Times",
 CellLabel->"In[129]:="],

Cell["\<\
If kron[a,c][t] would be a geodesic, the tangential component of this vector \
should vanish; but the following calculation shows that this is not the case.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ftest", "[", "t_", "]"}], "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dstorus", "[", "cc", "]"}], "[", 
      RowBox[{
       RowBox[{"aa", "*", "t"}], ",", "t"}], "]"}], ".", 
     RowBox[{"bincx", "[", "t", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.472787262742646*^9, 3.472787276848183*^9}, 
   3.472787412270585*^9, {3.473834481609375*^9, 3.47383449753125*^9}, 
   3.473834978921875*^9, {3.47383572796875*^9, 3.47383573940625*^9}, {
   3.4738378144375*^9, 3.473837822890625*^9}, 3.473838072140625*^9},
 FontFamily->"Times",
 CellLabel->"In[130]:="],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.472787444944274*^9, {3.473834661828125*^9, 3.47383467209375*^9}, {
   3.473836855375*^9, 3.473836858609375*^9}},
 FontFamily->"Times",
 CellLabel->"In[131]:="],

Cell[BoxData[
 RowBox[{"Clear", "[", "ftest", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[132]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ftest", "[", "t_", "]"}], "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"dttorus", "[", "cc", "]"}], "[", 
      RowBox[{
       RowBox[{"aa", "*", "t"}], ",", "t"}], "]"}], ".", 
     RowBox[{"bincx", "[", "t", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.472787471547335*^9, 3.47278749112058*^9}, {
   3.47383529709375*^9, 3.473835321203125*^9}, {3.473835765203125*^9, 
   3.47383577484375*^9}, {3.473837923921875*^9, 3.47383793534375*^9}, 
   3.473838086890625*^9},
 FontFamily->"Times",
 CellLabel->"In[133]:="],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.472787518036667*^9, {3.473836873703125*^9, 3.47383688178125*^9}},
 FontFamily->"Times",
 CellLabel->"In[134]:="],

Cell["\<\
This shows that the isogonal trajectory cx is not a geodesic.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Clear", "[", "ftest", "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[135]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5 Inversions at  hyperspheres", "Section",
 Evaluatable->False,
 CellChangeTimes->{{3.47383940065625*^9, 3.473839402375*^9}, 
   3.473864868046875*^9},
 FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell["\<\
Spherical reflections are fundamental in M\[ODoubleDot]bius geometry: every M\
\[ODoubleDot]bius transformation is a finite product of  \"Inversions\" ( = \
spherical reflections). They appear also in complex function  theory as the \
simplest conformal maps not being isometries (= motions). We construct a \
module for the spherical reflection in n dimension, and show the basic \
properties of these maps: they map circles in lines or circle, generally \
k-dimensional subspheres into k-planes or k-subspheres, and are conformal. \
Since inversions map the infinite outer region of  a sphere onto the inner \
region, and the infinite point to the center of the sphere, these maps may be \
used to visualize the behavior of figures or functions at  infinity. An \
example is the image of the spriral cylinder constructed in subsection 5.4.\
\>", "Text",
 CellChangeTimes->{{3.47278791136295*^9, 3.472787950060976*^9}, {
  3.473917684203125*^9, 3.473917698015625*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.1 Spherical reflections", "Subsection",
 FontFamily->"Times",
 FontSize->14],

Cell[TextData[{
 "Inversions at arbitrary hyperspheres are defined in the package euvec.m.  \
Two points x,y \[Element] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", 
    RowBox[{"n", "+", "1"}]], TraditionalForm]]],
 "are in inversion with respect to the hypersphere ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["S", "n"], "(", 
     RowBox[{"a", ",", "r"}], ")"}], " "}], TraditionalForm]]],
 "with center a and radius r, if the rays a\[Or]x, a\[Or]y coincide, and the \
distances fulfil"
}], "Text"],

Cell[BoxData[
 RowBox[{"|", 
  RowBox[{"y", "-", "a"}], "|", 
  RowBox[{"*", 
   RowBox[{"|", 
    RowBox[{"x", "-", "a"}], "|", 
    RowBox[{"\[Equal]", 
     SuperscriptBox["r", "2"]}]}]}]}]], "Input",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"?", "sphericalreflection"}]], "Input",
 CellLabel->"In[84]:="],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sphericalreflection", "[", 
    RowBox[{
     RowBox[{"{", "Infinity", "}"}], ",", "a_List", ",", 
     RowBox[{"r_:", "1"}]}], "]"}], ":=", "a"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sphericalreflection", "[", 
   RowBox[{"x_List", ",", "a_List", ",", 
    RowBox[{"r_:", "1"}]}], "]"}], ":=", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Not", "[", 
     RowBox[{"x", "\[Equal]", "a"}], "]"}], ",", 
    RowBox[{"a", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "a"}], ")"}], "*", 
        RowBox[{"r", "^", "2"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "a"}], ")"}], ".", 
        RowBox[{"(", 
         RowBox[{"x", "-", "a"}], ")"}]}], ")"}]}]}], ",", 
    RowBox[{"{", "Infinity", "}"}], ",", 
    RowBox[{"a", "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "a"}], ")"}], "*", 
        RowBox[{"r", "^", "2"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "a"}], ")"}], ".", 
        RowBox[{"(", 
         RowBox[{"x", "-", "a"}], ")"}]}], ")"}]}]}]}], "]"}]}]}], "Input",
 Evaluatable->False],

Cell["The reflection at the unit sphere can be defined simpler:", "Text"],

Cell["refl[x_List] := x/(x.x)", "Input",
 PageWidth->Infinity,
 InitializationCell->True,
 FontFamily->"Times",
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"refl", "::", "usage"}], " ", "=", " ", 
   "\"\<refl[x] is the image of the point x under spherical reflection \
(inversion) at the standard unit hypersphere of the n-dimensional Euclidean \
space.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.4729718475*^9},
 CellLabel->"In[41]:="],

Cell[CellGroupData[{

Cell["Tests", "Subsubsection",
 FontFamily->"Times",
 FontSize->14],

Cell[BoxData[
 RowBox[{"refl", "[", 
  RowBox[{"{", 
   RowBox[{"5", ",", "5", ",", "0", ",", "0"}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[88]:="],

Cell[BoxData[
 RowBox[{"refl", "[", 
  RowBox[{"{", 
   RowBox[{"2", ",", "2", ",", "2."}], "}"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{"refl", "[", 
  RowBox[{"vec", "[", "x", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[90]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"%", ".", "%"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"vec", "[", "x", "]"}], ".", 
      RowBox[{"vec", "[", "x", "]"}]}], ")"}]}], " ", "]"}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[91]:="],

Cell["Abbreviating we define", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sr", "[", 
   RowBox[{"x_List", ",", "a_List", ",", 
    RowBox[{"r_:", "1"}]}], "]"}], ":=", 
  RowBox[{"sphericalreflection", "[", 
   RowBox[{"x", ",", "a", ",", "r"}], "]"}]}]], "Input",
 CellLabel->"In[92]:="],

Cell[BoxData[
 RowBox[{"sr", "[", 
  RowBox[{
   RowBox[{"vec", "[", "x", "]"}], ",", 
   RowBox[{"vec", "[", "a", "]"}], ",", "r"}], "]"}]], "Input",
 CellLabel->"In[93]:="],

Cell["We confirm the distance condition formulated above", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"%", "-", 
     RowBox[{"vec", "[", "a", "]"}]}], ")"}], ".", 
   RowBox[{"(", 
    RowBox[{"%", "-", 
     RowBox[{"vec", "[", "a", "]"}]}], ")"}]}], "*", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"vec", "[", "x", "]"}], "-", 
      RowBox[{"vec", "[", "a", "]"}]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"vec", "[", "x", "]"}], "-", 
      RowBox[{"vec", "[", "a", "]"}]}], ")"}]}], ")"}]}]], "Input",
 CellLabel->"In[94]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[95]:="],

Cell["Any point of the hypersphere itself remains fixed:", "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"sr", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"vec", "[", "a", "]"}], " ", "+", " ", 
     RowBox[{
      RowBox[{"unit3", "[", 
       RowBox[{"s", ",", "t", ",", "u"}], "]"}], "*", "r"}]}], ",", " ", 
    RowBox[{"vec", "[", "a", "]"}], ",", "r"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472789177048724*^9, 3.472789188215775*^9}},
 CellLabel->"In[111]:="],

Cell[BoxData[
 RowBox[{"%", "\[Equal]", " ", 
  RowBox[{
   RowBox[{"vec", "[", "a", "]"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"unit3", "[", 
     RowBox[{"s", ",", "t", ",", "u"}], "]"}], "*", "r"}]}]}]], "Input",
 CellLabel->"In[112]:="],

Cell["The spherical reflections are involutive:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"sr", "[", 
    RowBox[{
     RowBox[{"sr", "[", 
      RowBox[{
       RowBox[{"vec", "[", "x", "]"}], ",", 
       RowBox[{"vec", "[", "a", "]"}], ",", "r"}], "]"}], ",", 
     RowBox[{"vec", "[", "a", "]"}], ",", "r"}], "]"}], "]"}], "\[Equal]", 
  " ", 
  RowBox[{"vec", "[", "x", "]"}]}]], "Input",
 CellChangeTimes->{{3.472788740175874*^9, 3.47278877518747*^9}, {
  3.472788813863194*^9, 3.472788845427971*^9}, {3.472788950447508*^9, 
  3.472788959902716*^9}},
 CellLabel->"In[108]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sr", "[", 
   RowBox[{
    RowBox[{"sr", "[", 
     RowBox[{
      RowBox[{"{", "Infinity", "}"}], ",", 
      RowBox[{"vec", "[", "a", "]"}], ",", "r"}], "]"}], ",", 
    RowBox[{"vec", "[", "a", "]"}], ",", "r"}], "]"}], "\[Equal]", " ", 
  RowBox[{"{", "Infinity", "}"}]}]], "Input",
 CellChangeTimes->{{3.472789022970405*^9, 3.472789053387267*^9}, {
  3.472789086029584*^9, 3.472789094682769*^9}},
 CellLabel->"In[110]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
5.2 Planes and spheres are transformed into planes or spheres\
\>", "Subsection",
 FontFamily->"Times",
 FontSize->14],

Cell[CellGroupData[{

Cell["\<\
5.2.1 The unit square in the plane z = 1 is transformed into a spherical \
region:\
\>", "Subsubsection"],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"refl", "[", 
    RowBox[{"{", 
     RowBox[{"u", ",", " ", "v", ",", " ", "1"}], "}"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"u", ",", " ", "0", ",", " ", "1"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", " ", "0", ",", " ", "1"}], "}"}]}], "]"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[113]:="],

Cell[BoxData[
 RowBox[{"tgr1", " ", "=", " ", "%"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[23]:="],

Cell["\<\
Table[ParametricPlot3D[refl[{u, v, k}], {u, 0, 1}, {v, 0, 1}], 
{k, 1, 6}]\
\>", "Input",
 PageWidth->Infinity,
 FontFamily->"Times",
 CellLabel->"In[116]:="],

Cell["Show[%,PlotRange \[Rule] All]", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.472791072218899*^9, 3.472791079507448*^9}},
 FontFamily->"Times",
 CellLabel->"In[117]:="],

Cell[BoxData[
 RowBox[{"tgr2", " ", "=", "%"}]], "Input",
 FontFamily->"Times",
 CellLabel->"In[26]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2.2  Reflection of a random sphere", "Subsubsection"],

Cell["We set now", "Text"],

Cell[BoxData[
 RowBox[{"dim", " ", "=", " ", "3"}]], "Input",
 CellLabel->"In[118]:="],

Cell["\<\
generate a random sphere,  apply refl, and Plot the sphere  and its image \
under refl, which is a sphere (up to numerical distortions)\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ftest", "[", 
    RowBox[{"s_", ",", "t_"}], "]"}], " ", "=", 
   RowBox[{
    RowBox[{"3", "*", 
     RowBox[{"randomv", "[", "]"}]}], " ", "+", 
    RowBox[{"2", "*", 
     RowBox[{"RandomReal", "[", "]"}], "*", 
     RowBox[{
      RowBox[{"unit", "[", "2", "]"}], "[", 
      RowBox[{"{", 
       RowBox[{"s", ",", "t"}], "}"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{"%", ",", " ", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", "  ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Opacity", "[", ".1", "]"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.472791326874826*^9, 3.472791328013554*^9}, {
   3.472791388936573*^9, 3.472791445342967*^9}, {3.472791597342796*^9, 
   3.47279160631447*^9}, 3.472791731191461*^9, {3.47279201545839*^9, 
   3.472792025625524*^9}, 3.472792124937412*^9, {3.472792247308251*^9, 
   3.472792263261575*^9}, {3.472792506685084*^9, 3.472792509838688*^9}},
 CellLabel->"In[150]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"refl", "[", 
    RowBox[{"ftest", "[", 
     RowBox[{"s", ",", "t"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{
      RowBox[{"-", "Pi"}], "/", "2"}], ",", " ", 
     RowBox[{"Pi", "/", "2"}]}], "}"}], ",", " ", 
   RowBox[{"PlotPoints", "\[Rule]", "70"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Opacity", "[", ".3", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472791326874826*^9, 3.472791328013554*^9}, {
  3.472791388936573*^9, 3.472791445342967*^9}, {3.472791597342796*^9, 
  3.47279160631447*^9}},
 CellLabel->"In[152]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"%", ",", "%%"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472791490601684*^9, 3.472791500180947*^9}},
 CellLabel->"In[153]:="],

Cell[BoxData[
 RowBox[{"Clear", "[", "ftest", "]"}]], "Input",
 CellChangeTimes->{{3.472792575377107*^9, 3.472792583609336*^9}},
 CellLabel->"In[154]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2.3 Reflection of  planes", "Subsubsection"],

Cell[BoxData[
 RowBox[{"ttt", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"randomv", "[", "]"}], ",", 
    RowBox[{"{", "3", "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[155]:="],

Cell[BoxData[
 RowBox[{"ttn", " ", "=", " ", 
  RowBox[{"esorthonorm", "[", "%", "]"}]}]], "Input",
 CellLabel->"In[156]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"pl", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"30", "*", 
    RowBox[{"ttn", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"ttn", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "*", "u"}], " ", "+", " ", 
   RowBox[{
    RowBox[{"ttn", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "*", "v"}]}]}]], "Input",
 CellLabel->"In[157]:="],

Cell["The next pl is a fixed randomly generated plane:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pl", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"21.304214864757284`", "\[InvisibleSpace]", "-", 
     RowBox[{"0.11151679499053971`", " ", "u"}], "-", 
     RowBox[{"0.695172267209748`", " ", "v"}]}], ",", 
    RowBox[{"2.0842209786609383`", "\[InvisibleSpace]", "+", 
     RowBox[{"0.9936567546174803`", " ", "u"}], "-", 
     RowBox[{"0.08842857453498164`", " ", "v"}]}], ",", 
    RowBox[{"21.01871670460317`", "\[InvisibleSpace]", "+", 
     RowBox[{"0.014500290965856108`", " ", "u"}], "+", 
     RowBox[{"0.7133834215260191`", " ", "v"}]}]}], "}"}]}]], "Input",
 CellLabel->"In[158]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"refl", "[", 
    RowBox[{"pl", "[", 
     RowBox[{"u", ",", "v"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{"-", "220"}], ",", "220"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"v", ",", 
     RowBox[{"-", "220"}], ",", "220"}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "80"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellLabel->"In[169]:="],

Cell["\<\
Obviously, the complete image is a sphere through the origin:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"%", ",", 
   RowBox[{"ViewPoint", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2.341"}], ",", 
      RowBox[{"-", " ", "1.257"}], ",", " ", 
      RowBox[{"-", "2.095"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472792768245596*^9, 3.47279277869952*^9}, {
  3.472793146910317*^9, 3.472793162825356*^9}},
 CellLabel->"In[171]:="],

Cell[BoxData[
 RowBox[{"Graphics3D", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"PointSize", "[", ".03", "]"}], ",", 
    RowBox[{"Point", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{3.472793066761493*^9},
 CellLabel->"In[172]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{"%%", ",", "%"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472792811624928*^9, 3.472792965074919*^9}, {
   3.472793009688934*^9, 3.472793043737486*^9}, 3.472793181577362*^9},
 CellLabel->"In[173]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "pl", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.472793286285411*^9, 3.4727932865145*^9}},
 CellLabel->"In[174]:="],

Cell[BoxData[
 RowBox[{"dim", " ", "=", " ", "4"}]], "Input",
 CellLabel->"In[175]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2.4 Proof of the general statement", "Subsubsection"],

Cell["\<\
Without restriction of generality we consider the reflection refl at the \
standard unit sphere. We start with the 3-dimensional case.\
\>", "Text",
 CellChangeTimes->{{3.472796446089631*^9, 3.472796454001333*^9}}],

Cell[BoxData[
 RowBox[{"refl", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472796461765724*^9, 3.472796464467789*^9}, 
   3.472797714970048*^9},
 CellLabel->"In[211]:="],

Cell["\<\
The restriction of refl  to the sphere with center {m, 0,0} and radius r, r^2 \
\[NotEqual] m^2, leads to\
\>", "Text",
 CellChangeTimes->{{3.472796479623952*^9, 3.472796490246692*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "0", ",", "0"}], "}"}], ",", "r"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellLabel->"In[205]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"refl", "[", " ", 
   RowBox[{
    RowBox[{"sphere", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"m", ",", "0", ",", "0"}], "}"}], ",", "r"}], "]"}], "[", 
    RowBox[{"u", ",", "v"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472795397838089*^9, 3.472795446065733*^9}, {
   3.472795480889981*^9, 3.472795488879074*^9}, 3.472796717308411*^9, {
   3.47279776918185*^9, 3.472797780109886*^9}},
 CellLabel->"In[212]:="],

Cell["Four points of the sphere are", "Text",
 CellChangeTimes->{{3.472796750887401*^9, 3.472796761675043*^9}}],

Cell[BoxData[
 RowBox[{"pts", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "+", 
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "u", "]"}], " ", 
        RowBox[{"Cos", "[", "v", "]"}]}]}], ",", 
      RowBox[{"r", " ", 
       RowBox[{"Cos", "[", "v", "]"}], " ", 
       RowBox[{"Sin", "[", "u", "]"}]}], ",", 
      RowBox[{"r", " ", 
       RowBox[{"Sin", "[", "v", "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "-", "r"}], ",", "0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "+", "r"}], ",", "0", ",", "0"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"m", ",", "r", ",", "0"}], "}"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.472796771946173*^9, 3.47279691090225*^9}, {
   3.472796949637101*^9, 3.472796984120893*^9}, {3.472797023376995*^9, 
   3.472797064073887*^9}, {3.472797099190015*^9, 3.472797114516648*^9}, 
   3.472797466222674*^9},
 CellLabel->"In[206]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sphere", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"m", ",", "0", ",", "0"}], "}"}], ",", "r"}], "]"}], "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.472796553612218*^9, 3.472796602281762*^9}, {
  3.47279665301189*^9, 3.472796658090863*^9}},
 CellLabel->"In[198]:="],

Cell["The  images of these points under refl are", "Text",
 CellChangeTimes->{{3.472795781185122*^9, 3.472795782037979*^9}, {
  3.472795852413712*^9, 3.472795919302764*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"rpts", " ", "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Map", "[", 
     RowBox[{"refl", ",", "pts"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.472797809134822*^9, 3.472797818877805*^9}},
 CellLabel->"In[213]:="],

Cell["\<\
The spheres through these 4 points  have constant radii and centers\
\>", "Text",
 CellChangeTimes->{{3.472796130996612*^9, 3.472796185253211*^9}, {
   3.472797880369467*^9, 3.472797934034424*^9}, 3.4733964925625*^9}],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"radius", "[", "rpts", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472796195003228*^9, 3.472796221027971*^9}, {
  3.472797566958503*^9, 3.472797574968159*^9}},
 CellLabel->"In[209]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"center", "[", "rpts", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.472796195003228*^9, 3.472796221027971*^9}, {
   3.472797566958503*^9, 3.472797574968159*^9}, {3.472797632004148*^9, 
   3.472797641986454*^9}, 3.4733964925625*^9},
 CellLabel->"In[210]:="],

Cell["\<\
Therefore the image point refl[sphere[{m, 0, 0}, r][u, v]] belongs to the \
sphere with these radius and cebtre, and we conclude\
\>", "Text",
 CellChangeTimes->{{3.472797983088283*^9, 3.472798038395229*^9}, {
  3.472798085431661*^9, 3.472798158803782*^9}}],

Cell[TextData[{
 StyleBox["PROPOSITION",
  FontColor->RGBColor[0, 0, 1]],
 ". The image of a hypersphere ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]]],
 "\[Subset] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 " of the n-dimensional Euclidean space, with distance m of its center to the \
origin and radius r, m^2 \[NotEqual] r^2, under the map refl is the \
hypersphere with distance  ms and radius rs,"
}], "Text",
 CellChangeTimes->{{3.472798251930633*^9, 3.472798253698144*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ms", "[", 
   RowBox[{"m_", ",", "r_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"m", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"m", "^", "2"}], "-", 
      RowBox[{"r", "^", "2"}]}], ")"}]}], "  "}]}]], "Input",
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"rs", "[", 
   RowBox[{"m_", ",", "r_"}], "]"}], " ", ":=", " ", 
  RowBox[{"r", "/", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"m", "^", "2"}], "-", 
     RowBox[{"r", "^", "2"}]}], "]"}]}], " "}]], "Input",
 CellLabel->"In[38]:="],

Cell["\<\
where in case m \[NotEqual] 0 the centers and the origin are collinear.\
\>", "Text"],

Cell["\<\
Proof. Indeed we proved this in the case n=3,  taking the x-axis as the line \
through the center of the preimage sphere and the origin. The x,y-plane z = 0 \
is invariant under refl:\
\>", "Text",
 CellChangeTimes->{{3.472798335060997*^9, 3.472798339536915*^9}, 
   3.472798382338421*^9, {3.47279853741571*^9, 3.47279853938406*^9}, {
   3.472798579180439*^9, 3.472798586592408*^9}, {3.472798621598909*^9, 
   3.472798674896187*^9}, {3.472798982469406*^9, 3.472799050847786*^9}}],

Cell[BoxData[
 RowBox[{"refl", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "0"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472798929441759*^9, 3.472798943379875*^9}},
 CellLabel->"In[214]:="],

Cell["the statement is true for n = 2, too. ", "Text",
 CellChangeTimes->{{3.472799120482048*^9, 3.472799137217556*^9}}],

Cell[TextData[{
 "Now we consider the bundle of the 3-dimensional Euclidean subspace in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 " through the line connecting the origin with the center. "
}], "Text",
 CellChangeTimes->{{3.472798335060997*^9, 3.472798339536915*^9}, 
   3.472798382338421*^9, {3.47279853741571*^9, 3.47279853938406*^9}, {
   3.472798579180439*^9, 3.472798586592408*^9}, {3.472798621598909*^9, 
   3.472798674896187*^9}, {3.472798982469406*^9, 3.472799050847786*^9}, {
   3.472799185108251*^9, 3.472799195706292*^9}, {3.472799244120689*^9, 
   3.472799294752965*^9}, 3.472799378461993*^9}],

Cell["\<\
Since the great 2-spheres (meridians) under rotations around this line \
generate the hypersphere, and the formulas are valid for any meridian, they \
are valid for the hypersphere, too, q.e.d. \
\>", "Text",
 CellChangeTimes->{{3.472798694698034*^9, 3.472798728976578*^9}, 
   3.472798784000757*^9, {3.472799402572413*^9, 3.472799446328577*^9}}],

Cell["\<\
Now we shall find the image of a line of distance p\[NotEqual]0 under refl:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"refl", "[", 
   RowBox[{"{", 
    RowBox[{"p", ",", "t"}], "}"}], "]"}], "]"}]], "Input",
 CellLabel->"In[215]:="],

Cell[BoxData[
 RowBox[{"Eliminate", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xs", " ", "\[Equal]", 
      FractionBox["p", 
       RowBox[{
        SuperscriptBox["p", "2"], "+", 
        SuperscriptBox["t", "2"]}]]}], ",", " ", 
     RowBox[{"ys", " ", "\[Equal]", "  ", 
      FractionBox["t", 
       RowBox[{
        SuperscriptBox["p", "2"], "+", 
        SuperscriptBox["t", "2"]}]]}]}], "}"}], ",", " ", "t"}], 
  "]"}]], "Input",
 CellLabel->"In[216]:="],

Cell["The last equation is equivalent to ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"xs", " ", "-", " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", "p"}], ")"}]}]}], ")"}], "^", "2"}], " ", "+", " ", 
   RowBox[{"ys", "^", "2"}]}], " ", "\[Equal]", " ", 
  RowBox[{"1", "/", 
   RowBox[{"(", 
    RowBox[{"4", 
     RowBox[{"p", "^", "2"}]}], ")"}]}]}]], "Input"],

Cell["Similar as the foregoing proposition we may prove", "Text"],

Cell[TextData[{
 StyleBox["PROPOSITION",
  FontColor->RGBColor[0, 0, 1]],
 ". The image of a hyperplane ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["H", 
    RowBox[{"n", "-", "1"}]], TraditionalForm]]],
 "\[Subset] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["E", "n"], TraditionalForm]]],
 " with distance p\[NotEqual]0 to the origin is the hyperphere of radius \
Abs[1/(2p)]   through the origin with center on the perpendicular through the \
origin to the hyperplane.  Since refl is involutive, in the converse the \
hyperspheres through the center, i. e. those for which m^2 == r^2,  are \
mapped on hypeplanes with distance 1/(2r) to the center, which are parallel \
to the tangent hyperplane of the hypersphere at the origin.  In the case p=0  \
the hyperplanes contain the origin and are mapped onto itself. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2.5 Illustrating examples n the plane", "Subsubsection"],

Cell["\<\
Of course, any point of the standard unit circle remains fixed:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"refl", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], ",", 
     RowBox[{"Sin", "[", "t", "]"}]}], "}"}], "]"}], "]"}]], "Input",
 CellLabel->"In[31]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", "t", "]"}], ",", 
     RowBox[{"Sin", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "50"}], ",", " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "Automatic"}]}], 
  "]"}]], "Input",
 CellLabel->"In[32]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"grc1", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472801053893218*^9},
 CellLabel->"In[33]:="],

Cell["This is the circle with m=2, r=.5;", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "+", 
      RowBox[{".5", "*", 
       RowBox[{"Cos", "[", "t", "]"}]}]}], ",", " ", 
     RowBox[{".5", "*", 
      RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "50"}], ",", " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "Automatic"}]}], 
  "]"}]], "Input",
 CellLabel->"In[64]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"grc", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472800940535194*^9},
 CellLabel->"In[65]:="],

Cell["The image of the circle with m=2, r =.5", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"refl", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", "+", 
       RowBox[{".5", "*", 
        RowBox[{"Cos", "[", "t", "]"}]}]}], ",", " ", 
      RowBox[{".5", "*", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "50"}], ",", " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "Automatic"}]}], 
  "]"}]], "Input",
 CellLabel->"In[36]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"grc0", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472800960270059*^9},
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"grc1", ",", "grc", ",", "grc0"}], "}"}], ",", " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "Automatic"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472801125930204*^9, 3.472801133723945*^9}},
 CellLabel->"In[67]:="],

Cell["The image of the circle with m = 0, r = .5", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"refl", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{".5", "*", 
       RowBox[{"Cos", "[", "t", "]"}]}], ",", " ", 
      RowBox[{".5", "*", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "50"}]}], "]"}]], "Input",
 CellChangeTimes->{3.472801166669252*^9},
 CellLabel->"In[68]:="],

Cell["The circle with m=1,r=.5", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{".5", "*", 
       RowBox[{"Cos", "[", "t", "]"}]}]}], ",", " ", 
     RowBox[{".5", "*", 
      RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "50"}], ",", " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "Automatic"}]}], 
  "]"}]], "Input",
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"grc3", " ", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472801231484677*^9},
 CellLabel->"In[70]:="],

Cell["The image of the circle with m =1, r = .5", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"refl", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "+", 
       RowBox[{".5", "*", 
        RowBox[{"Cos", "[", "t", "]"}]}]}], ",", " ", 
      RowBox[{".5", "*", 
       RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "50"}], ",", " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "Automatic"}]}], 
  "]"}]], "Input",
 CellLabel->"In[71]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"grc4", " ", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472801251946913*^9},
 CellLabel->"In[72]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"grc1", ",", "grc4"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472801283649508*^9, 3.472801291473657*^9}},
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"grc1", ",", "grc3", ",", "grc4"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{3.472801320642927*^9},
 CellLabel->"In[74]:="],

Cell["The case m=r=2", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "+", 
      RowBox[{"2", "*", 
       RowBox[{"Cos", "[", "t", "]"}]}]}], ",", " ", 
     RowBox[{"2", "*", 
      RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "50"}], ",", " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "Automatic"}]}], 
  "]"}]], "Input",
 CellLabel->"In[75]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"grc5", " ", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.472801359222451*^9, 3.472801363370436*^9}},
 CellLabel->"In[76]:="],

Cell["The next Graphics is a parallel to the z-axis:", "Text",
 CellChangeTimes->{{3.472801587513201*^9, 3.472801595385821*^9}, {
  3.47280198842658*^9, 3.472801996905964*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"refl", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Cos", "[", "t", "]"}]}]}], ",", " ", 
       RowBox[{"2", "*", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "Pi"}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "50"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472801400995937*^9, 3.472801408145588*^9}, {
  3.47280151194297*^9, 3.472801522325316*^9}, {3.472801611276181*^9, 
  3.472801647183065*^9}},
 CellLabel->"In[81]:="],

Cell[BoxData[
 RowBox[{"refl", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"2", "+", 
     RowBox[{"2", "*", 
      RowBox[{"Cos", "[", "t", "]"}]}]}], ",", " ", 
    RowBox[{"2", "*", 
     RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], "]"}]], "Input",
 CellLabel->"In[55]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"N", "[", 
    RowBox[{"refl", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "+", 
        RowBox[{"2", "*", 
         RowBox[{"Cos", "[", "t", "]"}]}]}], ",", " ", 
       RowBox[{"2", "*", 
        RowBox[{"Sin", "[", "t", "]"}]}]}], "}"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0.1", ",", " ", "3.1", ",", " ", 
     RowBox[{"3", "/", "10"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472801663722969*^9, 3.472801699209053*^9}},
 CellLabel->"In[82]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"tabrefl", " ", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472801750303046*^9},
 CellLabel->"In[83]:="],

Cell["Obviously, the image is the line xs =0.25:", "Text"],

Cell[BoxData[
 RowBox[{"refl", "[", 
  RowBox[{"{", 
   RowBox[{"0", ",", "4."}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.472801918208386*^9, 3.472801966813847*^9}},
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{".25", ",", " ", "t"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[90]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"grl1", " ", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472802015553541*^9},
 CellLabel->"In[91]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"grc1", ",", "grl1", ",", "grc5"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472802056900328*^9, 3.472802065630031*^9}},
 CellLabel->"In[93]:="],

Cell["We plot the inverse map", "Text"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"refl", "[", 
     RowBox[{"{", 
      RowBox[{"0.25", ",", " ", "t"}], "}"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"PlotPoints", " ", "\[Rule]", "50"}], ",", " ", 
   RowBox[{"AspectRatio", " ", "\[Rule]", " ", "Automatic"}]}], 
  "]"}]], "Input",
 CellLabel->"In[94]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.3 Conformity", "Subsection",
 CellChangeTimes->{{3.472800462922324*^9, 3.472800472617427*^9}},
 FontFamily->"Times",
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"ft", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", " ", 
  RowBox[{"refl", "[", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[217]:="],

Cell[BoxData[
 RowBox[{"ft", "[", 
  RowBox[{"x", ",", "y", ",", "z"}], "]"}]], "Input",
 CellLabel->"In[218]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "[", "1", "]"}], " ", "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"ft", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[219]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "[", "2", "]"}], " ", "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"ft", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", "y"}], "]"}]}]], "Input",
 CellLabel->"In[220]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "[", "3", "]"}], " ", "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"ft", "[", 
     RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", "z"}], "]"}]}]], "Input",
 CellLabel->"In[221]:="],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"v", "[", "i", "]"}], ".", 
    RowBox[{"v", "[", "j", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "3"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"j", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[222]:="],

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellLabel->"In[223]:="],

Cell[TextData[{
 "It follows, that the differential drefl at the point (x,y,z) is a \
dilatation with factor 1/(",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["x", "2"], "+", 
   SuperscriptBox["y", "2"], "+", 
   SuperscriptBox["z", "2"]}]]],
 "), thus the map refl is conformal. The same proof can be given for  the \
general spherical reflection."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.4 Spirals, spiral cylinder and their inversions", "Subsection",
 CellChangeTimes->{{3.47287563362803*^9, 3.472875649359831*^9}, {
  3.472875692337308*^9, 3.472875751295621*^9}}],

Cell[CellGroupData[{

Cell["5.4.1 Spiral transformations, the logarithmic spirals", "Subsubsection",
 CellChangeTimes->{{3.472875770610362*^9, 3.472875785069639*^9}, {
  3.474002563625*^9, 3.474002690734375*^9}, {3.47400274646875*^9, 
  3.47400275028125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dim", " ", "=", " ", "3"}], ";"}]], "Input",
 CellChangeTimes->{{3.472876246222296*^9, 3.472876252549995*^9}},
 CellLabel->"In[40]:="],

Cell["\<\
The spiral transformation of the Euclidean 3-space is defined  as the linear \
transformation with the following matrix:\
\>", "Text",
 CellChangeTimes->{{3.472876262269426*^9, 3.472876303650829*^9}, {
  3.472876382303408*^9, 3.47287641861073*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"spiral", "::", "usage"}], " ", "=", " ", "\n", 
   "\"\<spiral[t,a] is the rotation with angle t around the z-axis and \n\t\
simultaneous dilatation with the factor Exp[t a].\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.472876168447335*^9, 3.472876209506183*^9},
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"spiral", "[", 
   RowBox[{"t_", ",", " ", "a_"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Cos", "[", "t", "]"}], ",", " ", 
       RowBox[{"Sin", "[", "t", "]"}], ",", " ", "0"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sin", "[", "t", "]"}]}], ",", " ", 
       RowBox[{"Cos", "[", "t", "]"}], ",", " ", "0"}], "}"}], ",", " ", "\n", 
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], "}"}], " ", 
   RowBox[{"Exp", "[", 
    RowBox[{"t", " ", "a"}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"spiral", "[", 
   RowBox[{"t", ",", "a"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.47287631338543*^9, 3.472876336054146*^9}},
 CellLabel->"In[43]:="],

Cell["\<\
These matrices with  real variable t  and fixed parameter a form a \
1-parameter subgroup of the linear group:\
\>", "Text",
 CellChangeTimes->{{3.472876440425771*^9, 3.472876557283007*^9}}],

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"spiral", "[", 
    RowBox[{
     RowBox[{"s", "+", "t"}], ",", "a"}], "]"}], "\[Equal]", " ", 
   RowBox[{
    RowBox[{"spiral", "[", 
     RowBox[{"s", ",", "a"}], "]"}], ".", 
    RowBox[{"spiral", "[", 
     RowBox[{"t", ",", "a"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472876567863201*^9, 3.472876653050911*^9}},
 CellLabel->"In[44]:="],

Cell["\<\
For a = 0 we simply obtain the rotations around the z_axis; in the following \
we silently assume a  \[NotEqual] 0 and name the corresponding group a spiral \
group.\
\>", "Text",
 CellChangeTimes->{{3.472878944447071*^9, 3.472879006197246*^9}, {
  3.472879039934784*^9, 3.472879159386309*^9}}],

Cell["The fixed points are the solutions of", "Text",
 CellChangeTimes->{{3.472876783683276*^9, 3.472876795891017*^9}, {
  3.472877152072124*^9, 3.47287717609819*^9}}],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"spiral", "[", 
      RowBox[{"t", ",", "a"}], "]"}], ".", 
     RowBox[{"vec", "[", "x", "]"}]}], "\[Equal]", " ", 
    RowBox[{"vec", "[", "x", "]"}]}], ",", 
   RowBox[{"vec", "[", "x", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472876803374299*^9, 3.47287688152176*^9}},
 CellLabel->"In[45]:="],

Cell["\<\
The single fixed point is the origin. The 1-dimensional orbits are given by\
\>", "Text",
 CellChangeTimes->{{3.472876923630053*^9, 3.472876925659783*^9}, {
  3.472877122938245*^9, 3.472877135851285*^9}, {3.472877224161861*^9, 
  3.472877224965466*^9}, {3.472877269278332*^9, 3.472877301490133*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"spir", "[", 
    RowBox[{"b_List", ",", "a_"}], "]"}], "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"spiral", "[", 
    RowBox[{"t", ",", "a"}], "]"}], ".", "b"}]}]], "Input",
 CellChangeTimes->{{3.472877317305451*^9, 3.472877383509272*^9}},
 CellLabel->"In[46]:="],

Cell["with vec[b] \[NotEqual] null[]:", "Text",
 CellChangeTimes->{{3.472877564529715*^9, 3.472877654727991*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"spir", "[", 
   RowBox[{
    RowBox[{"vec", "[", "b", "]"}], ",", "a"}], "]"}], "[", "t", 
  "]"}]], "Input",
 CellChangeTimes->{{3.472877403320147*^9, 3.472877417465989*^9}},
 CellLabel->"In[47]:="],

Cell["Special cases are the open positive or negative half z-axes", "Text",
 CellChangeTimes->{{3.47287769616533*^9, 3.472877800275385*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"spir", "[", 
   RowBox[{
    RowBox[{"stb", "[", "3", "]"}], ",", "a"}], "]"}], "[", "t", 
  "]"}]], "Input",
 CellChangeTimes->{{3.472877824814742*^9, 3.472877849346663*^9}},
 CellLabel->"In[48]:="],

Cell["All the other orbits are in general spacelike spirals", "Text",
 CellChangeTimes->{{3.472878088318655*^9, 3.472878152185545*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"spir", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", "a"}], "]"}], "[", "t", 
  "]"}]], "Input",
 CellChangeTimes->{{3.472877925146831*^9, 3.472877951246861*^9}},
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"spir", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", ".2"}], "]"}], "[", "t",
     "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "8"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472878159000845*^9, 3.472878261993854*^9}, {
  3.472878323542479*^9, 3.472878324880814*^9}},
 CellLabel->"In[50]:="],

Cell["\<\
In the case b[3] = 0 we obtain plane curves, the logarithmic spirals:\
\>", "Text",
 CellChangeTimes->{{3.472878410283911*^9, 3.47287845215288*^9}, {
  3.472885161622738*^9, 3.47288516239864*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"spir", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"c", ",", "d", ",", "0"}], "}"}], ",", "a"}], "]"}], "[", "t", 
  "]"}]], "Input",
 CellChangeTimes->{3.47287871749714*^9},
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"spir", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", ".2"}], "]"}], "[", "t",
     "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "8"}], "}"}], ",", 
   RowBox[{"PlotStyle", " ", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Green", ",", " ", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472878159000845*^9, 3.472878261993854*^9}, {
   3.472878323542479*^9, 3.472878324880814*^9}, 3.472878496490678*^9, {
   3.472882942806333*^9, 3.472882963146724*^9}},
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sp1", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.472882982408711*^9, 3.47288298736978*^9}},
 CellLabel->"In[53]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"logspir", "[", 
    RowBox[{"c_", ",", "a_"}], "]"}], "[", "t_", "]"}], " ", ":=", 
  RowBox[{"Take", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"spir", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"c", ",", "0", ",", "0"}], "}"}], ",", "a"}], "]"}], "[", "t",
      "]"}], ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.472878523673956*^9, 3.472878661661985*^9}},
 CellLabel->"In[54]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"logspir", "[", 
   RowBox[{"c", ",", "a"}], "]"}], "[", "t", "]"}]], "Input",
 CellChangeTimes->{{3.472878755899613*^9, 3.47287876625706*^9}},
 CellLabel->"In[55]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"logspir", "[", 
     RowBox[{"1", ",", ".2"}], "]"}], "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "8"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472878795215407*^9, 3.472878860094527*^9}},
 CellLabel->"In[56]:="],

Cell["and circles in case a=0:", "Text",
 CellChangeTimes->{{3.472879208803074*^9, 3.472879220038976*^9}}],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"logspir", "[", 
     RowBox[{"1", ",", "0"}], "]"}], "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472878795215407*^9, 3.472878860094527*^9}, {
  3.472879229277529*^9, 3.472879267204892*^9}},
 CellLabel->"In[57]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["5.4.2 Spherical reflections of logarithmic spirals", "Subsubsection",
 CellChangeTimes->{{3.474002878609375*^9, 3.474002920390625*^9}}],

Cell[BoxData[
 RowBox[{"?", "sphericalreflection"}]], "Input",
 CellChangeTimes->{{3.472881799678519*^9, 3.472881809080999*^9}},
 CellLabel->"In[58]:="],

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"sphericalreflection", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"spir", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", ".2"}], "]"}], "[", 
      "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "10"}], ",", "8"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472878159000845*^9, 3.472878261993854*^9}, {
   3.472878323542479*^9, 3.472878324880814*^9}, 3.472878496490678*^9, {
   3.47288185760381*^9, 3.472882020138533*^9}, {3.472882649849447*^9, 
   3.472882651438673*^9}, {3.472882867043561*^9, 3.47288287606373*^9}},
 CellLabel->"In[59]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"rsp1", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.472882028837973*^9, 3.472882033614178*^9}},
 CellLabel->"In[60]:="],

Cell[BoxData[
 RowBox[{"sphereplot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "2", ",", " ", "0", ",", 
   RowBox[{"2", "*", "Pi"}], ",", " ", 
   RowBox[{
    RowBox[{"-", "Pi"}], "/", "2"}], ",", 
   RowBox[{"Pi", "/", "2"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", " ", 
    RowBox[{"Opacity", "[", ".1", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472882117330011*^9, 3.472882163796998*^9}, {
   3.472882230812837*^9, 3.472882278903131*^9}, {3.472882391220775*^9, 
   3.472882392635166*^9}, {3.472882491279818*^9, 3.472882497784424*^9}, {
   3.472882677409014*^9, 3.472882686974414*^9}, 3.472882771623826*^9, {
   3.472882802330356*^9, 3.472882826293866*^9}, {3.472883227508677*^9, 
   3.472883228387217*^9}},
 CellLabel->"In[61]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sph1", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.472882288452567*^9, 3.472882296310273*^9}},
 CellLabel->"In[62]:="],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"sp1", ",", "sph1", ",", " ", "rsp1"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472882300139376*^9, 3.472882335856842*^9}, {
  3.472883003744401*^9, 3.47288300537507*^9}},
 CellLabel->"In[63]:="],

Cell["\<\
The inner (outer) part of the green curve is mapped on the outer (resp. \
inner)  part of the red curve, and vice versa. The curves intersect at the \
fixed  intersection point of the curves with the sphere.\
\>", "Text",
 CellChangeTimes->{{3.472884801046593*^9, 3.472885024134628*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["5.4.3 Spiral cylinders and their spherical reflections", "Subsubsection",
 CellChangeTimes->{{3.474003065890625*^9, 3.474003115703125*^9}}],

Cell["\<\
The spiral cylinder erected on the logarithmic spiral is given by\
\>", "Text",
 CellChangeTimes->{{3.472885122083029*^9, 3.472885141818779*^9}}],

Cell["spy[u_, v_, r_:10] := {Cos[u], Sin[u], 1/v} Exp[u/r]", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.472885392839917*^9, 3.472885395858773*^9}, {
  3.472885510029587*^9, 3.472885510065038*^9}},
 FontFamily->"Times",
 CellLabel->"In[70]:="],

Cell[BoxData[
 RowBox[{"spy", "[", 
  RowBox[{"u", ",", "v", ",", "r"}], "]"}]], "Input",
 CellChangeTimes->{{3.474005902359375*^9, 3.4740059360625*^9}},
 CellLabel->"In[79]:="],

Cell[BoxData[
 RowBox[{"spy", "[", 
  RowBox[{"0", ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.47400493384375*^9, 3.474004983234375*^9}},
 CellLabel->"In[71]:="],

Cell["Of course, that is a comparatively simple surface:", "Text"],

Cell["\<\
ParametricPlot3D[spy[u, v,15], {u, 0, 8 Pi}, {v, 0.5, 5}, 
PlotPoints \[Rule] 50,PlotStyle \[Rule] Opacity[.6]]\
\>", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.472885217444239*^9, 3.472885238667888*^9}, 
   3.472885317120098*^9, {3.472885527991154*^9, 3.472885531987941*^9}, {
   3.472885596835595*^9, 3.472885664958482*^9}},
 FontFamily->"Times",
 CellLabel->"In[65]:="],

Cell["\<\
linspy[u_, v_, r_:10] := {Cos[u], Sin[u],0} *Exp[u/r] + {0,0,v}\
\>", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.472887277104336*^9, 3.472887359931345*^9}},
 FontFamily->"Times",
 CellLabel->"In[76]:="],

Cell[BoxData[
 RowBox[{"linspy", "[", 
  RowBox[{"u", ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.47288578734436*^9, 3.472885804269495*^9}},
 CellLabel->"In[67]:="],

Cell["\<\
ParametricPlot3D[linspy[u, v,15], {u, 0, 8 Pi}, {v, 0, 5}, 
PlotPoints \[Rule] {110, 20},PlotStyle \[Rule] Opacity[.6]]\
\>", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{3.472885883656177*^9},
 FontFamily->"Times",
 CellLabel->"In[68]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"spclin", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472885955106471*^9},
 CellLabel->"In[69]:="],

Cell[TextData[{
 "The spiral cylinder is of special interest in M\[ODoubleDot]bius geometry: \
it is a homogeneous surface. That means: the subgroup of the \
M\[ODoubleDot]bius group preserving the cylinder acts transitively on this \
manifold. Moreover, it admits an M\[ODoubleDot]bius-invariant metric of \
constant negative curvature, see R. Sulanke ",
 ButtonBox["[3]",
  BaseStyle->"Hyperlink",
  ButtonData:>"S4"],
 "."
}], "Text",
 CellChangeTimes->{{3.47288607175406*^9, 3.472886072765422*^9}, {
   3.472887109874317*^9, 3.472887121869848*^9}, 3.474003224296875*^9, {
   3.4740071125*^9, 3.4740071165625*^9}, 3.47400886825*^9}],

Cell["\<\
For visualizing the behavior at the infinite point, we reflect the infinite \
part of the spiral cylinder at the unit sphere\
\>", "Text",
 CellChangeTimes->{{3.47288607175406*^9, 3.472886072765422*^9}, {
   3.472887109874317*^9, 3.472887121869848*^9}, 3.474003224296875*^9, {
   3.4740032635*^9, 3.474003288109375*^9}}],

Cell["\<\
ParametricPlot3D[refl[spy[u, v,15]], {u, 0, 8 Pi}, {v, -.5, .5}, 
PlotPoints -> 90, PlotRange \[Rule] All, Boxed \[Rule] False, Axes \[Rule] \
False]\
\>", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.472886197942092*^9, 3.472886207238863*^9}, {
  3.472886311100863*^9, 3.472886313315402*^9}, {3.472886346918265*^9, 
  3.472886356763473*^9}, {3.47288639226843*^9, 3.472886430186353*^9}},
 FontFamily->"Times",
 CellLabel->"In[70]:="],

Cell["\<\
ParametricPlot3D[refl[spy[u, v,15]], {u, 0, 8 Pi}, {v, -.5, .5}, 
PlotPoints -> 90, PlotRange \[Rule] All, Boxed \[Rule] False, Axes \[Rule] \
False,PlotStyle \[Rule] Red]\
\>", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.472886197942092*^9, 3.472886207238863*^9}, {
  3.472886311100863*^9, 3.472886313315402*^9}, {3.472886346918265*^9, 
  3.472886356763473*^9}, {3.47288639226843*^9, 3.472886430186353*^9}, {
  3.472887613560676*^9, 3.472887636079473*^9}},
 FontFamily->"Times",
 CellLabel->"In[71]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"refllinc", " ", "=", " ", "%"}], ";"}]], "Input",
 CellChangeTimes->{3.472886151724755*^9},
 FontFamily->"Times",
 CellLabel->"In[72]:="],

Cell["\<\
A complementary picture is obtained reflecting a large finite part of the \
spiral cylinder at the unit sphere:\
\>", "Text",
 CellChangeTimes->{{3.472887156342476*^9, 3.472887226477813*^9}}],

Cell["\<\
ParametricPlot3D[refl[linspy[u, v,15]], {u, 0, 8 Pi}, {v, -20, 20}, 
PlotPoints -> 90, PlotRange \[Rule] All, Boxed \[Rule] False, Axes \[Rule] \
False, PlotStyle \[Rule] Opacity[.3]]\
\>", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.472886197942092*^9, 3.472886207238863*^9}, {
  3.472886311100863*^9, 3.472886313315402*^9}, {3.472886346918265*^9, 
  3.472886356763473*^9}, {3.47288639226843*^9, 3.472886430186353*^9}, {
  3.472886506786505*^9, 3.47288650746503*^9}, {3.47288669486217*^9, 
  3.472886705726865*^9}, {3.472886740606956*^9, 3.472886770114182*^9}, {
  3.472887727150577*^9, 3.472887728862115*^9}, {3.472887764461245*^9, 
  3.472887766210589*^9}},
 FontFamily->"Times",
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"reflcy", " ", "=", "%"}], ";"}]], "Input",
 CellChangeTimes->{{3.472887469912132*^9, 3.472887479554731*^9}},
 CellLabel->"In[74]:="],

Cell["\<\
Now we join the pictures; in this way the image of the infinite part  {u, 0, \
8 Pi}, {v,-\[Infinity],\[Infinity]} of the spiral cylinder under the \
reflection at the unit sphere is obtained:\
\>", "Text",
 CellChangeTimes->{{3.472887896337682*^9, 3.472887941412301*^9}, {
  3.472888210826758*^9, 3.472888265731278*^9}, {3.472888315319636*^9, 
  3.472888441102923*^9}}],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"refllinc", ",", "reflcy"}], "}"}], ",", 
   RowBox[{"PlotRange", " ", "\[Rule]", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.472887482868659*^9, 3.472887522879725*^9}},
 CellLabel->"In[75]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Subsubtitle",
 FontFamily->"Times"],

Cell["\<\
[1] Gray, Alfred. Modern Differential Geometry of Curves and Surfaces. CRC \
PRESS, 1993 (German translation: Spektrum Akademischer Verlag 1994)\
\>", "Text",
 CellTags->"G1"],

Cell[TextData[{
 "[2] Sulanke, Rolf. Spheres.  1999.  \
http://mathsource.com/Content/Enhancements/Geometry/0210-092, now: \
http://library.wolfram.com/infocenter/",
 StyleBox["MathSource",
  FontSlant->"Italic"],
 "/708"
}], "Text",
 CellChangeTimes->{{3.47280305276605*^9, 3.472803054637675*^9}},
 CellTags->"S3"],

Cell[TextData[{
 "[3] Sulanke, Rolf. M\[ODoubleDot]bius geometry V: Homogeneous surfaces in \
the M\[ODoubleDot]bius space ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["S", "3"], TraditionalForm]]],
 ". Colloquia Math. J. Bolyai 46, Topics in Differential Geometry, Debrecen \
1984, 1141-1154."
}], "Text",
 CellChangeTimes->{3.472886058115289*^9},
 CellTags->"S4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Author's  homepage and address", "Subsubtitle",
 CellChangeTimes->{{3.472803264121909*^9, 3.472803270954392*^9}},
 FontFamily->"Times"],

Cell[TextData[{
 "Homepage:\n",
 ButtonBox["http://www-irm.mathematik.hu-berlin.de/~sulanke",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www-irm.mathematik.hu-berlin.de/~sulanke"], None},
  ButtonNote->"http://www-irm.mathematik.hu-berlin.de/~sulanke"],
 "\ne-Mail:"
}], "Text",
 CellChangeTimes->{{3.4730023765625*^9, 3.4730023765625*^9}},
 CellTags->"HP"],

Cell["sulanke@mathematik.hu-berlin.de", "Text"],

Cell["\<\
The author will be very thankful for hints, corrections, comments.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{784, 649},
WindowMargins->{{-4, Automatic}, {Automatic, -1}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowSelection->True,
ShowCellLabel->False,
ShowCellTags->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Subsection"], 
         Cell[
          StyleData[All, "Working"], 
          CellBracketOptions -> {"Color" -> RGBColor[0, 0.2, 1]}, 
          ScriptMinSize -> 9], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Subsection"], 
         Cell[
         "  The options defined for the style below will be used at the \
Notebook level.  ", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                OptionValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                OptionValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False}, 
          CellLabelAutoDelete -> False, CellFrameLabelMargins -> 6, 
          StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Headings", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], CellMargins -> {{5, Inherited}, {2, 0}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
             False, InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 13}, CounterIncrements -> 
             "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
             "Times", FontSize -> 36, FontWeight -> "Bold", FontColor -> 
             GrayLevel[1], Background -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Title", "Printout"], CellMargins -> {{0, 10}, {2, 0}},
              FontSize -> 28, Background -> GrayLevel[0.6]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], CellMargins -> {{12, Inherited}, {2, 2}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, CounterIncrements -> "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 24], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{7, 10}, {2, 4}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], 
             CellMargins -> {{12, Inherited}, {2, 12}}, 
             CellGroupingRules -> {"TitleGrouping", 20}, PageBreakBelow -> 
             False, InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, CounterIncrements -> "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{7, 10}, {2, 8}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{6, 0.5}, {0.5, 0.5}}, 
             CellMargins -> {{8, 4}, {2, 50}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 18}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, CellFrameColor -> RGBColor[0, 0, 1], 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 18, FontWeight -> "Bold", 
             FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Section", "Printout"], 
             CellFrame -> {{6, 0.5}, {0.5, 0.5}}, 
             CellMargins -> {{6, 4}, {2, 70}}, CellFrameColor -> GrayLevel[0],
              FontSize -> 14, FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{24, 4}, {2, 18}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 12}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameLabelMargins -> 6, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, LineSpacing -> {1, 5}, CounterIncrements -> 
             "Subsection", CounterAssignments -> {{"Subsubsection", 0}}, 
             FontFamily -> "Times", FontSize -> 15, FontWeight -> "Bold", 
             FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{19, 4}, {2, 18}}, FontSize -> 12, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellMargins -> {{10, 4}, {2, 18}}, 
             CellElementSpacings -> {"ClosedGroupTopMargin" -> 12}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Helvetica", FontWeight -> "Bold", FontColor -> 
             RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{7, 4}, {2, 18}}, FontSize -> 10, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell["Text", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", 
               "webMathematica" -> FormBox[
                 RowBox[{"web", 
                   AdjustmentBox[
                    StyleBox["Mathematica", FontSlant -> "Italic"], 
                    BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
               Inherited}, Hyphenation -> True, LineSpacing -> {1, 3}, 
             ParagraphSpacing -> {0, 12}, CounterIncrements -> "Text", 
             FontSize -> 14], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{7, 0}, {0, 8}}, 
             FontSize -> 11]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], CellFrame -> {{3, 0}, {0, 0.5}}, 
             CellMargins -> {{47, 14}, {0, 14}}, CellFrameColor -> 
             RGBColor[0, 0, 1], Hyphenation -> True, LineSpacing -> {1, 3}, 
             ParagraphSpacing -> {0, 8}, FontFamily -> "Helvetica", FontSize -> 
             12], 
            Cell[
             StyleData["MathCaption", "Printout"], 
             CellMargins -> {{34, 54}, {0, 14}}, CellFrameColor -> 
             GrayLevel[0], FontSize -> 10]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Input/Output", "Subsection"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    ", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{54, 14}, {3, 8}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{21, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> "Formula", FormatType -> 
             StandardForm, ShowStringCharacters -> True, NumberMarks -> True, 
             LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, CounterIncrements -> 
             "Input", FontSize -> 16, FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{43, 4}, {3, 8}}, 
             LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 10]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellMargins -> {{55, 4}, {8, 3}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, 
             CellLabelMargins -> {{21, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> "Formula", FormatType -> 
             StandardForm, CounterIncrements -> "Output", FontSize -> 14], 
            Cell[
             StyleData["Output", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{43, 4}, {4, 2}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], CellMargins -> {{56, 4}, {3, 8}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelMargins -> {{21, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Message", StyleMenuListing -> None, 
             FontColor -> RGBColor[0, 0.2, 1]], 
            Cell[
             StyleData["Message", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{44, 4}, {3, 8}}, FontSize -> 10, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], CellMargins -> {{56, 4}, {3, 8}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelMargins -> {{21, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             "TwoByteSyntaxCharacterAutoReplacement" -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Print", StyleMenuListing -> None], 
            Cell[
             StyleData["Print", "Printout"], ShowCellBracket -> False, 
             CellMargins -> {{44, 4}, {3, 8}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{55, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, FormatType -> 
             InputForm, CounterIncrements -> "Graphics", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Graphics", "Printout"], 
             CellMargins -> {{42, 4}, {3, 8}}, ImageSize -> {250, 250}, 
             FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> RGBColor[0, 0.2, 1]], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 7, FontSlant -> 
             "Oblique", FontColor -> GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Unique Styles", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedText"], CellMargins -> {{26, 4}, {0, 8}}, 
             ShowSpecialCharacters -> Automatic, Hyphenation -> True, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             ParagraphIndent -> -19, CounterIncrements -> "Text", FontSize -> 
             14], 
            Cell[
             StyleData["ItemizedText", "Printout"], 
             CellMargins -> {{20, 4}, {0, 8}}, ParagraphIndent -> -14, 
             FontSize -> 11]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemizedTextNote"], CellMargins -> {{45, 4}, {0, 5}}, 
             ShowSpecialCharacters -> Automatic, Hyphenation -> True, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 5}, 
             CounterIncrements -> "Text", FontSize -> 14], 
            Cell[
             StyleData["ItemizedTextNote", "Printout"], 
             CellMargins -> {{34, 4}, {0, 4}}, ParagraphSpacing -> {0, 4}, 
             FontSize -> 11]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["IndentedText"], CellMargins -> {{26, 4}, {0, 8}}, 
             ShowSpecialCharacters -> Automatic, Hyphenation -> True, 
             LineSpacing -> {1, 3}, ParagraphSpacing -> {0, 8}, 
             CounterIncrements -> "Text", FontSize -> 14], 
            Cell[
             StyleData["IndentedText", "Printout"], 
             CellMargins -> {{20, 4}, {0, 8}}, FontSize -> 11]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Note"], CellFrame -> True, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, CellFrameColor -> RGBColor[0, 0, 1], ShowSpecialCharacters -> 
             Automatic, Hyphenation -> True, LineSpacing -> {1, 3}, 
             ParagraphSpacing -> {0, 8}, CounterIncrements -> "Text", 
             FontFamily -> "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["Note", "Printout"], CellMargins -> {{7, 4}, {0, 8}}, 
             CellFrameColor -> GrayLevel[0], FontSize -> 8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{10, Inherited}, {0, 8}}, 
             CellHorizontalScrolling -> True], 
            Cell[
             StyleData["Picture", "Printout"], 
             CellMargins -> {{7, Inherited}, {0, 8}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Caption"], CellMargins -> {{10, 50}, {0, 3}}, 
             PageBreakAbove -> False, Hyphenation -> True, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Caption", "Printout"], 
             CellMargins -> {{7, 50}, {2, 4}}, FontSize -> 7, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Tables", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["2ColumnTable"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {
                   Scaled[0.39], {
                    Scaled[0.59]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
                 "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["2ColumnTable", "Printout"], 
             CellMargins -> {{7, 4}, {0, 8}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["3ColumnTable"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, StyleMenuListing -> None, 
             GridBoxOptions -> {
              GridBoxAlignment -> {
                "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}, 
               GridBoxItemSize -> {"Columns" -> {{
                    Scaled[0.325]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
                  "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["3ColumnTable", "Printout"], 
             CellMargins -> {{7, 4}, {0, 8}}, FontSize -> 10]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Subsection"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChemicalFormula"], 
             CellMargins -> {{55, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultInputFormatType, "TwoByteSyntaxCharacterAutoReplacement" -> 
             True, HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", AutoSpacing -> False, 
             ScriptBaselineShifts -> {0.6, Automatic}, ScriptLevel -> 1, 
             SingleLetterItalics -> False, ZeroWidthTimes -> True, FontSize -> 
             14], 
            Cell[
             StyleData["ChemicalFormula", "Printout"], 
             CellMargins -> {{43, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{55, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultInputFormatType, "TwoByteSyntaxCharacterAutoReplacement" -> 
             True, HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             FontSize -> 14, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}, 
             GridBoxOptions -> {
              GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{1.}}, "RowsIndexed" -> {}}}], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{43, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], 
             CellMargins -> {{10, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, Hyphenation -> False, 
             LanguageCategory -> "Formula", FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{7, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 9.5]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Subsection"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[0, 0.6, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[0, 0.6, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[0, 0.6, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnLink", "Printout"], FontColor -> GrayLevel[0], 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontColor -> GrayLevel[1], Background -> RGBColor[0, 0.6, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuideLink", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Printout"], FontColor -> GrayLevel[0],
              Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[0, 0.6, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontColor -> GrayLevel[1], 
             Background -> RGBColor[0, 0.6, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], FontColor -> 
             GrayLevel[0], Background -> GrayLevel[1]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Palette Styles", "Subsection"], 
         Cell[
         "The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.", "Text"], 
         Cell[
          StyleData["Paste"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, After]}]& )}], 
         Cell[
          StyleData["Evaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["EvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionMove[
                FrontEnd`InputNotebook[], All, Cell, 1], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}]}, Closed]]}, Open]]}, 
  Visible -> False, FrontEndVersion -> 
  "7.0 for Microsoft Windows (32-bit) (November 10, 2008)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "copyrigt"->{
  Cell[5516, 141, 57, 1, 49, "Subsubsection",
   CellTags->"copyrigt"]},
 "G1"->{
  Cell[1180499, 27000, 185, 4, 57, "Text",
   CellTags->"G1"]},
 "HP"->{
  Cell[1181553, 27036, 372, 10, 100, "Text",
   CellTags->"HP"]},
 "ortho"->{
  Cell[124999, 3878, 185, 4, 103, "Section",
   CellTags->"ortho"]},
 "S3"->{
  Cell[1180687, 27006, 315, 9, 57, "Text",
   CellTags->"S3"]},
 "S4"->{
  Cell[1181005, 27017, 367, 10, 57, "Text",
   CellTags->"S4"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"copyrigt", 1216225, 27762},
 {"G1", 1216307, 27765},
 {"HP", 1216380, 27768},
 {"ortho", 1216458, 27771},
 {"S3", 1216536, 27774},
 {"S4", 1216609, 27777}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 114, 3, 59, "Title",
 Evaluatable->False],
Cell[684, 27, 135, 4, 31, "Subtitle",
 Evaluatable->False],
Cell[822, 33, 380, 10, 55, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1227, 47, 32, 0, 35, "Subsubsection"],
Cell[1262, 49, 1510, 25, 157, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2809, 79, 55, 1, 35, "Subsubsection"],
Cell[2867, 82, 657, 10, 81, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3561, 97, 32, 0, 35, "Subsubsection"],
Cell[3596, 99, 1883, 37, 188, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5516, 141, 57, 1, 49, "Subsubsection",
 CellTags->"copyrigt"],
Cell[5576, 144, 558, 8, 383, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[6171, 157, 56, 1, 31, "Subsection"],
Cell[6230, 160, 3090, 60, 658, "Text"],
Cell[9323, 222, 394, 10, 83, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[9754, 237, 55, 1, 57, "Section"],
Cell[9812, 240, 385, 7, 62, "Text"],
Cell[CellGroupData[{
Cell[10222, 251, 33, 0, 37, "Subsection"],
Cell[CellGroupData[{
Cell[10280, 255, 76, 1, 35, "Subsubsection"],
Cell[10359, 258, 559, 11, 197, "Text"],
Cell[10921, 271, 362, 9, 70, "Input",
 Evaluatable->False,
 InitializationCell->True],
Cell[11286, 282, 93, 1, 57, "Text"],
Cell[11382, 285, 481, 12, 70, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[11900, 302, 86, 1, 29, "Subsubsection"],
Cell[11989, 305, 196, 4, 57, "Text"],
Cell[12188, 311, 87, 1, 57, "Text"],
Cell[12278, 314, 113, 3, 70, "Input"],
Cell[12394, 319, 419, 9, 103, "Text"],
Cell[12816, 330, 131, 3, 70, "Text"],
Cell[12950, 335, 304, 7, 70, "Input",
 InitializationCell->True],
Cell[13257, 344, 127, 3, 70, "Text"],
Cell[CellGroupData[{
Cell[13409, 351, 305, 7, 70, "Input",
 Evaluatable->False,
 InitializationCell->True],
Cell[13717, 360, 124, 2, 121, "Output"]
}, Closed]],
Cell[13856, 365, 177, 4, 46, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[14082, 375, 134, 2, 31, "Subsection"],
Cell[14219, 379, 295, 6, 56, "Text"],
Cell[14517, 387, 223, 5, 46, "Text"],
Cell[14743, 394, 218, 5, 56, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[14998, 404, 98, 1, 31, "Subsection"],
Cell[15099, 407, 381, 8, 43, "Text"],
Cell[15483, 417, 94, 3, 29, "Input",
 Evaluatable->False],
Cell[15580, 422, 184, 4, 43, "Text"],
Cell[15767, 428, 75, 2, 29, "Input"],
Cell[15845, 432, 413, 10, 75, "Text"],
Cell[16261, 444, 228, 4, 43, "Text"],
Cell[16492, 450, 105, 3, 29, "Input",
 InitializationCell->True],
Cell[16600, 455, 100, 3, 29, "Input",
 InitializationCell->True],
Cell[16703, 460, 192, 4, 24, "Text"],
Cell[16898, 466, 141, 3, 29, "Input"],
Cell[CellGroupData[{
Cell[17064, 473, 141, 2, 35, "Subsubsection"],
Cell[17208, 477, 218, 5, 30, "Text"],
Cell[17429, 484, 142, 3, 36, "Input"],
Cell[17574, 489, 180, 4, 24, "Text"],
Cell[17757, 495, 138, 3, 36, "Input"],
Cell[17898, 500, 166, 3, 24, "Text"],
Cell[18067, 505, 156, 3, 36, "Input"],
Cell[18226, 510, 337, 6, 30, "Input"],
Cell[18566, 518, 138, 3, 36, "Input"],
Cell[18707, 523, 120, 1, 24, "Text"],
Cell[18830, 526, 92, 2, 36, "Input"],
Cell[18925, 530, 248, 5, 30, "Input"],
Cell[19176, 537, 238, 4, 48, "Text"],
Cell[19417, 543, 306, 7, 36, "Input"],
Cell[19726, 552, 154, 3, 36, "Input"],
Cell[19883, 557, 258, 5, 48, "Text",
 Evaluatable->False],
Cell[20144, 564, 98, 3, 36, "Input"],
Cell[20245, 569, 253, 6, 30, "Text",
 Evaluatable->False],
Cell[20501, 577, 181, 4, 36, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[20731, 587, 328, 6, 31, "Subsection"],
Cell[CellGroupData[{
Cell[21084, 597, 167, 2, 35, "Subsubsection"],
Cell[21254, 601, 377, 11, 50, "Text"],
Cell[21634, 614, 135, 3, 56, "Input"],
Cell[21772, 619, 201, 4, 46, "Text"],
Cell[21976, 625, 144, 3, 56, "Input"],
Cell[22123, 630, 259, 7, 46, "Text"],
Cell[22385, 639, 182, 4, 56, "Input"],
Cell[22570, 645, 185, 4, 56, "Input"],
Cell[22758, 651, 224, 4, 56, "Input"],
Cell[22985, 657, 201, 4, 56, "Input"],
Cell[23189, 663, 114, 2, 56, "Input"],
Cell[23306, 667, 301, 5, 83, "Text"],
Cell[23610, 674, 134, 3, 56, "Input"],
Cell[23747, 679, 138, 3, 56, "Input"],
Cell[23888, 684, 149, 3, 56, "Input"],
Cell[24040, 689, 140, 1, 46, "Text"],
Cell[24183, 692, 151, 3, 56, "Input"],
Cell[24337, 697, 143, 3, 56, "Input"],
Cell[24483, 702, 150, 3, 56, "Input"],
Cell[24636, 707, 168, 4, 56, "Input"],
Cell[24807, 713, 146, 3, 56, "Input"],
Cell[24956, 718, 433, 7, 121, "Text"],
Cell[25392, 727, 139, 4, 56, "Input"],
Cell[25534, 733, 183, 4, 56, "Input"],
Cell[25720, 739, 590, 12, 46, "Text"],
Cell[26313, 753, 163, 4, 56, "Input"],
Cell[26479, 759, 191, 4, 56, "Input"],
Cell[26673, 765, 181, 4, 56, "Input"],
Cell[26857, 771, 114, 3, 56, "Input"],
Cell[26974, 776, 184, 2, 46, "Text"],
Cell[27161, 780, 130, 3, 56, "Input"],
Cell[27294, 785, 140, 3, 56, "Input"],
Cell[27437, 790, 180, 4, 56, "Input"],
Cell[27620, 796, 142, 3, 56, "Input"],
Cell[27765, 801, 135, 3, 56, "Input"],
Cell[27903, 806, 350, 9, 56, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[28290, 820, 167, 2, 29, "Subsubsection"],
Cell[28460, 824, 184, 4, 135, "Input"],
Cell[28647, 830, 139, 3, 135, "Input"],
Cell[28789, 835, 179, 4, 135, "Input"],
Cell[28971, 841, 173, 4, 135, "Input"],
Cell[29147, 847, 173, 4, 135, "Input"],
Cell[29323, 853, 176, 4, 135, "Input"],
Cell[29502, 859, 174, 4, 135, "Input"],
Cell[29679, 865, 176, 4, 135, "Input"],
Cell[29858, 871, 193, 4, 110, "Text"],
Cell[30054, 877, 177, 4, 135, "Input"],
Cell[30234, 883, 135, 3, 135, "Input"],
Cell[30372, 888, 176, 4, 135, "Input"],
Cell[30551, 894, 136, 3, 135, "Input"],
Cell[30690, 899, 182, 4, 110, "Text"],
Cell[30875, 905, 194, 5, 135, "Input"],
Cell[31072, 912, 137, 3, 135, "Input"],
Cell[31212, 917, 193, 5, 135, "Input"],
Cell[31408, 924, 138, 3, 135, "Input"],
Cell[31549, 929, 265, 7, 135, "Input"],
Cell[31817, 938, 139, 3, 135, "Input"],
Cell[31959, 943, 264, 7, 135, "Input"],
Cell[32226, 952, 163, 4, 135, "Input"],
Cell[32392, 958, 137, 3, 135, "Input"],
Cell[32532, 963, 402, 9, 135, "Input"],
Cell[32937, 974, 136, 3, 135, "Input"],
Cell[33076, 979, 275, 5, 110, "Text"],
Cell[33354, 986, 319, 8, 135, "Input"],
Cell[33676, 996, 229, 6, 135, "Input"],
Cell[33908, 1004, 264, 7, 135, "Input"],
Cell[34175, 1013, 169, 4, 135, "Input"],
Cell[34347, 1019, 123, 1, 110, "Text"],
Cell[34473, 1022, 136, 3, 135, "Input"],
Cell[34612, 1027, 131, 3, 135, "Input"],
Cell[34746, 1032, 158, 3, 110, "Text"],
Cell[34907, 1037, 291, 7, 135, "Input"],
Cell[35201, 1046, 266, 7, 135, "Input"],
Cell[35470, 1055, 259, 7, 135, "Input"],
Cell[35732, 1064, 254, 7, 135, "Input"],
Cell[35989, 1073, 300, 8, 135, "Input"],
Cell[36292, 1083, 252, 7, 135, "Input"],
Cell[36547, 1092, 176, 4, 135, "Input"],
Cell[36726, 1098, 133, 1, 110, "Text"],
Cell[36862, 1101, 173, 4, 135, "Input"],
Cell[37038, 1107, 178, 4, 135, "Input"],
Cell[37219, 1113, 189, 4, 110, "Text"],
Cell[37411, 1119, 236, 5, 135, "Input"],
Cell[37650, 1126, 152, 3, 135, "Input"],
Cell[37805, 1131, 355, 10, 135, "Input"],
Cell[38163, 1143, 149, 3, 135, "Input"],
Cell[38315, 1148, 152, 3, 135, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[38504, 1156, 406, 7, 29, "Subsubsection"],
Cell[38913, 1165, 91, 1, 30, "Text"],
Cell[39007, 1168, 136, 3, 36, "Input"],
Cell[39146, 1173, 126, 1, 24, "Text"],
Cell[39275, 1176, 138, 3, 36, "Input"],
Cell[39416, 1181, 231, 6, 30, "Input"],
Cell[39650, 1189, 137, 3, 30, "Input"],
Cell[39790, 1194, 253, 5, 24, "Text"],
Cell[40046, 1201, 223, 5, 66, "Input"],
Cell[40272, 1208, 169, 4, 30, "Input"],
Cell[40444, 1214, 418, 12, 36, "Input"],
Cell[40865, 1228, 270, 8, 24, "Text"],
Cell[41138, 1238, 705, 18, 30, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[41880, 1261, 222, 4, 29, "Subsubsection"],
Cell[42105, 1267, 169, 4, 29, "Input"],
Cell[42277, 1273, 136, 3, 29, "Input"],
Cell[42416, 1278, 275, 7, 25, "Input"],
Cell[42694, 1287, 156, 2, 20, "Text"],
Cell[42853, 1291, 240, 6, 29, "Input"],
Cell[43096, 1299, 224, 5, 20, "Text"],
Cell[43323, 1306, 138, 3, 29, "Input"],
Cell[43464, 1311, 255, 7, 25, "Input"],
Cell[43722, 1320, 167, 4, 25, "Input"],
Cell[43892, 1326, 123, 1, 20, "Text"],
Cell[44018, 1329, 144, 3, 29, "Input"],
Cell[44165, 1334, 207, 5, 25, "Input"],
Cell[44375, 1341, 206, 5, 20, "Text"],
Cell[44584, 1348, 168, 4, 29, "Input"],
Cell[44755, 1354, 384, 12, 25, "Input"],
Cell[45142, 1368, 311, 6, 39, "Text"],
Cell[45456, 1376, 369, 10, 29, "Input"],
Cell[45828, 1388, 417, 7, 58, "Text"],
Cell[46248, 1397, 140, 3, 29, "Input"],
Cell[46391, 1402, 802, 22, 49, "Input"],
Cell[47196, 1426, 509, 9, 58, "Text"],
Cell[47708, 1437, 143, 3, 29, "Input"],
Cell[47854, 1442, 1982, 43, 118, "Input"],
Cell[49839, 1487, 2147, 43, 118, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[52023, 1535, 121, 1, 35, "Subsubsection"],
Cell[52147, 1538, 501, 8, 62, "Text"],
Cell[52651, 1548, 143, 3, 29, "Input"],
Cell[52797, 1553, 1995, 42, 118, "Input"],
Cell[54795, 1597, 112, 1, 20, "Text"],
Cell[54910, 1600, 677, 19, 76, "Input"],
Cell[55590, 1621, 225, 5, 20, "Text"],
Cell[55818, 1628, 750, 19, 76, "Input"],
Cell[56571, 1649, 327, 6, 20, "Text"],
Cell[56901, 1657, 752, 19, 76, "Input"],
Cell[57656, 1678, 151, 3, 20, "Text"],
Cell[57810, 1683, 152, 3, 29, "Input"],
Cell[57965, 1688, 179, 4, 25, "Input"],
Cell[58147, 1694, 149, 3, 25, "Input"],
Cell[58299, 1699, 178, 4, 25, "Input"],
Cell[58480, 1705, 1809, 36, 95, "Input"],
Cell[60292, 1743, 1787, 36, 72, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62140, 1786, 77, 1, 89, "Section"],
Cell[CellGroupData[{
Cell[62242, 1791, 54, 1, 35, "Subsubsection"],
Cell[62299, 1794, 460, 10, 62, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62796, 1809, 93, 2, 37, "Subsection"],
Cell[62892, 1813, 299, 5, 200, "Text"],
Cell[63194, 1820, 151, 5, 135, "Input",
 InitializationCell->True],
Cell[63348, 1827, 268, 7, 356, "Input",
 InitializationCell->True],
Cell[63619, 1836, 65, 0, 110, "Text"],
Cell[63687, 1838, 92, 3, 135, "Input"],
Cell[63782, 1843, 105, 3, 135, "Input"],
Cell[63890, 1848, 128, 4, 135, "Input"],
Cell[64021, 1854, 133, 4, 135, "Input"],
Cell[64157, 1860, 102, 3, 135, "Input"],
Cell[64262, 1865, 125, 4, 135, "Input"],
Cell[64390, 1871, 160, 3, 110, "Text"],
Cell[64553, 1876, 107, 3, 135, "Input"],
Cell[64663, 1881, 102, 3, 135, "Input"],
Cell[64768, 1886, 34, 0, 110, "Text"],
Cell[64805, 1888, 97, 3, 135, "Input"],
Cell[64905, 1893, 102, 3, 135, "Input"],
Cell[65010, 1898, 34, 0, 110, "Text"],
Cell[65047, 1900, 98, 3, 135, "Input"],
Cell[65148, 1905, 144, 3, 110, "Text"],
Cell[65295, 1910, 162, 5, 135, "Input"],
Cell[65460, 1917, 103, 3, 135, "Input"],
Cell[65566, 1922, 164, 5, 110, "Text"],
Cell[65733, 1929, 155, 5, 135, "Input"],
Cell[65891, 1936, 266, 9, 135, "Input"],
Cell[66160, 1947, 440, 15, 135, "Input"],
Cell[66603, 1964, 207, 7, 135, "Input"],
Cell[66813, 1973, 218, 7, 135, "Input"],
Cell[67034, 1982, 91, 2, 110, "Text"],
Cell[67128, 1986, 198, 6, 135, "Input"],
Cell[67329, 1994, 78, 2, 135, "Input"],
Cell[67410, 1998, 101, 3, 135, "Input"],
Cell[67514, 2003, 82, 2, 135, "Input"],
Cell[67599, 2007, 27, 0, 110, "Text"],
Cell[67629, 2009, 189, 6, 135, "Input"],
Cell[67821, 2017, 44, 0, 110, "Text"],
Cell[67868, 2019, 80, 2, 135, "Input"],
Cell[67951, 2023, 201, 6, 135, "Input"],
Cell[68155, 2031, 67, 0, 110, "Text"],
Cell[68225, 2033, 395, 13, 135, "Input"],
Cell[68623, 2048, 107, 3, 135, "Input"],
Cell[68733, 2053, 75, 0, 110, "Text"],
Cell[68811, 2055, 104, 3, 135, "Input"],
Cell[68918, 2060, 73, 0, 110, "Text"],
Cell[68994, 2062, 100, 3, 135, "Input"],
Cell[69097, 2067, 103, 3, 135, "Input"],
Cell[69203, 2072, 91, 3, 135, "Input"],
Cell[69297, 2077, 48, 0, 110, "Text"],
Cell[69348, 2079, 101, 3, 135, "Input"],
Cell[69452, 2084, 100, 3, 135, "Input"],
Cell[69555, 2089, 24, 0, 110, "Text"],
Cell[69582, 2091, 183, 6, 135, "Input"],
Cell[69768, 2099, 25, 0, 110, "Text"],
Cell[69796, 2101, 103, 3, 135, "Input"],
Cell[69902, 2106, 152, 4, 110, "Text"],
Cell[70057, 2112, 92, 3, 135, "Input"],
Cell[70152, 2117, 214, 7, 135, "Input"],
Cell[70369, 2126, 49, 0, 110, "Text"],
Cell[70421, 2128, 155, 5, 135, "Input"],
Cell[70579, 2135, 45, 0, 110, "Text"],
Cell[70627, 2137, 277, 9, 135, "Input"],
Cell[70907, 2148, 45, 0, 110, "Text"],
Cell[70955, 2150, 475, 16, 135, "Input"],
Cell[71433, 2168, 107, 3, 135, "Input"],
Cell[71543, 2173, 127, 3, 110, "Text"],
Cell[71673, 2178, 97, 3, 135, "Input"],
Cell[71773, 2183, 137, 4, 135, "Input"],
Cell[71913, 2189, 101, 1, 110, "Text"],
Cell[72017, 2192, 95, 3, 135, "Input"],
Cell[72115, 2197, 107, 3, 135, "Input"],
Cell[72225, 2202, 137, 3, 135, "Input"],
Cell[72365, 2207, 203, 5, 135, "Input"],
Cell[72571, 2214, 323, 6, 110, "Text"],
Cell[72897, 2222, 177, 4, 135, "Input"],
Cell[73077, 2228, 292, 7, 135, "Input"],
Cell[73372, 2237, 194, 5, 135, "Input"],
Cell[73569, 2244, 119, 1, 110, "Text"],
Cell[73691, 2247, 139, 3, 135, "Input"],
Cell[73833, 2252, 315, 6, 293, "Text"],
Cell[74151, 2260, 86, 2, 110, "Text"],
Cell[74240, 2264, 191, 6, 135, "Input"],
Cell[74434, 2272, 102, 2, 110, "Text"],
Cell[74539, 2276, 96, 3, 135, "Input"],
Cell[74638, 2281, 101, 3, 135, "Input"],
Cell[74742, 2286, 42, 0, 110, "Text"],
Cell[74787, 2288, 226, 7, 135, "Input"],
Cell[75016, 2297, 123, 4, 135, "Input"],
Cell[75142, 2303, 50, 0, 110, "Text"],
Cell[75195, 2305, 165, 5, 135, "Input"],
Cell[75363, 2312, 244, 8, 135, "Input"],
Cell[75610, 2322, 195, 7, 135, "Input"],
Cell[75808, 2331, 62, 0, 110, "Text"],
Cell[75873, 2333, 201, 7, 135, "Input"],
Cell[76077, 2342, 102, 3, 135, "Input"],
Cell[76182, 2347, 142, 4, 135, "Input"],
Cell[76327, 2353, 102, 3, 135, "Input"],
Cell[76432, 2358, 125, 3, 135, "Input"],
Cell[76560, 2363, 272, 5, 200, "Text"],
Cell[76835, 2370, 71, 2, 135, "Input"],
Cell[76909, 2374, 111, 3, 110, "Text"],
Cell[77023, 2379, 72, 2, 135, "Input"],
Cell[77098, 2383, 187, 4, 200, "Text"],
Cell[77288, 2389, 226, 5, 135, "Input"],
Cell[77517, 2396, 148, 3, 135, "Input"],
Cell[77668, 2401, 144, 3, 135, "Input"],
Cell[77815, 2406, 149, 3, 135, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[78001, 2414, 82, 2, 31, "Subsection"],
Cell[78086, 2418, 131, 4, 121, "Text"],
Cell[78220, 2424, 95, 3, 151, "Input"],
Cell[78318, 2429, 184, 4, 121, "Text"],
Cell[78505, 2435, 208, 7, 151, "Input"],
Cell[78716, 2444, 152, 3, 150, "Input"],
Cell[78871, 2449, 204, 4, 150, "Input"],
Cell[79078, 2455, 439, 15, 151, "Input"],
Cell[79520, 2472, 230, 7, 151, "Input"],
Cell[79753, 2481, 240, 8, 151, "Input"],
Cell[79996, 2491, 312, 10, 150, "Input"],
Cell[80311, 2503, 413, 11, 151, "Input"],
Cell[80727, 2516, 378, 10, 150, "Input"],
Cell[81108, 2528, 117, 5, 121, "Text"],
Cell[81228, 2535, 417, 12, 151, "Input",
 Evaluatable->False],
Cell[81648, 2549, 124, 3, 121, "Text"],
Cell[81775, 2554, 95, 3, 151, "Input"],
Cell[81873, 2559, 258, 8, 151, "Input"],
Cell[82134, 2569, 268, 9, 151, "Input"],
Cell[82405, 2580, 221, 6, 150, "Input"],
Cell[82629, 2588, 228, 6, 150, "Input"],
Cell[82860, 2596, 47, 0, 121, "Text"],
Cell[82910, 2598, 394, 12, 151, "Input",
 Evaluatable->False],
Cell[83307, 2612, 341, 11, 151, "Input"],
Cell[83651, 2625, 328, 10, 151, "Input"],
Cell[83982, 2637, 108, 3, 151, "Input"],
Cell[84093, 2642, 47, 0, 121, "Text"],
Cell[84143, 2644, 433, 13, 151, "Input"],
Cell[84579, 2659, 436, 12, 151, "Input"],
Cell[85018, 2673, 168, 5, 151, "Input"],
Cell[85189, 2680, 127, 1, 121, "Text"],
Cell[85319, 2683, 783, 22, 282, "Input"],
Cell[86105, 2707, 771, 21, 282, "Input"],
Cell[86879, 2730, 467, 12, 150, "Input"],
Cell[87349, 2744, 487, 12, 150, "Input"],
Cell[87839, 2758, 165, 3, 121, "Text"],
Cell[88007, 2763, 297, 10, 151, "Input"],
Cell[88307, 2775, 666, 20, 151, "Input"],
Cell[88976, 2797, 1106, 34, 291, "Input"],
Cell[90085, 2833, 108, 3, 151, "Input"],
Cell[90196, 2838, 219, 5, 150, "Input"],
Cell[90418, 2845, 637, 18, 282, "Input"],
Cell[91058, 2865, 771, 22, 282, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[91866, 2892, 154, 3, 31, "Subsection"],
Cell[CellGroupData[{
Cell[92045, 2899, 102, 1, 35, "Subsubsection"],
Cell[92150, 2902, 463, 8, 62, "Text"],
Cell[92616, 2912, 106, 3, 29, "Input",
 Evaluatable->False],
Cell[92725, 2917, 87, 2, 24, "Text"],
Cell[92815, 2921, 100, 3, 30, "Input"],
Cell[92918, 2926, 2047, 57, 291, "Input",
 Evaluatable->False]
}, Closed]],
Cell[CellGroupData[{
Cell[95002, 2988, 158, 2, 29, "Subsubsection"],
Cell[95163, 2992, 203, 5, 56, "Input"],
Cell[95369, 2999, 348, 10, 56, "Input"],
Cell[95720, 3011, 245, 8, 56, "Input"],
Cell[95968, 3021, 177, 4, 46, "Text"],
Cell[96148, 3027, 212, 5, 56, "Input"],
Cell[96363, 3034, 142, 3, 56, "Input"],
Cell[96508, 3039, 106, 1, 46, "Text"],
Cell[96617, 3042, 308, 9, 56, "Input"],
Cell[96928, 3053, 162, 5, 56, "Input"],
Cell[97093, 3060, 75, 0, 46, "Text"],
Cell[97171, 3062, 203, 6, 56, "Input"],
Cell[97377, 3070, 90, 2, 56, "Input"],
Cell[97470, 3074, 287, 9, 56, "Input"],
Cell[97760, 3085, 76, 2, 56, "Input"],
Cell[97839, 3089, 266, 9, 56, "Input"],
Cell[98108, 3100, 131, 3, 46, "Text"],
Cell[98242, 3105, 82, 2, 56, "Input"],
Cell[98327, 3109, 86, 2, 56, "Input"],
Cell[98416, 3113, 61, 0, 46, "Text"],
Cell[98480, 3115, 341, 10, 56, "Input"],
Cell[98824, 3127, 488, 15, 56, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[99349, 3147, 187, 2, 29, "Subsubsection"],
Cell[99539, 3151, 155, 3, 24, "Text"],
Cell[99697, 3156, 219, 5, 29, "Input"],
Cell[99919, 3163, 532, 15, 29, "Input"],
Cell[100454, 3180, 147, 3, 29, "Input"],
Cell[100604, 3185, 224, 5, 20, "Text"],
Cell[100831, 3192, 184, 4, 29, "Input"],
Cell[101018, 3198, 199, 5, 25, "Input"],
Cell[101220, 3205, 239, 5, 20, "Text"],
Cell[101462, 3212, 920, 28, 29, "Input",
 Evaluatable->False],
Cell[102385, 3242, 358, 7, 43, "Text"],
Cell[102746, 3251, 972, 27, 76, "Input"],
Cell[103721, 3280, 201, 3, 24, "Text"],
Cell[103925, 3285, 437, 11, 29, "Input"],
Cell[104365, 3298, 234, 5, 51, "Text"],
Cell[104602, 3305, 469, 9, 29, "Input"],
Cell[105074, 3316, 258, 5, 39, "Text"],
Cell[105335, 3323, 1161, 28, 99, "Input"],
Cell[106499, 3353, 200, 4, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[106736, 3362, 194, 3, 29, "Subsubsection"],
Cell[106933, 3367, 165, 2, 46, "Text"],
Cell[107101, 3371, 43, 0, 46, "Text"],
Cell[107147, 3373, 357, 10, 56, "Input"],
Cell[107507, 3385, 124, 1, 46, "Text"],
Cell[107634, 3388, 80, 2, 56, "Input"],
Cell[107717, 3392, 337, 6, 83, "Text"],
Cell[108057, 3400, 626, 20, 56, "Input",
 Evaluatable->False],
Cell[108686, 3422, 477, 9, 177, "Text"],
Cell[109166, 3433, 482, 10, 193, "Input",
 InitializationCell->True],
Cell[109651, 3445, 3603, 82, 420, "Input",
 InitializationCell->True],
Cell[113257, 3529, 325, 7, 56, "Input"],
Cell[113585, 3538, 400, 9, 56, "Input"],
Cell[113988, 3549, 374, 8, 56, "Input"],
Cell[114365, 3559, 301, 7, 56, "Input"],
Cell[114669, 3568, 302, 7, 56, "Input"],
Cell[114974, 3577, 260, 7, 56, "Input"],
Cell[115237, 3586, 756, 19, 102, "Input"],
Cell[115996, 3607, 595, 18, 56, "Input"],
Cell[116594, 3627, 441, 11, 56, "Input"],
Cell[117038, 3640, 349, 7, 83, "Text"],
Cell[117390, 3649, 851, 21, 102, "Input"],
Cell[118244, 3672, 489, 14, 56, "Input"],
Cell[118736, 3688, 169, 4, 56, "Input"],
Cell[118908, 3694, 119, 2, 56, "Input"],
Cell[119030, 3698, 450, 11, 56, "Input"],
Cell[119483, 3711, 247, 6, 56, "Input"],
Cell[119733, 3719, 238, 5, 46, "Text"],
Cell[119974, 3726, 139, 3, 56, "Input"],
Cell[120116, 3731, 873, 21, 102, "Input"],
Cell[120992, 3754, 391, 11, 56, "Input"],
Cell[121386, 3767, 169, 4, 56, "Input"],
Cell[121558, 3773, 1904, 52, 193, "Input"],
Cell[123465, 3827, 405, 10, 56, "Input"],
Cell[123873, 3839, 168, 4, 56, "Input"],
Cell[124044, 3845, 364, 10, 56, "Input"],
Cell[124411, 3857, 336, 8, 56, "Input"],
Cell[124750, 3867, 188, 4, 56, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[124999, 3878, 185, 4, 103, "Section",
 CellTags->"ortho"],
Cell[CellGroupData[{
Cell[125209, 3886, 55, 1, 35, "Subsubsection"],
Cell[125267, 3889, 1149, 17, 176, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126453, 3911, 88, 2, 37, "Subsection"],
Cell[126544, 3915, 100, 3, 36, "Input"],
Cell[126647, 3920, 116, 3, 36, "Input"],
Cell[126766, 3925, 86, 2, 30, "Text"],
Cell[126855, 3929, 76, 2, 36, "Input"],
Cell[126934, 3933, 363, 7, 90, "Text"],
Cell[127300, 3942, 73, 2, 36, "Input"],
Cell[127376, 3946, 94, 3, 36, "Input"],
Cell[127473, 3951, 126, 3, 30, "Text"],
Cell[127602, 3956, 94, 3, 36, "Input"],
Cell[127699, 3961, 96, 3, 36, "Input"],
Cell[127798, 3966, 45, 0, 30, "Text"],
Cell[127846, 3968, 71, 2, 36, "Input"],
Cell[127920, 3972, 292, 5, 54, "Text"],
Cell[128215, 3979, 100, 2, 30, "Text"],
Cell[128318, 3983, 6662, 172, 733, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[135005, 4159, 60, 1, 42, "Subsubsection"],
Cell[135068, 4162, 51, 0, 37, "Text"],
Cell[135122, 4164, 160, 5, 45, "Input"],
Cell[135285, 4171, 400, 12, 45, "Input"],
Cell[135688, 4185, 502, 15, 45, "Input"],
Cell[136193, 4202, 55, 0, 37, "Text"],
Cell[136251, 4204, 426, 14, 45, "Input"],
Cell[136680, 4220, 83, 2, 45, "Input"],
Cell[136766, 4224, 74, 0, 37, "Text"],
Cell[136843, 4226, 255, 7, 45, "Input"],
Cell[137101, 4235, 16, 0, 37, "Text"],
Cell[137120, 4237, 612, 19, 45, "Input"],
Cell[137735, 4258, 103, 3, 45, "Input"],
Cell[137841, 4263, 203, 6, 45, "Input"],
Cell[138047, 4271, 99, 3, 45, "Input"],
Cell[138149, 4276, 145, 3, 45, "Input"],
Cell[138297, 4281, 95, 2, 37, "Text"],
Cell[138395, 4285, 431, 14, 45, "Input"],
Cell[138829, 4301, 315, 8, 45, "Input"],
Cell[139147, 4311, 568, 18, 45, "Input"],
Cell[139718, 4331, 103, 3, 45, "Input"],
Cell[139824, 4336, 60, 0, 37, "Text"],
Cell[139887, 4338, 263, 7, 45, "Input"],
Cell[140153, 4347, 99, 3, 45, "Input"],
Cell[140255, 4352, 136, 4, 45, "Input"],
Cell[140394, 4358, 569, 18, 45, "Input"],
Cell[140966, 4378, 198, 5, 45, "Input"],
Cell[141167, 4385, 160, 4, 45, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[141376, 4395, 258, 6, 31, "Subsection"],
Cell[141637, 4403, 184, 4, 54, "Text"],
Cell[141824, 4409, 339, 11, 36, "Input"],
Cell[142166, 4422, 153, 5, 36, "Input"],
Cell[142322, 4429, 279, 9, 36, "Input"],
Cell[142604, 4440, 102, 3, 36, "Input"],
Cell[142709, 4445, 218, 6, 36, "Input"],
Cell[142930, 4453, 323, 8, 30, "Text"],
Cell[143256, 4463, 297, 8, 36, "Input"],
Cell[143556, 4473, 101, 3, 36, "Input"],
Cell[143660, 4478, 247, 7, 36, "Input"],
Cell[143910, 4487, 105, 3, 36, "Input"],
Cell[144018, 4492, 538, 16, 36, "Input"],
Cell[144559, 4510, 288, 7, 30, "Text"],
Cell[144850, 4519, 147, 4, 35, "Input"],
Cell[145000, 4525, 101, 3, 36, "Input"],
Cell[145104, 4530, 188, 4, 30, "Text"],
Cell[145295, 4536, 147, 3, 36, "Input"],
Cell[145445, 4541, 185, 4, 36, "Input"],
Cell[145633, 4547, 480, 8, 54, "Text"],
Cell[146116, 4557, 388, 10, 36, "Input"],
Cell[146507, 4569, 101, 3, 36, "Input"],
Cell[146611, 4574, 274, 7, 36, "Input"],
Cell[146888, 4583, 200, 4, 36, "Input"],
Cell[CellGroupData[{
Cell[147113, 4591, 88, 1, 42, "Subsubsection"],
Cell[147204, 4594, 98, 3, 36, "Input"],
Cell[147305, 4599, 152, 5, 30, "Text"],
Cell[147460, 4606, 131, 4, 36, "Input"],
Cell[147594, 4612, 88, 2, 30, "Text"],
Cell[147685, 4616, 391, 11, 36, "Input"],
Cell[148079, 4629, 600, 18, 36, "Input"],
Cell[148682, 4649, 196, 5, 36, "Input"],
Cell[148881, 4656, 253, 7, 36, "Input"],
Cell[149137, 4665, 195, 4, 30, "Text"],
Cell[149335, 4671, 704, 21, 36, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[150088, 4698, 120, 3, 31, "Subsection",
 Evaluatable->False],
Cell[150211, 4703, 219, 5, 54, "Text",
 Evaluatable->False],
Cell[150433, 4710, 82, 2, 36, "Input"],
Cell[150518, 4714, 115, 1, 30, "Text"],
Cell[150636, 4717, 2330, 57, 327, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[152991, 4778, 30, 0, 43, "Subsubsection"],
Cell[153024, 4780, 116, 2, 36, "Input"],
Cell[153143, 4784, 292, 8, 36, "Input"],
Cell[153438, 4794, 169, 4, 36, "Input"],
Cell[153610, 4800, 116, 1, 30, "Text"],
Cell[153729, 4803, 252, 6, 36, "Input"],
Cell[153984, 4811, 266, 7, 36, "Input"],
Cell[154253, 4820, 235, 5, 36, "Input"],
Cell[154491, 4827, 267, 7, 36, "Input"],
Cell[154761, 4836, 103, 3, 36, "Input"],
Cell[154867, 4841, 103, 3, 36, "Input"],
Cell[154973, 4846, 200, 5, 36, "Input"],
Cell[155176, 4853, 421, 14, 36, "Input"],
Cell[155600, 4869, 81, 2, 36, "Input"],
Cell[155684, 4873, 210, 6, 36, "Input"],
Cell[155897, 4881, 231, 6, 36, "Input"],
Cell[156131, 4889, 150, 4, 36, "Input"],
Cell[156284, 4895, 172, 3, 36, "Input"],
Cell[156459, 4900, 202, 6, 36, "Input"],
Cell[156664, 4908, 90, 2, 36, "Input"],
Cell[156757, 4912, 231, 5, 36, "Input"],
Cell[156991, 4919, 177, 6, 36, "Input"],
Cell[157171, 4927, 109, 3, 30, "Text"],
Cell[157283, 4932, 293, 10, 36, "Input"],
Cell[157579, 4944, 81, 2, 36, "Input"],
Cell[157663, 4948, 120, 3, 36, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[157820, 4956, 110, 2, 43, "Subsubsection"],
Cell[157933, 4960, 147, 3, 30, "Text"],
Cell[158083, 4965, 142, 4, 36, "Input"],
Cell[158228, 4971, 97, 2, 30, "Text"],
Cell[158328, 4975, 197, 6, 36, "Input"],
Cell[158528, 4983, 59, 0, 30, "Text"],
Cell[158590, 4985, 80, 2, 36, "Input"],
Cell[158673, 4989, 26, 0, 30, "Text"],
Cell[158702, 4991, 138, 4, 36, "Input"],
Cell[158843, 4997, 28, 0, 30, "Text"],
Cell[158874, 4999, 84, 2, 36, "Input"],
Cell[158961, 5003, 50, 0, 30, "Text"],
Cell[159014, 5005, 89, 2, 36, "Input"],
Cell[159106, 5009, 86, 2, 30, "Text"],
Cell[159195, 5013, 180, 5, 36, "Input"],
Cell[159378, 5020, 168, 5, 36, "Input"],
Cell[159549, 5027, 111, 3, 30, "Text"],
Cell[159663, 5032, 279, 7, 36, "Input"],
Cell[159945, 5041, 147, 4, 36, "Input"],
Cell[160095, 5047, 388, 13, 36, "Input"],
Cell[160486, 5062, 114, 3, 36, "Input"],
Cell[160603, 5067, 85, 2, 30, "Text"],
Cell[160691, 5071, 393, 13, 36, "Input"],
Cell[161087, 5086, 83, 2, 36, "Input"],
Cell[161173, 5090, 68, 0, 30, "Text"],
Cell[161244, 5092, 90, 2, 36, "Input"],
Cell[161337, 5096, 100, 3, 36, "Input"],
Cell[161440, 5101, 393, 13, 36, "Input"],
Cell[161836, 5116, 81, 2, 36, "Input"],
Cell[161920, 5120, 154, 3, 30, "Text"],
Cell[162077, 5125, 396, 13, 36, "Input"],
Cell[162476, 5140, 114, 3, 36, "Input"],
Cell[162593, 5145, 74, 0, 30, "Text"],
Cell[162670, 5147, 89, 2, 36, "Input"],
Cell[162762, 5151, 140, 3, 36, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[162963, 5161, 212, 3, 89, "Section"],
Cell[CellGroupData[{
Cell[163200, 5168, 32, 0, 35, "Subsubsection"],
Cell[163235, 5170, 425, 7, 81, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[163697, 5182, 201, 7, 37, "Subsection"],
Cell[163901, 5191, 171, 4, 24, "Text"],
Cell[164075, 5197, 475, 16, 30, "Input",
 InitializationCell->True],
Cell[164553, 5215, 503, 16, 30, "Input",
 InitializationCell->True],
Cell[165059, 5233, 519, 16, 30, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[165603, 5253, 195, 7, 35, "Subsubsection"],
Cell[165801, 5262, 384, 7, 62, "Text"],
Cell[166188, 5271, 1758, 52, 151, "Input",
 Evaluatable->False],
Cell[167949, 5325, 93, 3, 30, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[168079, 5333, 55, 1, 35, "Subsubsection"],
Cell[168137, 5336, 178, 6, 30, "Input"],
Cell[168318, 5344, 118, 3, 24, "Text"],
Cell[168439, 5349, 127, 4, 30, "Input"],
Cell[168569, 5355, 314, 10, 30, "Input"],
Cell[168886, 5367, 188, 6, 30, "Input"],
Cell[169077, 5375, 137, 4, 30, "Input"],
Cell[169217, 5381, 177, 4, 29, "Input"],
Cell[169397, 5387, 161, 5, 30, "Input"],
Cell[169561, 5394, 200, 5, 29, "Input"],
Cell[169764, 5401, 89, 2, 24, "Text"],
Cell[169856, 5405, 102, 3, 30, "Input"],
Cell[169961, 5410, 161, 5, 30, "Input"],
Cell[170125, 5417, 60, 0, 24, "Text"],
Cell[170188, 5419, 161, 5, 30, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[170398, 5430, 649, 18, 31, "Subsection"],
Cell[171050, 5450, 203, 4, 43, "Text"],
Cell[171256, 5456, 96, 3, 30, "Input"],
Cell[171355, 5461, 216, 6, 54, "Input",
 Evaluatable->False],
Cell[171574, 5469, 199, 4, 43, "Text"],
Cell[171776, 5475, 101, 3, 30, "Input"],
Cell[171880, 5480, 771, 23, 55, "Input",
 Evaluatable->False],
Cell[172654, 5505, 149, 3, 43, "Text"],
Cell[172806, 5510, 739, 24, 55, "Input",
 InitializationCell->True],
Cell[173548, 5536, 412, 10, 145, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[173985, 5550, 55, 1, 35, "Subsubsection"],
Cell[174043, 5553, 213, 7, 30, "Input"],
Cell[174259, 5562, 507, 12, 30, "Input"],
Cell[174769, 5576, 654, 14, 30, "Input"],
Cell[175426, 5592, 704, 16, 30, "Input"],
Cell[176133, 5610, 198, 6, 30, "Input"],
Cell[176334, 5618, 252, 8, 30, "Input"],
Cell[176589, 5628, 463, 11, 55, "Input"],
Cell[177055, 5641, 238, 8, 30, "Input"],
Cell[177296, 5651, 273, 9, 30, "Input"],
Cell[177572, 5662, 282, 9, 30, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[177903, 5677, 115, 1, 31, "Subsection"],
Cell[178021, 5680, 237, 5, 24, "Text"],
Cell[178261, 5687, 458, 13, 29, "Input",
 InitializationCell->True],
Cell[178722, 5702, 260, 8, 29, "Input"],
Cell[178985, 5712, 477, 15, 25, "Input"],
Cell[179465, 5729, 136, 1, 20, "Text"],
Cell[179604, 5732, 619, 17, 53, "Input",
 InitializationCell->True],
Cell[180226, 5751, 666, 17, 53, "Input"],
Cell[180895, 5770, 437, 12, 49, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[181369, 5787, 403, 11, 31, "Subsection"],
Cell[181775, 5800, 315, 6, 43, "Text"],
Cell[182093, 5808, 457, 11, 76, "Input",
 InitializationCell->True],
Cell[182553, 5821, 3765, 95, 260, "Input",
 InitializationCell->True],
Cell[186321, 5918, 916, 28, 79, "Input",
 InitializationCell->True],
Cell[187240, 5948, 355, 9, 76, "Input",
 InitializationCell->True],
Cell[187598, 5959, 1137, 30, 127, "Input",
 InitializationCell->True],
Cell[188738, 5991, 392, 9, 122, "Input",
 InitializationCell->True],
Cell[189133, 6002, 79, 2, 29, "Input"],
Cell[CellGroupData[{
Cell[189237, 6008, 62, 1, 35, "Subsubsection"],
Cell[189302, 6011, 246, 7, 29, "Input"],
Cell[189551, 6020, 246, 7, 29, "Input"],
Cell[189800, 6029, 564, 17, 30, "Input"],
Cell[190367, 6048, 274, 6, 30, "Input"],
Cell[190644, 6056, 445, 15, 30, "Input"],
Cell[191092, 6073, 107, 3, 30, "Input"],
Cell[191202, 6078, 95, 3, 30, "Input"],
Cell[191300, 6083, 416, 11, 30, "Input"],
Cell[191719, 6096, 172, 5, 30, "Input"],
Cell[191894, 6103, 53, 1, 29, "Input"],
Cell[191950, 6106, 309, 8, 29, "Input"],
Cell[192262, 6116, 162, 5, 30, "Input"],
Cell[192427, 6123, 173, 5, 30, "Input"],
Cell[192603, 6130, 422, 13, 30, "Input"],
Cell[193028, 6145, 378, 10, 29, "Input"],
Cell[193409, 6157, 226, 6, 30, "Input"],
Cell[193638, 6165, 443, 15, 30, "Input"],
Cell[194084, 6182, 106, 3, 30, "Input"],
Cell[194193, 6187, 658, 17, 55, "Input"],
Cell[194854, 6206, 197, 5, 29, "Input"],
Cell[195054, 6213, 30, 0, 24, "Text"],
Cell[195087, 6215, 171, 5, 30, "Input"],
Cell[195261, 6222, 407, 13, 30, "Input"],
Cell[195671, 6237, 146, 4, 30, "Input"],
Cell[195820, 6243, 106, 3, 30, "Input"],
Cell[195929, 6248, 116, 3, 30, "Input"],
Cell[196048, 6253, 129, 2, 25, "Text"],
Cell[196180, 6257, 363, 11, 29, "Input"],
Cell[196546, 6270, 147, 3, 29, "Input"],
Cell[196696, 6275, 469, 15, 29, "Input"],
Cell[197168, 6292, 147, 3, 29, "Input"],
Cell[197318, 6297, 147, 3, 29, "Input"],
Cell[197468, 6302, 250, 7, 29, "Input"],
Cell[197721, 6311, 253, 7, 29, "Input"],
Cell[197977, 6320, 94, 1, 24, "Text"],
Cell[198074, 6323, 192, 5, 29, "Input"],
Cell[198269, 6330, 289, 8, 29, "Input"],
Cell[198561, 6340, 149, 3, 29, "Input"],
Cell[198713, 6345, 148, 3, 29, "Input"],
Cell[198864, 6350, 336, 10, 29, "Input"],
Cell[199203, 6362, 151, 3, 29, "Input"],
Cell[199357, 6367, 109, 1, 24, "Text"],
Cell[199469, 6370, 501, 13, 53, "Input",
 InitializationCell->True],
Cell[199973, 6385, 1140, 33, 53, "Input"],
Cell[201116, 6420, 599, 17, 72, "Input"],
Cell[201718, 6439, 235, 6, 29, "Input"],
Cell[201956, 6447, 319, 9, 29, "Input"],
Cell[202278, 6458, 217, 5, 29, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[202544, 6469, 390, 10, 31, "Subsection"],
Cell[CellGroupData[{
Cell[202959, 6483, 32, 0, 35, "Subsubsection"],
Cell[202994, 6485, 2199, 51, 176, "Text"],
Cell[205196, 6538, 192, 6, 30, "Input"],
Cell[205391, 6546, 456, 11, 24, "Text"],
Cell[205850, 6559, 181, 4, 29, "Input"],
Cell[206034, 6565, 1376, 31, 119, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[207447, 6601, 522, 12, 29, "Subsubsection"],
Cell[207972, 6615, 540, 12, 62, "Text"],
Cell[208515, 6629, 177, 5, 29, "Input"],
Cell[208695, 6636, 401, 11, 29, "Input"],
Cell[209099, 6649, 110, 1, 24, "Text"],
Cell[209212, 6652, 253, 7, 29, "Input"],
Cell[209468, 6661, 231, 6, 29, "Input"],
Cell[209702, 6669, 341, 8, 43, "Text"],
Cell[210046, 6679, 181, 4, 29, "Input"],
Cell[210230, 6685, 229, 5, 29, "Input"],
Cell[210462, 6692, 160, 3, 24, "Text"],
Cell[210625, 6697, 387, 11, 29, "Input"],
Cell[211015, 6710, 113, 1, 24, "Text"],
Cell[211131, 6713, 118, 3, 29, "Input"],
Cell[211252, 6718, 110, 1, 24, "Text"],
Cell[211365, 6721, 183, 4, 29, "Input"],
Cell[211551, 6727, 231, 5, 29, "Input"],
Cell[211785, 6734, 230, 5, 29, "Input"],
Cell[212018, 6741, 296, 5, 43, "Text"],
Cell[212317, 6748, 14760, 380, 1019, "Input",
 InitializationCell->True],
Cell[227080, 7130, 371, 8, 29, "Input"],
Cell[227454, 7140, 392, 7, 29, "Input"],
Cell[227849, 7149, 391, 7, 29, "Input"],
Cell[228243, 7158, 522, 10, 29, "Input"],
Cell[228768, 7170, 773, 24, 53, "Input"],
Cell[229544, 7196, 215, 5, 29, "Input"],
Cell[229762, 7203, 773, 24, 53, "Input"],
Cell[230538, 7229, 505, 10, 29, "Input"],
Cell[231046, 7241, 664, 19, 53, "Input"],
Cell[231713, 7262, 100, 2, 24, "Text"],
Cell[231816, 7266, 2177, 60, 214, "Input",
 InitializationCell->True],
Cell[233996, 7328, 110, 3, 24, "Text"],
Cell[234109, 7333, 343, 8, 29, "Input"],
Cell[234455, 7343, 146, 3, 29, "Input"],
Cell[234604, 7348, 208, 4, 43, "Text"],
Cell[234815, 7354, 168, 4, 29, "Input"],
Cell[CellGroupData[{
Cell[235008, 7362, 146, 4, 29, "Input"],
Cell[235157, 7368, 428, 11, 28, "Output"],
Cell[235588, 7381, 400, 10, 28, "Output"],
Cell[235991, 7393, 403, 10, 28, "Output"],
Cell[236397, 7405, 375, 9, 28, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[236809, 7419, 542, 17, 53, "Input"],
Cell[237354, 7438, 1978, 50, 95, "Output"],
Cell[239335, 7490, 1952, 49, 117, "Output"],
Cell[241290, 7541, 1952, 49, 95, "Output"],
Cell[243245, 7592, 1954, 48, 117, "Output"]
}, Closed]],
Cell[245214, 7643, 1022, 28, 122, "Input"],
Cell[246239, 7673, 281, 5, 24, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[246557, 7683, 293, 4, 29, "Subsubsection"],
Cell[246853, 7689, 612, 12, 81, "Text"],
Cell[247468, 7703, 99, 3, 30, "Input"],
Cell[247570, 7708, 407, 13, 30, "Input"],
Cell[247980, 7723, 432, 14, 30, "Input"],
Cell[248415, 7739, 134, 4, 29, "Input"],
Cell[248552, 7745, 566, 15, 53, "Input"],
Cell[249121, 7762, 127, 3, 24, "Text"],
Cell[249251, 7767, 427, 12, 30, "Input"],
Cell[249681, 7781, 524, 14, 53, "Input"],
Cell[250208, 7797, 51, 0, 24, "Text"],
Cell[250262, 7799, 242, 8, 30, "Input"],
Cell[250507, 7809, 212, 7, 30, "Input"],
Cell[250722, 7818, 206, 4, 43, "Text"],
Cell[250931, 7824, 216, 7, 30, "Input"],
Cell[251150, 7833, 216, 7, 30, "Input"],
Cell[251369, 7842, 349, 12, 30, "Input"],
Cell[251721, 7856, 218, 7, 30, "Input"],
Cell[251942, 7865, 341, 11, 30, "Input"],
Cell[252286, 7878, 314, 10, 30, "Input"],
Cell[252603, 7890, 280, 9, 30, "Input"],
Cell[252886, 7901, 222, 7, 30, "Input"],
Cell[253111, 7910, 471, 15, 30, "Input"],
Cell[253585, 7927, 442, 14, 30, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[254064, 7946, 203, 4, 29, "Subsubsection"],
Cell[254270, 7952, 696, 15, 81, "Text"],
Cell[254969, 7969, 125, 4, 30, "Input"],
Cell[255097, 7975, 142, 4, 30, "Input"],
Cell[255242, 7981, 370, 11, 30, "Input"],
Cell[255615, 7994, 135, 4, 30, "Input"],
Cell[255753, 8000, 195, 5, 30, "Input"],
Cell[255951, 8007, 270, 8, 30, "Input"],
Cell[256224, 8017, 238, 6, 30, "Input"],
Cell[256465, 8025, 285, 8, 30, "Input"],
Cell[256753, 8035, 86, 2, 24, "Text"],
Cell[256842, 8039, 412, 13, 55, "Input"],
Cell[257257, 8054, 368, 11, 30, "Input"],
Cell[257628, 8067, 270, 8, 30, "Input"],
Cell[257901, 8077, 136, 4, 30, "Input"],
Cell[258040, 8083, 285, 8, 30, "Input"],
Cell[258328, 8093, 73, 0, 24, "Text"],
Cell[258404, 8095, 586, 18, 55, "Input"],
Cell[258993, 8115, 370, 11, 30, "Input"],
Cell[259366, 8128, 179, 4, 29, "Input"],
Cell[259548, 8134, 270, 8, 30, "Input"],
Cell[259821, 8144, 352, 10, 30, "Input"],
Cell[260176, 8156, 22, 0, 24, "Text"],
Cell[260201, 8158, 775, 24, 55, "Input"],
Cell[260979, 8184, 521, 15, 30, "Input"],
Cell[261503, 8201, 173, 5, 30, "Input"],
Cell[261679, 8208, 108, 3, 24, "Text"],
Cell[261790, 8213, 97, 3, 30, "Input"],
Cell[261890, 8218, 178, 5, 30, "Input"],
Cell[262071, 8225, 141, 3, 29, "Input"],
Cell[262215, 8230, 60, 0, 24, "Text"],
Cell[262278, 8232, 208, 6, 30, "Input"],
Cell[262489, 8240, 53, 0, 24, "Text"],
Cell[262545, 8242, 179, 5, 29, "Input"],
Cell[262727, 8249, 454, 14, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[263218, 8268, 187, 4, 29, "Subsubsection"],
Cell[263408, 8274, 154, 3, 24, "Text"],
Cell[263565, 8279, 100, 3, 30, "Input"],
Cell[263668, 8284, 436, 9, 62, "Text"],
Cell[264107, 8295, 246, 7, 30, "Input"],
Cell[264356, 8304, 237, 5, 24, "Text"],
Cell[264596, 8311, 354, 12, 30, "Input"],
Cell[264953, 8325, 437, 12, 29, "Input"],
Cell[265393, 8339, 239, 7, 30, "Input"],
Cell[265635, 8348, 363, 11, 29, "Input"],
Cell[266001, 8361, 696, 11, 100, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[266734, 8377, 155, 2, 29, "Subsubsection"],
Cell[CellGroupData[{
Cell[266914, 8383, 144, 3, 29, "Input"],
Cell[267061, 8388, 284, 7, 28, "Output"]
}, Closed]],
Cell[267360, 8398, 149, 2, 24, "Text"],
Cell[CellGroupData[{
Cell[267534, 8404, 193, 5, 29, "Input"],
Cell[267730, 8411, 424, 11, 28, "Output"],
Cell[268157, 8424, 396, 10, 28, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[268590, 8439, 567, 18, 29, "Input"],
Cell[269160, 8459, 429, 11, 28, "Output"],
Cell[269592, 8472, 402, 10, 28, "Output"]
}, Closed]],
Cell[270009, 8485, 206, 4, 24, "Text"],
Cell[CellGroupData[{
Cell[270240, 8493, 311, 8, 29, "Input"],
Cell[270554, 8503, 2028, 50, 117, "Output"],
Cell[272585, 8555, 2033, 50, 119, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[274655, 8610, 397, 13, 30, "Input"],
Cell[275055, 8625, 2246, 56, 95, "Output"],
Cell[277304, 8683, 2228, 56, 117, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[279569, 8744, 269, 8, 29, "Input"],
Cell[279841, 8754, 3415, 90, 183, "Output"],
Cell[283259, 8846, 3397, 89, 183, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[286693, 8940, 171, 4, 29, "Input"],
Cell[286867, 8946, 3303, 91, 183, "Output"],
Cell[290173, 9039, 3284, 90, 183, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[293494, 9134, 282, 8, 30, "Input"],
Cell[293779, 9144, 2193, 53, 95, "Output"],
Cell[295975, 9199, 2173, 52, 95, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[298185, 9256, 603, 17, 29, "Input"],
Cell[298791, 9275, 1561, 42, 73, "Output"],
Cell[300355, 9319, 1532, 41, 73, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[301924, 9365, 512, 13, 29, "Input"],
Cell[302439, 9380, 2352, 65, 117, "Output"],
Cell[304794, 9447, 2331, 64, 117, "Output"]
}, Closed]],
Cell[307140, 9514, 195, 5, 24, "Text"],
Cell[CellGroupData[{
Cell[307360, 9523, 781, 21, 53, "Input"],
Cell[308144, 9546, 200711, 3277, 212, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[508892, 12828, 918, 26, 76, "Input"],
Cell[509813, 12856, 206048, 3370, 212, "Output"]
}, Closed]],
Cell[715876, 16229, 1007, 27, 76, "Input"],
Cell[CellGroupData[{
Cell[716908, 16260, 830, 21, 53, "Input"],
Cell[717741, 16283, 256881, 4203, 212, "Output"]
}, Closed]],
Cell[974637, 20489, 560, 9, 62, "Text"],
Cell[CellGroupData[{
Cell[975222, 20502, 597, 18, 29, "Input"],
Cell[975822, 20522, 648, 20, 40, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[976507, 20547, 1000, 24, 76, "Input"],
Cell[977510, 20573, 981, 27, 51, "Output"],
Cell[978494, 20602, 879, 25, 51, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[979410, 20632, 860, 25, 76, "Input"],
Cell[980273, 20659, 878, 24, 51, "Output"],
Cell[981154, 20685, 874, 22, 51, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[982065, 20712, 776, 21, 76, "Input"],
Cell[982844, 20735, 883, 24, 51, "Output"],
Cell[983730, 20761, 882, 22, 51, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[984649, 20788, 179, 4, 29, "Input"],
Cell[984831, 20794, 447, 11, 28, "Output"],
Cell[985281, 20807, 373, 10, 28, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[985691, 20822, 179, 4, 29, "Input"],
Cell[985873, 20828, 443, 11, 28, "Output"],
Cell[986319, 20841, 372, 10, 28, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[986728, 20856, 178, 4, 29, "Input"],
Cell[986909, 20862, 449, 11, 28, "Output"],
Cell[987361, 20875, 374, 10, 28, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[987772, 20890, 179, 4, 29, "Input"],
Cell[987954, 20896, 299, 6, 28, "Output"],
Cell[988256, 20904, 278, 6, 28, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[988571, 20915, 173, 4, 29, "Input"],
Cell[988747, 20921, 300, 6, 28, "Output"],
Cell[989050, 20929, 278, 6, 28, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[989365, 20940, 178, 4, 29, "Input"],
Cell[989546, 20946, 294, 6, 28, "Output"],
Cell[989843, 20954, 277, 6, 28, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[990169, 20966, 243, 4, 29, "Subsubsection"],
Cell[990415, 20972, 138, 4, 30, "Input"],
Cell[990556, 20978, 54, 0, 24, "Text"],
Cell[990613, 20980, 253, 8, 30, "Input"],
Cell[990869, 20990, 229, 7, 29, "Input"],
Cell[991101, 20999, 55, 0, 24, "Text"],
Cell[991159, 21001, 272, 9, 30, "Input"],
Cell[991434, 21012, 270, 8, 29, "Input"],
Cell[991707, 21022, 162, 5, 30, "Input"],
Cell[991872, 21029, 231, 7, 30, "Input"],
Cell[992106, 21038, 85, 2, 24, "Text"],
Cell[992194, 21042, 696, 20, 55, "Input"],
Cell[992893, 21064, 237, 5, 24, "Text"],
Cell[993133, 21071, 951, 30, 79, "Input"],
Cell[994087, 21103, 647, 19, 29, "Input"],
Cell[994737, 21124, 1132, 28, 76, "Input"],
Cell[995872, 21154, 181, 4, 29, "Input"],
Cell[996056, 21160, 237, 5, 29, "Input"],
Cell[996296, 21167, 1151, 29, 99, "Input"],
Cell[997450, 21198, 138, 4, 30, "Input"],
Cell[997591, 21204, 254, 8, 30, "Input"],
Cell[997848, 21214, 311, 9, 29, "Input"],
Cell[998162, 21225, 204, 6, 24, "Text"],
Cell[998369, 21233, 327, 10, 29, "Input"],
Cell[998699, 21245, 605, 18, 30, "Input"],
Cell[999307, 21265, 376, 11, 29, "Input"],
Cell[999686, 21278, 688, 21, 55, "Input"],
Cell[1000377, 21301, 472, 14, 43, "Text"],
Cell[1000852, 21317, 258, 9, 30, "Input"],
Cell[1001113, 21328, 299, 10, 30, "Input"],
Cell[1001415, 21340, 701, 21, 55, "Input"],
Cell[1002119, 21363, 57, 0, 24, "Text"],
Cell[1002179, 21365, 1234, 32, 79, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1003450, 21402, 223, 3, 29, "Subsubsection"],
Cell[1003676, 21407, 245, 5, 43, "Text"],
Cell[1003924, 21414, 1825, 52, 199, "Input"],
Cell[1005752, 21468, 64, 0, 24, "Text"],
Cell[1005819, 21470, 508, 16, 30, "Input"],
Cell[1006330, 21488, 521, 14, 55, "Input"],
Cell[1006854, 21504, 449, 14, 30, "Input"],
Cell[1007306, 21520, 167, 5, 30, "Input"],
Cell[1007476, 21527, 371, 11, 30, "Input"],
Cell[1007850, 21540, 167, 5, 30, "Input"],
Cell[1008020, 21547, 671, 17, 55, "Input"],
Cell[1008694, 21566, 171, 5, 30, "Input"],
Cell[1008868, 21573, 160, 5, 30, "Input"],
Cell[1009031, 21580, 63, 0, 24, "Text"],
Cell[1009097, 21582, 485, 15, 30, "Input"],
Cell[1009585, 21599, 394, 12, 30, "Input"],
Cell[1009982, 21613, 324, 10, 30, "Input"],
Cell[1010309, 21625, 138, 3, 24, "Text"],
Cell[1010450, 21630, 667, 19, 55, "Input"],
Cell[1011120, 21651, 645, 18, 55, "Input"],
Cell[1011768, 21671, 169, 5, 30, "Input"],
Cell[1011940, 21678, 575, 17, 30, "Input"],
Cell[1012518, 21697, 347, 10, 30, "Input"],
Cell[1012868, 21709, 159, 5, 30, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1013088, 21721, 128, 2, 89, "Section"],
Cell[CellGroupData[{
Cell[1013241, 21727, 32, 0, 35, "Subsubsection"],
Cell[1013276, 21729, 1066, 34, 81, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1014379, 21768, 114, 2, 37, "Subsection"],
Cell[1014496, 21772, 811, 18, 81, "Text",
 Evaluatable->False],
Cell[1015310, 21792, 98, 3, 30, "Input"],
Cell[1015411, 21797, 67, 0, 24, "Text"],
Cell[1015481, 21799, 2041, 60, 199, "Input",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1017547, 21863, 92, 1, 35, "Subsubsection"],
Cell[1017642, 21866, 126, 4, 30, "Input"],
Cell[1017771, 21872, 162, 5, 30, "Input"],
Cell[1017936, 21879, 94, 3, 30, "Input"],
Cell[1018033, 21884, 179, 6, 30, "Input"],
Cell[1018215, 21892, 217, 7, 30, "Input"],
Cell[1018435, 21901, 230, 7, 30, "Input"],
Cell[1018668, 21910, 588, 16, 53, "Input"],
Cell[1019259, 21928, 221, 5, 29, "Input"],
Cell[1019483, 21935, 449, 15, 30, "Input"],
Cell[1019935, 21952, 227, 7, 30, "Input"],
Cell[1020165, 21961, 181, 4, 24, "Text"],
Cell[1020349, 21967, 156, 4, 29, "Input"],
Cell[1020508, 21973, 198, 6, 30, "Input"],
Cell[1020709, 21981, 284, 9, 30, "Input"],
Cell[1020996, 21992, 134, 4, 30, "Input"],
Cell[1021133, 21998, 90, 2, 24, "Text"],
Cell[1021226, 22002, 162, 5, 30, "Input"],
Cell[1021391, 22009, 100, 2, 24, "Text"],
Cell[1021494, 22013, 126, 4, 30, "Input"],
Cell[1021623, 22019, 162, 5, 30, "Input"],
Cell[1021788, 22026, 40, 0, 24, "Text"],
Cell[1021831, 22028, 103, 3, 30, "Input"],
Cell[1021937, 22033, 138, 4, 30, "Input"],
Cell[1022078, 22039, 57, 0, 24, "Text"],
Cell[1022138, 22041, 219, 7, 30, "Input"],
Cell[1022360, 22050, 286, 9, 30, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1022695, 22065, 142, 3, 31, "Subsection"],
Cell[1022840, 22070, 227, 4, 43, "Text"],
Cell[1023070, 22076, 101, 3, 30, "Input"],
Cell[1023174, 22081, 913, 30, 55, "Input",
 Evaluatable->False],
Cell[1024090, 22113, 165, 5, 30, "Input"],
Cell[1024258, 22120, 131, 4, 30, "Input"],
Cell[CellGroupData[{
Cell[1024414, 22128, 55, 1, 35, "Subsubsection"],
Cell[1024472, 22131, 28, 0, 24, "Text"],
Cell[1024503, 22133, 142, 4, 30, "Input"],
Cell[1024648, 22139, 45, 0, 24, "Text"],
Cell[1024696, 22141, 158, 5, 30, "Input"],
Cell[1024857, 22148, 714, 22, 98, "Input"],
Cell[1025574, 22172, 52, 0, 24, "Text"],
Cell[1025629, 22174, 418, 14, 30, "Input"],
Cell[1026050, 22190, 274, 7, 29, "Input"],
Cell[1026327, 22199, 72, 0, 24, "Text"],
Cell[1026402, 22201, 384, 12, 30, "Input"],
Cell[1026789, 22215, 215, 6, 30, "Input"],
Cell[1027007, 22223, 146, 4, 30, "Input"],
Cell[1027156, 22229, 108, 3, 30, "Input"],
Cell[1027267, 22234, 340, 11, 33, "Input"],
Cell[1027610, 22247, 39, 0, 24, "Text"],
Cell[1027652, 22249, 98, 3, 30, "Input"]
}, Closed]]
}, Closed]],
Cell[1027777, 22256, 240, 5, 31, "Subsection"],
Cell[CellGroupData[{
Cell[1028042, 22265, 141, 2, 31, "Subsection"],
Cell[1028186, 22269, 1052, 17, 138, "Text"],
Cell[CellGroupData[{
Cell[1029263, 22290, 124, 2, 35, "Subsubsection"],
Cell[1029390, 22294, 670, 12, 93, "Text"],
Cell[1030063, 22308, 472, 13, 29, "Input"],
Cell[1030538, 22323, 138, 1, 24, "Text"],
Cell[1030679, 22326, 352, 10, 29, "Input"],
Cell[1031034, 22338, 158, 3, 24, "Text"],
Cell[1031195, 22343, 241, 6, 29, "Input"],
Cell[1031439, 22351, 94, 1, 24, "Text"],
Cell[1031536, 22354, 165, 5, 29, "Input"],
Cell[1031704, 22361, 500, 15, 24, "Text"],
Cell[1032207, 22378, 478, 12, 29, "Input"],
Cell[1032688, 22392, 207, 4, 24, "Text"],
Cell[1032898, 22398, 558, 16, 53, "Input"],
Cell[1033459, 22416, 640, 10, 81, "Text"],
Cell[1034102, 22428, 750, 22, 76, "Input"],
Cell[1034855, 22452, 185, 4, 29, "Input"],
Cell[1035043, 22458, 176, 4, 29, "Input"],
Cell[1035222, 22464, 194, 4, 24, "Text"],
Cell[1035419, 22470, 182, 4, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1035638, 22479, 158, 2, 29, "Subsubsection"],
Cell[1035799, 22483, 215, 4, 43, "Text"],
Cell[1036017, 22489, 2124, 52, 237, "Input"],
Cell[1038144, 22543, 283, 7, 29, "Input"],
Cell[1038430, 22552, 127, 1, 24, "Text"],
Cell[1038560, 22555, 970, 25, 99, "Input"],
Cell[1039533, 22582, 240, 5, 24, "Text"],
Cell[1039776, 22589, 294, 6, 29, "Input"],
Cell[1040073, 22597, 216, 5, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1040326, 22607, 109, 1, 29, "Subsubsection"],
Cell[1040438, 22610, 206, 4, 24, "Text"],
Cell[1040647, 22616, 719, 18, 53, "Input"],
Cell[1041369, 22636, 176, 2, 24, "Text"],
Cell[1041548, 22640, 574, 18, 29, "Input"],
Cell[1042125, 22660, 529, 13, 29, "Input"],
Cell[1042657, 22675, 349, 6, 43, "Text"],
Cell[1043009, 22683, 11945, 335, 789, "Input",
 InitializationCell->True],
Cell[1054957, 23020, 277, 6, 29, "Input"],
Cell[1055237, 23028, 334, 8, 43, "Text"],
Cell[1055574, 23038, 379, 7, 43, "Text"],
Cell[1055956, 23047, 798, 15, 29, "Input",
 InitializationCell->True],
Cell[1056757, 23064, 678, 17, 76, "Input",
 InitializationCell->True],
Cell[1057438, 23083, 274, 5, 43, "Text"],
Cell[1057715, 23090, 370, 9, 29, "Input"],
Cell[1058088, 23101, 289, 7, 29, "Input"],
Cell[1058380, 23110, 338, 8, 29, "Input"],
Cell[1058721, 23120, 517, 12, 29, "Input"],
Cell[1059241, 23134, 223, 5, 29, "Input"],
Cell[1059467, 23141, 613, 13, 29, "Input"],
Cell[1060083, 23156, 198, 4, 29, "Input"],
Cell[1060284, 23162, 777, 15, 29, "Input"],
Cell[1061064, 23179, 853, 17, 29, "Input"],
Cell[1061920, 23198, 298, 6, 43, "Text"],
Cell[1062221, 23206, 480, 11, 53, "Input"],
Cell[1062704, 23219, 479, 11, 53, "Input"],
Cell[1063186, 23232, 522, 11, 53, "Input"],
Cell[1063711, 23245, 250, 6, 29, "Input"],
Cell[1063964, 23253, 276, 6, 29, "Input"],
Cell[1064243, 23261, 549, 12, 29, "Input"],
Cell[1064795, 23275, 166, 3, 24, "Text"],
Cell[1064964, 23280, 895, 22, 99, "Input",
 InitializationCell->True],
Cell[1065862, 23304, 394, 8, 29, "Input"],
Cell[1066259, 23314, 165, 4, 29, "Input"],
Cell[1066427, 23320, 390, 7, 43, "Text"],
Cell[1066820, 23329, 440, 11, 44, "Input"],
Cell[1067263, 23342, 168, 4, 29, "Input"],
Cell[1067434, 23348, 176, 4, 29, "Input"],
Cell[1067613, 23354, 352, 7, 43, "Text"],
Cell[1067968, 23363, 1241, 29, 99, "Input"],
Cell[1069212, 23394, 208, 5, 29, "Input"],
Cell[1069423, 23401, 201, 2, 24, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1069673, 23409, 100, 1, 31, "Subsection"],
Cell[1069776, 23412, 621, 12, 81, "Text"],
Cell[1070400, 23426, 224, 7, 29, "Input"],
Cell[1070627, 23435, 229, 7, 29, "Input"],
Cell[1070859, 23444, 229, 7, 29, "Input"],
Cell[1071091, 23453, 339, 11, 29, "Input"],
Cell[1071433, 23466, 89, 2, 24, "Text"],
Cell[1071525, 23470, 119, 3, 29, "Input"],
Cell[1071647, 23475, 198, 4, 24, "Text"],
Cell[1071848, 23481, 269, 9, 29, "Input"],
Cell[1072120, 23492, 269, 9, 29, "Input"],
Cell[1072392, 23503, 269, 9, 29, "Input"],
Cell[1072664, 23514, 333, 10, 43, "Text"],
Cell[1073000, 23526, 345, 11, 29, "Input"],
Cell[1073348, 23539, 119, 3, 29, "Input"],
Cell[1073470, 23544, 94, 2, 24, "Text"],
Cell[1073567, 23548, 475, 16, 65, "Output"],
Cell[1074045, 23566, 131, 3, 24, "Text"],
Cell[1074179, 23571, 402, 14, 45, "Input"],
Cell[1074584, 23587, 90, 2, 29, "Input"],
Cell[1074677, 23591, 127, 3, 24, "Text"],
Cell[1074807, 23596, 35, 0, 29, "Input"],
Cell[1074845, 23598, 136, 3, 24, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1075018, 23606, 319, 7, 31, "Subsection",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1075362, 23617, 98, 1, 35, "Subsubsection"],
Cell[1075463, 23620, 810, 22, 62, "Text"],
Cell[1076276, 23644, 220, 6, 47, "Input"],
Cell[1076499, 23652, 25, 0, 20, "Text"],
Cell[1076527, 23654, 1106, 40, 68, "Input",
 InitializationCell->True],
Cell[1077636, 23696, 366, 9, 99, "Input",
 InitializationCell->True],
Cell[1078005, 23707, 171, 6, 28, "Input"],
Cell[1078179, 23715, 171, 6, 24, "Input"],
Cell[1078353, 23723, 729, 20, 47, "Input"],
Cell[1079085, 23745, 128, 4, 24, "Input"],
Cell[1079216, 23751, 539, 15, 43, "Text",
 Evaluatable->False],
Cell[1079758, 23768, 928, 29, 48, "Input",
 InitializationCell->True],
Cell[1080689, 23799, 362, 8, 122, "Input",
 InitializationCell->True],
Cell[1081054, 23809, 176, 6, 28, "Input"],
Cell[1081233, 23817, 164, 3, 39, "Text"],
Cell[1081400, 23822, 201, 7, 28, "Input"],
Cell[1081604, 23831, 661, 18, 47, "Input"],
Cell[1082268, 23851, 129, 4, 24, "Input"],
Cell[1082400, 23857, 95, 3, 28, "Input"],
Cell[1082498, 23862, 129, 4, 24, "Input"],
Cell[1082630, 23868, 62, 0, 24, "Text"],
Cell[1082695, 23870, 696, 20, 28, "Input"],
Cell[1083394, 23892, 169, 5, 26, "Input"],
Cell[1083566, 23899, 156, 5, 30, "Input"],
Cell[1083725, 23906, 162, 5, 26, "Input"],
Cell[1083890, 23913, 205, 4, 43, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1084132, 23922, 164, 2, 29, "Subsubsection"],
Cell[1084299, 23926, 126, 3, 24, "Text"],
Cell[1084428, 23931, 526, 16, 30, "Input"],
Cell[1084957, 23949, 489, 15, 30, "Input"],
Cell[1085449, 23966, 166, 3, 20, "Text"],
Cell[1085618, 23971, 3486, 104, 191, "Input",
 InitializationCell->True],
Cell[1089107, 24077, 367, 10, 29, "Input"],
Cell[1089477, 24089, 86, 2, 20, "Text"],
Cell[1089566, 24093, 499, 15, 30, "Input",
 InitializationCell->True],
Cell[1090068, 24110, 158, 5, 30, "Input"],
Cell[1090229, 24117, 501, 15, 26, "Input",
 InitializationCell->True],
Cell[1090733, 24134, 158, 5, 30, "Input"],
Cell[1090894, 24141, 156, 5, 26, "Input"],
Cell[1091053, 24148, 156, 5, 26, "Input"],
Cell[1091212, 24155, 110, 3, 20, "Text"],
Cell[1091325, 24160, 298, 10, 30, "Input"],
Cell[1091626, 24172, 191, 4, 20, "Text"],
Cell[1091820, 24178, 557, 16, 30, "Input"],
Cell[1092380, 24196, 480, 13, 29, "Input"],
Cell[1092863, 24211, 206, 4, 20, "Text"],
Cell[1093072, 24217, 583, 16, 30, "Input"],
Cell[1093658, 24235, 459, 13, 29, "Input"],
Cell[1094120, 24250, 562, 16, 25, "Input"],
Cell[1094685, 24268, 224, 6, 26, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1094946, 24279, 162, 3, 29, "Subsubsection"],
Cell[1095111, 24284, 736, 19, 100, "Text"],
Cell[1095850, 24305, 739, 23, 55, "Input"],
Cell[1096592, 24330, 76, 0, 24, "Text"],
Cell[1096671, 24332, 410, 12, 30, "Input"],
Cell[1097084, 24346, 158, 5, 30, "Input"],
Cell[1097245, 24353, 405, 12, 30, "Input"],
Cell[1097653, 24367, 158, 5, 30, "Input"],
Cell[1097814, 24374, 57, 0, 24, "Text"],
Cell[1097874, 24376, 1160, 36, 122, "Input"],
Cell[1099037, 24414, 119, 3, 29, "Input"],
Cell[1099159, 24419, 285, 6, 55, "Text"],
Cell[1099447, 24427, 158, 5, 30, "Input"],
Cell[1099608, 24434, 158, 5, 30, "Input"],
Cell[1099769, 24441, 270, 9, 30, "Input"],
Cell[1100042, 24452, 355, 12, 30, "Input"],
Cell[1100400, 24466, 2176, 64, 131, "Input"],
Cell[1102579, 24532, 173, 5, 29, "Input"],
Cell[1102755, 24539, 270, 9, 30, "Input"],
Cell[1103028, 24550, 270, 9, 30, "Input"],
Cell[1103301, 24561, 600, 18, 51, "Input"],
Cell[1103904, 24581, 144, 3, 43, "Text"],
Cell[1104051, 24586, 496, 17, 30, "Input"],
Cell[1104550, 24605, 222, 4, 43, "Text"],
Cell[1104775, 24611, 313, 9, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1105125, 24625, 308, 7, 29, "Subsubsection"],
Cell[1105436, 24634, 1017, 17, 131, "Text"],
Cell[1106456, 24653, 96, 1, 29, "Input"],
Cell[1106555, 24656, 322, 10, 30, "Input"],
Cell[1106880, 24668, 489, 14, 29, "Input"],
Cell[1107372, 24684, 122, 1, 24, "Text"],
Cell[1107497, 24687, 5942, 173, 482, "Input",
 InitializationCell->True],
Cell[1113442, 24862, 523, 11, 43, "Text"],
Cell[1113968, 24875, 761, 21, 30, "Input",
 InitializationCell->True],
Cell[1114732, 24898, 72, 0, 24, "Text"],
Cell[1114807, 24900, 221, 7, 30, "Input"],
Cell[1115031, 24909, 299, 8, 30, "Input"],
Cell[1115333, 24919, 260, 8, 30, "Input"],
Cell[1115596, 24929, 180, 3, 43, "Text"],
Cell[1115779, 24934, 460, 13, 30, "Input"],
Cell[1116242, 24949, 334, 8, 29, "Input"],
Cell[1116579, 24959, 367, 10, 30, "Input"],
Cell[1116949, 24971, 108, 3, 30, "Input"],
Cell[1117060, 24976, 415, 12, 30, "Input"],
Cell[1117478, 24990, 333, 8, 29, "Input"],
Cell[1117814, 25000, 259, 8, 30, "Input"],
Cell[1118076, 25010, 85, 2, 24, "Text"],
Cell[1118164, 25014, 108, 3, 30, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1118309, 25022, 276, 3, 29, "Subsubsection"],
Cell[1118588, 25027, 785, 19, 62, "Text"],
Cell[1119376, 25048, 400, 9, 29, "Input"],
Cell[1119779, 25059, 530, 11, 29, "Input"],
Cell[1120312, 25072, 72, 0, 24, "Text"],
Cell[1120387, 25074, 267, 8, 30, "Input"],
Cell[1120657, 25084, 752, 16, 53, "Input"],
Cell[1121412, 25102, 953, 26, 51, "Input"],
Cell[1122368, 25130, 388, 10, 30, "Input"],
Cell[1122759, 25142, 370, 11, 30, "Input"],
Cell[1123132, 25155, 180, 3, 43, "Text"],
Cell[1123315, 25160, 640, 16, 30, "Input"],
Cell[1123958, 25178, 389, 10, 30, "Input"],
Cell[1124350, 25190, 109, 3, 30, "Input"],
Cell[1124462, 25195, 597, 16, 30, "Input"],
Cell[1125062, 25213, 282, 8, 30, "Input"],
Cell[1125347, 25223, 85, 2, 24, "Text"],
Cell[1125435, 25227, 109, 3, 30, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1125605, 25237, 179, 4, 89, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1125809, 25245, 32, 0, 35, "Subsubsection"],
Cell[1125844, 25247, 979, 14, 138, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1126860, 25266, 84, 2, 37, "Subsection"],
Cell[1126947, 25270, 537, 16, 200, "Text"],
Cell[1127487, 25288, 224, 8, 157, "Input",
 Evaluatable->False],
Cell[1127714, 25298, 86, 2, 135, "Input"],
Cell[1127803, 25302, 1284, 42, 470, "Input",
 Evaluatable->False],
Cell[1129090, 25346, 73, 0, 110, "Text"],
Cell[1129166, 25348, 135, 4, 135, "Input",
 InitializationCell->True],
Cell[1129304, 25354, 357, 9, 470, "Input",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[1129686, 25367, 67, 2, 168, "Subsubsection"],
Cell[1129756, 25371, 170, 5, 151, "Input"],
Cell[1129929, 25378, 161, 5, 151, "Input"],
Cell[1130093, 25385, 133, 4, 151, "Input"],
Cell[1130229, 25391, 341, 11, 151, "Input"],
Cell[1130573, 25404, 38, 0, 121, "Text"],
Cell[1130614, 25406, 249, 7, 150, "Input"],
Cell[1130866, 25415, 174, 5, 150, "Input"],
Cell[1131043, 25422, 66, 0, 121, "Text"],
Cell[1131112, 25424, 545, 19, 150, "Input"],
Cell[1131660, 25445, 85, 2, 150, "Input"],
Cell[1131748, 25449, 66, 0, 121, "Text"],
Cell[1131817, 25451, 420, 11, 150, "Input"],
Cell[1132240, 25464, 244, 7, 150, "Input"],
Cell[1132487, 25473, 57, 0, 121, "Text"],
Cell[1132547, 25475, 554, 15, 282, "Input"],
Cell[1133104, 25492, 461, 12, 150, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1133614, 25510, 128, 4, 31, "Subsection"],
Cell[CellGroupData[{
Cell[1133767, 25518, 115, 3, 35, "Subsubsection"],
Cell[1133885, 25523, 400, 11, 151, "Input"],
Cell[1134288, 25536, 108, 3, 151, "Input"],
Cell[1134399, 25541, 168, 6, 285, "Input"],
Cell[1134570, 25549, 181, 4, 151, "Input"],
Cell[1134754, 25555, 103, 3, 151, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1134894, 25563, 61, 0, 29, "Subsubsection"],
Cell[1134958, 25565, 26, 0, 121, "Text"],
Cell[1134987, 25567, 86, 2, 150, "Input"],
Cell[1135076, 25571, 159, 3, 228, "Text"],
Cell[1135238, 25576, 1263, 32, 538, "Input"],
Cell[1136504, 25610, 823, 21, 408, "Input"],
Cell[1137330, 25633, 271, 7, 150, "Input"],
Cell[1137604, 25642, 153, 3, 150, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1137794, 25650, 52, 0, 29, "Subsubsection"],
Cell[1137849, 25652, 188, 6, 150, "Input"],
Cell[1138040, 25660, 124, 3, 150, "Input"],
Cell[1138167, 25665, 434, 14, 150, "Input"],
Cell[1138604, 25681, 64, 0, 121, "Text"],
Cell[1138671, 25683, 680, 15, 921, "Input"],
Cell[1139354, 25700, 504, 14, 282, "Input"],
Cell[1139861, 25716, 85, 2, 121, "Text"],
Cell[1139949, 25720, 401, 11, 150, "Input"],
Cell[1140353, 25733, 317, 10, 150, "Input"],
Cell[1140673, 25745, 268, 6, 150, "Input"],
Cell[1140944, 25753, 166, 4, 150, "Input"],
Cell[1141113, 25759, 86, 2, 150, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1141236, 25766, 61, 0, 29, "Subsubsection"],
Cell[1141300, 25768, 224, 4, 43, "Text"],
Cell[1141527, 25774, 231, 6, 29, "Input"],
Cell[1141761, 25782, 195, 4, 24, "Text"],
Cell[1141959, 25788, 220, 7, 29, "Input"],
Cell[1142182, 25797, 489, 12, 29, "Input"],
Cell[1142674, 25811, 111, 1, 24, "Text"],
Cell[1142788, 25814, 989, 27, 53, "Input"],
Cell[1143780, 25843, 334, 9, 29, "Input"],
Cell[1144117, 25854, 173, 2, 24, "Text"],
Cell[1144293, 25858, 270, 7, 29, "Input"],
Cell[1144566, 25867, 227, 4, 24, "Text"],
Cell[1144796, 25873, 237, 5, 29, "Input"],
Cell[1145036, 25880, 308, 6, 29, "Input"],
Cell[1145347, 25888, 267, 5, 43, "Text"],
Cell[1145617, 25895, 571, 16, 43, "Text"],
Cell[1146191, 25913, 287, 10, 29, "Input"],
Cell[1146481, 25925, 275, 9, 29, "Input"],
Cell[1146759, 25936, 95, 2, 24, "Text"],
Cell[1146857, 25940, 489, 8, 43, "Text"],
Cell[1147349, 25950, 205, 5, 29, "Input"],
Cell[1147557, 25957, 120, 1, 24, "Text"],
Cell[1147680, 25960, 642, 12, 43, "Text"],
Cell[1148325, 25974, 356, 6, 43, "Text"],
Cell[1148684, 25982, 99, 2, 24, "Text"],
Cell[1148786, 25986, 166, 5, 29, "Input"],
Cell[1148955, 25993, 482, 16, 51, "Input"],
Cell[1149440, 26011, 51, 0, 24, "Text"],
Cell[1149494, 26013, 387, 13, 29, "Input"],
Cell[1149884, 26028, 65, 0, 24, "Text"],
Cell[1149952, 26030, 835, 19, 100, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1150824, 26054, 64, 0, 150, "Subsubsection"],
Cell[1150891, 26056, 87, 2, 121, "Text"],
Cell[1150981, 26060, 231, 7, 150, "Input"],
Cell[1151215, 26069, 446, 13, 282, "Input"],
Cell[1151664, 26084, 136, 4, 150, "Input"],
Cell[1151803, 26090, 50, 0, 121, "Text"],
Cell[1151856, 26092, 540, 16, 282, "Input"],
Cell[1152399, 26110, 135, 4, 150, "Input"],
Cell[1152537, 26116, 55, 0, 121, "Text"],
Cell[1152595, 26118, 579, 17, 282, "Input"],
Cell[1153177, 26137, 136, 4, 150, "Input"],
Cell[1153316, 26143, 365, 8, 282, "Input"],
Cell[1153684, 26153, 58, 0, 121, "Text"],
Cell[1153745, 26155, 511, 15, 282, "Input"],
Cell[1154259, 26172, 40, 0, 121, "Text"],
Cell[1154302, 26174, 535, 16, 282, "Input"],
Cell[1154840, 26192, 141, 4, 150, "Input"],
Cell[1154984, 26198, 57, 0, 121, "Text"],
Cell[1155044, 26200, 574, 17, 282, "Input"],
Cell[1155621, 26219, 141, 4, 150, "Input"],
Cell[1155765, 26225, 280, 7, 150, "Input"],
Cell[1156048, 26234, 269, 7, 150, "Input"],
Cell[1156320, 26243, 30, 0, 121, "Text"],
Cell[1156353, 26245, 533, 16, 282, "Input"],
Cell[1156889, 26263, 165, 4, 150, "Input"],
Cell[1157057, 26269, 176, 2, 121, "Text"],
Cell[1157236, 26273, 742, 19, 282, "Input"],
Cell[1157981, 26294, 276, 9, 150, "Input"],
Cell[1158260, 26305, 564, 16, 282, "Input"],
Cell[1158827, 26323, 144, 4, 150, "Input"],
Cell[1158974, 26329, 58, 0, 121, "Text"],
Cell[1159035, 26331, 195, 5, 150, "Input"],
Cell[1159233, 26338, 250, 8, 150, "Input"],
Cell[1159486, 26348, 141, 4, 150, "Input"],
Cell[1159630, 26354, 288, 7, 150, "Input"],
Cell[1159921, 26363, 39, 0, 121, "Text"],
Cell[1159963, 26365, 455, 13, 282, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1160467, 26384, 139, 3, 31, "Subsection"],
Cell[1160609, 26389, 236, 7, 150, "Input"],
Cell[1160848, 26398, 113, 3, 150, "Input"],
Cell[1160964, 26403, 226, 7, 150, "Input"],
Cell[1161193, 26412, 226, 7, 150, "Input"],
Cell[1161422, 26421, 226, 7, 150, "Input"],
Cell[1161651, 26430, 303, 10, 150, "Input"],
Cell[1161957, 26442, 86, 2, 150, "Input"],
Cell[1162046, 26446, 362, 10, 233, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1162445, 26461, 185, 2, 31, "Subsection"],
Cell[CellGroupData[{
Cell[1162655, 26467, 237, 3, 35, "Subsubsection"],
Cell[1162895, 26472, 169, 4, 29, "Input"],
Cell[1163067, 26478, 258, 5, 24, "Text"],
Cell[1163328, 26485, 361, 8, 76, "Input",
 InitializationCell->True],
Cell[1163692, 26495, 712, 21, 53, "Input",
 InitializationCell->True],
Cell[1164407, 26518, 205, 5, 29, "Input"],
Cell[1164615, 26525, 200, 4, 20, "Text"],
Cell[1164818, 26531, 417, 12, 29, "Input"],
Cell[1165238, 26545, 304, 6, 39, "Text"],
Cell[1165545, 26553, 167, 2, 24, "Text"],
Cell[1165715, 26557, 390, 11, 29, "Input"],
Cell[1166108, 26570, 309, 5, 20, "Text"],
Cell[1166420, 26577, 324, 9, 29, "Input"],
Cell[1166747, 26588, 113, 1, 24, "Text"],
Cell[1166863, 26591, 234, 7, 29, "Input"],
Cell[1167100, 26600, 140, 1, 20, "Text"],
Cell[1167243, 26603, 234, 7, 29, "Input"],
Cell[1167480, 26612, 135, 1, 20, "Text"],
Cell[1167618, 26615, 263, 8, 29, "Input"],
Cell[1167884, 26625, 471, 14, 25, "Input"],
Cell[1168358, 26641, 206, 4, 20, "Text"],
Cell[1168567, 26647, 238, 8, 29, "Input"],
Cell[1168808, 26657, 666, 18, 49, "Input"],
Cell[1169477, 26677, 168, 4, 25, "Input"],
Cell[1169648, 26683, 455, 14, 29, "Input"],
Cell[1170106, 26699, 201, 5, 29, "Input"],
Cell[1170310, 26706, 353, 10, 25, "Input"],
Cell[1170666, 26718, 106, 1, 20, "Text"],
Cell[1170775, 26721, 406, 11, 29, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1171218, 26737, 141, 1, 35, "Subsubsection"],
Cell[1171362, 26740, 152, 3, 29, "Input"],
Cell[1171517, 26745, 970, 24, 72, "Input"],
Cell[1172490, 26771, 160, 4, 25, "Input"],
Cell[1172653, 26777, 795, 17, 53, "Input"],
Cell[1173451, 26796, 170, 4, 25, "Input"],
Cell[1173624, 26802, 345, 8, 29, "Input"],
Cell[1173972, 26812, 297, 5, 39, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1174306, 26822, 145, 1, 35, "Subsubsection"],
Cell[1174454, 26825, 155, 3, 24, "Text"],
Cell[1174612, 26830, 252, 5, 30, "Input"],
Cell[1174867, 26837, 177, 4, 29, "Input"],
Cell[1175047, 26843, 168, 4, 29, "Input"],
Cell[1175218, 26849, 66, 0, 24, "Text"],
Cell[1175287, 26851, 392, 9, 54, "Input"],
Cell[1175682, 26862, 222, 6, 26, "Input"],
Cell[1175907, 26870, 171, 4, 29, "Input"],
Cell[1176081, 26876, 254, 7, 50, "Input"],
Cell[1176338, 26885, 148, 4, 25, "Input"],
Cell[1176489, 26891, 635, 13, 62, "Text"],
Cell[1177127, 26906, 330, 6, 24, "Text"],
Cell[1177460, 26914, 451, 10, 54, "Input"],
Cell[1177914, 26926, 522, 11, 50, "Input"],
Cell[1178439, 26939, 172, 5, 26, "Input"],
Cell[1178614, 26946, 201, 4, 24, "Text"],
Cell[1178818, 26952, 725, 14, 54, "Input"],
Cell[1179546, 26968, 167, 4, 25, "Input"],
Cell[1179716, 26974, 380, 7, 43, "Text"],
Cell[1180099, 26983, 281, 7, 29, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1180441, 26997, 55, 1, 30, "Subsubtitle"],
Cell[1180499, 27000, 185, 4, 57, "Text",
 CellTags->"G1"],
Cell[1180687, 27006, 315, 9, 57, "Text",
 CellTags->"S3"],
Cell[1181005, 27017, 367, 10, 57, "Text",
 CellTags->"S4"]
}, Closed]],
Cell[CellGroupData[{
Cell[1181409, 27032, 141, 2, 22, "Subsubtitle"],
Cell[1181553, 27036, 372, 10, 100, "Text",
 CellTags->"HP"],
Cell[1181928, 27048, 47, 0, 24, "Text"],
Cell[1181978, 27050, 90, 2, 24, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
